
/*-----------------------------------------------------------------
	
	Kummer threefold with functions

	-- Steffen Mueller --

-----------------------------------------------------------------*/



function kappa(P)
/* Compute the image on the associated Kummer variety of a point P on the 
	Jacobian of a hyperelliptic genus 3 curve C	given by an equation y^2=f(x), deg(f)=7
	Here, affine Kummer coordinates are returned as a sequence of length 8.
*/

    J := Parent(P);
    a := P[1];
    case Degree(a):
        when 3:
            a0 := 1; 
            a1 := -Coefficient(a,2);
            a2 := Coefficient(a,1);
            a3 := -Coefficient(a,0);
            b := P[2];
            b0 := Coefficient(b,2);
            b1 := Coefficient(b,1);
            f := HyperellipticPolynomials(Curve(J));
            f5 := Coefficient(f,5);
            f6 := Coefficient(f,6);
            f7 := Coefficient(f,7);
            H0 := -f7*a1^3+f7*a2*a1-f6*a1^2+3*f7*a3+2*f6*a2;
            H1 := -f7*a1^4+3*f7*a2*a1^2-f6*a1^3-f7*a2^2-f7*a3*a1+2*f6*a2*a1-f5*a1^2+2*f5*a2;
            H2 := f7*a2*a1^3-2*f7*a2^2*a1+f6*a2*a1^2+f7*a3*a2-f6*a2^2+f5*a2*a1-3*f5*a3;
            H3 := f7*a2^2*a1^2-f7*a1^3*a3+f7*a1*a2*a3-f7*a2^3+f6*a2^2*a1-f6*a3*a1^2+f5*a2^2-f5*a3*a1;
            C0 := a0*b0^2;
            C1 := a1*b0^2+2*a0*b0*b1;
            C2 := a0*b1^2-a2*b0^2;
            C3 := a1*b1^2+2*a2*b0*b1+a3*b0^2;
            c0 := C0+H0;
            c1 := C1+H1;
            c2 := C2+H2;
            c3 := C3+H3;
            return [1,a1,a2,a3,c0,c1,c2,c3];

        when 2:
            // P=[(x1,y1)+(x2,y2)-2(infty)], (x1,y1) ne (x1,-y1)
            a1 := -Coefficient(a,1);
            a2 := Coefficient(a,0);
            disc := Discriminant(a);
            b := P[2];
            b0 := Coefficient(b,0);
            b1 := Coefficient(b,1);
            y1y2 := b1^2*a2 + b0*b1*a1 + b0^2;
            f := HyperellipticPolynomials(Curve(J));
            f0,f1,f2,f3,f4,f5,f6,f7 := Explode(Coefficients(f));
            if disc ne 0 then //(x1,y1) ne (x2,y2) 
                return [0, 1, a1, a2, f5+2*f6*a1+f7*a1^2+2*a2*f7, f4+f5*a1-a2*f7*a1, -f4*a1-3*a2*f5+a2^2*f7, 
                        (f3*a1^3+f1*a1+f2*a1^2+2*f0-2*y1y2+a2*f4*a1^2-3*a2*f3*a1-2*a2*f2+a2^2*f5*a1-2*a2^2*f4+a2^3*f7*a1+2*a2^3*f6)/disc];
            else	          //(x1,y1)=(x2,y2) 
                return [0, 1, a1, a2, f5+2*f6*a1+f7*a1^2+2*a2*f7, f4+f5*a1-a2*f7*a1, -f4*a1-3*a2*f5+a2^2*f7, 
                        b1^2+(a2-a1^2)*(-2*a2*f7*a1-a2*f6+f7*a1^3+a1^2*f6+f5*a1+f4)];
            end if;

        when 1:
            // 	P=[(x1,y1)-(infty)]
            a1 := -Coefficient(a,0);
            return [0,0,0,0,1,-a1,a1^2,a1^3];
        when 0:
            return [0,0,0,0,0,0,0,1]; 
    end case;
end function;





duplication_polynomials := func<f, x |  
/*
	These homogeneous polynomials conjecturally describe the duplication map on
	the Kummer threefold of a hyperelliptic genus 3 curve with a rational Weierstrass
	point at infinity.
        Note that they map (0,0,0,0,0,0,0,1) to (0,0,0,0,0,0,0,f7^2).
*/
	[ 
(16*f0^2*f5^2*f7 - 32*f0*f1*f2*f7^2 - 16*f0*f1*f4*f5*f7 + 8*f0*f2^2*f6*f7 - 16*f0*f2*f3*f5*f7 + 384*f1^3*f7^2 - 384*f1^2*f2*f6*f7 - 2224*f1^2*f3*f5*f7 - 
    988*f1^2*f4^2*f7 - 92*f1*f2^2*f5*f7 - 744*f1*f2*f3*f4*f7 - 16*f2^3*f4*f7)*x1^4 + (64*f0^2*f5*f6*f7 - 32*f0*f1*f3*f7^2 - 32*f0*f1*f4*f6*f7 - 
    16*f0*f1*f5^2*f7 + 32*f0*f2^2*f7^2 - 16*f0*f2*f3*f6*f7 - 32*f0*f2*f4*f5*f7 - 16*f0*f3^2*f5*f7 + 572*f1^2*f2*f7^2 - 360*f1^2*f3*f6*f7 + 
    4268*f1^2*f4*f5*f7 - 56*f1*f2^2*f6*f7 - 1984*f1*f2*f3*f5*f7 - 2024*f1*f2*f4^2*f7 - 744*f1*f3^2*f4*f7 - 32*f2^2*f3*f4*f7)*x1^3*x2 + (-192*f0^2*f5*f7^2 + 
    64*f0^2*f6^2*f7 + 64*f0*f1*f4*f7^2 - 96*f0*f1*f5*f6*f7 + 64*f0*f2*f3*f7^2 - 144*f0*f2*f4*f6*f7 + 32*f0*f2*f5^2*f7 - 32*f0*f3^2*f6*f7 - 
    2976*f0*f3*f4*f5*f7 - 1440*f1^2*f3*f7^2 - 96*f1^2*f4*f6*f7 - 484*f1^2*f5^2*f7 + 988*f1*f2^2*f7^2 + 1120*f1*f2*f3*f6*f7 + 7496*f1*f2*f4*f5*f7 + 
    4192*f1*f3^2*f5*f7 + 2720*f1*f3*f4^2*f7 - 56*f2^3*f6*f7 - 1928*f2^2*f3*f5*f7 - 1992*f2^2*f4^2*f7 + 744*f2*f3^2*f4*f7)*x1^3*x3 + (96*f0^2*f6*f7^2 - 
    5920*f0*f1*f5*f7^2 - 224*f0*f2*f4*f7^2 + 6848*f0*f2*f5*f6*f7 - 48*f0*f3^2*f7^2 + 26848*f0*f3*f5^2*f7 + 11888*f0*f4^2*f5*f7 - 504*f1^2*f4*f7^2 + 
    2560*f1^2*f5*f6*f7 - 256*f1*f2*f3*f7^2 - 16*f1*f2*f4*f6*f7 - 3780*f1*f2*f5^2*f7 - 3024*f1*f3*f4*f5*f7 - 1976*f1*f4^3*f7 + 384*f2^3*f7^2 + 
    488*f2^2*f3*f6*f7 + 2340*f2^2*f4*f5*f7 - 832*f2*f3^2*f5*f7 - 744*f2*f3*f4^2*f7)*x1^3*x4 + (-32*f0^2*f6*f7 + 448*f0*f1*f5*f7 + 64*f0*f2*f4*f7 + 
    16*f0*f3^2*f7 + 424*f1^2*f4*f7 - 128*f1*f2*f3*f7)*x1^3*x5 + (64*f0^2*f7^2 - 384*f0*f1*f6*f7 - 16*f0*f2*f5*f7 + 1504*f0*f3*f4*f7 + 524*f1^2*f5*f7 + 
    72*f1*f2*f4*f7 + 128*f1*f3^2*f7 - 4*f2^2*f3*f7)*x1^3*x6 + (-1504*f0*f1*f7^2 + 2288*f0*f2*f6*f7 + 8944*f0*f3*f5*f7 + 3968*f0*f4^2*f7 + 1264*f1^2*f6*f7 - 
    1632*f1*f2*f5*f7 + 728*f1*f3*f4*f7 - 156*f2^2*f4*f7 - 272*f2*f3^2*f7)*x1^3*x7 + (-1616*f0*f2*f7^2 - 296*f0*f3*f6*f7 - 14884*f0*f4*f5*f7 + 660*f1^2*f7^2 
    + 1036*f1*f2*f6*f7 - 3500*f1*f3*f5*f7 - 840*f1*f4^2*f7 - 788*f2^2*f5*f7 - 592*f2*f3*f4*f7 - 128*f3^3*f7)*x1^3*x8 + (160*f0^2*f5*f7^2 + 32*f0^2*f6^2*f7 -
    80*f0*f1*f4*f7^2 + 16*f0*f1*f5*f6*f7 + 16*f0*f2*f3*f7^2 + 16*f0*f2*f4*f6*f7 - 48*f0*f2*f5^2*f7 - 8*f0*f3^2*f6*f7 + 1456*f0*f3*f4*f5*f7 + 
    696*f1^2*f3*f7^2 + 8*f1^2*f4*f6*f7 + 564*f1^2*f5^2*f7 - 416*f1*f2^2*f7^2 - 504*f1*f2*f3*f6*f7 - 2920*f1*f2*f4*f5*f7 - 1764*f1*f3^2*f5*f7 - 
    2768*f1*f3*f4^2*f7 - 4*f2^2*f3*f5*f7 - 32*f2^2*f4^2*f7 - 16*f2*f3^2*f4*f7)*x1^2*x2^2 + (160*f0^2*f6*f7^2 + 1888*f0*f1*f5*f7^2 - 32*f0*f2*f4*f7^2 - 
    2608*f0*f2*f5*f6*f7 + 48*f0*f3^2*f7^2 - 80*f0*f3*f4*f6*f7 - 16160*f0*f3*f5^2*f7 - 12080*f0*f4^2*f5*f7 - 1740*f1^2*f4*f7^2 - 720*f1^2*f5*f6*f7 + 
    660*f1*f2*f3*f7^2 + 1440*f1*f2*f4*f6*f7 + 2284*f1*f2*f5^2*f7 + 1120*f1*f3^2*f6*f7 + 4944*f1*f3*f4*f5*f7 + 4000*f1*f4^3*f7 - 416*f2^3*f7^2 - 
    512*f2^2*f3*f6*f7 - 2652*f2^2*f4*f5*f7 - 1792*f2*f3^2*f5*f7 - 1248*f2*f3*f4^2*f7 + 744*f3^3*f4*f7)*x1^2*x2*x3 + (640*f0^2*f7^3 - 1760*f0*f1*f6*f7^2 - 
    1840*f0*f2*f5*f7^2 - 32*f0*f2*f6^2*f7 + 5792*f0*f3*f4*f7^2 + 7504*f0*f3*f5*f6*f7 - 32*f0*f4^2*f6*f7 - 21192*f0*f4*f5^2*f7 + 104*f1^2*f5*f7^2 - 
    2464*f1^2*f6^2*f7 + 916*f1*f2*f4*f7^2 + 2440*f1*f2*f5*f6*f7 + 328*f1*f3^2*f7^2 - 1488*f1*f3*f4*f6*f7 + 2308*f1*f3*f5^2*f7 + 12224*f1*f4^2*f5*f7 + 
    784*f2^2*f3*f7^2 - 88*f2^2*f4*f6*f7 - 144*f2^2*f5^2*f7 + 944*f2*f3^2*f6*f7 + 4408*f2*f3*f4*f5*f7 - 2024*f2*f4^3*f7 - 576*f3^3*f5*f7 - 
    744*f3^2*f4^2*f7)*x1^2*x2*x4 + (-192*f0^2*f7^2 + 416*f0*f1*f6*f7 + 48*f0*f2*f5*f7 - 1440*f0*f3*f4*f7 - 124*f1^2*f5*f7 - 72*f1*f2*f4*f7 - 280*f1*f3^2*f7 
    + 4*f2^2*f3*f7)*x1^2*x2*x5 + (-336*f0*f1*f7^2 + 128*f0*f2*f6*f7 + 3632*f0*f3*f5*f7 + 4080*f0*f4^2*f7 + 808*f1^2*f6*f7 - 196*f1*f2*f5*f7 + 
    584*f1*f3*f4*f7 + 32*f2^2*f4*f7 - 4*f2*f3^2*f7)*x1^2*x2*x6 + (2584*f0*f3*f6*f7 - 2092*f0*f4*f5*f7 - 812*f1^2*f7^2 - 236*f1*f2*f6*f7 + 3652*f1*f3*f5*f7 +
    2848*f1*f4^2*f7 + 492*f2^2*f5*f7 + 648*f2*f3*f4*f7 - 144*f3^3*f7)*x1^2*x2*x7 + (-960*f0*f3*f7^2 - 852*f0*f4*f6*f7 - 4672*f0*f5^2*f7 - 912*f1*f2*f7^2 - 
    1036*f1*f3*f6*f7 + 2452*f1*f4*f5*f7 - 224*f2^2*f6*f7 + 1100*f2*f3*f5*f7 + 2652*f2*f4^2*f7 - 1284*f3^2*f4*f7)*x1^2*x2*x8 + (128*f0^2*f7^3 + 
    2880*f0*f1*f6*f7^2 + 1568*f0*f2*f5*f7^2 - 2752*f0*f2*f6^2*f7 + 1408*f0*f3*f4*f7^2 - 24072*f0*f3*f5*f6*f7 - 20152*f0*f4^2*f6*f7 + 14812*f0*f4*f5^2*f7 + 
    256*f1^2*f5*f7^2 + 2164*f1^2*f6^2*f7 - 1828*f1*f2*f4*f7^2 + 324*f1*f2*f5*f6*f7 + 1856*f1*f3^2*f7^2 + 624*f1*f3*f4*f6*f7 - 892*f1*f3*f5^2*f7 - 
    8676*f1*f4^2*f5*f7 - 848*f2^2*f3*f7^2 + 984*f2^2*f4*f6*f7 + 1092*f2^2*f5^2*f7 - 432*f2*f3^2*f6*f7 - 3672*f2*f3*f4*f5*f7 + 4032*f2*f4^3*f7 - 
    2096*f3^3*f5*f7 - 1732*f3^2*f4^2*f7)*x1^2*x3^2 + (8928*f0*f1*f7^3 - 10000*f0*f2*f6*f7^2 - 52544*f0*f3*f5*f7^2 + 3248*f0*f3*f6^2*f7 - 40096*f0*f4^2*f7^2 
    - 5960*f0*f4*f5*f6*f7 - 10688*f0*f5^3*f7 + 7992*f1^2*f6*f7^2 - 2408*f1*f2*f5*f7^2 + 4192*f1*f2*f6^2*f7 + 2680*f1*f3*f4*f7^2 - 27016*f1*f3*f5*f6*f7 - 
    13584*f1*f4^2*f6*f7 - 1060*f1*f4*f5^2*f7 + 456*f2^2*f4*f7^2 - 840*f2^2*f5*f6*f7 + 1424*f2*f3^2*f7^2 - 1888*f2*f3*f4*f6*f7 + 8364*f2*f3*f5^2*f7 + 
    9064*f2*f4^2*f5*f7 - 288*f3^3*f6*f7 + 592*f3^2*f4*f5*f7 + 2720*f3*f4^3*f7)*x1^2*x3*x4 + (-2432*f0*f1*f7^2 + 2528*f0*f2*f6*f7 + 16176*f0*f3*f5*f7 + 
    12064*f0*f4^2*f7 - 1376*f1^2*f6*f7 + 248*f1*f2*f5*f7 - 1120*f1*f3*f4*f7 - 188*f2^2*f4*f7 - 160*f2*f3^2*f7)*x1^2*x3*x5 + (8*f0*f2*f7^2 + 8*f0*f3*f6*f7 + 
    84*f0*f4*f5*f7 + 20*f1^2*f7^2 - 12*f1*f2*f6*f7 - 48*f1*f3*f5*f7 - 4*f1*f4^2*f7 + 4*f2^2*f5*f7 - 32*f2*f3*f4*f7)*x1^2*x3*x6 + (2560*f0*f3*f7^2 - 
    816*f0*f4*f6*f7 - 5328*f0*f5^2*f7 - 916*f1*f2*f7^2 - 4016*f1*f3*f6*f7 - 5080*f1*f4*f5*f7 + 360*f2^2*f6*f7 + 3384*f2*f3*f5*f7 + 1984*f2*f4^2*f7 - 
    456*f3^2*f4*f7)*x1^2*x3*x7 + (2796*f0*f4*f7^2 + 10880*f0*f5*f6*f7 - 924*f1*f3*f7^2 - 3020*f1*f4*f6*f7 - 5012*f1*f5^2*f7 + 1264*f2^2*f7^2 + 
    908*f2*f3*f6*f7 + 3632*f2*f4*f5*f7 + 1052*f3^2*f5*f7 - 1112*f3*f4^2*f7)*x1^2*x3*x8 + (-368*f0*f2*f7^3 + 4872*f0*f3*f6*f7^2 + 2788*f0*f4*f5*f7^2 - 
    35008*f0*f5^2*f6*f7 + 9336*f1^2*f7^3 + 7012*f1*f2*f6*f7^2 - 49220*f1*f3*f5*f7^2 - 29024*f1*f4^2*f7^2 + 3504*f1*f4*f5*f6*f7 + 7928*f1*f5^3*f7 - 
    9004*f2^2*f5*f7^2 + 420*f2^2*f6^2*f7 - 5152*f2*f3*f4*f7^2 - 7136*f2*f3*f5*f6*f7 + 368*f2*f4^2*f6*f7 + 19180*f2*f4*f5^2*f7 - 432*f3^3*f7^2 + 
    28608*f3^2*f5^2*f7 + 11104*f3*f4^2*f5*f7 - 988*f4^4*f7)*x1^2*x4^2 + (112*f0*f2*f7^2 - 1624*f0*f3*f6*f7 - 860*f0*f4*f5*f7 - 3612*f1^2*f7^2 - 
    2172*f1*f2*f6*f7 + 13772*f1*f3*f5*f7 + 9144*f1*f4^2*f7 + 2940*f2^2*f5*f7 + 1256*f2*f3*f4*f7 + 144*f3^3*f7)*x1^2*x4*x5 + (704*f0*f3*f7^2 - 
    1856*f0*f4*f6*f7 + 1896*f0*f5^2*f7 + 1592*f1*f2*f7^2 + 1592*f1*f3*f6*f7 - 4440*f1*f4*f5*f7 + 184*f2^2*f6*f7 - 784*f2*f3*f5*f7 - 2676*f2*f4^2*f7 + 
    1632*f3^2*f4*f7)*x1^2*x4*x6 + (4608*f0*f4*f7^2 - 29120*f0*f5*f6*f7 - 3064*f1*f3*f7^2 + 1744*f1*f4*f6*f7 + 7412*f1*f5^2*f7 - 1264*f2^2*f7^2 - 
    2688*f2*f3*f6*f7 + 7000*f2*f4*f5*f7 + 10400*f3^2*f5*f7 + 4696*f3*f4^2*f7)*x1^2*x4*x7 + (5288*f0*f5*f7^2 - 13832*f0*f6^2*f7 + 760*f1*f4*f7^2 + 
    3128*f1*f5*f6*f7 - 4328*f2*f3*f7^2 + 6064*f2*f4*f6*f7 + 5852*f2*f5^2*f7 - 1172*f3^2*f6*f7 - 5112*f3*f4*f5*f7 + 1872*f4^3*f7)*x1^2*x4*x8 + 
    252*f1^2*f7*x1^2*x5^2 + (224*f0*f3*f7 - 548*f1*f2*f7)*x1^2*x5*x6 + (-1504*f0*f4*f7 + 712*f1*f3*f7 + 440*f2^2*f7)*x1^2*x5*x7 + (-2340*f0*f5*f7 - 
    48*f1*f4*f7 + 928*f2*f3*f7)*x1^2*x5*x8 + (-28*f0*f4*f7 - 272*f1*f3*f7)*x1^2*x6^2 + (1520*f0*f5*f7 - 364*f1*f4*f7 + 300*f2*f3*f7)*x1^2*x6*x7 + 
    (-5560*f0*f6*f7 + 2472*f1*f5*f7 + 1312*f2*f4*f7 + 612*f3^2*f7)*x1^2*x6*x8 + (-5816*f0*f6*f7 + 1724*f1*f5*f7 + 976*f2*f4*f7 + 288*f3^2*f7)*x1^2*x7^2 + 
    (12*f0*f7^2 - 744*f1*f6*f7 - 340*f2*f5*f7 + 600*f3*f4*f7)*x1^2*x7*x8 + (80*f1*f7^2 + 16*f2*f6*f7 - 1336*f3*f5*f7 - 640*f4^2*f7)*x1^2*x8^2 + 
    (32*f0^2*f6*f7^2 + 16*f0*f1*f5*f7^2 + 32*f0*f2*f4*f7^2 + 80*f0*f2*f5*f6*f7 - 16*f0*f3*f4*f6*f7 + 3584*f0*f3*f5^2*f7 + 4048*f0*f4^2*f5*f7 + 
    608*f1^2*f4*f7^2 - 936*f1^2*f5*f6*f7 - 392*f1*f2*f3*f7^2 - 24*f1*f2*f4*f6*f7 + 52*f1*f2*f5^2*f7 - 472*f1*f3^2*f6*f7 - 4952*f1*f3*f4*f5*f7 - 
    2024*f1*f4^3*f7 - 4*f2*f3^2*f5*f7 - 32*f2*f3*f4^2*f7)*x1*x2^3 + (-192*f0^2*f7^3 - 1592*f0*f2*f5*f7^2 + 160*f0*f2*f6^2*f7 - 2880*f0*f3*f4*f7^2 + 
    3120*f0*f3*f5*f6*f7 + 8048*f0*f4^2*f6*f7 - 9120*f0*f4*f5^2*f7 - 616*f1^2*f5*f7^2 - 1896*f1^2*f6^2*f7 + 1164*f1*f2*f4*f7^2 - 2048*f1*f2*f5*f6*f7 - 
    808*f1*f3^2*f7^2 + 1848*f1*f3*f4*f6*f7 + 2096*f1*f3*f5^2*f7 + 2604*f1*f4^2*f5*f7 - 392*f2^2*f3*f7^2 - 24*f2^2*f4*f6*f7 - 56*f2^2*f5^2*f7 - 
    480*f2*f3^2*f6*f7 - 4808*f2*f3*f4*f5*f7 - 1992*f2*f4^3*f7 + 8*f3^3*f5*f7 + 1488*f3^2*f4^2*f7)*x1*x2^2*x3 + (-1776*f0*f1*f7^3 - 1280*f0*f2*f6*f7^2 + 
    10944*f0*f3*f5*f7^2 - 1888*f0*f3*f6^2*f7 + 16048*f0*f4^2*f7^2 - 8280*f0*f4*f5*f6*f7 + 10984*f0*f5^3*f7 - 5528*f1^2*f6*f7^2 + 6232*f1*f2*f5*f7^2 - 
    1320*f1*f2*f6^2*f7 - 1388*f1*f3*f4*f7^2 + 10880*f1*f3*f5*f6*f7 + 2168*f1*f4^2*f6*f7 + 980*f1*f4*f5^2*f7 + 352*f2^2*f4*f7^2 - 880*f2^2*f5*f6*f7 + 
    384*f2*f3^2*f7^2 + 424*f2*f3*f4*f6*f7 - 6136*f2*f3*f5^2*f7 - 3236*f2*f4^2*f5*f7 + 472*f3^3*f6*f7 + 4252*f3^2*f4*f5*f7 - 2768*f3*f4^3*f7)*x1*x2^2*x4 + 
    (416*f0*f1*f7^2 - 80*f0*f2*f6*f7 - 3296*f0*f3*f5*f7 - 4016*f0*f4^2*f7 + 800*f1^2*f6*f7 - 168*f1*f2*f5*f7 - 24*f1*f3*f4*f7 + 4*f2*f3^2*f7)*x1*x2^2*x5 + 
    (816*f0*f2*f7^2 + 960*f0*f3*f6*f7 + 5656*f0*f4*f5*f7 - 400*f1^2*f7^2 + 280*f1*f2*f6*f7 + 672*f1*f3*f5*f7 + 1240*f1*f4^2*f7 + 28*f2*f3*f4*f7)*x1*x2^2*x6 
    + (-1008*f0*f3*f7^2 + 1924*f0*f4*f6*f7 + 6112*f0*f5^2*f7 + 1280*f1*f2*f7^2 + 2796*f1*f3*f6*f7 - 1672*f1*f4*f5*f7 - 272*f2^2*f6*f7 - 680*f2*f3*f5*f7 - 
    1332*f2*f4^2*f7 + 1224*f3^2*f4*f7)*x1*x2^2*x7 + (-1432*f0*f4*f7^2 + 6492*f0*f5*f6*f7 + 1248*f1*f3*f7^2 - 1928*f1*f4*f6*f7 - 1540*f1*f5^2*f7 + 
    400*f2^2*f7^2 - 52*f2*f3*f6*f7 + 1672*f2*f4*f5*f7 + 704*f3^2*f5*f7 + 292*f3*f4^2*f7)*x1*x2^2*x8 + (-1136*f0*f1*f7^3 + 544*f0*f2*f6*f7^2 + 
    3136*f0*f3*f5*f7^2 - 6176*f0*f3*f6^2*f7 - 144*f0*f4^2*f7^2 - 3924*f0*f4*f5*f6*f7 + 3536*f0*f5^3*f7 - 448*f1^2*f6*f7^2 - 1296*f1*f2*f5*f7^2 - 
    2984*f1*f2*f6^2*f7 + 2536*f1*f3*f4*f7^2 + 3788*f1*f3*f5*f6*f7 + 2392*f1*f4^2*f6*f7 - 2696*f1*f4*f5^2*f7 + 172*f2^2*f4*f7^2 - 1016*f2^2*f5*f6*f7 - 
    1204*f2*f3^2*f7^2 + 672*f2*f3*f4*f6*f7 + 1488*f2*f3*f5^2*f7 - 388*f2*f4^2*f5*f7 - 456*f3^3*f6*f7 - 6088*f3^2*f4*f5*f7 - 696*f3*f4^3*f7)*x1*x2*x3^2 + 
    (-3168*f0*f2*f7^3 - 16240*f0*f3*f6*f7^2 - 17592*f0*f4*f5*f7^2 - 1736*f0*f4*f6^2*f7 + 3136*f0*f5^2*f6*f7 - 2480*f1^2*f7^3 - 6464*f1*f2*f6*f7^2 + 
    16248*f1*f3*f5*f7^2 + 3088*f1*f3*f6^2*f7 + 9668*f1*f4^2*f7^2 + 6688*f1*f4*f5*f6*f7 + 740*f1*f5^3*f7 + 4492*f2^2*f5*f7^2 - 1448*f2^2*f6^2*f7 + 
    1600*f2*f3*f4*f7^2 - 4464*f2*f3*f5*f6*f7 - 2168*f2*f4^2*f6*f7 + 6712*f2*f4*f5^2*f7 + 824*f3^3*f7^2 - 1752*f3^2*f4*f6*f7 - 10828*f3^2*f5^2*f7 - 
    10176*f3*f4^2*f5*f7 + 4000*f4^4*f7)*x1*x2*x3*x4 + (1624*f0*f2*f7^2 + 4608*f0*f3*f6*f7 + 10688*f0*f4*f5*f7 + 416*f1^2*f7^2 + 1624*f1*f2*f6*f7 - 
    3100*f1*f3*f5*f7 - 3396*f1*f4^2*f7 + 48*f2^2*f5*f7 - 16*f2*f3*f4*f7 - 8*f3^3*f7)*x1*x2*x3*x5 + (-64*f0*f3*f7^2 + 116*f0*f4*f6*f7 + 40*f0*f5^2*f7 + 
    8*f1*f2*f7^2 - 60*f1*f3*f6*f7 - 72*f1*f4*f5*f7 + 8*f2^2*f6*f7 + 44*f2*f3*f5*f7 - 40*f2*f4^2*f7 + 16*f3^2*f4*f7)*x1*x2*x3*x6 + (-60*f0*f4*f7^2 + 
    48*f0*f5*f6*f7 - 36*f1*f3*f7^2 - 36*f1*f4*f6*f7 - 40*f1*f5^2*f7 + 8*f2^2*f7^2 + 20*f2*f3*f6*f7 - 64*f2*f4*f5*f7 - 52*f3^2*f5*f7 - 
    8*f3*f4^2*f7)*x1*x2*x3*x7 + (-3648*f0*f5*f7^2 + 8056*f0*f6^2*f7 + 440*f1*f4*f7^2 - 1200*f1*f5*f6*f7 + 2160*f2*f3*f7^2 - 2168*f2*f4*f6*f7 - 
    1248*f2*f5^2*f7 + 464*f3^2*f6*f7 + 5184*f3*f4*f5*f7 - 1856*f4^3*f7)*x1*x2*x3*x8 + (-576*f0*f3*f7^3 - 10428*f0*f4*f6*f7^2 - 20160*f0*f5^2*f7^2 + 
    62352*f0*f5*f6^2*f7 + 976*f1*f2*f7^3 + 2796*f1*f3*f6*f7^2 + 10588*f1*f4*f5*f7^2 - 3456*f1*f4*f6^2*f7 - 19880*f1*f5^2*f6*f7 + 1568*f2^2*f6*f7^2 - 
    18892*f2*f3*f5*f7^2 + 2696*f2*f3*f6^2*f7 - 10884*f2*f4^2*f7^2 - 7248*f2*f4*f5*f6*f7 - 7532*f2*f5^3*f7 - 676*f3^2*f4*f7^2 - 6424*f3^2*f5*f6*f7 - 
    1128*f3*f4^2*f6*f7 + 3756*f3*f4*f5^2*f7 + 14436*f4^3*f5*f7)*x1*x2*x4^2 + (1504*f0*f3*f7^2 + 2804*f0*f4*f6*f7 + 8320*f0*f5^2*f7 - 360*f1*f2*f7^2 - 
    668*f1*f3*f6*f7 - 3788*f1*f4*f5*f7 + 64*f2^2*f6*f7 + 4868*f2*f3*f5*f7 + 2080*f2*f4^2*f7 + 308*f3^2*f4*f7)*x1*x2*x4*x5 + (1080*f0*f4*f7^2 - 
    12688*f0*f5*f6*f7 - 424*f1*f3*f7^2 + 3392*f1*f4*f6*f7 + 476*f1*f5^2*f7 - 1216*f2^2*f7^2 - 1112*f2*f3*f6*f7 - 5648*f2*f4*f5*f7 + 2624*f3^2*f5*f7 + 
    3420*f3*f4^2*f7)*x1*x2*x4*x6 + (2912*f0*f5*f7^2 + 25384*f0*f6^2*f7 - 2484*f1*f4*f7^2 - 9432*f1*f5*f6*f7 + 984*f2*f3*f7^2 - 9280*f2*f4*f6*f7 - 
    4692*f2*f5^2*f7 - 2060*f3^2*f6*f7 + 3648*f3*f4*f5*f7 + 4104*f4^3*f7)*x1*x2*x4*x7 + (15308*f0*f6*f7^2 - 2448*f1*f5*f7^2 - 1064*f1*f6^2*f7 - 
    3320*f2*f4*f7^2 - 888*f2*f5*f6*f7 - 3716*f3^2*f7^2 - 1008*f3*f4*f6*f7 + 13812*f3*f5^2*f7 + 8716*f4^2*f5*f7)*x1*x2*x4*x8 + (-288*f0*f3*f7 + 
    116*f1*f2*f7)*x1*x2*x5^2 + (-72*f0*f4*f7 + 24*f1*f3*f7)*x1*x2*x5*x6 + (-44*f0*f5*f7 + 28*f1*f4*f7 - 4*f2*f3*f7)*x1*x2*x5*x7 + (-2544*f0*f6*f7 - 
    264*f1*f5*f7 + 432*f2*f4*f7 + 484*f3^2*f7)*x1*x2*x5*x8 + (832*f0*f5*f7 - 392*f1*f4*f7 + 4*f2*f3*f7)*x1*x2*x6^2 + (-8*f0*f6*f7 + 24*f1*f5*f7 - 
    56*f2*f4*f7 - 28*f3^2*f7)*x1*x2*x6*x7 + (924*f0*f7^2 - 60*f1*f6*f7 + 304*f2*f5*f7 + 1224*f3*f4*f7)*x1*x2*x6*x8 + (-108*f0*f7^2 - 4*f2*f5*f7 + 
    24*f3*f4*f7)*x1*x2*x7^2 + (-48*f1*f7^2 - 24*f2*f6*f7 - 48*f3*f5*f7 - 56*f4^2*f7)*x1*x2*x7*x8 + (8*f2*f7^2 - 508*f3*f6*f7 - 636*f4*f5*f7)*x1*x2*x8^2 + 
    (-1608*f0*f2*f7^3 - 3296*f0*f3*f6*f7^2 - 14884*f0*f4*f5*f7^2 + 6304*f0*f4*f6^2*f7 + 17520*f0*f5^2*f6*f7 - 136*f1^2*f7^3 - 200*f1*f2*f6*f7^2 + 
    2328*f1*f3*f5*f7^2 - 1256*f1*f3*f6^2*f7 + 2044*f1*f4^2*f7^2 - 5428*f1*f4*f5*f6*f7 - 4420*f1*f5^3*f7 - 52*f2^2*f5*f7^2 - 1008*f2^2*f6^2*f7 + 
    1732*f2*f3*f4*f7^2 + 2684*f2*f3*f5*f6*f7 + 608*f2*f4^2*f6*f7 - 4776*f2*f4*f5^2*f7 - 800*f3^3*f7^2 - 832*f3^2*f4*f6*f7 - 1200*f3^2*f5^2*f7 + 
    4328*f3*f4^2*f5*f7 - 2024*f4^4*f7)*x1*x3^3 + (-10464*f0*f3*f7^3 + 8120*f0*f4*f6*f7^2 + 24384*f0*f5^2*f7^2 + 7848*f0*f5*f6^2*f7 - 2028*f1*f2*f7^3 + 
    128*f1*f3*f6*f7^2 - 14440*f1*f4*f5*f7^2 + 4296*f1*f4*f6^2*f7 - 64*f1*f5^2*f6*f7 - 1088*f2^2*f6*f7^2 + 12576*f2*f3*f5*f7^2 + 1088*f2*f3*f6^2*f7 + 
    9048*f2*f4^2*f7^2 - 4184*f2*f4*f5*f6*f7 - 4568*f2*f5^3*f7 - 1712*f3^2*f4*f7^2 - 8716*f3^2*f5*f6*f7 - 9592*f3*f4^2*f6*f7 + 17580*f3*f4*f5^2*f7 - 
    9964*f4^3*f5*f7)*x1*x3^2*x4 + (3072*f0*f3*f7^2 - 2064*f0*f4*f6*f7 - 7748*f0*f5^2*f7 + 156*f1*f2*f7^2 - 112*f1*f3*f6*f7 + 1400*f1*f4*f5*f7 + 
    1000*f2^2*f6*f7 - 1456*f2*f3*f5*f7 - 2032*f2*f4^2*f7 + 984*f3^2*f4*f7)*x1*x3^2*x5 + (-1380*f0*f4*f7^2 - 9560*f0*f5*f6*f7 - 1516*f1*f3*f7^2 + 
    3652*f1*f4*f6*f7 + 5360*f1*f5^2*f7 - 464*f2^2*f7^2 - 1452*f2*f3*f6*f7 + 3524*f2*f4*f5*f7 + 2584*f3^2*f5*f7 + 2512*f3*f4^2*f7)*x1*x3^2*x6 + 
    (3180*f0*f5*f7^2 - 208*f0*f6^2*f7 + 460*f1*f4*f7^2 - 1808*f1*f5*f6*f7 + 848*f2*f3*f7^2 - 1768*f2*f4*f6*f7 - 2084*f2*f5^2*f7 + 1584*f3^2*f6*f7 + 
    3568*f3*f4*f5*f7 - 1828*f4^3*f7)*x1*x3^2*x7 + (-3888*f0*f6*f7^2 - 208*f1*f5*f7^2 + 1280*f1*f6^2*f7 - 612*f2*f4*f7^2 - 36*f2*f5*f6*f7 + 1660*f3^2*f7^2 - 
    320*f3*f4*f6*f7 + 664*f3*f5^2*f7 - 8080*f4^2*f5*f7)*x1*x3^2*x8 + (-13260*f0*f4*f7^3 + 18736*f0*f5*f6*f7^2 - 24368*f0*f6^3*f7 - 1124*f1*f3*f7^3 + 
    23388*f1*f4*f6*f7^2 + 696*f1*f5^2*f7^2 + 17152*f1*f5*f6^2*f7 + 4064*f2^2*f7^3 + 292*f2*f3*f6*f7^2 - 4128*f2*f4*f5*f7^2 + 13344*f2*f4*f6^2*f7 - 
    2120*f2*f5^2*f6*f7 - 23052*f3^2*f5*f7^2 + 1400*f3^2*f6^2*f7 - 12104*f3*f4^2*f7^2 - 2640*f3*f4*f5*f6*f7 + 7528*f3*f5^3*f7 - 8064*f4^3*f6*f7 - 
    16336*f4^2*f5^2*f7)*x1*x3*x4^2 + (8964*f0*f4*f7^2 - 10088*f0*f5*f6*f7 - 76*f1*f3*f7^2 - 6244*f1*f4*f6*f7 - 92*f1*f5^2*f7 - 1652*f2^2*f7^2 + 
    148*f2*f3*f6*f7 - 1464*f2*f4*f5*f7 + 7492*f3^2*f5*f7 + 3872*f3*f4^2*f7)*x1*x3*x4*x5 + (296*f0*f5*f7^2 + 8*f0*f6^2*f7 + 88*f1*f5*f6*f7 - 44*f2*f3*f7^2 + 
    72*f2*f4*f6*f7 - 160*f2*f5^2*f7 + 164*f3^2*f6*f7 + 44*f3*f4*f5*f7 + 32*f4^3*f7)*x1*x3*x4*x6 + (392*f0*f6*f7^2 - 296*f1*f5*f7^2 + 1192*f1*f6^2*f7 - 
    964*f2*f4*f7^2 - 2072*f2*f5*f6*f7 + 1880*f3^2*f7^2 - 848*f3*f4*f6*f7 - 3564*f3*f5^2*f7 - 11360*f4^2*f5*f7)*x1*x3*x4*x7 + (24*f0*f7^3 - 2136*f1*f6*f7^2 -
    8840*f2*f5*f7^2 - 2792*f2*f6^2*f7 - 348*f3*f4*f7^2 + 4620*f3*f5*f6*f7 + 1052*f4^2*f6*f7 - 19336*f4*f5^2*f7)*x1*x3*x4*x8 + (-1504*f0*f4*f7 + 168*f1*f3*f7
    + 8*f2^2*f7)*x1*x3*x5^2 + (1508*f0*f5*f7 - 112*f1*f4*f7 - 220*f2*f3*f7)*x1*x3*x5*x6 + (32*f0*f6*f7 + 288*f1*f5*f7 + 24*f2*f4*f7 + 
    24*f3^2*f7)*x1*x3*x5*x7 + (-20*f0*f7^2 + 8*f1*f6*f7 + 8*f2*f5*f7 + 8*f3*f4*f7)*x1*x3*x5*x8 + (1640*f0*f6*f7 - 604*f1*f5*f7 - 424*f2*f4*f7 - 
    308*f3^2*f7)*x1*x3*x6^2 + (-108*f0*f7^2 + 32*f1*f6*f7 - 36*f2*f5*f7 + 8*f3*f4*f7)*x1*x3*x6*x7 + (4*f1*f7^2 - 20*f3*f5*f7 - 20*f4^2*f7)*x1*x3*x6*x8 + 
    (-72*f1*f7^2 + 648*f2*f6*f7 - 1424*f3*f5*f7 - 608*f4^2*f7)*x1*x3*x7^2 + (-1224*f2*f7^2 + 820*f3*f6*f7 + 684*f4*f5*f7)*x1*x3*x7*x8 + (-480*f3*f7^2 + 
    2116*f4*f6*f7 - 1220*f5^2*f7)*x1*x3*x8^2 + (-75592*f0*f5*f7^3 - 36552*f0*f6^2*f7^2 + 24408*f1*f4*f7^3 + 40840*f1*f5*f6*f7^2 - 9160*f2*f3*f7^3 + 
    25008*f2*f4*f6*f7^2 + 33188*f2*f5^2*f7^2 - 12080*f2*f5*f6^2*f7 + 2100*f3^2*f6*f7^2 - 8280*f3*f4*f5*f7^2 + 18400*f3*f5^2*f6*f7 - 20000*f4^3*f7^2 + 
    12848*f4^2*f5*f6*f7 - 47592*f4*f5^3*f7)*x1*x4^3 + (44988*f0*f5*f7^2 + 12184*f0*f6^2*f7 - 13640*f1*f4*f7^2 - 14360*f1*f5*f6*f7 + 5192*f2*f3*f7^2 - 
    7920*f2*f4*f6*f7 - 11104*f2*f5^2*f7 - 700*f3^2*f6*f7 + 2200*f3*f4*f5*f7 + 6008*f4^3*f7)*x1*x4^2*x5 + (-29640*f0*f6*f7^2 - 680*f1*f5*f7^2 + 
    2464*f1*f6^2*f7 + 9324*f2*f4*f7^2 + 12352*f2*f5*f6*f7 + 3036*f3^2*f7^2 + 1624*f3*f4*f6*f7 - 23672*f3*f5^2*f7 - 11372*f4^2*f5*f7)*x1*x4^2*x6 + 
    (-15420*f0*f7^3 + 6408*f1*f6*f7^2 + 11988*f2*f5*f7^2 - 4296*f2*f6^2*f7 + 3296*f3*f4*f7^2 + 2208*f3*f5*f6*f7 + 4448*f4^2*f6*f7 - 
    41724*f4*f5^2*f7)*x1*x4^2*x7 + (-6032*f1*f7^3 - 1316*f2*f6*f7^2 + 47960*f3*f5*f7^2 - 1284*f3*f6^2*f7 + 15880*f4^2*f7^2 - 16580*f4*f5*f6*f7 + 
    4712*f5^3*f7)*x1*x4^2*x8 + (-6572*f0*f5*f7 + 1920*f1*f4*f7 - 784*f2*f3*f7)*x1*x4*x5^2 + (8952*f0*f6*f7 + 1756*f1*f5*f7 - 3072*f2*f4*f7 - 
    532*f3^2*f7)*x1*x4*x5*x6 + (10644*f0*f7^2 - 2248*f1*f6*f7 - 4436*f2*f5*f7 - 632*f3*f4*f7)*x1*x4*x5*x7 + (2016*f1*f7^2 + 2920*f2*f6*f7 - 5884*f3*f5*f7 - 
    3612*f4^2*f7)*x1*x4*x5*x8 + (-2784*f0*f7^2 - 2040*f1*f6*f7 - 300*f2*f5*f7 - 2164*f3*f4*f7)*x1*x4*x6^2 + (-1768*f1*f7^2 + 3440*f2*f6*f7 - 7432*f3*f5*f7 -
    1584*f4^2*f7)*x1*x4*x6*x7 + (3196*f2*f7^2 + 4160*f3*f6*f7 + 172*f4*f5*f7)*x1*x4*x6*x8 + (2416*f2*f7^2 - 1256*f3*f6*f7 - 10572*f4*f5*f7)*x1*x4*x7^2 + 
    (2084*f3*f7^2 + 14404*f4*f6*f7 + 6244*f5^2*f7)*x1*x4*x7*x8 + (5732*f4*f7^2 - 6420*f5*f6*f7)*x1*x4*x8^2 - 1824*f0*f7*x1*x5^2*x7 + 896*f0*f7*x1*x5*x6^2 + 
    1000*f1*f7*x1*x5*x6*x7 - 840*f2*f7*x1*x5*x6*x8 - 968*f2*f7*x1*x5*x7^2 - 2120*f3*f7*x1*x5*x7*x8 - 2640*f4*f7*x1*x5*x8^2 - 336*f1*f7*x1*x6^3 + 
    444*f2*f7*x1*x6^2*x7 + 1456*f3*f7*x1*x6^2*x8 - 328*f3*f7*x1*x6*x7^2 + 3928*f4*f7*x1*x6*x7*x8 - 804*f4*f7*x1*x7^3 + 8*f5*f7*x1*x7^2*x8 - 104*f7^2*x1*x8^3
    + (16*f0^2*f7^3 + 784*f0*f2*f5*f7^2 - 16*f0*f3*f4*f7^2 + 944*f0*f3*f5*f6*f7 + 8*f0*f4^2*f6*f7 + 5620*f0*f4*f5^2*f7 - 248*f1^2*f5*f7^2 + 404*f1^2*f6^2*f7
    - 384*f1*f2*f4*f7^2 + 256*f1*f2*f5*f6*f7 - 472*f1*f3*f4*f6*f7 - 608*f1*f3*f5^2*f7 - 3684*f1*f4^2*f5*f7 - 4*f2*f3*f4*f5*f7 - 16*f2*f4^3*f7)*x2^4 + 
    (16*f0*f1*f7^3 + 1568*f0*f2*f6*f7^2 + 1536*f0*f3*f5*f7^2 + 1888*f0*f3*f6^2*f7 + 48*f0*f4^2*f7^2 + 9344*f0*f4*f5*f6*f7 - 2872*f0*f5^3*f7 + 
    336*f1^2*f6*f7^2 - 924*f1*f2*f5*f7^2 + 1320*f1*f2*f6^2*f7 - 776*f1*f3*f4*f7^2 - 1944*f1*f3*f5*f6*f7 - 768*f1*f4^2*f6*f7 - 200*f1*f4*f5^2*f7 - 
    384*f2^2*f4*f7^2 + 256*f2^2*f5*f6*f7 - 480*f2*f3*f4*f6*f7 - 608*f2*f3*f5^2*f7 - 3508*f2*f4^2*f5*f7 + 8*f3^2*f4*f5*f7 + 744*f3*f4^3*f7)*x2^3*x3 + 
    (1536*f0*f2*f7^3 + 1888*f0*f3*f6*f7^2 + 10728*f0*f4*f5*f7^2 - 7352*f0*f5^2*f6*f7 - 304*f1^2*f7^3 + 512*f1*f2*f6*f7^2 - 520*f1*f3*f5*f7^2 - 
    808*f1*f3*f6^2*f7 - 956*f1*f4^2*f7^2 + 4840*f1*f4*f5*f6*f7 + 3872*f1*f5^3*f7 - 1552*f2^2*f5*f7^2 + 392*f2*f3*f4*f7^2 - 2120*f2*f3*f5*f6*f7 - 
    56*f2*f4^2*f6*f7 - 9528*f2*f4*f5^2*f7 + 472*f3^2*f4*f6*f7 + 176*f3^2*f5^2*f7 + 5380*f3*f4^2*f5*f7 - 2024*f4^4*f7)*x2^3*x4 + (-784*f0*f2*f7^2 - 
    944*f0*f3*f6*f7 - 5592*f0*f4*f5*f7 - 40*f1^2*f7^2 - 256*f1*f2*f6*f7 + 608*f1*f3*f5*f7 + 752*f1*f4^2*f7 + 4*f2*f3*f4*f7)*x2^3*x5 + (16*f0*f3*f7^2 - 
    16*f0*f4*f6*f7 + 864*f0*f5^2*f7 + 384*f1*f2*f7^2 + 472*f1*f3*f6*f7 + 2168*f1*f4*f5*f7 + 4*f2*f3*f5*f7 + 32*f2*f4^2*f7)*x2^3*x6 + (88*f0*f4*f7^2 - 
    3372*f0*f5*f6*f7 - 752*f1*f3*f7^2 + 2224*f1*f4*f6*f7 + 1956*f1*f5^2*f7 - 384*f2^2*f7^2 - 460*f2*f3*f6*f7 - 1984*f2*f4*f5*f7 + 24*f3^2*f5*f7 + 
    1396*f3*f4^2*f7)*x2^3*x7 + (1968*f0*f5*f7^2 - 1616*f0*f6^2*f7 - 496*f1*f4*f7^2 + 256*f1*f5*f6*f7 - 512*f2*f4*f6*f7 - 4*f2*f5^2*f7 + 728*f3*f4*f5*f7 + 
    1476*f4^3*f7)*x2^3*x8 + (800*f0*f2*f7^3 + 4048*f0*f3*f6*f7^2 + 7088*f0*f4*f5*f7^2 - 3824*f0*f4*f6^2*f7 - 6892*f0*f5^2*f6*f7 + 68*f1^2*f7^3 + 
    840*f1*f2*f6*f7^2 - 1224*f1*f3*f5*f7^2 + 296*f1*f3*f6^2*f7 - 1296*f1*f4^2*f7^2 + 3024*f1*f4*f5*f6*f7 + 16*f1*f5^3*f7 - 292*f2^2*f5*f7^2 + 
    916*f2^2*f6^2*f7 - 1164*f2*f3*f4*f7^2 - 1220*f2*f3*f5*f6*f7 - 864*f2*f4^2*f6*f7 + 1456*f2*f4*f5^2*f7 - 456*f3^2*f4*f6*f7 - 596*f3^2*f5^2*f7 - 
    4508*f3*f4^2*f5*f7 + 1036*f4^4*f7)*x2^2*x3^2 + (3072*f0*f3*f7^3 - 5360*f0*f4*f6*f7^2 - 5760*f0*f5^2*f7^2 - 2312*f0*f5*f6^2*f7 - 328*f1*f2*f7^3 + 
    4200*f1*f3*f6*f7^2 + 6188*f1*f4*f5*f7^2 - 2880*f1*f4*f6^2*f7 + 1888*f1*f5^2*f6*f7 - 288*f2^2*f6*f7^2 - 3200*f2*f3*f5*f7^2 - 2288*f2*f3*f6^2*f7 - 
    1312*f2*f4^2*f7^2 - 2408*f2*f4*f5*f6*f7 + 4484*f2*f5^3*f7 + 808*f3^2*f4*f7^2 - 1880*f3^2*f5*f6*f7 - 40*f3*f4^2*f6*f7 - 16888*f3*f4*f5^2*f7 - 
    6376*f4^3*f5*f7)*x2^2*x3*x4 + (-1552*f0*f3*f7^2 + 1968*f0*f4*f6*f7 + 3016*f0*f5^2*f7 - 36*f1*f2*f7^2 + 256*f1*f3*f6*f7 - 1524*f1*f4*f5*f7 - 
    256*f2^2*f6*f7 + 604*f2*f3*f5*f7 + 636*f2*f4^2*f7 - 8*f3^2*f4*f7)*x2^2*x3*x5 + (-40*f0*f4*f7^2 + 36*f0*f5*f6*f7 + 24*f1*f3*f7^2 - 48*f1*f4*f6*f7 - 
    20*f1*f5^2*f7 + 20*f2*f3*f6*f7 + 24*f2*f4*f5*f7 + 16*f3^2*f5*f7 + 44*f3*f4^2*f7)*x2^2*x3*x6 + (-1952*f0*f5*f7^2 - 1720*f0*f6^2*f7 + 160*f1*f4*f7^2 + 
    2920*f1*f5*f6*f7 - 1152*f2*f3*f7^2 + 2104*f2*f4*f6*f7 + 1480*f2*f5^2*f7 - 456*f3^2*f6*f7 - 2976*f3*f4*f5*f7 + 200*f4^3*f7)*x2^2*x3*x7 + (608*f0*f6*f7^2 
    + 96*f1*f5*f7^2 - 296*f1*f6^2*f7 - 8*f2*f4*f7^2 - 528*f2*f5*f6*f7 + 8*f3*f4*f6*f7 + 1280*f3*f5^2*f7 + 3416*f4^2*f5*f7)*x2^2*x3*x8 + (-1720*f0*f4*f7^3 + 
    19996*f0*f5*f6*f7^2 - 1616*f0*f6^3*f7 + 6272*f1*f3*f7^3 - 7480*f1*f4*f6*f7^2 - 10116*f1*f5^2*f7^2 + 2720*f1*f5*f6^2*f7 - 400*f2^2*f7^3 - 
    1020*f2*f3*f6*f7^2 - 7248*f2*f4*f5*f7^2 - 512*f2*f4*f6^2*f7 - 5744*f2*f5^2*f6*f7 - 1248*f3^2*f5*f7^2 + 404*f3^2*f6^2*f7 - 1176*f3*f4^2*f7^2 - 
    6120*f3*f4*f5*f6*f7 - 17876*f3*f5^3*f7 + 2160*f4^3*f6*f7 - 38820*f4^2*f5^2*f7)*x2^2*x4^2 + (864*f0*f4*f7^2 - 1948*f0*f5*f6*f7 - 2376*f1*f3*f7^2 + 
    1696*f1*f4*f6*f7 + 1504*f1*f5^2*f7 + 400*f2^2*f7^2 + 740*f2*f3*f6*f7 + 2704*f2*f4*f5*f7 + 384*f3^2*f5*f7 - 304*f3*f4^2*f7)*x2^2*x4*x5 + 
    (-3688*f0*f5*f7^2 + 1616*f0*f6^2*f7 + 500*f1*f4*f7^2 + 144*f1*f5*f6*f7 - 392*f2*f3*f7^2 + 624*f2*f4*f6*f7 - 60*f2*f5^2*f7 - 472*f3^2*f6*f7 + 
    1172*f3*f4*f5*f7 + 2572*f4^3*f7)*x2^2*x4*x6 + (4052*f0*f6*f7^2 - 2768*f1*f5*f7^2 + 1360*f1*f6^2*f7 - 2072*f2*f4*f7^2 - 2184*f2*f5*f6*f7 + 740*f3^2*f7^2 
    - 2928*f3*f4*f6*f7 - 8044*f3*f5^2*f7 - 17012*f4^2*f5*f7)*x2^2*x4*x7 + (3232*f0*f7^3 + 512*f1*f6*f7^2 - 1232*f2*f5*f7^2 + 1616*f2*f6^2*f7 - 
    3920*f3*f4*f7^2 + 680*f3*f5*f6*f7 - 232*f4^2*f6*f7 + 6704*f4*f5^2*f7)*x2^2*x4*x8 - 28*f0*f4*f7*x2^2*x5^2 + (-32*f0*f5*f7 + 24*f1*f4*f7 - 
    4*f2*f3*f7)*x2^2*x5*x6 + (-32*f0*f6*f7 + 16*f1*f5*f7 + 8*f2*f4*f7 + 4*f3^2*f7)*x2^2*x5*x7 + (-816*f0*f7^2 - 256*f1*f6*f7 + 8*f2*f5*f7 + 
    488*f3*f4*f7)*x2^2*x5*x8 + (8*f0*f6*f7 + 4*f1*f5*f7 - 16*f2*f4*f7)*x2^2*x6^2 + (-44*f0*f7^2 + 20*f1*f6*f7 - 8*f3*f4*f7)*x2^2*x6*x7 + (496*f1*f7^2 + 
    512*f2*f6*f7 - 728*f3*f5*f7 - 360*f4^2*f7)*x2^2*x6*x8 + (16*f1*f7^2 - 8*f2*f6*f7 + 32*f3*f5*f7 + 40*f4^2*f7)*x2^2*x7^2 + (-24*f2*f7^2 - 4*f3*f6*f7 + 
    12*f4*f5*f7)*x2^2*x7*x8 + (-512*f4*f6*f7 + 28*f5^2*f7)*x2^2*x8^2 + (1568*f0*f3*f7^3 + 976*f0*f4*f6*f7^2 - 2040*f0*f5^2*f7^2 - 6552*f0*f5*f6^2*f7 + 
    92*f1*f2*f7^3 + 224*f1*f3*f6*f7^2 + 1012*f1*f4*f5*f7^2 - 320*f1*f4*f6^2*f7 + 72*f1*f5^2*f6*f7 + 504*f2^2*f6*f7^2 - 1248*f2*f3*f5*f7^2 + 
    824*f2*f3*f6^2*f7 - 960*f2*f4^2*f7^2 + 2320*f2*f4*f5*f6*f7 - 28*f2*f5^3*f7 - 768*f3^2*f4*f7^2 - 1360*f3^2*f5*f6*f7 - 2312*f3*f4^2*f6*f7 + 
    516*f3*f4*f5^2*f7 + 4268*f4^3*f5*f7)*x2*x3^3 + (2232*f0*f4*f7^3 - 7396*f0*f5*f6*f7^2 - 2128*f0*f6^3*f7 + 1528*f1*f3*f7^3 + 200*f1*f4*f6*f7^2 + 
    3628*f1*f5^2*f7^2 - 7368*f1*f5*f6^2*f7 - 808*f2^2*f7^3 - 232*f2*f3*f6*f7^2 + 36*f2*f4*f5*f7^2 - 1104*f2*f4*f6^2*f7 + 7512*f2*f5^2*f6*f7 - 
    2116*f3^2*f5*f7^2 - 3192*f3^2*f6^2*f7 - 1744*f3*f4^2*f7^2 - 12008*f3*f4*f5*f6*f7 + 612*f3*f5^3*f7 - 1704*f4^3*f6*f7 + 27244*f4^2*f5^2*f7)*x2*x3^2*x4 + 
    (-1448*f0*f4*f7^2 + 5584*f0*f5*f6*f7 + 16*f1*f3*f7^2 - 96*f1*f4*f6*f7 - 780*f1*f5^2*f7 + 4*f2^2*f7^2 - 16*f2*f3*f6*f7 - 932*f2*f4*f5*f7 + 540*f3^2*f5*f7
    + 1472*f3*f4^2*f7)*x2*x3^2*x5 + (-4*f0*f5*f7^2 + 56*f0*f6^2*f7 - 40*f1*f4*f7^2 - 108*f1*f5*f6*f7 + 12*f2*f3*f7^2 - 40*f2*f4*f6*f7 + 40*f2*f5^2*f7 + 
    16*f3*f4*f5*f7 - 16*f4^3*f7)*x2*x3^2*x6 + (-704*f0*f6*f7^2 + 920*f1*f5*f7^2 - 344*f1*f6^2*f7 + 568*f2*f4*f7^2 + 2292*f2*f5*f6*f7 - 732*f3^2*f7^2 + 
    696*f3*f4*f6*f7 - 1372*f3*f5^2*f7 + 8824*f4^2*f5*f7)*x2*x3^2*x7 + (704*f0*f7^3 - 224*f1*f6*f7^2 + 644*f2*f5*f7^2 - 824*f2*f6^2*f7 + 1516*f3*f5*f6*f7 + 
    1176*f4^2*f6*f7 - 300*f4*f5^2*f7)*x2*x3^2*x8 + (22192*f0*f5*f7^3 - 10704*f0*f6^2*f7^2 - 2964*f1*f4*f7^3 - 2288*f1*f5*f6*f7^2 - 2720*f1*f6^3*f7 + 
    2560*f2*f3*f7^3 + 1336*f2*f4*f6*f7^2 - 4672*f2*f5^2*f7^2 + 1392*f2*f5*f6^2*f7 - 8872*f3^2*f6*f7^2 - 11448*f3*f4*f5*f7^2 + 2624*f3*f4*f6^2*f7 + 
    7688*f3*f5^2*f6*f7 + 9016*f4^3*f7^2 + 19872*f4^2*f5*f6*f7 + 1304*f4*f5^3*f7)*x2*x3*x4^2 + (-7816*f0*f5*f7^2 + 4504*f0*f6^2*f7 + 560*f1*f4*f7^2 + 
    2320*f1*f5*f6*f7 - 504*f2*f3*f7^2 - 472*f2*f4*f6*f7 - 116*f2*f5^2*f7 + 2144*f3^2*f6*f7 + 6524*f3*f4*f5*f7 - 1672*f4^3*f7)*x2*x3*x4*x5 + (188*f0*f6*f7^2 
    - 152*f1*f5*f7^2 - 64*f1*f6^2*f7 - 68*f2*f4*f7^2 - 96*f2*f5*f6*f7 - 68*f3^2*f7^2 + 112*f3*f4*f6*f7 + 24*f3*f5^2*f7 + 12*f4^2*f5*f7)*x2*x3*x4*x6 + 
    (104*f0*f7^3 + 16*f1*f6*f7^2 + 52*f2*f5*f7^2 + 24*f2*f6^2*f7 + 16*f3*f4*f7^2 - 100*f3*f5*f6*f7 - 44*f4^2*f6*f7 + 40*f4*f5^2*f7)*x2*x3*x4*x7 + 
    (1328*f1*f7^3 + 1520*f2*f6*f7^2 - 6416*f3*f5*f7^2 + 3808*f3*f6^2*f7 - 1956*f4^2*f7^2 + 12240*f4*f5*f6*f7 + 396*f5^3*f7)*x2*x3*x4*x8 + (-48*f0*f5*f7 + 
    4*f2*f3*f7)*x2*x3*x5^2 + (-64*f0*f6*f7 + 44*f1*f5*f7 + 40*f2*f4*f7 + 12*f3^2*f7)*x2*x3*x5*x6 + (-44*f0*f7^2 + 8*f1*f6*f7 - 8*f2*f5*f7 - 
    8*f3*f4*f7)*x2*x3*x5*x7 + (-16*f1*f7^2 + 16*f2*f6*f7 - 8*f3*f5*f7 - 24*f4^2*f7)*x2*x3*x5*x8 + (36*f0*f7^2 + 36*f1*f6*f7 - 12*f2*f5*f7 + 
    464*f3*f4*f7)*x2*x3*x6^2 + (52*f1*f7^2 + 8*f2*f6*f7 + 60*f3*f5*f7 + 108*f4^2*f7)*x2*x3*x6*x7 + (-16*f2*f7^2 - 12*f3*f6*f7 - 12*f4*f5*f7)*x2*x3*x6*x8 + 
    (16*f2*f7^2 - 4*f3*f6*f7 - 16*f4*f5*f7)*x2*x3*x7^2 + (-32*f3*f7^2 + 20*f4*f6*f7 + 12*f5^2*f7)*x2*x3*x7*x8 + (288*f4*f7^2 - 656*f5*f6*f7)*x2*x3*x8^2 + 
    (-6908*f0*f6*f7^3 + 15320*f1*f5*f7^3 - 6504*f1*f6^2*f7^2 + 11576*f2*f4*f7^3 - 29136*f2*f5*f6*f7^2 + 1616*f2*f6^3*f7 - 7852*f3^2*f7^3 + 
    5408*f3*f4*f6*f7^2 - 5796*f3*f5^2*f7^2 - 2824*f3*f5*f6^2*f7 + 56076*f4^2*f5*f7^2 - 992*f4^2*f6^2*f7 + 12080*f4*f5^2*f6*f7 - 10888*f5^4*f7)*x2*x4^3 + 
    (4068*f0*f6*f7^2 - 7512*f1*f5*f7^2 + 2168*f1*f6^2*f7 - 6352*f2*f4*f7^2 + 648*f2*f5*f6*f7 + 4312*f3^2*f7^2 - 1784*f3*f4*f6*f7 - 8296*f3*f5^2*f7 - 
    14184*f4^2*f5*f7)*x2*x4^2*x5 + (-9708*f0*f7^3 + 1740*f1*f6*f7^2 + 5616*f2*f5*f7^2 - 1104*f2*f6^2*f7 + 3596*f3*f4*f7^2 - 264*f3*f5*f6*f7 - 304*f4^2*f6*f7
    + 25316*f4*f5^2*f7)*x2*x4^2*x6 + (-720*f1*f7^3 - 12500*f2*f6*f7^2 - 10808*f3*f5*f7^2 - 1412*f3*f6^2*f7 + 3324*f4^2*f7^2 - 21188*f4*f5*f6*f7 - 
    14268*f5^3*f7)*x2*x4^2*x7 + (-1576*f2*f7^3 + 1388*f3*f6*f7^2 + 7620*f4*f5*f7^2 - 512*f4*f6^2*f7 + 23256*f5^2*f6*f7)*x2*x4^2*x8 + (-912*f0*f6*f7 + 
    300*f1*f5*f7 + 896*f2*f4*f7 - 476*f3^2*f7)*x2*x4*x5^2 + (5764*f0*f7^2 + 52*f1*f6*f7 + 40*f2*f5*f7 - 516*f3*f4*f7)*x2*x4*x5*x6 + (32*f1*f7^2 + 4*f3*f5*f7
    + 108*f4^2*f7)*x2*x4*x5*x7 + (8*f2*f7^2 - 692*f3*f6*f7 + 4*f4*f5*f7)*x2*x4*x5*x8 + (-2568*f1*f7^2 - 568*f2*f6*f7 - 4936*f3*f5*f7 - 
    2096*f4^2*f7)*x2*x4*x6^2 + (36*f2*f7^2 - 16*f3*f6*f7 - 12*f4*f5*f7)*x2*x4*x6*x7 + (3920*f3*f7^2 - 16*f4*f6*f7 - 8*f5^2*f7)*x2*x4*x6*x8 + (-20*f3*f7^2 - 
    13324*f4*f6*f7 - 3148*f5^2*f7)*x2*x4*x7^2 + (44*f4*f7^2 + 11316*f5*f6*f7)*x2*x4*x7*x8 + (2080*f5*f7^2 - 1616*f6^2*f7)*x2*x4*x8^2 - 832*f0*f7*x2*x5^2*x6 
    - 168*f1*f7*x2*x5^2*x7 - 4*f2*f7*x2*x5^2*x8 + 736*f1*f7*x2*x5*x6^2 + 408*f2*f7*x2*x5*x6*x7 - 488*f3*f7*x2*x5*x6*x8 + 1088*f3*f7*x2*x5*x7^2 + 
    2096*f4*f7*x2*x5*x7*x8 - 56*f5*f7*x2*x5*x8^2 - 1336*f3*f7*x2*x6^2*x7 - 684*f4*f7*x2*x6^2*x8 - 5864*f4*f7*x2*x6*x7^2 + 680*f5*f7*x2*x6*x7*x8 + 
    512*f6*f7*x2*x6*x8^2 + 632*f5*f7*x2*x7^3 + 416*f6*f7*x2*x7^2*x8 + 8*f7^2*x2*x7*x8^2 + (1412*f0*f4*f7^3 - 4112*f0*f5*f6*f7^2 - 48*f0*f6^3*f7 + 
    40*f1*f3*f7^3 - 208*f1*f4*f6*f7^2 + 20*f1*f5^2*f7^2 + 24*f1*f5*f6^2*f7 + 24*f2^2*f7^3 + 408*f2*f3*f6*f7^2 + 444*f2*f4*f5*f7^2 + 816*f2*f4*f6^2*f7 - 
    20*f2*f5^2*f6*f7 - 932*f3^2*f5*f7^2 + 4*f3^2*f6^2*f7 - 2088*f3*f4^2*f7^2 + 240*f3*f4*f5*f6*f7 + 1224*f3*f5^3*f7 - 1536*f4^3*f6*f7 + 
    604*f4^2*f5^2*f7)*x3^4 + (-2776*f0*f5*f7^3 + 528*f0*f6^2*f7^2 + 1520*f1*f4*f7^3 - 4016*f1*f5*f6*f7^2 - 464*f2*f3*f7^3 + 600*f2*f4*f6*f7^2 + 
    224*f2*f5^2*f7^2 + 360*f2*f5*f6^2*f7 - 1152*f3^2*f6*f7^2 - 10712*f3*f4*f5*f7^2 - 2672*f3*f4*f6^2*f7 - 4548*f3*f5^2*f6*f7 - 8684*f4^3*f7^2 - 
    12460*f4^2*f5*f6*f7 + 11020*f4*f5^3*f7)*x3^3*x4 + (1436*f0*f5*f7^2 + 688*f0*f6^2*f7 - 208*f1*f4*f7^2 - 104*f1*f5*f6*f7 + 52*f2*f3*f7^2 - 712*f2*f4*f6*f7
    - 40*f2*f5^2*f7 + 144*f3^2*f6*f7 + 1096*f3*f4*f5*f7 + 2220*f4^3*f7)*x3^3*x5 + (32*f0*f6*f7^2 - 40*f1*f5*f7^2 - 24*f1*f6^2*f7 + 24*f2*f4*f7^2 + 
    20*f2*f5*f6*f7 + 36*f3^2*f7^2 - 8*f3*f4*f6*f7 - 4*f3*f5^2*f7 - 12*f4^2*f5*f7)*x3^3*x6 + (32*f0*f7^3 - 208*f1*f6*f7^2 + 444*f2*f5*f7^2 + 816*f2*f6^2*f7 -
    576*f3*f4*f7^2 + 228*f3*f5*f6*f7 - 808*f4^2*f6*f7 + 6668*f4*f5^2*f7)*x3^3*x7 + (-40*f1*f7^3 - 408*f2*f6*f7^2 + 1216*f3*f5*f7^2 - 8*f3*f6^2*f7 + 
    1040*f4^2*f7^2 - 1452*f4*f5*f6*f7 - 728*f5^3*f7)*x3^3*x8 + (10664*f0*f6*f7^3 - 4204*f1*f5*f7^3 + 1544*f1*f6^2*f7^2 - 4620*f2*f4*f7^3 + 
    3088*f2*f5*f6*f7^2 - 2512*f2*f6^3*f7 - 920*f3^2*f7^3 - 13328*f3*f4*f6*f7^2 - 948*f3*f5^2*f7^2 - 18060*f3*f5*f6^2*f7 - 45036*f4^2*f5*f7^2 - 
    6904*f4^2*f6^2*f7 - 5652*f4*f5^2*f6*f7 + 6688*f5^4*f7)*x3^2*x4^2 + (-1016*f0*f6*f7^2 + 1508*f1*f5*f7^2 + 456*f1*f6^2*f7 + 1784*f2*f4*f7^2 - 
    836*f2*f5*f6*f7 - 44*f3^2*f7^2 + 3712*f3*f4*f6*f7 + 6852*f3*f5^2*f7 + 12172*f4^2*f5*f7)*x3^2*x4*x5 + (-2360*f0*f7^3 - 688*f1*f6*f7^2 + 4860*f2*f5*f7^2 +
    2048*f2*f6^2*f7 + 648*f3*f4*f7^2 + 12628*f3*f5*f6*f7 + 3636*f4^2*f6*f7 - 8940*f4*f5^2*f7)*x3^2*x4*x6 + (736*f1*f7^3 + 192*f2*f6*f7^2 - 3860*f3*f5*f7^2 -
    2704*f3*f6^2*f7 - 6496*f4^2*f7^2 + 14900*f4*f5*f6*f7 + 5976*f5^3*f7)*x3^2*x4*x7 + (1008*f2*f7^3 + 920*f3*f6*f7^2 + 1200*f4*f5*f7^2 + 72*f4*f6^2*f7 - 
    7972*f5^2*f6*f7)*x3^2*x4*x8 + (-544*f0*f6*f7 + 168*f1*f5*f7 - 104*f2*f4*f7 + 28*f3^2*f7)*x3^2*x5^2 + (788*f0*f7^2 + 104*f1*f6*f7 - 1212*f2*f5*f7 - 
    408*f3*f4*f7)*x3^2*x5*x6 + (-208*f1*f7^2 - 712*f2*f6*f7 + 40*f3*f5*f7 + 1848*f4^2*f7)*x3^2*x5*x7 + (-52*f2*f7^2 - 288*f3*f6*f7 - 
    568*f4*f5*f7)*x3^2*x5*x8 + (20*f1*f7^2 - 20*f3*f5*f7 + 12*f4^2*f7)*x3^2*x6^2 + (24*f2*f7^2 + 4*f3*f6*f7 + 44*f4*f5*f7)*x3^2*x6*x7 + (-32*f3*f7^2 + 
    4*f4*f6*f7 - 664*f5^2*f7)*x3^2*x6*x8 + (-32*f4*f6*f7 - 16*f5^2*f7)*x3^2*x7^2 - 24*f4*f7^2*x3^2*x7*x8 + (-8*f5*f7^2 + 4*f6^2*f7)*x3^2*x8^2 + 
    (15752*f0*f7^4 + 7464*f1*f6*f7^3 - 19304*f2*f5*f7^3 + 13240*f2*f6^2*f7^2 - 10988*f3*f4*f7^3 - 37852*f3*f5*f6*f7^2 + 4440*f3*f6^3*f7 - 20060*f4^2*f6*f7^2
    - 25636*f4*f5^2*f7^2 - 10184*f4*f5*f6^2*f7 - 2352*f5^3*f6*f7)*x3*x4^3 + (-11444*f0*f7^3 - 784*f1*f6*f7^2 + 7512*f2*f5*f7^2 + 3216*f2*f6^2*f7 + 
    6772*f3*f4*f7^2 + 26044*f3*f5*f6*f7 + 5116*f4^2*f6*f7 + 7820*f4*f5^2*f7)*x3*x4^2*x5 + (-68*f1*f7^3 - 164*f2*f6*f7^2 + 276*f3*f5*f7^2 + 52*f3*f6^2*f7 + 
    76*f4^2*f7^2 + 60*f4*f5*f6*f7 + 72*f5^3*f7)*x3*x4^2*x6 + (-4216*f2*f7^3 - 10364*f3*f6*f7^2 - 12148*f4*f5*f7^2 + 26984*f4*f6^2*f7 - 
    7976*f5^2*f6*f7)*x3*x4^2*x7 + (-544*f3*f7^3 - 6316*f4*f6*f7^2 + 2164*f5^2*f7^2 - 7880*f5*f6^2*f7)*x3*x4^2*x8 + (2356*f0*f7^2 - 104*f1*f6*f7 - 
    264*f2*f5*f7 - 952*f3*f4*f7)*x3*x4*x5^2 + (92*f1*f7^2 - 3864*f2*f6*f7 - 7792*f3*f5*f7 + 88*f4^2*f7)*x3*x4*x5*x6 + (1732*f2*f7^2 + 1324*f3*f6*f7 + 
    3428*f4*f5*f7)*x3*x4*x5*x7 + (672*f3*f7^2 - 1396*f4*f6*f7 + 696*f5^2*f7)*x3*x4*x5*x8 + (-3680*f2*f7^2 - 96*f3*f6*f7 - 4*f4*f5*f7)*x3*x4*x6^2 + 
    (380*f3*f7^2 - 20*f4*f6*f7)*x3*x4*x6*x7 + (672*f4*f7^2 + 4*f5*f6*f7)*x3*x4*x6*x8 + (-572*f4*f7^2 - 7584*f5*f6*f7)*x3*x4*x7^2 + (1712*f5*f7^2 + 
    2984*f6^2*f7)*x3*x4*x7*x8 + 784*f6*f7^2*x3*x4*x8^2 - 96*f0*f7*x3*x5^3 - 168*f1*f7*x3*x5^2*x6 - 104*f2*f7*x3*x5^2*x7 - 56*f3*f7*x3*x5^2*x8 + 
    1252*f2*f7*x3*x5*x6^2 + 648*f3*f7*x3*x5*x6*x7 + 1096*f4*f7*x3*x5*x6*x8 + 60*f4*f7*x3*x5*x7^2 + 40*f5*f7*x3*x5*x7*x8 + 144*f6*f7*x3*x5*x8^2 - 
    1200*f3*f7*x3*x6^3 - 5504*f4*f7*x3*x6^2*x7 + 1824*f5*f7*x3*x6^2*x8 + 1024*f5*f7*x3*x6*x7^2 - 1448*f6*f7*x3*x6*x7*x8 - 280*f7^2*x3*x6*x8^2 - 
    760*f6*f7*x3*x7^3 + 448*f7^2*x3*x7^2*x8 + (11664*f1*f7^4 + 22756*f2*f6*f7^3 - 14080*f3*f5*f7^3 + 6660*f3*f6^2*f7^2 - 13252*f4^2*f7^3 - 
    17452*f4*f5*f6*f7^2 - 2280*f5^3*f7^2 + 1760*f5^2*f6^2*f7)*x4^4 + (-8440*f1*f7^3 - 3140*f2*f6*f7^2 + 28052*f3*f5*f7^2 - 2220*f3*f6^2*f7 + 5828*f4^2*f7^2 
    + 6132*f4*f5*f6*f7 + 64*f5^3*f7)*x4^3*x5 + (9252*f2*f7^3 + 2432*f3*f6*f7^2 - 22436*f4*f5*f7^2 + 992*f4*f6^2*f7 - 2936*f5^2*f6*f7)*x4^3*x6 + 
    (-9828*f3*f7^3 + 39420*f4*f6*f7^2 - 12180*f5^2*f7^2 + 1712*f5*f6^2*f7)*x4^3*x7 + (-12164*f4*f7^3 - 8604*f5*f6*f7^2 - 1616*f6^3*f7)*x4^3*x8 + 
    (2352*f1*f7^2 - 1384*f2*f6*f7 - 7884*f3*f5*f7 - 580*f4^2*f7)*x4^2*x5^2 + (-6956*f2*f7^2 - 664*f3*f6*f7 + 5520*f4*f5*f7)*x4^2*x5*x6 + (3356*f3*f7^2 - 
    12980*f4*f6*f7 + 3616*f5^2*f7)*x4^2*x5*x7 + (2236*f4*f7^2 + 2916*f5*f6*f7)*x4^2*x5*x8 + (448*f3*f7^2 - 1856*f4*f6*f7 - 1324*f5^2*f7)*x4^2*x6^2 + 
    (21500*f4*f7^2 - 1216*f5*f6*f7)*x4^2*x6*x7 + (-10000*f5*f7^2 + 2128*f6^2*f7)*x4^2*x6*x8 + (-12024*f5*f7^2 + 420*f6^2*f7)*x4^2*x7^2 + 
    3872*f6*f7^2*x4^2*x7*x8 + 3288*f7^3*x4^2*x8^2 - 264*f1*f7*x4*x5^3 + 1244*f2*f7*x4*x5^2*x6 + 48*f3*f7*x4*x5^2*x7 + 552*f4*f7*x4*x5^2*x8 - 
    640*f3*f7*x4*x5*x6^2 - 7440*f4*f7*x4*x5*x6*x7 + 2576*f5*f7*x4*x5*x6*x8 + 3992*f5*f7*x4*x5*x7^2 - 1344*f6*f7*x4*x5*x7*x8 - 904*f7^2*x4*x5*x8^2 + 
    1548*f4*f7*x4*x6^3 - 2352*f5*f7*x4*x6^2*x7 + 248*f6*f7*x4*x6^2*x8 - 168*f6*f7*x4*x6*x7^2 - 1328*f7^2*x4*x6*x7*x8 - 1248*f7^2*x4*x7^3 + 28*f7*x5^2*x8^2 +
    488*f7*x5*x6*x7*x8 + 432*f7*x5*x7^3 - 432*f7*x6^3*x8 - 404*f7*x6^2*x7^2
, -48*x1^2*x3*x7*f7^2*
f1^2+32*x1^3*x7*f0*f4*f3*f7-32*x1^3*x6*f0*f6^2*f1+16*x1^4*f0*f6*f5*f4*f1+192*
x1^2*x4^2*f7^2*f0*f6*f2+48*x1^2*x2*x5*f7*f1*f3*f2+16*x1^2*x3*x5*f4*f6*f2^2+16*
x1^3*x7*f2*f6*f5*f1-96*x1^2*x2^2*f6*f0^2*f7*f5-156*x1^2*x4^2*f7^2*f4*f3*f1-8*
x1^2*x2*x7*f4*f7*f3*f1-16*x1^2*x2*x7*f0*f7*f4^2+32*x1^3*x7*f4*f6*f1*f3+8*x1^4*
f2*f5*f4^2*f1-16*x1^4*f0*f5*f3*f7*f1-6*x1^4*f5^2*f4*f1^2-4*x1^4*f2*f5*f3^3-64*
x1^3*x3*f1*f6^2*f3*f2-16*x1^3*x3*f0*f6*f4*f7*f1+24*x1^2*x2^2*f0*f5^2*f7*f1+24*
x1^2*x2*x6*f1^2*f5*f7-248*x1^2*x2*x4*f6*f7*f5*f1^2+16*x1^2*x3*x6*f4*f1*f5^2+48
*x1^2*x2*x3*f0*f7^2*f4*f1+96*x1^2*x2*x3*f5*f0^2*f7^2+48*x1^2*x2*x3*f0*f6*f7*f3
^2+8*x1^2*x2*x3*f4^2*f7*f2^2+48*x1^2*x2*x3*f2*f4*f7*f1*f5-24*x1^2*x2*x3*f6*f7*
f4*f1^2-32*x1^2*x2*x3*f4^2*f5^2*f1-96*x1^2*x2*x3*f0*f5*f7*f4*f3+96*x1^2*x2*x3*
f0*f6*f5*f7*f1-36*x1^2*x2*x3*f4^2*f7*f3*f1-12*x1^2*x2*x3*f5^2*f7*f1^2+16*x1^2*
x4^2*f7*f4*f1*f5^2-12*x1^2*x4^2*f7^2*f6*f1^2+192*x1^2*x4^2*f7^2*f0*f4^2-172*x1
^2*x4^2*f7*f5^2*f2*f3+16*x1^3*x4*f6*f7*f4*f1^2-96*x1^3*x4*f1*f6*f7*f3*f2-24*x1
^3*x4*f5^2*f2*f3*f4+12*x1^3*x4*f1*f2^2*f7^2+24*x1^3*x4*f2^3*f6*f7+40*x1^3*x4*
f5^2*f7*f1^2-28*x1^3*x4*f4^2*f7*f3*f1-128*x1^3*x4*f0*f7^2*f3*f2+112*x1^3*x4*f0
*f6*f5*f7*f1+60*x1^3*x4*f3*f5*f7*f2^2-96*x1^3*x4*f0*f5^2*f2*f7-24*x1^3*x4*f3^2
*f5*f2*f6+160*x1^3*x4*f5*f0^2*f7^2-8*x1^3*x4*f4^2*f7*f2^2-96*x1^3*x4*f5*f6^2*
f1^2-8*x1^3*x4*f2*f4*f7*f1*f5+72*x1^3*x4*f0*f5^3*f4-48*x1^3*x4*f4*f5*f2^2*f6+
96*x1^3*x4*f0*f6^2*f5*f2-60*x1^2*x2*x4*f5^3*f1*f4+60*x1^2*x2*x4*f1*f7*f5^2*f2-\
144*x1^2*x2*x4*f0*f5^2*f7*f3+32*x1^2*x2*x4*f0*f5*f7*f4^2-20*x1^2*x2*x7*f4*f1*
f5^2-4*x1^2*x5*x8*f7*f2^2+4*x1^2*x2*x8*f7*f5*f2^2+40*x1^3*x3*f1*f6*f5*f4*f2+16
*x1^3*x3*f0*f5^3*f3+8*x1^4*f0*f5*f7*f2^2-144*x1^2*x3*x4*f5^2*f2*f3*f6-24*x1^2*
x3^2*f5*f6*f1*f4^2+408*x1^2*x4^2*f7^2*f0*f5*f3+48*x1^2*x2*x4*f0*f3^2*f7^2-8*x1
^2*x2^2*f4^2*f2*f3*f5-48*x1^2*x2^2*f2*f5*f7*f3*f1-8*x1^3*x5*f0*f4^3+44*x1^2*x3
^2*f4*f5*f7*f2^2+12*x1^3*x2*f3^2*f5^2*f1+48*x1^2*x2^2*f0*f6*f4*f7*f1+40*x1^2*
x4*x7*f7*f1*f4*f5+4*x1^4*f1*f5*f4*f3^2+16*x1^4*f0*f6*f2*f7*f1-192*x1^2*x2*x3*
f6^2*f0^2*f7+96*x1^2*x3*x7*f0*f7^2*f2-24*x1^2*x3*x7*f4*f5*f1*f6+16*x1^3*x3*f3^
2*f5*f1*f6+8*x1^3*x3*f2*f5^3*f1+16*x1^3*x6*f6*f5*f1^2+34*x1^2*x4^2*f7^2*f4*f2^
2+16*x1^3*x3*f6*f3*f7*f1^2-32*x1^3*x3*f6*f5^2*f1^2+64*x1^3*x2*f6*f0^2*f7*f4-16
*x1^4*f0*f4*f3*f7*f2+36*x1^2*x4^2*f7^2*f3^2*f2-96*x1^2*x4^2*f7^3*f0*f1-96*x1^2
*x3*x4*f2*f6*f7*f5*f1-80*x1^2*x4*x5*f0*f7*f4^2+12*x1^2*x3*x4*f4^3*f7*f2+32*x1^
3*x5*f0*f5*f4*f3+96*x1^2*x2*x5*f7*f6*f0^2+16*x1^2*x3^2*f0*f5^4-20*x2^2*x4^2*f7
^3*f2*f1+24*x2^2*x1*x4*f7*f2*f3*f4*f5+20*x2^2*x1*x3*f7^2*f1^2*f4+96*x2^2*x3^2*
f0*f6^2*f5^2+8*x2^2*x3*x6*f7*f3^2*f4-8*x2^3*x6*f2*f5^2*f4-24*x2^2*x1*x7*f7^2*
f1^2-8*x2^2*x3*x4*f3^2*f6*f4*f7+8*x2^2*x3*x4*f1*f5^3*f7+160*x2^2*x3*x4*f0*f5*
f7^2*f4+16*x2^2*x4*x8*f4*f7^2*f2+60*x2^2*x3*x4*f4^2*f5^3-8*x2^3*x5*f7*f3*f0*f5
+376*x2^2*x4^2*f7^2*f0*f5^2+84*x2^2*x4*x7*f7^2*f1*f4+16*x2^2*x1*x6*f0*f5^3-16*
x2^3*x3*f2*f7*f4^3+32*x2^3*x3*f0*f6*f5^3-32*x2^2*x4*x5*f0*f7^2*f3-16*x2^2*x4*
x7*f7*f4^3+16*x2^2*x3*x8*f7^2*f0*f5+72*x2^2*x4*x7*f4^2*f5*f6+40*x2^2*x3^2*f0*
f4^2*f7^2-4*x2^2*x1*x5*f4^3*f2-32*x2^3*x7*f0*f5^2*f7-28*x2^2*x7^2*f7*f3*f4-24*
x2^2*x3^2*f1*f6*f5^3-24*x2^2*x3^2*f0*f7^3*f1-24*x2^3*x1*f0*f4^3*f7+12*x2^2*x4*
x7*f7*f5^2*f2+8*x2^2*x1*x6*f7*f3*f0*f5+48*x2^2*x1*x6*f7*f4^2*f0+40*x2^2*x5*x7*
f7*f0*f5+24*x2^2*x3*x6*f5^2*f1*f6-8*x2^2*x3^2*f3*f6*f2*f7*f4+72*x2^2*x1*x4*f4*
f5^2*f1*f6+12*x2^3*x4*f4^3*f5^2+32*x2^3*x4*f0*f6*f7^2*f2+12*x2^3*x6*f5*f4^2*f3
-96*x2^2*x4*x5*f0*f5^2*f7-100*x2^2*x3*x4*f7*f5^2*f2*f4-20*x2^2*x3*x4*f3*f2*f7^
2*f4+24*x2^2*x1*x7*f1*f6*f5*f4-48*x2^2*x3^2*f1*f6^2*f4*f5+20*x2^2*x3*x4*f5*f1*
f7^2*f3-144*x2^2*x3*x4*f5*f7*f4^2*f3-60*x2^2*x3*x4*f1^2*f7^3+8*x2^3*x7*f3^2*f7
*f4-16*x2^2*x1*x7*f7*f3*f4*f2+8*x2^2*x1*x7*f4^2*f3*f5+40*x2^2*x5*x6*f7*f0*f4+
16*x2^2*x6^2*f7*f0*f5+2*x6^4*f4+4*x5^4*f0+4*x5^2*x6^2*f2+12*x2^2*x6^2*f4^3+2*
x2^4*f4^5-16*x7*x1*x2*x8*f0*f7^2-16*x2*x7^2*x4*f2*f7^2+8*x7^3*x2*f5*f6+24*x7^3
*x4*f6*f7+24*x7^2*x3*x8*f6*f7+12*x6^2*x7^2*f6-4*x1^2*x2*x4*f4*f5*f7*f2^2+128*
x1^2*x2*x4*f0*f7^2*f5*f1+336*x1^2*x3*x4*f0*f7^2*f4*f3-48*x1^2*x3*x4*f6^2*f2^2*
f5-192*x1^2*x3*x4*f0*f5^2*f7*f4-68*x1^2*x3*x4*f4*f5*f7*f2*f3+352*x1^2*x3*x4*f0
*f6^2*f7*f2-72*x1^2*x3*x4*f5^2*f1*f4*f6-32*x1^3*x5*f0*f6*f4*f2+32*x1^3*x5*f1*
f6*f3*f2+32*x1^3*x5*f0*f3*f7*f2-32*x1^3*x5*f0*f6*f3^2-12*x1^3*x5*f3^2*f5*f1-12
*x1^2*x3*x5*f4*f5*f2*f3-24*x1^2*x3*x5*f0*f5^2*f4-24*x1^2*x4*x5*f4^2*f2*f5+36*
x1^2*x4*x5*f4*f1*f5^2+28*x1^2*x4*x5*f1*f5*f7*f2+16*x1^2*x4*x5*f0*f7^2*f1-176*
x1^2*x4*x5*f0*f6*f7*f2-96*x1^2*x4*x5*f0*f5^3-8*x1^3*x6*f0*f5*f4^2-48*x1^2*x2*
x6*f0*f6*f7*f1-20*x6^2*x1^2*f7*f0*f3+8*x6*x1*x3*x8*f0*f7^2+4*x5*x6^2*x7*f4+4*
x6^2*x2*x8*f3*f7+20*x6*x2*x7^2*f7*f3-24*x6^2*x1^2*f3*f1*f6-8*x6^2*x1*x5*f1*f5+
12*x6^2*x1*x4*f5*f4^2-32*x3*x6*x7^2*f5*f6+8*x6*x1^2*x7*f1*f5^2+8*x6^2*x1*x2*f1
*f5^2-16*x6*x1^2*x7*f3^2*f5-52*x4*x6*x7^2*f7*f5+12*x4*x6^2*x5*f4*f5+4*x4^2*x6^
2*f3*f6*f7-8*x4^2*x6*x7*f7*f4*f6-32*x6*x2*x3*x7*f4^2*f6+48*x6*x1^2*x7*f2*f3*f6
-24*x3*x6*x4*x7*f2*f7^2-16*x3^2*x6*x7*f7*f2*f6+4*x7^3*x1*f5^2-4*x7^3*x6*f7-12*
x7^2*x5*x8*f7-2*x7^2*x1^2*f4^3-8*x7^3*x5*f6+48*x7^2*x4*x8*f7^2+16*x7^3*x3*f6^2
-2*x5^2*x7^2*f4+4*x2*x8^3*f7^2-8*x2*x6^2*x3*f7*f3^2-40*x6*x2*x4*x8*f7*f4*f5-24
*x6*x2*x7^2*f4*f6-16*x6*x2*x7*x8*f4*f7-32*x6*x1^2*x7*f0*f5*f6-16*x6*x1^2*x7*f1
*f4*f6+80*x6*x1*x3*x7*f6*f2*f5-16*x6*x1*x3*x7*f7*f3^2+4*x6^2*x1*x7*f4^2+4*x6^2
*x1*x3*f4^3+28*x6*x1*x7^2*f2*f7-12*x6*x1*x7^2*f4*f5-4*x6*x1^2*x7*f4^2*f3-8*x3^
2*x6*x7*f7*f4^2-16*x3^2*x6^2*f7*f1*f6+8*x5*x6^2*f7*f1*x3+8*x5*x7*f7*f2*x3*x6-\
32*x3*x6*x7*x8*f7*f5+8*x6*x1^2*x7*f2*f4*f5+4*x3*x6^2*x5*f4^2-8*x3*x6*x7^2*f7*
f4+4*x7^2*x2*x8*f5*f7+48*x7^2*x1^2*f0*f6^2+18*x4^2*x2^2*f4*f5^4+24*x4*x2*x3*x7
*f5^4+8*x2^2*x4*x7*f3*f7^2*f2+12*x4^2*x2^2*f3*f5*f2*f7^2+152*x4*x2*x5*x7*f0*f7
^2-28*x4*x2*x7*x8*f7^2*f3-40*x4*x2*x5*x7*f7*f3*f4-144*x4*x2*x6*x7*f4*f5*f6+32*
x4*x2*x6*x7*f7*f4^2-76*x4*x2*x6*x7*f1*f7^2-8*x4*x2*x6*x8*f7^2*f2+240*x4*x1*x3*
x6*f5^2*f6*f2+144*x4*x1*x6^2*f7*f0*f6+76*x4*x1*x5*x6*f7*f2*f3-32*x4*x1*x5*x6*
f7*f1*f4-240*x4*x1^2*x7*f0*f6*f4*f7+72*x4*x1^2*x7*f5^2*f3*f4-48*x4*x1^2*x7*f1*
f6*f5^2+288*x4*x1^2*x7*f0*f6^2*f5-72*x4*x1^2*x7*f3^2*f5*f6+36*x4*x1*x7^2*f1*f7
^2+48*x4*x1^2*x7*f2*f6*f4*f5-48*x4*x1^2*x7*f2*f7^2*f1+192*x4*x1^2*x7*f0*f3*f7^
2+16*x4*x1*x2*x7*f3*f6*f2*f7-48*x4*x1*x3*x7*f4^2*f6*f5-24*x4*x1*x5*x7*f3*f5^2-\
24*x4*x1*x5*x7*f7*f2*f4+32*x4*x1*x6*x7*f7*f3*f4-4*x4*x1*x5*x8*f7*f2*f5-88*x4*
x1*x5*x8*f7^2*f0-60*x4*x1*x5*x7*f7*f1*f5+8*x4^2*x6*f7*f4^2*x3*f6-192*x4*x3*x6*
x7*f6*f5^2+16*x4*x3*x2*x8*f7*f4^2*f6-16*x4*x3^2*x7*f7*f4*f5^2-32*x5*x7*x3*x4*
f7*f2*f6-80*x4*x3*x6*x8*f7*f5^2-16*x4*x3*x6^2*f1*f7^2-48*x4*x3*x5^2*f7*f1*f5+8
*x4*x3*x5*x7*f1*f7^2+16*x4*x3^2*x8*f7*f3*f6^2+144*x4*x3*x7^2*f5*f6^2-32*x4*x3*
x6*x7*f3*f6*f7+80*x4*x3*x6^2*f7*f2*f6-28*x4*x3*x6^2*f7*f3*f5+48*x4*x3*x6^2*f4*
f5*f6-36*x4^2*x3*x5*f5^4+32*x4*x3*x5*x7*f7*f4^2-96*x4*x3*x5*x7*f4*f5*f6+48*x4^
2*x3*x5*f4*f6*f3*f7-72*x4^2*x1*x3*f4^2*f5^2*f6+24*x4*x1^2*x5*f3^2*f4*f5-18*x4^
2*x1^2*f4^3*f5^2-36*x4*x1*x5*x6*f3*f5*f4-120*x4*x1*x6^2*f6*f2*f5+24*x4*x1^2*x6
*f5^2*f2*f4-12*x4*x1^2*x6*f5*f4^2*f3-20*x4*x3*x6^2*f7*f4^2-16*x5^3*x2*f0*f5+44
*x5^2*x4*x6*f1*f7-56*x5^3*x4*f7*f0+24*x5^2*x3*x6*f1*f6-12*x5^2*x1^2*f6*f1^2-4*
x5^2*x1^2*f1*f3*f4+4*x5^2*x1^2*f1*f2*f5+48*x5*x1^2*x6*f0*f6*f3+20*x5*x1^2*x6*
f3*f1*f5-8*x5*x1^2*x6*f2*f1*f6+8*x5^2*x1*x2*f0*f5*f4-4*x5*x1*x6^2*f2*f4-12*x5^
2*x3*x4*f5*f4^2-8*x3*x5^2*x4*f7*f3^2-4*x5*x2^2*x6*f7*f3*f1+4*x2^2*x5*x7*f7*f2*
f3+8*x5*x2*x3*x7*f5*f4^2-4*x5*x2*x3*x7*f7*f3^2+20*x5*x2*x6*x7*f7*f1-8*x5*x2*x6
*x7*f4^2-4*x5*x2*x4*x6*f7*f3^2+12*x5*x2*x6^2*f3*f4+12*x5*x2*x7^2*f2*f7-12*x5*
x2*x4*x8*f1*f7^2+32*x5^2*x1*x2*f7*f0*f2+4*x5^2*x1^2*f3^2*f2+8*x5^2*x1^2*f0*f4^
2-8*x5*x1^2*x6*f0*f5*f4+24*x5*x1*x6*x7*f1*f6+12*x5*x1^2*x6*f2*f3*f4-12*x5^2*x1
*x4*f1*f5^2+32*x3^2*x5*x6*f7*f0*f6-16*x3*x5*x2*x7*f7*f1*f5-8*x5*x3^2*x7*f4^2*
f6-8*x5*x3^2*x8*f7*f4^2-16*x5*x3*x4*x8*f7^2*f2-32*x5*x1^2*x6*f7*f0*f2+8*x5^2*
x1*x8*f7*f0-20*x1^2*x6^2*f2*f3*f5-8*x1^3*x7*f4^2*f1*f5-32*x1^3*x7*f0*f5*f7*f2-\
32*x1^3*x7*f0^2*f7^2-24*x1^2*x2*x6*f0*f5^2*f4+12*x1^2*x2*x6*f4^2*f1*f5-24*x1^2
*x2*x6*f4*f6*f2^2+40*x1^3*x6*f1*f5*f0*f7-4*x1^4*f2^2*f4*f3*f5+4*x1^4*f2*f3^2*
f7*f1-16*x1^4*f2*f6*f4*f3*f1+4*x1^4*f2*f5^2*f3*f1-8*x1^4*f1*f6*f5*f2^2+12*x1^4
*f4*f7*f3*f1^2-16*x1^4*f6*f5^2*f0^2-16*x1^4*f0*f6^2*f2^2+4*x1^4*f6*f3^2*f2^2+4
*x1^4*f6*f4^2*f1^2-4*x1^4*f1*f4^3*f3-8*x1^4*f0*f4^2*f5*f3+32*x1^4*f4*f0^2*f7*
f5-16*x1^4*f0*f4^2*f7*f1-8*x1^4*f2*f5*f7*f1^2+4*x1^4*f1*f7*f4*f2^2-8*x1^4*f6*
f7*f1^3+16*x1^4*f6^2*f2*f1^2-72*x1^2*x2^2*f0*f4^2*f7*f3+80*x1^2*x3*x6*f0*f6*f7
*f2+8*x1^3*x2*f7*f4*f2^3-32*x1^3*x2*f0*f4*f5*f7*f1-16*x1^3*x2*f0*f6*f4^2*f3+48
*x1^3*x2*f0*f1*f7^2*f2+32*x1^3*x2*f6*f2*f7*f1^2-16*x1^3*x2*f0*f5^2*f4*f3+16*x1
^3*x2*f3*f6*f4*f2^2-16*x1^3*x2*f0*f6*f3*f7*f1-32*x1^3*x2*f1*f6*f5*f3*f2-12*x1^
3*x2*f1*f5*f7*f2^2-8*x1^3*x2*f4^2*f2^2*f5+20*x1^3*x2*f1*f5^2*f4*f2+16*x1^3*x2*
f0*f6*f5^2*f1-16*x1^3*x2*f7*f3^2*f0*f4-8*x3^4*f1*f5^2*f6*f7+16*x3^4*f3*f5*f2*
f7^2-8*x3^2*x4*x7*f7*f4^2*f6-48*x3^2*x4*x7*f7^2*f3*f4-32*x3^4*f1*f6^3*f5+8*x3^
4*f4^2*f7^2*f2-8*x3^4*f5^3*f3*f6-6*x3^4*f3^2*f7^2*f4+52*x3^4*f0*f5^2*f7^2+12*
x3^4*f0*f3*f7^3-24*x3^3*x1*f6*f7^2*f1^2-32*x3^3*x1*f0*f5*f3*f7^2+32*x3^3*x1*f7
*f1*f6*f4^2+64*x3^3*x1*f0*f6*f2*f7^2-40*x3^3*x1*f3*f5*f1*f6*f7+36*x3^3*x1*f2*
f5^2*f7*f3-64*x3^3*x1*f0*f5^3*f7+80*x3^3*x1*f0*f6*f5*f4*f7-24*x3^3*x2*f3*f6*f4
*f5^2+128*x3^3*x2*f0*f5*f6^3-20*x3^3*x2*f1*f5^3*f7+24*x3^3*x2*f0*f5*f4*f7^2+8*
x3^3*x2*f2*f7*f4*f5^2-36*x3^3*x2*f3*f4^2*f5*f7+8*x3^3*x2*f4*f6*f7*f1*f5-32*x3^
3*x2*f0*f6^2*f4*f7-368*x3^2*x4^2*f5*f6*f1*f7^2+360*x3^2*x4^2*f5^2*f6^2*f4+224*
x3^2*x1*x4*f3*f5*f2*f6*f7-48*x3^2*x1*x4*f4*f6^2*f2*f5-32*x3^2*x1*x4*f0*f6*f5^2
*f7-52*x3^2*x1*x4*f1*f5^3*f7+248*x3^2*x1*x4*f0*f5*f4*f7^2-80*x3^2*x1*x4*f3*f4^
2*f5*f7+120*x3^2*x2*x4*f7*f4*f6*f2*f5-16*x3^2*x2*x4*f3^2*f5*f6*f7+16*x3^2*x2*
x4*f3*f6*f7*f4^2-128*x3^2*x2*x4*f1*f5^2*f6*f7-80*x3^2*x2*x4*f4^3*f5*f7+16*x3^2
*x2*x4*f4^2*f7^2*f2+672*x3^2*x2*x4*f0*f6^2*f7*f5+160*x3^3*x4*f5^2*f7*f2*f6+16*
x3^3*x4*f0*f4*f7^3+64*x3^3*x4*f4*f5*f7^2*f2-40*x1*x5*f7*f0*f4*x3^2*f5-4*x3^2*
x1*x5*f2*f4*f5^2+48*x3^2*x1*x5*f0*f6*f7*f3+48*x3^2*x1*x5*f3*f6^2*f1-8*x3^2*x2*
x5*f0*f3*f7^2+48*x3^2*x2*x5*f1*f5^2*f6+12*x3^3*x5*f3*f7^2*f1+12*x3^3*x5*f4^2*
f7*f3-16*x3^3*x5*f0*f4*f7^2-12*x3^2*x4*x5*f5^3*f4+8*x3^2*x4*x5*f3*f7^2*f2+12*
x3^2*x4*x5*f7^2*f4*f1+192*x3^2*x4*x5*f5*f6*f1*f7+104*x3^2*x4*x5*f4*f7*f3*f5+32
*x3^2*x4*x5*f3^2*f7*f6+4*x6^3*x2*f3*f5-16*x6^2*x4*x7*f7*f4+40*x6*x1^2*x7*f7*f3
*f1-20*x6^2*x1*x2*f2*f4*f5-28*x6*x1*x2*x7*f3*f5*f4+4*x6*x1*x3*x8*f7*f2*f5-4*x6
^2*x1*x8*f7*f2+4*x6*x1*x2*x8*f7*f2*f4+8*x6^2*x1^2*f0*f6*f4+4*x5^3*x3*f1*f5+4*
x5^3*x1*f3*f1-8*x5^2*x1*x6*f2*f3+12*x5^2*x2*x6*f1*f5+4*x5^3*x2*f1*f4-8*x5^3*x1
*f0*f4-12*x5^2*x1*x2*f7*f1^2+32*x5^2*x1^2*f0*f2*f6-16*x5^2*x1*x3*f7*f0*f3+16*
x5^2*x1*x6*f0*f5-8*x5^2*x1*x3*f1*f4*f5+48*x5^2*x1*x3*f0*f6*f4-64*x5*x1^2*x7*f7
*f0*f3+8*x5*x1^2*x7*f3^2*f4-48*x5*x1^2*x7*f3*f1*f6+16*x5*x1^2*x7*f7*f2*f1-16*
x4^2*x5*x7*f3*f6*f7+12*x4*x5*x6*x7*f7*f3+28*x4^2*x5^2*f7*f2*f5+24*x4*x5*x6*x7*
f5^2-16*x4^2*x5^2*f7*f3*f4-8*x4^2*x5*x6*f7*f4^2+8*x4*x5^2*x7*f7*f2+8*x4*x5*x6*
x8*f7*f4-40*x4*x5*x6^2*f7*f2-8*x4*x5*x2*x8*f7*f4^2-12*x4*x5^2*x7*f4*f5-72*x4*
x5*x7*x8*f7*f5-18*x4^2*x5^2*f4*f5^2-72*x4*x5*x7^2*f5*f6+20*x4*x5*x7^2*f7*f4+4*
x4*x5^2*x8*f7*f3+32*x5*x1*x3*x6*f0*f5*f6-8*x5*x1*x2*x7*f2*f4*f5+8*x5*x1*x7^2*
f2*f6+8*x5*x1*x3*x6*f7*f2^2-28*x5*x1*x3*x6*f7*f3*f1+8*x5^2*x1*x4*f7*f2^2-24*x5
^2*x1^2*f3*f0*f5+128*x5*x3*x4*x6*f0*f7^2+32*x5*x3^2*x6*f6*f2*f5+4*x5^2*x1*x3*
f4^2*f2+16*x5*x2^2*x6*f2*f4*f5+16*x5*x2*x3*x6*f5^2*f2-24*x5*x2*x6^2*f7*f0-24*
x2^2*x5*x7*f7*f1*f4-8*x5*x2*x6^2*f2*f5-48*x5*x1*x6^2*f0*f6+64*x5*x1^2*x7*f0*f6
*f4+32*x5*x1*x2*x7*f7*f0*f4-2*x5^2*x1^2*f2^2*f4-4*x5*x1^2*x6*f2^2*f5-4*x5*x1^2
*x6*f1*f4^2-8*x5*x1*x2*x6*f7*f2*f1+4*x5^2*x1*x7*f2*f4-4*x5^2*x1*x7*f1*f5-12*x5
*x1*x6*x7*f3*f4-4*x5^2*x1*x2*f1*f4^2+4*x5^2*x1*x6*f1*f4-12*x5*x1*x7^2*f1*f7-4*
x5*x1*x7^2*f3*f5-20*x5*x3*x7*x8*f4*f7-16*x5*x3*x7^2*f4*f6+8*x3*x5^2*x4*f7*f2*
f4+32*x5*x3*x2*x6*f2*f4*f6-16*x5*x3*x6^2*f2*f6+8*x3^2*x5*x6*f7*f2*f4+120*x5*x3
*x4*x6*f7*f2*f5-8*x3^2*x5*x6*f7*f3^2-24*x5*x1*x2*x7*f1*f4*f6-8*x5*x1*x2*x6*f7*
f0*f3+48*x5*x1*x6*x7*f7*f0+84*x4*x5*x2*x6*f7*f2*f4-4*x5^2*x3*x7*f4^2+12*x5*x3*
x6^2*f3*f5+16*x5*x3*x7^2*f7*f3+4*x5*x3*x6*x8*f3*f7-4*x5*x3^2*x8*f7*f3*f5+8*x6^
3*x1*f7*f0+16*x6^2*x1^2*f7*f2*f1-40*x6^2*x1*x7*f2*f6-8*x2^2*x6*x7*f7*f3^2+8*x6
^3*x2*f7*f1+16*x6^2*x3*x8*f7*f4+8*x6^3*x4*f7*f3-16*x6^3*x3*f7*f2+20*x6^2*x2*x7
*f4*f5+72*x6^2*x4*x7*f5*f6+16*x6^3*x1*f1*f6+28*x6^2*x4*x8*f5*f7-16*x6^3*x3*f4*
f5+8*x6^3*x3*f3*f6+8*x6^3*x1*f2*f5-8*x6^3*x1*f3*f4-24*x6^2*x1*x7*f7*f1+20*x6^2
*x1*x7*f3*f5-36*x6^2*x2*x7*f7*f2+16*x6^2*x3*x7*f4*f6-8*x6^2*x3*x7*f7*f3+10*x6^
2*x1^2*f3^2*f4-24*x2^2*x1*x6*f7*f2^2*f4+16*x2^2*x1*x6*f7*f2*f1*f5-8*x2^2*x1*x6
*f2*f5^2*f3+24*x2^2*x1*x6*f4*f5*f3^2+4*x2^3*x6*f5^3*f1+4*x2^3*x6*f5*f1*f7*f3+
24*x2^2*x3*x6*f5^2*f3*f4+20*x2^2*x3*x7*f5^2*f4^2-68*x2^2*x3*x7*f2*f5*f7*f4+12*
x2^2*x3*x7*f5*f7*f3^2-8*x2^2*x3*x7*f1*f7^2*f3-16*x2^2*x6*x7*f5*f4^2+68*x2^2*x6
*x7*f7*f2*f4-28*x2^2*x6*x7*f7*f1*f5+16*x2^2*x3*x8*f7^2*f2*f3+4*x2^3*x5*f4^3*f3
+4*x2^3*x5*f3*f7*f1*f4-20*x2^2*x4*x6*f5*f7*f3^2+104*x2^2*x4*x6*f2*f5*f7*f4-12*
x2^2*x6^2*f3*f5*f4-12*x2^2*x5*x6*f4^2*f3-12*x2^2*x5*x6*f1*f5^2+4*x2^2*x7^2*f7*
f2*f5+4*x2^3*x7*f4^3*f5-4*x2^3*x7*f3*f7*f2*f5+4*x2^2*x4*x8*f7^2*f1*f5-8*x2^2*
x6*x8*f7*f3*f4+4*x2^2*x7*x8*f7*f4^2+4*x2^3*x8*f7^2*f2^2+4*x2^3*x8*f7*f4^2*f3+4
*x2^3*x8*f7^2*f3*f1+8*x2^2*x3*x8*f7*f4^3-192*x2*x1*x4*x6*f0*f5^2*f7-24*x2^2*x1
^2*f4^2*f1*f6*f3+12*x2*x1*x3^2*f7^2*f3*f2^2-28*x2*x1*x3^2*f5^2*f1*f3*f7+20*x2*
x1*x3^2*f5^2*f7*f2^2-92*x2*x1*x4^2*f4*f5^2*f7*f2+56*x2*x1*x3*x6*f4^2*f1*f7+32*
x2*x1*x3*x6*f3*f7*f1*f5+48*x2*x1^2*x6*f3*f1*f4*f6-48*x2*x1^2*x6*f0*f6*f5*f3+40
*x2*x1*x6*x7*f7*f1*f4-96*x2*x1*x6*x7*f7*f0*f5-8*x2*x1*x4*x6*f3*f6*f1*f7-24*x2^
2*x1*x6*f3*f4^3+48*x2*x1^2*x4*f5*f6*f1*f4^2-16*x2*x1*x3*x4*f0*f4^2*f7^2-16*x2*
x1*x3*x4*f4^2*f7*f2*f5+80*x2^2*x1*x3*f0*f6*f5^2*f4-32*x2^2*x1*x3*f0*f4*f7^2*f2
-32*x2^2*x1*x3*f4^3*f2*f6-16*x2^2*x1*x3*f0*f5^2*f3*f7+88*x2*x1*x3*x4*f5*f6*f1*
f3*f7+112*x2^2*x1*x4*f5^2*f1*f3*f7+12*x2*x1^2*x4*f4^3*f3*f5-40*x2*x1*x4*x7*f7^
2*f2^2+48*x2*x1^2*x7*f3*f5*f1*f6-12*x2*x1*x3^2*f5^3*f3^2-16*x2^2*x1*x4*f1*f4*
f7^2*f2-24*x2^2*x1*x3*f1*f4*f6*f7*f2-8*x2*x1*x7^2*f7*f2*f4+4*x2^2*x1*x3*f4*f5*
f7*f2^2+128*x2^2*x1*x3*f0*f6*f5*f7*f2-24*x2^2*x1*x3*f3^2*f5^2*f4+32*x2^2*x1*x3
*f4*f7*f3*f1*f5-24*x2^2*x1*x3*f4^2*f1*f5*f6+72*x2*x1*x4^2*f5^3*f4^2-76*x2*x1*
x4^2*f4^2*f7*f3*f5-96*x2*x1*x4^2*f4^2*f1*f7^2-16*x2*x1*x4^2*f0*f5*f7^2*f4+48*
x2*x1*x4^2*f0*f6*f7^2*f3+188*x2*x1*x4^2*f3*f7^2*f1*f5-48*x2*x1*x4^2*f5^3*f1*f7
+144*x2*x1^2*x4*f3*f5^2*f1*f6-36*x2*x1^2*x4*f4*f7*f3^3-16*x2*x1^2*x4*f1*f4*f6*
f7*f2+24*x2*x1^2*x4*f2^3*f7^2+144*x2*x1^2*x4*f0*f6*f7*f3*f4-96*x2*x1^2*x4*f0*
f5^2*f6*f4-144*x2*x1^2*x4*f4*f6*f2*f5*f3-48*x2^2*x1*x4*f0*f6*f5*f7*f3-76*x2^2*
x1*x4*f4^2*f1*f7*f5-40*x2^2*x1*x4*f4^2*f7*f3^2+12*x2^2*x1*x4*f4^4*f5+160*x2^2*
x1*x4*f0*f6*f4^2*f7+32*x2^2*x1*x4*f0*f5^2*f7*f4-96*x2^2*x1*x4*f5*f7^2*f1^2+8*
x2^2*x1*x4*f4*f6*f1*f3*f7-12*x2^2*x1*x7*f4^2*f1*f7+4*x2^2*x1*x7*f4*f5^2*f2+4*
x2^2*x1*x7*f4^4+4*x2^2*x1*x7*f7*f3^3-4*x2*x1*x5*x8*f7*f2*f3-4*x2*x1*x6*x8*f1*
f5*f7+4*x2^2*x1*x8*f5*f7*f1*f4+4*x2^2*x1*x8*f5*f7*f2*f3-12*x2*x1*x3*x8*f7^2*f3
*f1+36*x2*x1*x4^2*f5^4*f3+96*x2^2*x1*x4*f0^2*f7^3+8*x2*x1*x4*x6*f1*f7^2*f2+8*
x2^3*x1*f4^4*f3+16*x2^2*x1*x7*f0*f7^2*f2-240*x2*x1*x3*x4*f5^2*f6*f2*f4-24*x2^2
*x1*x3*f3*f5^2*f1*f6+24*x2*x1*x3*x7*f4^3*f5-12*x2^2*x1*x4*f5^4*f1-32*x2^2*x1*
x3*f6*f5*f7*f1^2+36*x2*x1*x3*x7*f5^2*f3*f4+32*x2^3*x1*f0*f5^2*f2*f7-24*x2*x1*
x3^2*f4*f5^2*f1*f6+40*x2*x1*x3^2*f5*f7^2*f1^2-48*x2*x1*x3*x4*f6*f7^2*f1^2+192*
x2^2*x1*x4*f0*f5*f7^2*f2-56*x2^2*x1*x4*f5^2*f7*f2^2+32*x2*x1*x4*x6*f0*f7^2*f3-\
48*x2*x1*x4*x6*f4^2*f2*f7-44*x2*x1*x4^2*f5*f7^2*f2^2+84*x2*x1*x4^2*f7^3*f1^2+
10*x2^2*x1^2*f4^3*f3^2+32*x2^2*x1*x3*f4^3*f3*f5-64*x2*x1*x3*x4*f0*f5*f7^2*f3-8
*x2^3*x3*f3*f6*f1*f4*f7+8*x2^4*f0*f4^2*f5*f7+24*x1^2*x3^2*f4^3*f2*f6-20*x1^2*
x3^2*f3*f5^3*f2+48*x1^2*x3^2*f6*f7*f5*f1^2-144*x1^2*x3^2*f0*f6*f5*f7*f2-192*x1
^2*x3^2*f6*f0^2*f7^2-44*x1^2*x3^2*f7^2*f4*f1^2-8*x1^3*x3*f3^4*f6-24*x1^3*x3*f2
*f4^2*f7*f1-32*x1^3*x3*f6^2*f4*f1^2-36*x1^3*x3*f3^2*f7*f4*f1+32*x1^3*x3*f0*f5^
2*f4^2+8*x1^3*x3*f4*f6*f3^2*f2+192*x1^3*x3*f6*f0^2*f7*f5+48*x1^3*x3*f0*f4^2*f7
*f3+96*x1^3*x3*f0*f6^2*f4*f2+32*x1^3*x3*f3*f7*f4*f2^2+8*x1^3*x3*f1*f6*f2^2*f7-\
16*x1^3*x3*f2^2*f0*f7^2-16*x1^3*x3*f0*f6*f4^3-64*x1^3*x3*f0*f5*f4*f7*f2-24*x1^
3*x3*f4^2*f2^2*f6+8*x1^3*x3*f3*f5*f2^2*f6-96*x1^3*x3*f0*f6*f5*f4*f3+16*x1^3*x3
*f2^3*f6^2+20*x1^3*x3*f2*f5*f7*f3*f1-88*x1^2*x2*x3*f1*f6*f7*f3*f2-48*x1^2*x4*
x6*f7^2*f1^2+12*x1^3*x4*f3^3*f5^2+32*x1^2*x3*x4*f4*f6*f1*f3*f7-80*x1^2*x3*x4*
f0*f6*f7*f4^2+24*x1^2*x2^2*f0*f5*f3^2*f7+48*x1^3*x4*f1*f6*f5^2*f2+96*x1^3*x4*
f0*f6*f7*f3^2-8*x1^3*x6*f1*f5^2*f2-12*x1^3*x3*f4^3*f1*f5-8*x1^3*x5*f3^2*f2*f4+
16*x1^3*x5*f1*f4*f0*f7-64*x1^3*x5*f5*f0^2*f7-16*x1^2*x3*x6*f6*f7*f1^2+8*x1^2*
x3*x8*f6*f7*f2^2-24*x1^3*x4*f4^2*f5^2*f1+16*x1^3*x3*f7^2*f3*f0*f1-80*x1^3*x3*
f0*f6*f3*f7*f2-64*x1^2*x2*x7*f6*f7*f1^2-16*x1^3*x6*f0*f5^2*f3-76*x1^2*x4*x6*f7
*f2^2*f5-8*x1^3*x7*f4*f5*f2*f3-112*x1^2*x2*x4*f1*f7^2*f3*f2+16*x1^3*x6*f0*f6*
f4*f3+8*x1^3*x6*f3^2*f6*f1-16*x1^3*x3*f0*f5*f3^2*f7-64*x1^3*x3*f4*f0^2*f7^2+80
*x1^3*x4*f0*f6*f7*f4*f2+32*x1^3*x7*f0*f6^2*f2+32*x1^2*x2*x7*f0*f5^3-192*x1^3*
x4*f6^2*f0^2*f7+368*x1^2*x2*x4*f0*f6*f5*f7*f2-40*x1^2*x2*x4*f4*f5*f7*f3*f1+52*
x1^3*x3*f5*f4*f7*f1^2-48*x1^3*x3*f0*f5^2*f7*f1+144*x1^2*x4*x6*f7^2*f0*f2+56*x1
^2*x2*x3*f0*f5^3*f4+24*x1^2*x2*x3*f2^3*f6*f7-64*x3^2*x1*x6*f4*f5^2*f3+64*x3^2*
x1*x6*f4*f6*f2*f5-16*x3^3*x6*f3*f7^2*f2-32*x3^3*x6*f2*f6^2*f5-56*x3^3*x6*f5^2*
f7*f2-88*x3^3*x6*f0*f5*f7^2+24*x3^3*x6*f5^2*f3*f6-16*x3^3*x6*f4^2*f6*f5+8*x3^2
*x4*x6*f4^2*f5*f7+176*x3^2*x4*x6*f7*f6^2*f1+24*x3^2*x4*x6*f4*f6*f3*f7-24*x3^2*
x6^2*f3*f5*f6-16*x3^2*x1*x7*f6^2*f4*f2+12*x3^2*x1*x7*f3^2*f5*f7-16*x3^2*x1*x7*
f2^2*f7^2-20*x3^2*x1*x7*f5^2*f7*f1+8*x3^2*x2*x7*f3^2*f7*f6+44*x3^2*x2*x7*f7^2*
f4*f1+32*x3^2*x2*x7*f5*f6*f1*f7-12*x3^2*x2*x7*f4^3*f7+16*x3^3*x7*f2*f6*f7*f5+
64*x3^2*x4*x7*f7^2*f5*f2+240*x3^2*x4*x7*f6^2*f4*f5-8*x5*x7*f7*f2*x3^2*f5-8*x3^
3*x8*f7^2*f2*f5+24*x3^3*x8*f7*f4*f5^2-16*x3^3*x8*f7^3*f0-8*x3^2*x6*x8*f7*f3*f6
-40*x3^2*x6*x8*f7*f4*f5+16*x3*x1*x2*x4*f3*f5^2*f7*f2-72*x3*x1*x2*x4*f4^2*f3*f5
*f6+144*x3*x1*x2*x4*f4*f6^2*f1*f5+16*x3^2*x1*x4*f2*f6*f7^2*f1+32*x3^2*x1*x4*f6
^2*f7*f2^2-24*x3^2*x1*x4*f5^2*f6*f3*f4+16*x3^2*x1*x4*f2^2*f5*f7^2+48*x3^2*x1*
x4*f3*f2*f7^2*f4-16*x3*x1*x5^2*f0*f5^2+48*x3*x1^2*x5*f1^2*f6^2-8*x3*x1^2*x5*f1
*f6*f2*f5-128*x3*x1^2*x5*f2*f6^2*f0+48*x3*x1^2*x5*f3*f0*f6*f5-20*x3*x1^2*x5*f7
*f1^2*f5+64*x3*x1^2*x5*f0*f7*f2*f5+96*x3*x1^2*x5*f7^2*f0^2-32*x3*x1^2*x5*f3*f4
*f1*f6-8*x3*x1*x2*x5*f1*f6*f4^2+24*x3*x1*x4*x5*f4^3*f5+12*x3*x1*x4*x5*f5^2*f3*
f4-128*x3*x1*x4*x5*f3*f7*f2*f5+256*x3*x1*x4*x5*f1*f6*f7*f3+80*x3*x1^2*x6*f7*f3
*f0*f5-96*x3*x1^2*x6*f0*f3*f6^2+176*x3*x1*x4*x8*f7^2*f0*f6-80*x3*x1*x6^2*f7*f0
*f5-32*x3*x1*x6^2*f6*f1*f5+16*x3*x1*x5*x6*f1*f5^2-32*x3*x1^2*x7*f7*f2*f6*f1-36
*x3*x1^2*x6*f4*f5*f3^2+32*x3*x1*x5*x6*f2*f3*f6+56*x3*x1*x4*x7*f3^2*f6*f7-96*x3
*x1*x4*x6*f5^2*f4^2-120*x3*x1*x4*x6*f3*f5^3-4*x3*x2^2*x6*f2*f7^2*f1+4*x3*x2*x4
*x7*f7^2*f4*f2+84*x3*x2*x6*x7*f7*f2*f5+4*x3*x2^2*x5*f3*f5*f1*f7+140*x3*x2*x4*
x6*f5^2*f2*f7-12*x3*x2*x6^2*f3*f5^2-8*x3*x2*x5*x6*f4^3+20*x3*x2*x7^2*f1*f7^2-4
*x3*x2*x5*x8*f7*f3*f4+12*x3*x2*x6*x8*f7^2*f1-24*x3*x2*x6*x8*f7*f4^2-52*x3*x2*
x4*x6*f7^2*f4*f1+40*x3*x2*x4*x6*f4^3*f7+80*x3^2*x1^2*f1*f6^2*f4*f3-28*x3^2*x1^
2*f3^2*f6*f4^2-48*x3^2*x1^2*f0*f6^2*f4^2+16*x3^2*x1^2*f3^2*f6^2*f2+144*x3^2*x1
^2*f7*f3*f6*f0*f4+26*x3^2*x1^2*f3^2*f5^2*f4+16*x3^2*x1^2*f3*f1*f6*f5^2+128*x3^
2*x1^2*f0*f6^3*f2-24*x3^2*x1^2*f3^3*f6*f5-40*x3^2*x1^2*f2*f1*f6*f7*f4+16*x3^2*
x1^2*f4^3*f3*f5-32*x3^2*x1^2*f7*f3^2*f6*f1+24*x3*x1*x7^2*f7*f1*f6+64*x3*x1*x6*
x7*f7*f2*f4-24*x3*x1*x7^2*f7*f2*f5+16*x3*x1^2*x7*f3^2*f5^2+120*x3*x1*x2*x7*f1*
f6*f7*f3-48*x3*x1*x2*x7*f1*f4*f5*f7-12*x3*x1*x4*x8*f4*f7^2*f2-16*x3*x1*x5*x7*
f7*f0*f5+24*x3*x1*x2*x6*f7*f4*f0*f5-48*x3^2*x1*x2*f6^2*f7*f1^2+704*x3*x1*x4^2*
f7^2*f0*f6*f4-32*x3*x1*x5*x8*f7*f0*f6+176*x3*x1*x2*x4*f0*f5^3*f7-24*x3*x1*x6^2
*f5^2*f2+8*x3*x1*x7^2*f3*f5*f6-56*x3*x1*x4*x5*f1*f4*f5*f7-12*x3*x1*x4*x5*f7*f3
^2*f4+12*x3*x1*x2*x5*f4^3*f3-168*x3*x1*x4*x7*f7*f5^2*f2+16*x3*x1^2*x5*f7*f3^2*
f1-16*x3*x1*x2*x7*f2*f7^2*f1+16*x3*x1*x2*x7*f0*f7^2*f3+8*x3*x1*x2*x7*f1*f6*f5^
2+8*x3*x1^2*x6*f3*f1*f6*f5-8*x3*x1*x6*x8*f1*f6*f7-40*x3*x1^2*x7*f7*f3*f4*f2+8*
x1^2*x3*x4*f3*f7^2*f2^2+16*x1^3*x3*f7^2*f2*f1^2+20*x1^3*x2*f4^2*f7*f1^2+8*x1^3
*x6*f0*f3^2*f7-24*x1^2*x3*x4*f4*f6*f7*f2^2-32*x1^3*x2*f0*f4^2*f7*f2+4*x1^2*x3^
2*f5^2*f6*f2^2-24*x1^2*x3^2*f4*f6^2*f2^2+56*x1^2*x3*x4*f3^2*f7*f2*f6+32*x1^2*
x3*x7*f4^2*f6*f2-8*x1^3*x7*f3^2*f6*f2-16*x1^3*x7*f1*f4*f7*f2-8*x1^4*f6*f5*f3*
f1^2+16*x1^4*f0*f5*f6*f3*f2-68*x1^2*x3^2*f4*f5*f7*f3*f1+4*x1^2*x3^2*f1*f7*f5^2
*f2+24*x1^2*x4*x8*f7^2*f2^2-32*x1^3*x6*f6*f0^2*f7-16*x1^3*x6*f1*f3*f7*f2-48*x1
^2*x3*x7*f5*f6*f2*f3-96*x1^2*x3*x7*f0*f7*f4*f5-12*x1^3*x5*f1*f5*f4*f2+8*x1^3*
x5*f5^2*f1^2+64*x1^3*x3*f0*f6^2*f5*f1-56*x1^2*x3^2*f0*f5*f7*f4^2-8*x1^2*x2*x3*
f0*f4^3*f7-144*x1^2*x4^2*f7^2*f1*f5*f2-12*x1^3*x4*f5^3*f3*f1+96*x1^2*x3^2*f0*
f4*f7^2*f2-32*x1^3*x2*f0*f6*f7*f2^2+24*x1^3*x3*f4^2*f6*f3*f1+8*x1^3*x3*f4*f5*
f3^3-8*x1^3*x2*f5^3*f1^2+104*x1^2*x3^2*f0*f7^2*f5*f1-64*x1^3*x2*f6^2*f0^2*f5-8
*x1^3*x2*f3^2*f4*f2*f5-16*x1^3*x6*f3*f6*f2^2+16*x1^3*x6*f3^2*f5*f2-28*x1^3*x4*
f3^2*f5*f1*f7+88*x1^2*x3*x4*f5^2*f7*f2^2-192*x1^2*x2*x4*f6*f0^2*f7^2-80*x1^2*
x4^2*f7*f5*f6*f2^2+44*x1^2*x4^2*f7*f4^2*f2*f5+112*x4^3*x5*f7^2*f3*f4-128*x4^2*
x1*x7*f2*f6*f5*f7+132*x4^3*x8*f7^3*f3+28*x4^2*x2*x6*f7^2*f3^2-16*x4^3*x5*f7^2*
f1*f6+8*x4^2*x2*x8*f7^2*f2*f6-312*x4^2*x3*x6*f0*f7^3+32*x4^3*x6*f2*f6*f7^2+16*
x4^3*x7*f7^3*f2+88*x4^2*x1*x6*f4*f7*f3*f5+40*x4^2*x3*x8*f7^3*f2+112*x4^2*x3*x8
*f7^2*f3*f6-24*x4^3*x6*f4*f7*f5*f6+156*x4^2*x3*x5*f1*f5*f7^2-28*x2*x7*x4^2*f5^
2*f7*f4+4*x4^2*x1*x7*f2*f7^2*f4+216*x4^2*x3*x8*f7*f6*f5^2-204*x4^3*x7*f7^2*f4*
f5+152*x4^4*f7^2*f3*f5*f6+40*x4^4*f7^3*f6*f1-196*x4^4*f7^3*f3*f4-524*x4^3*x1*
f3*f1*f7^3-36*x4^3*x1*f4^2*f7^2*f3-16*x4^3*x2*f7^2*f6*f4*f2+32*x4^3*x2*f7^2*f0
*f6^2-156*x4^3*x2*f7^3*f4*f1-48*x4^3*x2*f5^3*f4*f7+24*x4^3*x2*f7*f6*f5*f4^2-\
232*x4^3*x2*f0*f7^3*f5-176*x4^3*x3*f3*f5^2*f7^2+216*x4^3*x3*f5^2*f7*f6*f4-72*
x4^2*x1*x5*f7^2*f2^2-92*x4^2*x1*x5*f3^2*f5*f7-72*x4^2*x1*x5*f7*f1*f5^2+172*x4^
2*x2*x5*f7^2*f4*f1-148*x4^2*x1*x6*f7^2*f2*f3-216*x4^2*x1*x6*f0*f7^2*f5-172*x4^
2*x2*x6*f2*f7^2*f4-32*x4^2*x2*x6*f1*f5*f7^2-264*x4^2*x3*x6*f2*f5*f7^2+48*x4^2*
x3*x6*f7^2*f3*f4-140*x4^3*x6*f5*f7^2*f3+100*x4^3*x6*f7^3*f1+56*x4^2*x5*x6*f7*
f3*f5+96*x4^2*x1*x7*f7^2*f3^2+80*x4^2*x3*x7*f7^2*f2*f6-180*x4^2*x3*x7*f5*f7^2*
f3+88*x4^2*x3*x7*f5^3*f7+116*x4^2*x5*x7*f7*f4*f5-216*x4^2*x5*x7*f6*f5^2+236*x4
^2*x3*x8*f7^2*f4*f5+380*x4^3*x8*f7^2*f5^2-56*x4^2*x5*x8*f7^2*f3+268*x4^2*x7*x8
*f5*f7^2+36*x4^2*x2*x8*f7*f5^3-220*x4^2*x1*x2*f5^2*f7*f3^2-24*x4^2*x1*x3*f3*f6
*f7*f4^2-68*x4*x1*x5^2*f7*f3*f1+192*x4*x1^2*x5*f0*f6*f4*f5-48*x4*x1^2*x5*f7*f0
*f3*f5-72*x4*x1*x2*x5*f1*f6*f5*f4+112*x4*x1*x3*x5*f0*f3*f7^2-336*x4*x1*x3*x5*
f0*f6*f4*f7-16*x4^2*x1*x5*f4*f6*f1*f7-68*x4^2*x1*x5*f4*f5*f7*f2+12*x4^2*x1*x5*
f4^2*f7*f3+36*x4^2*x1*x5*f5^2*f4^2-72*x4*x1*x6^2*f7*f1*f5-8*x2^2*x3^2*f3*f7^2*
f1*f4-12*x2^2*x3^2*f6*f7^2*f1^2-16*x2^3*x7*f0*f7^2*f3+16*x2^3*x3*f0*f5*f6*f7*
f3+24*x2^2*x1*x4*f4^2*f5^2*f3-52*x2^2*x4^2*f4^3*f7*f5-20*x2^3*x1*f7*f1*f5*f2*
f4-4*x2^4*f4^3*f1*f7-32*x2^3*x3*f0^2*f7^3-44*x2^2*x4*x5*f4^2*f2*f7-4*x2^4*f3*
f5*f1*f4*f7+16*x2^3*x1*f7^2*f0*f3*f2+12*x2^2*x3*x5*f5*f4^2*f3-80*x2^2*x3*x7*f0
*f6*f5*f7-16*x2^3*x1*f1*f6*f4^3-32*x2^3*x1*f5*f0^2*f7^2-32*x2^3*x7*f2*f7*f4^2+
16*x2^4*f0*f4*f7^2*f2-6*x2^4*f7^2*f1^2*f4-48*x2^2*x1*x3*f7*f0*f4^2*f5-24*x2^2*
x1*x3*f3^2*f6*f4^2+16*x2^2*x1*x5*f7*f1^2*f5-8*x2^3*x1*f0*f5^3*f4+8*x2^3*x1*f3*
f5^2*f2*f4+24*x2^2*x3*x4*f5^2*f7*f3^2+8*x2^2*x1*x3*f4*f5^3*f1+16*x2^3*x3*f4^2*
f6*f2*f5-16*x2^3*x5*f0*f4^2*f7+12*x2^3*x3*f5*f4^4+16*x2^2*x3^2*f2*f6^2*f4^2-8*
x2^3*x3*f4^3*f3*f6-20*x2^2*x6^2*f7*f1*f4+8*x2^3*x6*f7^2*f1^2-16*x2^2*x3*x6*f0*
f7^2*f3-16*x2^3*x4*f0*f5^3*f7+4*x2^2*x4^2*f7*f2*f5^3+32*x2^2*x3^2*f1*f6*f4^2*
f7-48*x2^2*x1*x4*f7^2*f0*f4*f3+16*x2^2*x3^2*f2*f6*f0*f7^2+12*x2^2*x1*x5*f3^2*
f4^2+80*x2^2*x3*x4*f1*f4^2*f7^2-16*x2^4*f6*f0^2*f7^2+8*x3*x1*x5*x7*f4^3-40*x3*
x1*x6*x7*f3*f5^2-28*x3*x1*x6^2*f7*f1*f4+8*x3*x1*x5*x6*f2*f4*f5-24*x3*x1*x5*x6*
f3^2*f5+48*x3*x1*x4*x7*f5^2*f6*f3+16*x3*x1*x2*x8*f7*f0*f5*f6+44*x3*x1*x6^2*f3*
f5*f4-48*x3*x1*x6*x7*f6^2*f1-8*x3*x1*x5*x7*f6*f1*f5+208*x3*x1*x4*x7*f7*f6*f1*
f5-24*x3*x1*x5^2*f3*f1*f6+72*x3*x1*x4^2*f7^3*f2*f1-24*x3*x1*x4*x5*f1*f6*f5^2-\
32*x3^2*x1*x2*f0*f5*f6*f7*f3-664*x3*x1*x4^2*f7^2*f1*f6*f3+72*x3*x1*x4*x7*f7^2*
f2*f3+4*x3*x1*x5*x7*f3*f5*f4+16*x3*x1^2*x6*f2*f6^2*f1+8*x3*x1*x2*x8*f7*f1*f4*
f6+12*x3^2*x1^2*f3^3*f4*f7+48*x3*x1*x4*x5*f0*f5^2*f7+8*x3*x1^2*x5*f3^2*f4^2-32
*x3*x1*x6*x7*f5*f4^2-12*x3*x2*x5^2*f1*f5^2+300*x4^3*x2*f4*f7^2*f3*f5+388*x4^3*
x1*f1*f5^2*f7^2-124*x4^2*x5*x6*f1*f7^2-36*x4^2*x1*x5*f3*f5^3+432*x4^2*x3*x7*f5
^2*f6^2+168*x4^3*x5*f7*f4*f5^2-288*x4^2*x3*x6*f6*f5^3+20*x4^2*x2*x8*f7^2*f4^2-\
108*x4^2*x5*x8*f7*f5^2-1264*x4^2*x3*x5*f0*f6*f7^2+96*x4^3*x3*f3*f6^2*f5*f7-80*
x4^2*x2*x7*f3*f7*f5*f6-108*x4^2*x1*x6*f5^3*f4-160*x4^3*x3*f3*f6*f7^2*f4+272*x4
^3*x3*f2*f6*f5*f7^2+4*x4^4*f7^2*f4^2*f6-192*x4^2*x1*x7*f0*f6*f7^2-8*x4^3*x2*f6
*f7^2*f3^2-32*x4^2*x3*x5*f2*f7^2*f4-276*x4^4*f7^2*f5^2*f4+216*x4^3*x2*f5^4*f6-\
792*x4^3*x5*f7^3*f0+20*x4^3*x6*f4^2*f7^2+432*x4^3*x3*f6^2*f5^3-72*x4^2*x3*x7*
f7^3*f1-40*x4^2*x5*x7*f7^2*f2+296*x4^2*x3*x6*f7^2*f6*f1-144*x4^2*x3*x6*f3*f7*
f5*f6+332*x4^2*x1*x5*f7^2*f1*f3-196*x4^2*x6*x7*f7*f5^2+124*x4^4*f7^3*f2*f5+208
*x4^2*x7^2*f7*f5*f6+176*x4^2*x1*x5*f5*f6*f0*f7+316*x4^2*x1*x6*f7*f2*f5^2+100*
x4^2*x3*x5*f3*f5^2*f7+100*x4^2*x3*x5*f5*f7*f4^2-20*x4^2*x6*x7*f3*f7^2-24*x4^3*
x2*f4^3*f7^2+576*x4^4*f7*f6*f5^3+1712*x4^3*x3*f0*f6*f7^3-48*x4^3*x5*f7*f3*f5*
f6-152*x4^3*x5*f7^2*f2*f5+120*x4^3*x3*f5^4*f7+144*x4^2*x3*x7*f4*f7*f5*f6+176*
x4^3*x1*f2^2*f7^3+216*x4^2*x2*x7*f6*f5^3-280*x4^3*x3*f1*f5*f7^3-16*x4^2*x6*x8*
f7^2*f4-48*x4^2*x3*x6*f5^2*f7*f4+68*x4^2*x3*x5*f7^2*f3^2-136*x4^3*x3*f5*f7^2*
f4^2+172*x4^2*x2*x6*f3*f5^2*f7+96*x4^2*x2*x6*f5*f7*f4^2-28*x4^2*x1*x7*f3*f5^2*
f7-44*x4^2*x1*x7*f5*f7*f4^2+48*x4^3*x7*f7^2*f3*f6+600*x4^3*x7*f7*f6*f5^2+12*x5
*x1*x2*x7*f4^2*f3+4*x5*x1*x6*x8*f7*f1-4*x5*x1*x2*x8*f7*f1*f4+12*x5^2*x1*x4*f2*
f4*f5-8*x5*x1*x2*x8*f7*f0*f5+4*x5^2*x2^2*f7*f0*f3-32*x5^3*x3*f0*f6-8*x5^2*x2*
x6*f2*f4-8*x5^2*x3*x6*f7*f0-8*x5^2*x3*x6*f2*f5-8*x5^2*x2*x7*f7*f0+4*x5*x2^2*x7
*f4^3+12*x5*x1*x6^2*f3^2-2*x5^2*x3^2*f4^3+36*x4^2*x5*x6*f5^3-4*x6^3*x5*f3+12*
x6^2*x7*x8*f7-8*x6^3*x2*f4^2+24*x6^2*x3*x7*f5^2-8*x6^3*x7*f5-24*x6^3*x4*f5^2-4
*x4^3*x1*f2*f5*f7^2*f4-44*x4^2*x3*x7*f4^2*f7^2-32*x4^2*x2*x8*f5*f7^2*f3+144*x4
*x1^2*x7*f1*f6*f7*f3-56*x4*x1^2*x6*f7*f2*f3*f4+24*x4*x1^2*x6*f1*f5^3+32*x4^2*
x1*x3*f4*f6^2*f1*f7-96*x4*x1^2*x6*f0*f6*f5^2+192*x4*x1*x6*x7*f7*f2*f5-96*x4*x1
*x6*x7*f0*f7^2+4*x4*x1*x3*x6*f5*f7*f3^2+48*x4*x1*x5*x7*f6*f2*f5+192*x4^2*x1*x8
*f7^3*f0+144*x4*x1^2*x6*f2*f5*f3*f6+432*x4^2*x1^2*f3*f1*f5*f6*f7-24*x1^2*x2*x4
*f5^2*f6*f2^2+16*x1^2*x2*x7*f1*f5*f7*f2+64*x1^2*x2*x7*f0*f6*f7*f2-32*x1^3*x7*
f6^2*f1^2+96*x1^2*x2*x4*f0*f5^4-8*x1^3*x5*f2^3*f6+12*x1^3*x4*f5^3*f2^2-104*x1^
2*x3*x4*f5^2*f7*f3*f1+96*x1^2*x3*x4*f4^2*f5*f2*f6+4*x1^2*x3^2*f3*f6*f7*f2^2-16
*x1^3*x6*f7*f4*f1^2+16*x1^2*x2*x3*f0*f6*f7*f4*f2-28*x1^2*x2*x3*f5^2*f2*f3*f4+
32*x1^3*x2*f5^2*f0^2*f7-144*x1^2*x2*x4*f0*f4*f7^2*f2-16*x1^3*x5*f0*f6*f5*f1+88
*x1^2*x3^2*f0*f6*f5^2*f4-24*x1^2*x3^2*f4*f5*f2*f3*f6+72*x1^2*x2*x4*f7^2*f4*f1^
2+64*x1^3*x3*f0*f6^2*f3^2+16*x1^2*x3*x4*f0*f6*f7^2*f1-24*x1^2*x2*x5*f7*f0*f3^2
+8*x1^2*x3*x6*f4^2*f2*f5+40*x1^2*x3*x6*f5^2*f2*f3-32*x1^3*x7*f0*f6*f4^2+40*x1^
3*x4*f0*f4^3*f7+12*x1^3*x4*f4^3*f2*f5-48*x1^3*x4*f0*f6*f5^2*f3+16*x1^3*x6*f0*
f4*f7*f2-4*x1^4*f3*f7*f2^3+16*x1^2*x4*x7*f7*f4^2*f2-120*x1^2*x4*x7*f7*f2*f3*f5
-8*x1^2*x2*x7*f5*f6*f2^2+32*x1^3*x4*f7^2*f3*f1^2+96*x1^3*x4*f4*f5*f1*f6*f3+28*
x1^3*x4*f3^2*f7*f2*f4+4*x1^4*f0*f3^2*f5^2-12*x1^2*x3*x4*f7^2*f5*f1^2-16*x1^2*
x3*x7*f2^2*f6^2+56*x1^2*x4*x5*f4*f7*f3*f1-16*x1^2*x2^2*f0*f5*f4*f7*f2-12*x1^2*
x2^2*f5*f4*f7*f1^2+16*x1^2*x2*x5*f7*f0*f4*f2-24*x1^2*x2*x5*f7*f0*f5*f1+56*x1^2
*x4*x5*f6*f7*f1^2+16*x1^3*x2*f0*f5*f4^3-32*x3^3*x1*f3*f6^3*f1-192*x3^2*x2*x5*
f0*f5*f6^2+52*x3^2*x4*x8*f7*f5^3+48*x3^2*x4*x8*f7^2*f3*f5+16*x3^2*x4*x8*f7^2*
f2*f6-72*x3^2*x4^2*f7^3*f4*f1+28*x3^2*x2*x6*f4^2*f7*f3-12*x3^2*x2*x7*f3*f7^2*
f2+24*x3^2*x1*x7*f3*f6*f2*f7+32*x3^2*x1*x7*f5*f6^2*f1+52*x3^2*x2*x6*f5^2*f7*f1
-32*x3^3*x4*f3^2*f6^2*f7+168*x3^2*x2*x4*f4^2*f5^2*f6+136*x3^2*x4*x8*f7*f4*f5*
f6+176*x3^3*x4*f0*f6*f5*f7^2+8*x3^3*x5*f3^2*f5*f7-28*x3^2*x7^2*f3*f6*f7-16*x3^
4*f1*f6*f7^2*f3+8*x3^3*x8*f7^2*f3*f4-4*x2*x5*x3^2*f1*f7*f4*f5-120*x3^2*x1*x4*
f5^3*f6*f2-32*x3^2*x2*x6*f4*f6^2*f2-20*x3^3*x1*f4*f5^2*f1*f7+32*x3^2*x1*x7*f0*
f4*f7^2-20*x3^2*x1*x5*f7*f4^2*f1+32*x3^3*x4*f6^2*f7*f4*f2-24*x3^3*x4*f4^2*f5^2
*f7-16*x3^3*x2*f0*f7^3*f2-32*x3^3*x6*f0*f6^2*f7-16*x3^3*x6*f4*f6*f2*f7-24*x3^2
*x5^2*f6*f1*f5-672*x3^2*x4*x5*f0*f6^2*f7-80*x3^2*x4*x5*f5^2*f7*f2+16*x3^3*x2*
f1*f4^2*f7^2-80*x3^2*x2*x4*f2*f7*f5^3-32*x3^2*x4^2*f4^2*f6*f7*f5-16*x3^2*x2*x6
*f0*f4*f7^2-68*x3^2*x2*x6*f4^2*f5^2+32*x3^3*x1*f3*f5*f6^2*f2-8*x3^2*x2*x6*f4^3
*f6-144*x3^2*x4*x6*f4*f6*f5^2-16*x3^4*f3^2*f5*f6*f7+56*x3^2*x1*x7*f4*f6*f1*f7+
48*x3^2*x2*x6*f1*f5*f6^2+52*x6^2*f7*f2*x3^2*f5-16*x3^2*x6^2*f7*f3*f4-240*x3^2*
x4*x6*f7*f5*f2*f6+120*x3^2*x4*x7*f5^3*f6+40*x3^2*x1*x7*f4^2*f5^2+144*x3^2*x1*
x4*f0*f7^3*f2+20*x3^2*x1*x7*f5^3*f3+8*x3^2*x6*x8*f7^2*f2+8*x3^2*x4*x6*f7^2*f5*
f1+24*x3^4*f0*f6*f4*f7^2+24*x3^2*x4*x8*f7^3*f1+40*x3^2*x7*x8*f7*f4*f6-148*x3^2
*x2*x4*f4*f5^2*f7*f3+32*x3^2*x4*x8*f7^2*f4^2-20*x3^3*x4*f4^2*f7^2*f3+96*x3^3*
x4*f4^2*f5*f6^2-32*x3^3*x6*f5^3*f4+56*x3^2*x2*x7*f4^2*f6*f5-12*x5*x6*f7*f1*x3^
2*f5-8*x3^2*x1*x7*f6*f3*f4*f5+8*x3^2*x1*x8*f7*f2*f4*f6-36*x3*x1*x4*x8*f7^2*f1*
f5-96*x3*x1*x4*x7*f0*f6^2*f7+12*x3*x1^2*x5*f3^3*f5-24*x3^2*x1^2*f7*f4^2*f2*f3+
72*x3*x1*x4^2*f5^3*f3*f6+364*x3*x1*x4^2*f7^2*f3*f2*f5+24*x3*x1^2*x6*f3^3*f6-16
*x3*x1*x4*x5*f4^2*f2*f7-128*x3^2*x1*x6*f0*f6^2*f5-8*x3^2*x1*x2*f4^2*f3^2*f7-16
*x3^2*x1*x6*f7*f6*f2^2+32*x3^2*x2*x5*f0*f6*f4*f7+32*x3*x2*x5*x7*f7*f0*f6-60*x2
*x3*x4*x5*f4*f5*f7*f2-32*x2*x3*x4^2*f3*f6*f2*f7^2-184*x3*x2*x4^2*f5^3*f7*f3-40
*x3*x2*x6*x7*f7*f1*f6+56*x3*x2*x6*x7*f0*f7^2+432*x3*x2*x4^2*f5^3*f6*f4+76*x3*
x2*x4*x8*f7*f4*f5^2+152*x3*x2*x4*x6*f4*f7*f3*f5-376*x2*x3*x4^2*f4*f6*f1*f7^2-\
40*x3*x2*x6^2*f7*f1*f5-24*x2^2*x3*x4*f3*f5*f2*f6*f7+640*x2*x3*x4^2*f0*f6*f5*f7
^2+8*x3*x2*x5^2*f2*f4*f5-24*x3*x2*x6^2*f3*f6*f4-8*x3*x2^2*x5*f0*f5*f7*f4-16*x3
*x1^2*x5*f2*f6*f3^2+64*x3*x1*x4*x7*f7^2*f1*f4-92*x3*x1*x4*x7*f7*f3*f5*f4-16*x3
*x1*x7^2*f6^2*f2+24*x3*x1*x7^2*f4*f5^2+96*x3*x1*x6^2*f0*f6^2-144*x3*x1*x4*x6*
f2*f6*f7*f3-256*x3*x1*x4*x6*f0*f7^2*f4-16*x3*x1*x5*x7*f7*f2*f3+48*x3*x1*x2*x5*
f6*f7*f1^2-8*x3*x1^2*x6*f1*f6*f4^2-20*x3*x1^2*x5*f1*f5^2*f3+16*x3*x1*x2*x6*f1*
f6*f7*f2-16*x3*x1*x2*x6*f5^3*f1-32*x3*x1*x4*x5*f7*f6*f2^2+144*x3*x1*x4^2*f7^2*
f6*f2^2-8*x3^2*x1*x5*f5^3*f1-96*x3*x1^2*x5*f7*f4*f0*f3+24*x3*x1^2*x5*f7*f2*f1*
f4+80*x3*x1*x5*x6*f7*f0*f4+4*x3^2*x1*x5*f3^3*f7+4*x3^2*x1*x5*f4^4+16*x3^2*x2*
x4*f0*f3*f7^3-8*x3*x2*x5^2*f7*f0*f4+32*x3*x2*x1*x5*f7*f0*f3*f5-16*x3*x2^2*x5*
f5^2*f2*f4-16*x3*x2^2*x5*f3*f6*f0*f7-32*x3^2*x2*x5*f4*f6*f5*f2+96*x2*x3*x4*x5*
f0*f4*f7^2+8*x2*x3*x4*x5*f3^2*f5*f7-672*x2*x3*x4*x5*f0*f6*f5*f7+208*x2*x3*x4*
x5*f4*f6*f1*f7-12*x2*x3*x4*x5*f4^2*f7*f3-32*x3*x2^2*x6*f4*f6*f5*f2-32*x3^2*x2*
x6*f5^2*f6*f2-136*x3*x2*x4*x6*f0*f5*f7^2+8*x3*x2*x4*x6*f3^2*f7*f6+16*x3*x2*x4*
x6*f3*f7^2*f2+4*x3*x2*x5*x6*f7*f1*f4-24*x3*x2*x5*x6*f3*f5*f4+16*x3*x2*x6^2*f6*
f2*f5+24*x2^2*x3*x7*f5^2*f1*f7+48*x2^2*x3*x7*f4*f6*f1*f7-8*x2^2*x3*x7*f3*f6*f2
*f7+164*x3*x2*x4*x7*f7^2*f5*f1-128*x3*x2*x4*x7*f5^2*f7*f3+56*x3*x2*x4*x7*f4*f6
*f3*f7+288*x3*x2*x4*x7*f4*f6*f5^2-304*x3*x2*x4*x7*f0*f6*f7^2-88*x3*x2*x4*x7*f4
^2*f5*f7+16*x3^2*x2^2*f0*f6^2*f7*f3-12*x3^2*x2^2*f4*f5^3*f3-196*x3*x2*x4^2*f4^
2*f5^2*f7-20*x2*x3*x4^2*f3^2*f5*f7^2+100*x2*x3*x4^2*f5^2*f1*f7^2-216*x2*x3*x4^
2*f0*f4*f7^3-224*x3*x2*x4^2*f5^2*f7*f2*f6-24*x2^2*x3*x4*f5*f7^2*f2^2+220*x2*x3
*x4^2*f4*f5*f7^2*f2+32*x2*x3*x4^2*f4^2*f7^2*f3+80*x2*x3*x4^2*f3*f7^3*f1+16*x3^
2*x2^2*f0*f6*f5*f7*f4+12*x3*x2*x4*x8*f7^2*f3*f4+168*x3*x2*x4^2*f4*f6*f7*f3*f5-\
20*x3*x2*x7^2*f7*f3*f5+8*x3^2*x2*x8*f7*f3*f5^2+8*x3*x2^2*x6*f3*f6*f1*f7-56*x2*
x3*x4^2*f2^2*f7^3+28*x3*x2*x7*x8*f7*f4*f5+48*x3*x2*x6^2*f7*f0*f6+96*x3*x2*x5^2
*f0*f5*f6+12*x3*x2*x5*x7*f7*f2*f4+16*x3*x2*x4*x8*f7*f3*f5*f6+24*x3*x2*x4*x8*f7
^2*f2*f5+144*x3*x2*x4*x8*f7^3*f0-48*x3*x2*x5*x8*f7^2*f0-12*x3*x2*x6*x8*f7*f3*
f5-8*x3*x2^2*x8*f7^2*f1*f4-32*x3^2*x1*x6*f1*f6^2*f4+24*x3^2*x1*x6*f6*f4^2*f3+
16*x3^2*x1*x6*f5^2*f1*f6+56*x3^2*x1*x6*f3*f6*f1*f7-240*x3*x1*x4*x6*f0*f6*f7*f5
-16*x3*x1*x4*x6*f1*f6*f7*f4+168*x3*x1*x4*x6*f2*f5*f7*f4+36*x3*x1*x4*x6*f7*f4^2
*f3-144*x3*x1*x4*x6*f1*f6^2*f5+72*x3*x1*x4*x6*f4*f6*f3*f5+124*x3*x1*x4*x6*f1*
f5^2*f7+124*x3*x1*x4*x6*f1*f7^2*f3-24*x3*x1*x6^2*f6*f3^2+8*x3*x1*x5*x6*f1*f4*
f6-12*x3*x1*x5*x6*f4^2*f3-24*x3*x1^2*x7*f4*f5^2*f2+80*x3*x1^2*x7*f0*f6*f7*f3-\
40*x3*x1^2*x7*f3^2*f6*f4+96*x3*x1^2*x7*f6^2*f1*f3-8*x3*x1^2*x7*f5^3*f1+12*x3*
x1^2*x7*f3^3*f7-36*x3*x1*x2*x7*f3^2*f7*f4-24*x3*x1*x2*x7*f4^2*f6*f3+48*x3*x1*
x2*x7*f1*f6^2*f4+96*x3*x1*x2*x7*f0*f5^2*f7+288*x3*x1*x4*x7*f0*f5*f7^2+144*x3*
x1*x4*x7*f5^3*f4-12*x3*x1*x4*x7*f7*f4^3-96*x3*x1*x4*x7*f2*f6^2*f5-48*x3*x1*x6*
x7*f7*f0*f6+44*x3*x1*x6*x7*f7*f1*f5+32*x3^2*x1*x8*f7*f0*f6^2+8*x3*x1*x4*x8*f7*
f6*f2*f5-4*x3*x1^2*x6*f4^3*f3+4*x3*x1^2*x5*f2^2*f5^2+8*x3*x1*x5^2*f2*f3*f5+4*
x3*x1*x2*x6*f3^3*f7+12*x1^2*x2^2*f3^2*f7*f4*f1-4*x1^3*x2*f3*f5^2*f2^2+4*x1^3*
x2*f7*f3^3*f1+4*x1^3*x2*f4^2*f3^3-4*x1^3*x2*f3^4*f5-4*x1^3*x2*f4^4*f1+4*x1^3*
x2*f3*f4^3*f2-4*x1^3*x2*f3*f5*f1*f4^2-4*x1^3*x2*f5*f3*f7*f1^2+20*x1^2*x3^2*f3^
2*f5*f7*f2-12*x1^2*x3^2*f5^3*f1*f4+20*x1^2*x3^2*f7*f4^3*f1+4*x1^3*x3*f4^4*f2-4
*x1^3*x3*f4*f5^2*f3*f1+4*x1^3*x3*f7*f3^3*f2-4*x1^3*x3*f4^2*f2*f3*f5-16*x1^2*x3
^2*f4^2*f5^2*f2+76*x1^2*x2*x4*f3^2*f5*f7*f2+4*x1^2*x2*x3*f1*f2^2*f7^2-4*x1^2*
x2*x3*f3^2*f5*f1*f7+12*x1^2*x2*x3*f3*f5*f7*f2^2+36*x1^2*x2*x3*f3^2*f7*f2*f4-24
*x1^2*x2*x4*f7*f4^3*f1+16*x1^2*x3*x5*f4^2*f1*f5-16*f7^2*x8^2*x3*x4*f5+12*f7^2*
x4*x8^2*x6-8*x7^2*x1*x4*f7*f4^2+4*x5*x7^2*x6*f5+4*x2*x7^2*x3*f5^3-4*x2*x7^2*x6
*f5^2+2*x2^2*x7^2*f4*f5^2-8*x7^2*x1^2*f5^2*f2+8*x2^2*x1*x4*f7^2*f1*f3^2+20*x2^
3*x4*f3^2*f5*f4*f7-44*x2^3*x4*f2*f5*f4^2*f7-12*x2^3*x4*f3*f5^2*f7*f2-16*x2^3*
x4*f6*f7^2*f1^2-32*x2^3*x4*f7^2*f3*f0*f5+16*x2^3*x4*f0*f7^3*f1+48*x2^3*x4*f0*
f4^2*f7^2-16*x2^3*x4*f4^3*f3*f7-16*x2^3*x4*f2^2*f7^2*f4+48*x2^2*x3*x4*f4^3*f5*
f6-96*x2^2*x3*x4*f1*f6*f5*f7*f4+64*x2^2*x3*x4*f0*f6*f7^2*f3+88*x2^2*x3*x4*f7*
f4^2*f2*f6+192*x2^2*x3*x4*f0*f6*f5^2*f7+80*x2^2*x3*x4*f2*f0*f7^3-64*x2^2*x1*x5
*f0*f7*f2*f5+12*x2^3*x5*f1*f5^2*f4-8*x2^3*x5*f5*f2*f4^2-8*x2^3*x5*f0*f7^2*f1-\
16*x2^2*x3*x5*f2*f0*f7^2-16*x2^2*x3*x5*f2*f6*f4^2-24*x2^3*x6*f7*f4*f0*f5-16*x2
^3*x6*f0*f7^2*f2-80*x2^2*x3*x6*f0*f6*f7*f4+24*x2^2*x3*x6*f6*f4^2*f3+44*x2^2*x3
*x6*f1*f4*f5*f7-48*x2^2*x4*x6*f5^2*f4^2-136*x2^2*x4*x6*f0*f7^2*f4+40*x2^2*x4*
x6*f7*f4^2*f3-16*x2^2*x4*x6*f1*f7^2*f3-40*x2^2*x1*x7*f4^2*f6*f2+64*x2^2*x1*x7*
f7*f3*f1*f5+16*x2^2*x3*x7*f4^3*f6+64*x2^2*x3*x7*f0*f4*f7^2-40*x2^2*x3*x7*f4^2*
f7*f3-144*x2^2*x4*x7*f7*f3*f5*f4+168*x2^2*x4*x7*f0*f5*f7^2-4*x2^4*f1*f4*f5^3-4
*x2^4*f4^3*f5*f3+4*x2^4*f0*f5^2*f7*f3-24*x2^2*x1*x7*f7*f2^2*f5+32*x2^3*x1*f0*
f4*f7^2*f1+12*x2^3*x1*f4^2*f7*f2^2+48*x2^3*x1*f0*f6*f5*f4^2-12*x2^3*x1*f3^2*f5
*f4^2+6*x2^2*x3^2*f2^2*f7^2*f4-24*x2^2*x3^2*f1*f5^2*f7*f4-20*x2^2*x3^2*f2*f5*
f4^2*f7-12*x2^2*x3^2*f3^2*f5*f4*f7-24*x2^2*x3^2*f3*f6*f5*f4^2-20*x2^2*x3^2*f4^
3*f7*f3+32*x2^2*x1*x3*f3*f5*f2*f4*f6-16*x2^2*x1*x3*f0*f5^4+16*x2^2*x1*x3*f7*f4
^2*f2*f3+96*x2^2*x1*x3*f0*f6^2*f4^2+32*x2^3*x3*f2*f5*f0*f7^2-24*x2^3*x3*f1*f5^
2*f6*f4+16*x2^3*x3*f0*f4*f7^2*f3-12*x2^3*x3*f3*f5^2*f4^2+32*x2^3*x3*f0*f6*f4^2
*f7-176*x2^2*x4^2*f7*f5^2*f3*f4+108*x2^2*x4^2*f4^2*f6*f5^2+88*x2^2*x4^2*f7^3*
f0*f3+4*x2^2*x4^2*f7^2*f1*f4*f5-120*x2^2*x1*x4*f4^2*f6*f2*f5+24*x2^2*x1*x4*f7*
f2*f4^3+12*x2^2*x3*x5*f7^2*f1^2+4*x2^2*x4*x8*f7*f3*f5^2+12*x2^2*x4*x8*f7*f5*f4
^2-12*x2^2*x1*x3*f4^2*f5^2*f2+16*x2^3*x6*f7*f4^2*f1-4*x2^4*f2*f7^2*f1*f3+4*x2^
4*f4^2*f5^2*f2+24*x2^2*x3^2*f0*f5^3*f7+48*x2^2*x3^2*f7^2*f3*f0*f5-24*x2^2*x1*
x3*f7*f4^3*f1+48*x2^2*x3*x5*f4*f6*f1*f5-8*x2^3*x8*f7^2*f0*f4+16*x2^2*x1*x6*f4^
2*f2*f5-12*x2^2*x1*x6*f5^2*f1*f4-96*x2^2*x3*x5*f0*f6*f5^2+20*x2^2*x3*x6*f2*f7*
f4^2-48*x2^2*x3*x6*f0*f5^2*f7-12*x2^3*x3*f5*f7^2*f1^2+4*x2^4*f0*f3^2*f7^2+24*
x2^2*x4^2*f7^2*f1*f6*f3-20*x2^2*x3*x4*f4^4*f7+8*x2^4*f0*f5*f7^2*f1+104*x2^2*x4
^2*f7^2*f2*f4^2+48*x2^2*x1*x6*f1*f6*f4^2-8*x2^2*x3*x6*f5^3*f2+16*x2^3*x4*f3*f7
^2*f1*f4+8*x2^3*x3*f4*f5^3*f2+32*x2^3*x7*f1*f4*f5*f7-24*x2^2*x1*x6*f7^2*f0*f1-\
40*x2^2*x3*x6*f4^3*f5+64*x2^2*x7^2*f0*f7^2+4*x2^4*f0*f5^4+24*x2^2*x5^2*f0*f5^2
-8*x2^3*x6*f4^4+4*x2^2*x3^2*f4^4*f6+30*x2^2*x3^2*f4^3*f5^2+4*x3^2*x5^2*f5^2*f2
-4*x3*x1^2*x7*f4^4-24*x3^2*x6*x7*f5^3+64*x3^4*f0*f6^4+180*x3^2*x4^2*f5^4*f6-8*
x3^2*x4^2*f4^3*f7^2+8*x3^4*f4^3*f6^2+96*x3^2*x5^2*f0*f6^2+24*x3^3*x4*f5^5+36*
x3^2*x6^2*f4*f5^2+20*x3^2*x7^2*f6*f5^2+40*x3^2*x6^2*f0*f7^2+10*x3^4*f5^4*f4+4*
x3^2*x6^2*f4^2*f6-72*x3^2*x4*x6*f5^4+40*x3^2*x7^2*f6^2*f4+8*x3^2*x7^2*f2*f7^2+
8*x3^3*x7*f5^4+16*x3^2*x6^2*f6^2*f2+4*x3*x2^2*x5*f4^4-2*x3^2*x1^2*f4^5+68*x4^2
*x6^2*f2*f7^2+836*x4^4*f7^4*f0+108*x4^2*x1*x7*f5^4+108*x4^2*x6^2*f6*f5^2+304*
x4^2*x5^2*f0*f7^2+108*x4^3*x1*f5^5-38*x4^2*x7^2*f7^2*f4+72*x4*x3*x6^2*f5^3+36*
x4*x1*x7^2*f5^3-4*x5^3*x6*f1-12*x5*x1^2*x6*f3^3-16*x2^3*x5*f0*f5^3-48*x2^2*x1*
x5*f0*f6*f4^2-96*x2^2*x1*x6*f0*f6*f5*f4-30*x2^2*x4^2*f7^2*f3^2*f4+28*x2^3*x4*
f1*f5^2*f7*f4+48*x2^2*x4*x5*f1*f4*f5*f7+4*x2^2*x4*x5*f7*f3^2*f4+12*x2^2*x3*x8*
f7*f3*f5*f4-16*x2*x1*x3*x4*f7^2*f3^2*f2+72*x2*x1*x3*x4*f3*f7^2*f1*f4-32*x2*x1*
x3*x4*f2*f5*f7^2*f1-8*x2*x1*x3*x4*f4^2*f7*f1*f6-48*x2*x1*x3*x4*f5*f6*f7*f2^2+
136*x2*x1*x3*x4*f4*f6*f7*f2*f3-4*x2*x1*x3*x4*f7^2*f4*f2^2+72*x2*x1*x3*x4*f4^3*
f5^2+8*x2*x1^2*x5*f2*f1*f6*f4-8*x2*x1^2*x5*f3^2*f2*f5-8*x2*x1^2*x5*f0*f5*f4^2-\
12*x2*x1^2*x5*f3*f4*f1*f5-8*x2*x1^2*x5*f1^2*f7*f4-48*x2*x1^2*x5*f3*f0*f6*f4-8*
x2*x1^2*x5*f2*f1*f5^2+24*x2*x1^2*x5*f1^2*f6*f5+12*x2*x1*x3*x5*f7*f4*f2^2+4*x2*
x1*x3*x5*f3^2*f7*f2-128*x2*x1*x3*x5*f0*f6*f5*f4-40*x2*x1*x4*x5*f0*f5*f7*f4-96*
x2*x1*x4*x5*f0*f7^2*f2+40*x2*x1*x4*x5*f4^2*f1*f7+24*x2*x1*x4*x5*f5^3*f1+24*x2*
x1*x4*x5*f7^2*f1^2-48*x2*x1*x6^2*f1*f4*f6-20*x2*x1^2*x6*f5^2*f1*f3-40*x2*x1^2*
x6*f1*f4*f7*f2-12*x2*x1^2*x6*f3*f7*f2^2-32*x2*x1*x6^2*f7*f0*f4+56*x2*x1*x3*x6*
f4*f6*f1*f5+32*x2^2*x1^2*f0*f6*f5^2*f2+4*x2^2*x1^2*f3^2*f5^2*f2-6*x2^2*x1^2*f5
^2*f2^2*f4+4*x2^2*x1^2*f6*f3*f7*f1^2+20*x2^2*x1^2*f1*f4^2*f7*f2+8*x2^2*x1^2*f0
*f6*f4^3+48*x2^2*x1^2*f0*f6*f5*f3*f4+16*x2^2*x1^2*f3*f5^2*f4*f1+4*x2^2*x1^2*f1
*f5^3*f2-12*x2^2*x1^2*f3^3*f5*f4-24*x2^2*x1^2*f0*f5^3*f3+224*x2*x1*x3^2*f0*f5*
f6^2*f4-48*x2*x1*x3^2*f3*f6^2*f1*f5-8*x2*x1*x3^2*f1*f4*f7^2*f2+64*x2*x1*x3^2*
f4*f6*f1*f3*f7-24*x2*x1*x3^2*f4*f6*f7*f2^2+40*x2*x1*x3^2*f3*f5*f7*f2*f4-48*x2*
x1^2*x3*f0*f3*f2*f7^2+20*x2*x1^2*x3*f3*f5^3*f1+32*x2*x1^2*x3*f3*f7^2*f1^2+16*
x2*x1^2*x3*f3^2*f5*f2*f6-64*x2*x1^2*x3*f0*f5^2*f2*f7-24*x2*x1^2*x3*f4^2*f6*f3*
f2-48*x2*x1^2*x3*f6^2*f5*f1^2+8*x2*x1^2*x3*f1*f6*f5^2*f2+24*x2*x1^2*x3*f1*f4*
f6*f3*f5-16*x2*x1^2*x3*f2*f4*f1*f6^2+24*x2*x1^2*x4*f5^2*f3^2*f4-48*x2*x1^2*x3*
f0*f6*f5^2*f3+32*x2*x1*x3*x5*f0*f5^3+48*x2*x1*x3*x6*f3^2*f6*f4+96*x2*x1^2*x3*
f0*f6^2*f4*f3+48*x2*x1*x4*x7*f4^2*f5^2+96*x2*x1*x5*x6*f0*f6*f4+24*x2*x1*x4*x5*
f5*f7*f2^2+12*x2*x1*x6^2*f7*f2^2+24*x2*x1*x6^2*f4^2*f3-144*x2*x1*x4*x7*f0*f7^2
*f4-28*x2*x1*x4*x7*f5^2*f7*f1+192*x2*x1*x3*x4*f0*f6*f7^2*f2+672*x2*x1*x3*x4*f0
*f6*f5*f4*f7-32*x2*x1*x3*x5*f4*f6*f2*f3+64*x2*x1*x3*x6*f0*f7^2*f2+12*x2^2*x1*
x4*f4*f5^3*f2-12*x2^2*x1*x4*f3*f7^2*f2^2-64*x2*x1*x4*x5*f3*f7*f2*f4-12*x2*x1^2
*x3*f3^3*f5^2+12*x2^2*x1^2*f3*f4*f7*f2^2+688*x2*x1*x4^2*f0*f6*f5^2*f7+208*x2*
x1*x4^2*f4*f6*f1*f5*f7-8*x2^2*x1^2*f2*f6*f4*f1*f5+48*x2*x1*x6^2*f0*f5*f6-12*x2
^2*x1^2*f6*f5^2*f1^2-32*x2*x1*x5*x6*f0*f5^2-12*x2*x1*x3^2*f4^3*f7*f2-8*x2^2*x1
*x3*f3^2*f6*f1*f7-64*x2*x1^2*x5*f5*f6*f0*f2+12*x2*x1^2*x5*f3^3*f4-8*x2*x1*x7^2
*f6*f2*f5+8*x2^2*x1*x5*f0*f5^2*f4-24*x2*x1*x3*x7*f3*f7*f2*f5+24*x2*x1*x3*x5*f3
^2*f5*f4+8*x2^2*x1^2*f7^2*f2*f1^2+24*x2*x1*x4*x7*f5^3*f3-24*x2*x1^2*x3*f4*f6*
f3^3+28*x2*x1^2*x3*f3^2*f5*f4^2+32*x2*x1^2*x6*f0*f5*f7*f2+48*x2*x1^2*x4*f4^2*
f3*f7*f2+128*x2*x1^2*x3*f0*f6^2*f5*f2+8*x2*x1^2*x6*f5*f6*f1*f2+32*x2*x1*x3^2*
f3*f5^2*f6*f2-12*x2*x1^2*x5*f3*f4^2*f2+16*x2*x1*x4*x8*f7^2*f2*f3-16*x2*x1^2*x6
*f0*f6*f4^2-76*x2*x1*x3*x6*f4^2*f3*f5-8*x2^2*x1*x6*f3*f7*f1*f4+4*x2*x1*x3^2*f3
^2*f7^2*f1-4*x2*x1^2*x3*f5^3*f2^2+4*x2*x1^2*x3*f4^4*f3-20*x2*x1*x3^2*f4*f5^3*
f2+56*x2*x1*x3^2*f4^2*f5^2*f3+4*x2^2*x1*x3*f4^5-32*x2*x1*x3*x6*f7*f5*f2^2-32*
x2*x1*x3*x6*f3*f6*f2*f5-32*x2*x1*x3*x6*f0*f6*f5^2+24*x2*x1*x3*x6*f3^2*f5^2-192
*x2*x1*x3*x6*f0*f6^2*f4+64*x2*x1*x3*x6*f4^2*f6*f2-48*x2*x1*x3*x6*f7*f3*f4*f2-\
72*x2*x1*x4*x6*f5^2*f1*f6+240*x2*x1*x4*x6*f4*f5*f2*f6-304*x2*x1*x4*x6*f0*f6*f7
*f4+152*x2*x1*x4*x6*f4*f5*f1*f7-12*x2*x1*x4*x6*f3*f7*f2*f5+72*x2*x1*x4*x6*f3^2
*f7*f4-12*x2*x1*x6^2*f3^2*f5+16*x2*x1^2*x7*f3^2*f7*f2+16*x2*x1^2*x7*f1*f0*f7^2
-32*x2*x1^2*x7*f0*f6*f5*f4+8*x2*x1^2*x7*f3^2*f5*f4-16*x2^2*x1*x7*f0*f6*f7*f3-\
80*x2*x1*x3*x7*f4*f5*f2*f6-16*x2*x1*x3*x7*f4^2*f2*f7-32*x2*x1*x3*x7*f2^2*f6*f7
+528*x2*x1*x4*x7*f0*f6*f7*f5+64*x2*x1*x4*x7*f4*f6*f1*f7-56*x2*x1*x4*x7*f4*f5*
f2*f7-48*x2*x1*x4*x7*f5^2*f6*f2+80*x2*x1*x6*x7*f2*f4*f6-24*x2*x1*x6*x7*f6*f1*
f5+4*x2*x1*x3*x8*f7*f2*f4*f5+8*x2*x1*x3*x8*f7*f2*f3*f6+4*x2*x1*x4*x8*f7^2*f1*
f4+8*x2*x1*x4*x8*f7^2*f0*f5+4*x2*x1*x4*x8*f7*f5^2*f2-144*x4*x1^2*x6*f7*f6*f0*
f3+60*x4*x1*x6^2*f3*f5^2+24*x4*x1*x6^2*f7*f2*f4-48*x4*x1^2*x6*f1*f6*f5*f4-12*
x4*x1^2*x7*f4^3*f5+72*x4*x1*x5*x6*f6*f1*f5-84*x4*x1*x2*x6*f4*f5^2*f3-32*x4^2*
x3^2*f6^2*f7*f3*f4+112*x4^2*x3^2*f5*f6^2*f7*f2-16*x4^2*x3^2*f5^3*f4*f7+336*x4*
x3*x5^2*f7*f0*f6-8*x4*x3*x1*x5*f1*f7^2*f2-24*x4*x3^2*x5*f4^2*f6*f5+124*x2*x4*
x6*x7*f7*f3*f5+4*x4*x2^2*x5*f1*f7^2*f2-4*x2*x4*x7^2*f7*f4*f5+24*x2*x4*x7*x8*f7
*f5^2+96*x4*x2*x6^2*f0*f7^2+4*x4*x1*x6*x8*f7^2*f1+72*x4^2*x1^2*f4*f6*f5^2*f2+
48*x4*x1*x5*x7*f7*f0*f6+88*x4*x1*x5^2*f7*f0*f4+64*x4*x1*x5*x6*f7*f0*f5-172*x4*
x1*x2*x7*f3^2*f5*f7-24*x4*x1*x7^2*f7*f2*f6+24*x4*x1^2*x6*f7*f1*f2*f6-48*x4*x1^
2*x6*f5^2*f3^2+8*x4^2*x1*x6*f4*f6*f2*f7-216*x4^2*x1*x6*f5*f6*f1*f7-88*x4^2*x1*
x8*f7^2*f2*f5-96*x4*x3*x2*x6*f4^2*f6*f5-176*x4*x3*x5*x6*f7*f1*f6-16*x4*x3*x5*
x6*f7*f3*f4-16*x3^2*x7*x4*f6*f7^2*f1+88*x4*x3*x5*x7*f7*f3*f5-16*x4*x3*x5*x8*f7
*f3*f6-68*x4*x3*x5*x8*f7*f4*f5-12*x4*x1^2*x7*f3^2*f4*f7+76*x2*x4*x5*x7*f7*f2*
f5+36*x4^2*x2*x3*f5^5-8*x2*x4^2*x3*f4^3*f7*f6+168*x2*x4*x5^2*f7*f0*f5-8*x2*x4*
x5*x8*f7*f3*f5+24*x4*x2*x3*x7*f3^2*f7^2+24*x4*x2*x3*x5*f4^2*f5^2+36*x4*x1^2*x6
*f3^3*f7-72*x4*x1*x6*x7*f4*f5^2-28*x4*x1*x5*x7*f7*f3^2-40*x4*x1*x7*x8*f2*f7^2-\
108*x4^2*x1^2*f6*f5^2*f3^2+48*x4^2*x1*x2*f3*f5*f2*f6*f7-48*x4*x1^2*x7*f5^3*f2+
144*x4*x3*x7*x8*f7*f5*f6+76*x4*x3*x7*x8*f7^2*f4-112*x3*x4^2*x5*f7*f6*f5*f2+32*
x4^2*x3*x7*f6^2*f3*f7-40*x4*x3*x6*x7*f7*f4*f5-24*x4*x3*x5*x7*f5^3-28*x4*x3*x6*
x8*f3*f7^2+32*x3^2*x7*f7*f2*f6^2*x4+24*x3*x4*x7^2*f7*f4*f6-32*x4*x3*x7^2*f3*f7
^2-168*x4*x3*x2*x6*f7*f6*f4*f2-16*x4*x3*x6*x8*f7*f4*f6+16*x4*x3*x7^2*f7*f5^2-\
12*x4^2*x2^2*f2^2*f6*f7^2+8*x4^2*x2^2*f0*f6*f4*f7^2-52*x4*x2*x5^2*f7*f1*f4+12*
x4*x2^2*x5*f4^3*f5+8*x2*x4^2*x5*f4^3*f7-36*x4^2*x2*x6*f5^4-60*x2*x4*x6^2*f7*f2
*f5+72*x4*x2*x7^2*f6*f5^2+28*x1^2*x2*x6*f4*f5*f2*f3+96*x1^2*x2*x6*f0*f4*f3*f7-\
20*x1^2*x3*x6*f1*f5*f7*f2-40*x1^2*x3*x6*f7*f4*f2^2+60*x1^2*x3*x6*f4*f7*f3*f1-\
16*x1^2*x3*x6*f5*f6*f2^2-80*x1^2*x3*x6*f0*f7^2*f1+24*x1^3*x7*f1^2*f5*f7-16*x1^
3*x7*f4*f6*f2^2+24*x1^3*x7*f3*f7*f2^2+16*x1^3*x7*f0*f6*f7*f1-16*x1^3*x7*f0*f6*
f5*f3+96*x1^2*x3*x7*f0*f6*f5^2-24*x1^2*x4*x7*f7*f2^2*f6-128*x1^2*x4*x7*f7*f0*
f5^2-4*x2^3*x1*f7^2*f3*f1^2-4*x2^3*x1*f7*f5^2*f1^2-4*x2^3*x1*f7*f1*f5*f3^2+4*
x2^3*x1*f7*f3*f4^2*f1-4*x2^3*x1*f3*f5^3*f1-4*x2^3*x1*f4^3*f2*f5+4*x2^3*x1*f4^2
*f1*f5^2-8*x2^2*x3^2*f3^2*f7^2*f2-4*x2^2*x3^2*f1*f7^2*f2*f5+12*x2^2*x7^2*f4^2*
f6+12*x1^2*x2^2*f5*f7*f2^3-8*x1^2*x2^2*f4^3*f1*f5-8*x1^2*x3*x5*f4^3*f2-28*x1^2
*x4*x5*f3^2*f7*f2+4*x1^2*x4*x5*f7*f4*f2^2+4*x1^3*x6*f2^3*f7+4*x1^3*x6*f4^3*f1-\
4*x1^3*x6*f4*f3^3-84*x1^2*x3*x4*f3^2*f7^2*f1+4*x1^3*x5*f4^2*f2^2+4*x1^3*x5*f5*
f3*f2^2+4*x1^3*x5*f4^2*f3*f1-4*x1^3*x5*f7*f2^2*f1+4*x1^3*x6*f4*f5*f2^2-4*x1^3*
x6*f4^2*f2*f3-16*x1^2*x2*x6*f3^2*f7*f1-24*x1^2*x3*x6*f3^2*f7*f2+32*x1^2*x3*x7*
f1*f7*f4^2-52*x1^2*x3*x7*f3*f7*f1*f5-8*x1^2*x5*x7*f4^2*f2+12*x1^2*x5*x7*f1*f4*
f5-28*x1^2*x6*x7*f7*f2^2-12*x1^2*x2*x5*f7*f2^3+24*x1^2*x4*x6*f7*f1*f4^2+80*x1^
2*x4*x6*f7*f3*f1*f5-4*x1^2*x6^2*f1*f4*f5+4*x1^3*x7*f5^2*f2^2-4*x1^3*x7*f5^2*f3
*f1+4*x1^3*x7*f4^3*f2+4*x1^3*x7*f3^3*f5-2*x1^4*f4^3*f2^2+4*x1^3*x5*f3^4+12*x1^
2*x6^2*f2^2*f6+16*x1^2*x6^2*f0*f5^2+8*x1^2*x3^2*f2^3*f7^2+4*x1^4*f0*f4^4+4*x2^
2*x3^2*f2*f5^4+4*x2^2*x5^2*f4^2*f2+4*x2^2*x6^2*f5^2*f2-16*x2*x1*x3*x5*f4^2*f2*
f5-16*x2*x1*x3*x5*f5^2*f2*f3+4*x2*x1^2*x6*f5^2*f2^2-28*x2*x1*x3*x4*f4^3*f7*f3+
4*x2*x1^2*x5*f4^3*f1-12*x2*x1*x5^2*f3*f1*f5+8*x2*x1*x5^2*f2*f3*f4-4*x2^2*x1*x7
*f5^3*f1+184*x2*x1*x4*x7*f3*f7^2*f1-24*x2*x1*x4*x7*f4^2*f7*f3-64*x2*x1*x5*x7*
f7*f3*f1+8*x2*x1*x5*x7*f1*f5^2-8*x2*x1*x6*x7*f4^3+24*x2*x1*x6*x7*f7*f2*f3+4*x2
^2*x1*x5*f3^2*f7*f1-8*x2*x1*x3*x6*f4^4+40*x2*x1*x3*x6*f4*f5^2*f2+4*x2*x1*x6^2*
f7*f3*f1+8*x2*x1*x5*x6*f4^2*f2-24*x2*x1*x5*x6*f3^2*f4+8*x2*x1*x5*x6*f1*f4*f5+
16*x2*x1*x5*x6*f2*f3*f5+8*x2*x1*x7^2*f5*f4^2-4*x2*x1*x7^2*f7*f1*f5+4*x2*x1*x7^
2*f3*f5^2+4*x2*x1^2*x7*f4^3*f3-16*x2*x1*x3^2*f0*f6*f5^3-72*x2*x1*x4^2*f5^3*f6*
f2-20*x2*x1^2*x6*f4^2*f3^2+48*x2*x1^2*x5*f3*f0*f5^2-12*x2*x1*x4^2*f3^3*f7^2-48
*x2*x1*x3*x6*f7^2*f1^2-96*x2*x1*x4^2*f0*f7^3*f2-44*x2*x1*x4*x5*f3*f7*f1*f5-24*
x2*x1*x4*x6*f4^3*f5+8*x2*x1^2*x3*f4^3*f1*f6+8*x2*x1^2*x5*f2^2*f4*f5-164*x2*x1*
x3*x4*f3^2*f5*f7*f4+108*x2*x1*x3*x4*f3*f5^3*f4+48*x2*x1*x3*x4*f1*f0*f7^3-48*x2
*x1^2*x7*f4*f2*f3*f6+16*x2*x1*x5*x7*f7*f2^2+12*x2*x1^2*x6*f3^3*f5-36*x2*x1*x3*
x5*f3*f7*f1*f4+48*x2*x1*x3*x5*f5*f6*f1*f3-8*x2*x1*x3^2*f3^2*f6*f7*f2-56*x2*x1*
x3^2*f4^2*f6*f2*f5+16*x2*x1*x3^2*f4^4*f5-56*x2*x1*x3^2*f4^2*f1*f7*f5+32*x2*x1*
x3^2*f3*f6^2*f2*f4-48*x2*x1*x3^2*f3^2*f5*f6*f4+16*x2*x1^2*x7*f4^2*f1*f6+132*x2
*x1*x4^2*f3*f7^2*f2*f4-168*x2*x1*x3*x4*f5^2*f7*f1*f4+16*x3^3*x1*f5*f6*f7*f2^2-\
280*x3*x1*x4^2*f7*f2*f5^3-96*x3^2*x1*x5*f0*f6^2*f4+48*x3*x2*x1*x7*f0*f6*f4*f7-\
48*x3*x2*x6*x7*f4*f5^2+12*x3*x2*x6^2*f7*f2*f4+172*x3^2*x2*x4*f4*f5*f1*f7^2-208
*x2*x3^2*x4*f0*f6*f4*f7^2-8*x3^2*x2^2*f3*f5*f1*f6*f7+64*x2*x3*x4*x5*f5^2*f1*f7
+8*x2*x3^3*f5*f7^2*f2^2-152*x3*x2*x4*x7*f7*f5*f2*f6+48*x3^2*x2*x8*f7^2*f0*f6+
88*x3*x2*x4*x6*f5*f6*f1*f7+48*x3*x2*x7^2*f4*f5*f6-24*x2*x3*x4*x5*f3*f7^2*f1+32
*x3^2*x2*x8*f7*f5*f4^2+72*x3*x2*x5*x6*f7*f0*f5+32*x3^3*x2*f0*f6*f7^2*f3-24*x3*
x2*x5^2*f1*f4*f6+16*x3^3*x2*f2*f6*f5^3+44*x3*x2*x6^2*f5*f4^2+32*x3*x2*x6*x7*f7
*f3*f4+32*x3^2*x2^2*f4*f5^2*f6*f2-24*x3*x2*x7^2*f7*f2*f6-144*x3*x2*x4*x6*f5^3*
f4-48*x3*x2*x5*x6*f6*f1*f5-144*x2*x3^2*x6*f0*f6*f5*f7+48*x3^2*x2*x6*f4*f6*f3*
f5-24*x3^2*x4*x6*f7^2*f4*f2-8*x3^4*f4*f5*f1*f7^2-208*x3^2*x4*x6*f0*f6*f7^2+16*
x3^3*x1*f3*f6*f7*f2*f4+40*x3^2*x1*x6*f4^2*f7*f2+16*x3^3*x6*f3^2*f7*f6+44*x3^3*
x6*f4*f7*f3*f5-36*x3^3*x1*f4^2*f7*f2*f5-48*x3^3*x7*f4*f6*f3*f7-28*x3^3*x4*f3*
f7^3*f1-8*x3^3*x5*f2*f7*f5*f4-4*x3^2*x2*x6*f3*f7^2*f1-16*x3^3*x1*f7^2*f4*f2^2-\
32*x3^2*x2*x7*f0*f6^2*f7-8*x3^3*x2*f4*f6*f7*f3^2-36*x3^2*x1*x4*f7^3*f1^2-60*x3
^2*x2*x4*f3*f5*f2*f7^2-56*x3^2*x2*x4*f0*f5^2*f7^2+8*x3^2*x1*x5*f1*f5*f4*f6+28*
x3^2*x5*x7*f7*f3*f4+8*x3^2*x2*x8*f7*f3*f6*f4+12*x3^2*x2*x8*f7^2*f3^2-136*x3^2*
x4^2*f5^2*f7*f3*f6-240*x3^2*x1*x4*f1*f6^2*f7*f3+320*x3^2*x1*x4*f0*f6^2*f4*f7-\
32*x3^3*x2*f4*f6^3*f1-20*x3^2*x4^2*f3*f7^3*f2+16*x3^3*x8*f7*f4^2*f6+8*x3^3*x8*
f7*f3*f5*f6+96*x3^3*x4*f5^3*f6*f4-20*x3^2*x2*x6*f4*f5*f7*f2-32*x3^2*x1*x5*f0*
f7^2*f2+20*x3^2*x1*x5*f1*f5*f7*f3+16*x3^4*f7*f4*f6*f2*f5-16*x3^3*x1*f4^2*f3*f5
*f6-56*x3^2*x1*x7*f4*f5*f7*f2-192*x3^3*x4*f5*f6^2*f1*f7-8*x3^3*x4*f4^3*f7*f6-8
*x3^3*x1*f2*f5^4-24*x3^3*x4*f4*f6*f1*f7^2-32*x3^3*x4*f3^2*f5*f7^2+64*x2*x3^3*
f0*f6*f5^2*f7-16*x3^3*x2*f1*f6*f7^2*f2+1264*x3^2*x4^2*f0*f6^2*f7^2-40*x3^2*x2*
x4*f1*f7^3*f2-16*x3^2*x2*x4*f2^2*f6*f7^2-16*x3^3*x5*f2*f6*f5^2-48*x3^2*x5*x6*
f6^2*f1+20*x3^3*x1*f4^3*f5^2-124*x3^2*x4^2*f3^2*f7^2*f6+16*x3^2*x1*x5*f0*f6*f5
^2+48*x3^3*x5*f5*f6^2*f1-4*x3^2*x2*x8*f7^2*f2*f4+84*x3^2*x2*x4*f4*f5^4-32*x3^2
*x2*x5*f0*f5^2*f7-48*x3^2*x1*x4*f5*f4^3*f6+12*x3^2*x1*x5*f3^2*f5^2+32*x3^3*x2*
f4^2*f5^3-48*x3^3*x4*f5^3*f7*f3-8*x3^2*x1*x5*f4^2*f6*f2+8*x3^2*x1*x5*f4^2*f3*
f5-32*x3^2*x1*x5*f5*f6*f3*f2+20*x3^4*f2*f7*f5^3+16*x3^3*x7*f7^2*f4*f2+24*x3^3*
x6*f5*f6*f1*f7-144*x3^2*x4*x7*f7*f3*f5*f6-8*x3^2*x2*x5*f2*f5^3-76*x3^2*x1*x6*
f2*f5*f7*f3-8*x3^2*x2*x6*f2^2*f7^2+248*x3^2*x4^2*f5^2*f7^2*f2-212*x3^2*x4^2*f4
*f7^2*f3*f5+248*x3^2*x4^2*f0*f5*f7^3+96*x3^2*x1*x4*f1*f6^2*f5^2+8*x3^3*x1*f4*
f5*f7*f3^2-176*x3^3*x4*f4*f6*f7*f3*f5+184*x3^2*x1*x4*f4*f6*f7*f1*f5+12*x3^4*f4
^2*f5^2*f6+12*x3^3*x1*f3^2*f7^2*f2+28*x3^3*x1*f4*f5^3*f3-32*x3^2*x1*x6*f3*f6^2
*f2+48*x3^2*x1*x6*f3^2*f5*f6-8*x3^3*x1*f3^3*f6*f7-40*x3^2*x2*x7*f4*f7*f3*f5+16
*x3^4*f5^2*f6^2*f2-48*x3^2*x2*x7*f5^2*f7*f2-24*x3^2*x2*x7*f4*f6*f2*f7-80*x3^2*
x2*x7*f0*f5*f7^2+16*x3^3*x2*f5*f4^3*f6+16*x3^2*x4*x6*f3^2*f7^2-48*x3^2*x6*x7*
f4*f5*f6+16*x3^3*x1*f1*f5*f2*f7^2-168*x1*x4*x3^2*f5^2*f7*f2*f4-48*x3^3*x2*f1*
f6^2*f5^2-20*x3^3*x7*f5^2*f7*f3-8*x3^2*x2*x6*f4*f6*f1*f7+28*x3^2*x2*x7*f4*f5^3
+32*x3^3*x7*f4^2*f6^2-16*x3^3*x2*f5^2*f7*f3^2-32*x3^2*x4*x5*f4*f6*f2*f7-120*x3
^2*x4*x5*f0*f5*f7^2+24*x3^2*x2*x6*f3^2*f5*f7+16*x3^3*x8*f7^2*f1*f6-16*x3^2*x1*
x7*f4^3*f6+72*x3^2*x4^2*f4*f6*f2*f7^2-128*x3^3*x5*f0*f6^3+48*x3^2*x1*x6*f4*f5*
f1*f7+32*x3^3*x2*f4*f6^2*f2*f5-12*x3^2*x1*x7*f4^2*f7*f3-20*x3^4*f3*f6*f7*f4^2-\
28*x3^4*f4*f5^2*f7*f3-224*x3^2*x1*x4*f0*f6*f7^2*f3+48*x3^2*x2*x4*f3*f6*f7^2*f1
-208*x3^2*x2*x4*f1*f6^2*f7*f4-48*x3^2*x4*x7*f0*f7^3-8*x1*x5*f7*f2^2*x3^2*f5+32
*x3^3*x6*f6^3*f1+16*x3^2*x1*x7*f0*f6*f5*f7+20*x3^2*x7*x8*f7*f5^2+40*x3^2*x1*x7
*f3*f7^2*f1+12*x3^2*x1*x5*f7^2*f1^2+48*x3^2*x2*x5*f6^2*f1*f4+448*x3^3*x4*f6^3*
f7*f0-20*x3^2*x1*x6*f4^3*f5+32*x3^3*x7*f4*f6*f5^2+68*x3^2*x4*x6*f5^2*f7*f3+8*
x3^2*x1*x6*f0*f7^2*f3-8*x7^2*x1*x3*f4^2*f6-8*x7^2*x1^2*f6*f1*f5-12*x7^2*x1^2*
f6*f3^2-8*x7*x1*x3*x8*f1*f7^2+12*x7^2*x1^2*f7*f1*f4-40*x7^2*x1^2*f7*f0*f5-8*x2
*x7^2*x3*f7*f4^2-16*x2*x7^2*x4*f3*f6*f7+8*x7^2*x1^2*f2*f4*f6-20*x7^2*x1^2*f7*
f2*f3+96*x7^2*x1*x2*f7*f0*f6-32*x7^2*x1*x2*f7*f3^2+48*x7^2*x1*x3*f0*f7^2-8*x7^
2*x1*x3*f7*f3*f4+4*x7^2*x1*x5*f4^2-4*x3^2*x7^2*f7*f4*f5+12*x7^2*x1^2*f3*f5*f4-\
4*x3*x7^2*x5*f5^2+4*x3^2*x7*x8*f3*f7^2-8*f7^2*x8^2*x2^2*f2-12*f7^2*x8^2*x2*x3*
f3-16*f7^2*x8^2*x2*x4*f4-12*f7^2*x4^2*x8^2*f6-2*f7^2*x8^2*x3^2*f4+288*x1^2*x3*
x4*f0*f6*f5^3-16*x1^3*x3*f3^2*f5^2*f2-16*x1^3*x2*f6*f5*f4*f1^2-8*x1^3*x2*f3^2*
f6*f4*f1-96*x1^2*x2*x6*f0^2*f7^2+32*x1^3*x2*f0*f6*f5*f3^2+32*x1^3*x2*f0*f6^2*
f4*f1-16*x1^3*x2*f7^2*f1^3-20*x1^3*x7*f3^2*f7*f1+96*x1^2*x2^2*f4*f0^2*f7^2+16*
x1^2*x2^2*f0*f5^2*f4^2-128*x1^3*x3*f6^3*f0^2+24*x1^3*x7*f0*f5^2*f4-8*x1^3*x3*
f5*f7*f2^3-12*x1^3*x4*f3^4*f7-112*x1^2*x3*x4*f6^2*f7*f1^2+32*x1^3*x2*f0*f6*f5*
f4*f2-32*x1^2*x5*x7*f0*f5^2+8*x1^2*x5*x7*f2^2*f6+8*x1^3*x2*f2^3*f5*f6+64*x1^3*
x5*f6^2*f0^2+4*x1^4*f2*f4^2*f3^2+8*x1^4*f6*f4*f2^3+8*x1^4*f0*f7^2*f1^2-384*x1^
2*x3*x4*f0^2*f7^3+12*x1^2*x2^2*f4^2*f2^2*f6-96*x1^3*x4*f0*f7^2*f4*f1-96*x1^3*
x4*f0*f6*f5*f4^2-16*x1^2*x3^2*f1*f7^2*f3*f2-32*x1^2*x4^2*f7*f0*f5^3+8*x1^2*x4*
x6*f7*f0*f4*f5-32*x1^2*x3*x6*f0*f5^3+24*x1^2*x4*x5*f5*f6*f2^2-4*x3^3*x1*f4^3*
f7*f3-4*x3^3*x2*f7*f4^4-4*x3^3*x2*f5^4*f3+4*x3^3*x2*f7^3*f1^2-4*x3^3*x2*f3^3*
f7^2-4*x3^3*x2*f3*f5*f1*f7^2-4*x3^2*x1*x4*f7*f4^4+4*x3^3*x5*f5^3*f3+4*x3^3*x5*
f5^2*f7*f1+12*x3^2*x4*x5*f4^3*f7-12*x3^2*x1*x5*f7*f4*f3*f2-12*x3^2*x1*x6*f3^2*
f7*f4-12*x3^2*x1*x6*f1*f7^2*f2+12*x3^2*x2*x6*f5^3*f3+8*x2^2*x1*x3*f2*f3*f5^3-4
*x2^2*x1*x3*f7*f3^2*f2*f5-8*x2^2*x1*x3*f7*f2*f5^2*f1-4*x2^3*x3*f2^2*f7^2*f3+12
*x2^2*x1*x3*f7^2*f2*f1*f3-4*x2^3*x3*f4*f5*f7*f2*f3-4*x2^3*x3*f1*f5^4-4*x2^3*x3
*f1*f3^2*f7^2-4*x2^3*x3*f1*f5^2*f7*f3+12*x2^2*x1*x4*f3^3*f5*f7+4*x2^3*x4*f1*f7
^2*f2*f5+12*x2^2*x3*x5*f5^3*f1+4*x2^2*x3*x5*f7*f4*f2*f3-16*x2^2*x3*x5*f7*f4^2*
f1-16*x2^2*x1*x5*f3*f4*f2*f5+12*x2^2*x1*x5*f7*f2*f1*f4+12*x2^2*x1*x5*f1*f5^2*
f3-12*x2^2*x5^2*f1*f4*f5-48*x4^3*x1*f5^3*f7*f3+324*x4^3*x1*f3^2*f5*f7^2-168*x4
^3*x1*f5^2*f7*f2*f6-60*x4^3*x1*f4^2*f5^2*f7-656*x4^3*x1*f0*f6*f5*f7^2+64*x4^3*
x1*f4*f6*f1*f7^2-72*x4^2*x1^2*f5^4*f2-36*x4^2*x1^2*f3^2*f7*f5*f4-720*x4^2*x1^2
*f0*f6*f5*f4*f7-72*x4^2*x1^2*f1*f6*f5^3+432*x4^2*x1^2*f0*f6^2*f5^2-144*x4*x1^2
*x5*f1*f5*f3*f6+24*x4*x1*x5*x7*f5*f4^2-4*x4*x1*x7^2*f7*f3*f5+36*x4*x1*x2*x5*f4
^2*f3*f5+60*x4^2*x1*x6*f7^2*f4*f1-32*x4*x1*x6^2*f7*f3^2-72*x4*x1*x6*x7*f7*f1*
f6-376*x4^2*x1*x5*f0*f4*f7^2+108*x4^2*x1^2*f4*f5^3*f3-32*x4^3*x1*f3*f6*f2*f7^2
+72*x4^2*x1*x5*f5^2*f2*f6+568*x4^3*x1*f0*f4*f7^3-8*x4^2*x1*x2*f4^2*f7*f2*f6+60
*x4*x2*x6^2*f4*f5^2-56*x2*x4^3*f3*f7^3*f2-168*x2*x4^3*f5^2*f7^2*f2-216*x4^2*x2
*x6*f4*f6*f5^2-8*x4^2*x2*x6*f4*f6*f3*f7+36*x4^2*x2*x8*f7^3*f1+12*x2^2*x4*x5*f2
*f5*f7*f3+112*x2*x4^2*x5*f5^2*f7*f2-280*x2*x4^2*x5*f0*f5*f7^2-112*x2*x4^2*x7*
f7^2*f5*f2-48*x4^2*x2*x6*f0*f6*f7^2-24*x4*x2*x1*x5*f2*f4*f5^2-24*x4*x2*x6*x7*
f5^3-24*x4*x2*x5*x6*f5*f4^2-384*x4^2*x2*x7*f0*f7^3+16*x2*x4^2*x5*f3*f7^2*f2+8*
x4^2*x2*x7*f7*f4^2*f6+108*x4^2*x2*x7*f7^2*f3*f4-96*x2*x4^3*f5^2*f7*f3*f6+4*x4^
2*x2^2*f3*f6*f7*f4^2-44*x2*x4*x5*x6*f7*f1*f5-108*x2*x4^2*x5*f4*f7*f3*f5+16*x4*
x2*x3*x5*f2^2*f7^2-24*x2^2*x4*x6*f5^2*f7*f1+12*x4*x2^2*x6*f2^2*f7^2-32*x4*x2*
x6^2*f7*f3*f4+12*x4*x2^2*x7*f4*f5^3+240*x4^2*x1*x7*f1*f5*f7^2-228*x4^3*x6*f5^3
*f7-136*x4^3*x3*f7^3*f3^2-144*x4^2*x3*x5*f4*f5^2*f6-16*x4^4*f7^2*f2*f6^2-216*
x4^3*x5*f6*f5^3-44*x4^2*x6^2*f7*f4*f5-4*x3^3*x7*f3^2*f7^2-4*x3^3*x7*f4^2*f5*f7
-4*x3^2*x5*x7*f4*f5^2+28*x3^2*x6*x7*f7*f3*f5-4*x3^2*x6*x7*f1*f7^2+4*x3^2*x2*x5
*f3^2*f7*f4+12*x3^2*x2*x5*f1*f7^2*f2+12*x3^2*x2*x5*f4*f5^2*f3+8*x3^2*x2*x5*f4^
3*f5-4*x3^3*x6*f4^3*f7+4*x3^3*x6*f7^2*f4*f1-4*x3^2*x5*x6*f5*f4^2-12*x3^2*x5*x6
*f3*f5^2-12*x3^2*x5*x8*f7^2*f1-4*x3^2*x2*x8*f7^2*f1*f5-56*x3^2*x1^2*f7*f0*f5^2
*f3-28*x3*x1*x4^2*f7^2*f2*f4^2+120*x3^2*x1*x4*f4^2*f5^3+60*x3^2*x1*x4*f3*f5^4+
24*x3^2*x1*x6*f5^3*f2-40*x3^2*x1*x7*f5^2*f6*f2-48*x3^2*x1^2*f6^3*f1^2-144*x3*
x1*x4^2*f6^2*f5^2*f2-32*x3*x1^2*x6*f0*f6*f5*f4-128*x3*x1*x2*x5*f0*f6*f7*f2+32*
x3*x1^2*x7*f7*f2^2*f5-12*x3*x1^2*x4*f3^2*f7*f4^2+28*x3*x1^2*x7*f4^2*f3*f5+172*
x3*x1*x4^2*f7^2*f1*f4*f5-4*x3^2*x1*x4*f5*f1*f7^2*f3+136*x3^2*x1*x6*f0*f5^2*f7+
32*x3^2*x1*x2*f1*f6^2*f4^2+32*x3^2*x1*x4*f1*f4^2*f7^2+16*x3^2*x1*x4*f5^2*f7*f3
^2-32*x3*x1^2*x7*f0*f6^2*f4-32*x3^3*x1*f0*f6^2*f3*f7+24*x3*x1^2*x6*f4*f6*f2*f3
+32*x3*x1^2*x5*f0*f6*f4^2-32*x3*x1*x5*x7*f7*f1*f4+28*x3^3*x1*f3*f7^2*f1*f4-32*
x3^3*x1*f2*f6*f5^2*f4+8*x3^2*x1*x2*f1*f5^4+32*x3^2*x1*x2*f0*f6*f4^2*f7-24*x3^2
*x1*x2*f4^3*f3*f6-8*x3^2*x1*x2*f3^3*f7*f5-48*x3^2*x1*x2*f2*f5*f0*f7^2+60*x3*x1
*x4^2*f7^2*f3^2*f4-200*x3*x1*x4^2*f7*f5^2*f3*f4+304*x3*x1*x4^2*f7^2*f0*f5^2-\
240*x3*x1*x4^2*f7^3*f0*f3-352*x3*x1*x4^2*f0*f6^2*f5*f7+408*x3*x1*x4^2*f7*f1*f6
*f5^2-32*x3*x1*x4^2*f4^3*f7*f5+184*x3*x1*x4^2*f3^2*f5*f6*f7+96*x3*x1^2*x4*f0*
f6*f7*f5*f3+44*x3*x1^2*x4*f7*f4^2*f5*f1-12*x3*x1^2*x4*f4^4*f5-72*x3*x1^2*x4*f4
*f5^3*f2+84*x3*x1^2*x4*f4^2*f5^2*f3-64*x3*x1^2*x4*f7^2*f2*f1*f4-96*x3*x1^2*x4*
f0*f5*f6^2*f4+24*x3*x1*x2*x4*f1*f6*f5^3-4*x3^2*x1*x8*f7^2*f1*f4-4*x3^2*x1*x8*
f7^2*f2*f3-4*x3*x1*x5*x8*f7*f2*f4-128*x3^2*x1*x6*f0*f6*f7*f4+216*x3*x1*x4^2*f5
^4*f4+32*x3^3*x1*f0*f6^2*f5^2+40*x3*x1*x6^2*f7*f2*f3+288*x3*x1^2*x4*f3*f6^2*f1
*f5+16*x3^3*x1*f1*f6^2*f4*f5-24*x3^3*x1*f3^2*f6*f5^2-8*x3^3*x1*f4^4*f6+8*x3^2*
x1*x4*f7*f4^2*f2*f6+128*x3^2*x1*x2*f0*f6^2*f7*f2+24*x3^2*x1*x4*f3^2*f6*f4*f7+
24*x3*x1*x6*x7*f3*f6*f4-32*x3*x1*x6^2*f2*f4*f6+64*x3^3*x1*f0*f6^3*f4-24*x3*x1^
2*x4*f5^4*f1-56*x3*x1*x4*x6*f2^2*f7^2-120*x3*x1^2*x4*f3^2*f6*f5*f4+48*x3*x1^2*
x4*f3^2*f5^3, 16*x1^3*x7*f0*f4*f2*f7-16*x1^3*x7*f0*f5^2*f3-132*x1^2*x4^2*f7*f3
*f5*f2*f4+120*x1^2*x3^2*f0*f4*f3*f7*f5+32*x1^2*x2^2*f5^2*f0^2*f7+80*x1^2*x3*x6
*f0*f5^2*f4-48*x1^2*x2*x7*f7*f2*f1*f4-32*x1^2*x6^2*f2*f1*f6+32*x1^2*x4^2*f7*f0
*f5^2*f4-32*x1^2*x6^2*f0*f4*f5+32*x1^3*x6*f0*f4*f5*f3-48*x3^2*x4*x6*f5*f6*f1*
f7+28*x3^2*x4*x6*f4*f7*f3*f5+32*x3^2*x2*x7*f5^2*f2*f6+8*x3^2*x2*x7*f4*f5*f7*f2
-12*x3^3*x7*f5^2*f2*f7+8*x3^3*x7*f4*f6*f2*f7-32*x3^3*x7*f4^2*f6*f5+144*x3^2*x4
*x7*f3*f5*f6^2+48*x3^2*x5*x7*f6^2*f1+48*x3^2*x5*x7*f7*f0*f6-32*x3^2*x5*x7*f6*
f2*f5-32*x3^2*x6*x7*f6^2*f2+8*x3^3*x8*f7^2*f1*f5+16*x3^3*x8*f7*f6*f2*f5-40*x3^
2*x4*x8*f7^2*f1*f6+8*x3^2*x4*x8*f7*f3*f5*f6+16*x3^2*x5*x8*f7*f1*f6+32*x1*x3*x5
*x6*f2*f3*f5-64*x1*x3*x5*x6*f0*f5^2-40*x1^2*x3*x4*f4*f7^2*f1^2-160*x1*x3*x4^2*
f5*f7^2*f2^2-76*x1*x3*x4^2*f3*f7^2*f2*f4-352*x1*x3*x4^2*f0*f6*f5^2*f7+32*x1*x3
^2*x2*f0*f4*f7^2*f2-56*x1*x3*x4*x8*f7^2*f0*f5+16*x1*x3*x5*x8*f7*f0*f5+8*x1*x3^
2*x6*f7*f2*f1*f6-64*x1^2*x3*x5*f0*f7*f1*f5-4*x1*x3^2*x6*f3^3*f7+12*x1*x3*x5*x6
*f3^2*f4+16*x1*x3*x5*x6*f4^2*f2-4*x1^2*x3*x7*f4^3*f3+8*x1*x3*x4*x7*f3*f7^2*f1-\
8*x1*x3*x5*x7*f7*f3*f1-12*x1*x3*x5*x7*f3^2*f5+8*x1*x3*x5*x7*f7*f2^2+16*x1*x3*
x6*x7*f4^3+4*x1*x3*x2*x8*f7*f4^2*f2+4*x1*x3^2*x8*f7*f2*f4*f5+4*x1*x3^2*x8*f7^2
*f3*f1+4*x1*x3^2*x8*f7*f1*f5^2+4*x1*x3^2*x8*f7^2*f2^2-12*x1*x3*x6*x8*f1*f5*f7-\
4*x1*x3*x6*x8*f7*f2*f4-144*x1*x3^2*x4*f4*f6^2*f1*f5+16*x1*x3^2*x4*f3^3*f6*f7+
32*x1*x3^2*x4*f0*f6*f7^2*f2+48*x1^2*x3*x5*f3*f0*f5^2-20*x1^2*x3*x5*f3^2*f2*f5+
32*x1^2*x3*x5*f3^2*f6*f1-12*x1^2*x3*x5*f3^3*f4+16*x1^2*x3*x5*f5*f6*f0*f2-16*x1
^2*x3*x5*f0*f7*f2*f4+8*x1^2*x3^2*f4^2*f1*f5^2-20*x1^2*x3^2*f3*f5*f7*f2^2-8*x1^
2*x3^2*f2^2*f6^2*f3+120*x1*x3*x4*x6*f5^2*f3*f4+8*x1^2*x3*x5*f2^2*f3*f6+48*x1^2
*x3*x6*f0*f6*f5*f3-32*x1*x3*x4^2*f7^3*f1^2+4*x1^2*x3^2*f2^3*f6*f7+72*x1*x3*x4^
2*f3*f5^2*f4*f6-32*x1*x3*x2*x7*f4^2*f3*f5+8*x1^2*x3*x5*f1^2*f7*f4-56*x1*x3*x6*
x7*f7*f1*f4-48*x1*x3*x4*x8*f7*f6*f1*f5-64*x1*x3*x6^2*f0*f5*f6-8*x1^2*x3*x7*f4^
2*f1*f6+16*x1*x3^2*x5*f4*f6*f2*f3-96*x1*x3*x4^2*f3*f7^2*f1*f5+16*x1^2*x3*x7*f4
^2*f2*f5-16*x1*x3*x6^2*f4^2*f3+32*x1*x3*x6^2*f2*f3*f6+64*x1*x3*x6^2*f7*f0*f4+
160*x1*x3*x4*x6*f3*f6*f1*f7-96*x1^2*x3*x7*f0*f6^2*f3-32*x1*x3*x5*x6*f2^2*f6-80
*x1*x3*x4*x7*f4*f6*f1*f7-16*x2^2*x4*x7*f4*f6*f1*f7-64*x2^2*x4^2*f4*f6*f1*f5*f7
+24*x2^3*x4*f4*f5^3*f2+8*x2^2*x1*x3*f0*f3*f2*f7^2-16*x2^2*x1*x7*f4^3*f3+20*x2^
2*x4*x7*f4*f5*f2*f7+8*x2^3*x3*f2*f3*f7^2*f1-4*x2^4*f4^2*f1*f3*f7+24*x2^3*x4*f0
*f5*f7^2*f2+32*x2^2*x1*x3*f0*f4^3*f7-8*x2^3*x5*f0*f7*f3*f4-8*x2^3*x6*f3*f4^3+
36*x2^2*x4*x5*f5^3*f1+16*x2^2*x3^2*f2*f6*f7*f1*f5+24*x2^2*x1*x3*f1*f6*f5^2*f2+
24*x2^2*x1*x4*f0*f5^4-8*x2^3*x1*f3*f4*f7*f2^2-12*x2^2*x1*x4*f3*f5^3*f2+8*x2^3*
x4*f4^2*f7*f3^2+16*x2^3*x1*f3*f5*f2*f4^2-20*x2^3*x1*f1*f4^2*f7*f2+24*x2^2*x1*
x7*f4^2*f2*f5-24*x2^2*x5*x6*f0*f5^2-2*x1^2*x3^2*f7*f3^4-4*x1*x3^2*x2*f2^3*f7^2
+20*x1*x3*x4*x5*f4^2*f1*f7-8*x1*x3*x5^2*f2^2*f5-4*x1*x3*x5^2*f2*f3*f4-24*x4^2*
x2*x3*f3^2*f7^2*f4+48*x2*x3*x4*x5*f4^3*f5-48*x2*x3*x4*x5*f2*f5^3-6*x2^2*x3^2*
f2^2*f5^2*f7-88*x2*x3*x4*x6*f0*f7^2*f4+8*x2*x3*x4*x6*f7*f4^2*f3+24*x2*x3*x4*x6
*f2*f6*f7*f3-48*x2*x3*x1*x4*f3*f5^2*f6*f2-64*x2*x3*x4*x7*f7*f3*f5*f4+240*x2*x3
*x4*x5*f0*f5^2*f7-16*x2*x3*x4*x5*f1*f6*f7*f3+320*x3*x2*x4*x5*f0*f6*f7*f4-8*x2*
x3*x7^2*f7*f1*f6+80*x2*x3*x4*x7*f7*f2*f4*f6-16*x2^2*x3*x5*f0*f4^2*f7+48*x2*x3^
2*x7*f6*f3*f4*f5-24*x2*x3*x6^2*f7*f0*f5+24*x2*x3*x6^2*f3*f5*f4+8*x2^2*x3*x6*f7
*f2^2*f5-4*x2^2*x3*x7*f2*f7*f4^2+4*x2*x3^2*x7*f2^2*f7^2+4*x2^2*x3*x5*f3*f7*f1*
f4+8*x2*x3*x5^2*f4^2*f2-4*x2*x3*x5^2*f1*f4*f5-4*x2*x3^2*x6*f1*f7^2*f2+8*x2*x3*
x4*x6*f2^2*f7^2+8*x2*x3*x4*x6*f1*f7^2*f3+16*x2*x3*x5*x6*f2*f4*f5+16*x2*x3*x5*
x7*f4^3-16*x2*x3*x5*x7*f5^2*f2+4*x2*x3*x6*x7*f7*f2*f4+4*x2^2*x3*x8*f7*f2*f4*f5
+4*x2^2*x3*x8*f7*f4^2*f3-4*x2^2*x3*x8*f7^2*f2^2-4*x2*x3^2*x8*f7^2*f1*f4+4*x2*
x3^2*x8*f7*f4^3+12*x2*x3*x4*x8*f7^2*f3^2+4*x2*x3*x5*x8*f7*f1*f5-8*x2*x3*x6*x8*
f7*f2*f5+20*x2*x3*x7*x8*f7*f4^2+12*x2*x3*x7*x8*f7*f3*f5+344*x1*x3*x4^2*f4*f5^2
*f7*f2+48*x1*x3^2*x4*f3*f5*f4^2*f6-48*x1*x3*x4*x6*f3*f7*f2*f5+48*x1*x3*x4*x5*
f0*f6*f5^2-48*x1*x3^2*x7*f6^2*f1*f4+16*x1*x3^2*x7*f4^2*f3*f6+72*x1^2*x3*x4*f3*
f5^3*f2-180*x1*x3*x4^2*f5^3*f4^2+16*x1*x3*x5^2*f0*f5*f4+24*x1*x3*x5^2*f2*f6*f1
-272*x1*x3*x4^2*f4*f6*f1*f5*f7+64*x1^2*x3*x5*f0*f6^2*f1-72*x1*x3*x4*x5*f4*f5^2
*f2+8*x1^2*x3*x7*f5^2*f1*f4-44*x1*x3*x4*x6*f4^2*f2*f7+48*x1*x3*x4*x5*f3*f7*f1*
f5-192*x1*x3^2*x4*f0*f6^2*f5^2-8*x1*x3^2*x7*f2^2*f6*f7+72*x1^2*x3*x4*f3^3*f5*
f6+32*x1^2*x3*x5*f6*f0^2*f7+32*x1*x3*x4*x5*f3*f7*f2*f4-84*x1*x3*x4*x6*f4*f5*f1
*f7-32*x2*x3^2*x6*f1*f6^2*f4-36*x2*x3^2*x4*f4^2*f5^3+24*x2*x3*x7^2*f0*f7^2-12*
x2*x3^2*x7*f5^2*f4^2-48*x2*x3*x4^2*f7^3*f2*f1+68*x2*x3*x4^2*f7^2*f2*f4^2-32*x2
*x3*x1*x4*f7^3*f0^2+16*x2*x3^2*x4*f1*f6^2*f7*f3+144*x2*x3^2*x4*f5^2*f6*f3*f4-\
24*x2*x3^2*x4*f4^3*f5*f6-24*x2*x3*x5^2*f0*f5^2+16*x2*x3^2*x5*f4*f6*f1*f5-8*x2*
x3^2*x5*f5^3*f1-72*x2*x3*x4*x5*f5^2*f3*f4-48*x2*x3*x4*x7*f7*f4^3+16*x2^2*x3*x7
*f1*f6*f7*f3-16*x2*x3*x1*x7*f3*f6*f2*f5-8*x2^2*x3*x8*f7^2*f0*f4-32*x2*x3*x5*x7
*f2*f4*f6+256*x2*x3*x4^2*f0*f6^2*f5*f7+16*x2*x3*x5*x6*f1*f5^2+188*x2*x3*x4^2*
f7*f2*f5^3-24*x2*x3*x4*x6*f1*f6*f7*f4-96*x2*x3*x4*x5*f2*f6*f4*f5+48*x2*x3*x5*
x7*f6*f1*f5+144*x2*x3*x4*x7*f5^2*f6*f3+8*x2*x3*x4*x5*f2*f7^2*f1-16*x2^2*x3*x6*
f0*f6*f7*f3-12*x2*x3*x7^2*f4*f5^2-12*x1^3*x2*f3*f7*f2^3+32*x1^3*x2*f0*f6*f4*f3
^2+24*x1^3*x2*f4*f5^2*f1^2+32*x1^3*x2*f6*f5^2*f0^2+12*x1^3*x2*f3*f4^3*f1+28*x1
^3*x2*f7*f2^2*f1*f4-64*x1^3*x2*f6^2*f0^2*f4+8*x1^2*x3^2*f7*f2*f1*f6*f3+32*x1^2
*x3^2*f0*f5^2*f2*f7-8*x1^2*x3^2*f3^2*f5*f7*f1-4*x1^2*x3^2*f2*f5*f1*f4*f7-48*x1
^2*x3^2*f0^2*f7^2*f5-50*x1^2*x3^2*f5^2*f7*f1^2-32*x1^2*x3^2*f2*f5^2*f1*f6+16*
x1^2*x3^2*f2*f6^2*f1*f4-24*x1^2*x3^2*f0*f7^2*f2*f3-16*x1^3*x3*f2^3*f5*f6-52*x1
^3*x3*f5*f1^2*f7*f3+12*x1^3*x3*f3*f5^2*f2^2+16*x1^3*x3*f0*f5*f6*f3^2+64*x1^3*
x6*f6^2*f0^2-32*x1^3*x7*f6*f0^2*f7+24*x1^3*x4*f3^2*f5*f1*f6+40*x1^2*x2^2*f0*f4
^2*f7*f2+8*x1^2*x2^2*f5*f1^2*f7*f3-136*x1^2*x3*x4*f3^2*f7*f1*f6+48*x1^2*x3*x4*
f5^2*f6*f3*f1+8*x1^3*x7*f3^2*f1*f6+24*x1^3*x4*f2^2*f6*f1*f7-20*x1^3*x4*f7*f2*
f1*f4^2+16*x1^3*x5*f3^2*f4*f1-8*x1^3*x5*f4*f1^2*f5+16*x1^3*x5*f0*f5^2*f1+16*x1
^2*x3*x7*f0*f7*f4^2-48*x1^2*x2*x3*f2*f5*f1*f4*f6-20*x1^3*x2*f2*f5*f1*f4^2+8*x1
^3*x5*f0*f3^2*f5-32*x2^2*x1*x6*f3*f5*f2*f4+56*x2^2*x1*x6*f1*f4*f7*f2-24*x2^2*
x1*x6*f0*f7*f3*f4+24*x2^2*x3*x6*f0*f5*f7*f4-16*x2^2*x4*x6*f3^2*f7*f4-8*x2^2*x4
*x6*f0*f7^2*f3+48*x2^2*x4*x6*f0*f5^2*f7-20*x2^2*x1*x7*f5^2*f1*f4-24*x2^2*x1*x7
*f0*f5*f7*f3+8*x2^2*x1*x7*f0*f5^3+8*x2^3*x7*f4*f5^2*f2+28*x2^2*x4*x7*f3*f7^2*
f1+28*x2^2*x4*x7*f7*f3^2*f5-48*x2^2*x4*x7*f0*f7^2*f4-48*x2*x1*x3*x5*f2*f6*f5*
f1+40*x2*x1*x3^2*f4^3*f2*f6-48*x2*x1*x4*x5*f4^2*f2*f5+20*x1^2*x4^2*f7^2*f2*f1*
f4-32*x1^3*x2*f5*f7*f2*f1^2-64*x1^3*x2*f0*f6*f7*f2*f1-32*x1^2*x3^2*f3*f5*f1*f4
*f6-48*x1^2*x3^2*f0*f5^3*f4-12*x1^3*x6*f1*f7*f2^2+32*x1^3*x2*f6*f7*f1^3-16*x1^
3*x2*f6*f4^2*f1^2+16*x1^3*x2*f6*f5*f1^2*f3-8*x1^3*x2*f0*f3^2*f5^2-32*x1^2*x3*
x6*f0*f6*f1*f7+24*x1^2*x3*x6*f3^2*f7*f1-72*x1^2*x2*x3*f0*f5^2*f4^2-64*x1^2*x2*
x7*f0*f6*f1*f7+96*x1^2*x3^2*f0*f6*f5*f1*f7-152*x1^2*x4^2*f7^2*f3^2*f1-8*x1^3*
x7*f0*f5*f4^2+12*x1^2*x3*x6*f7*f2*f1*f4-60*x1^2*x4*x6*f7*f3^2*f2+44*x1^2*x4*x6
*f7*f3*f1*f4+16*x1^2*x4*x6*f7*f2^2*f4+8*x1^2*x6^2*f2*f3*f4+36*x1^2*x6^2*f3*f1*
f5+4*x1^3*x7*f2^2*f5*f4+16*x1^2*x5*x7*f3*f1*f5+8*x1^2*x5*x7*f2*f3*f4+36*x1^2*
x6*x7*f7*f2*f1-4*x1^2*x2*x8*f2*f5*f1*f7+4*x1^2*x5*x8*f7*f2*f1-8*x1^3*x2*f0*f4^
4+16*x1^2*x3*x4*f0*f4*f2*f7^2+96*x3^2*x2*x4*f4*f6^2*f2*f5+8*x3^3*x2*f4*f5^3*f3
+20*x3^2*x1*x7*f7*f4^2*f2+12*x4*x8*f7*x3^2*f4*f5^2-32*x3^3*x6*f5*f6^2*f1+36*x3
^2*x4*x6*f3*f7^2*f2-32*x3^3*x2*f3*f6*f7*f2*f4-96*x3^2*x4*x5*f5^2*f2*f6-16*x3^2
*x2*x5*f5^2*f2*f4+8*x3^3*x6*f4^3*f6-112*x3^3*x4*f0*f6*f4*f7^2-20*x3^2*x2*x4*f7
*f4^4+8*x3^3*x1*f2*f4*f5^3-36*x3^3*x1*f7*f3*f5*f2*f4+24*x3^4*f4^2*f3*f6^2+8*x3
^4*f0*f6*f7^2*f3-8*x3^3*x1*f5^2*f2^2*f7-16*x3^4*f3*f5*f1*f7^2+32*x3^2*x1*x6*f6
^2*f2^2-32*x3^3*x1*f0*f6^2*f5*f4-64*x3^2*x4*x6*f4*f6*f2*f7-96*x3^2*x4*x6*f5*f6
^2*f2+24*x3^3*x2*f0*f7^3*f1+16*x3^3*x8*f7^2*f0*f6-32*x3^2*x2*x4*f4*f6*f1*f5*f7
-16*x3^2*x1*x5*f3*f5^2*f2-8*x3^4*f3*f5*f2*f6*f7-32*x3^4*f1*f6^3*f4-16*x3^4*f1*
f7*f5^3+16*x3^4*f0*f6*f5^2*f7+16*x3^4*f3*f6^2*f1*f7+4*x3^4*f0*f7^3*f2+12*x3^4*
f5^2*f7*f3^2+4*x3^4*f7*f4^2*f2*f6-64*x3^4*f0*f6^3*f5+24*x3^4*f4*f6*f1*f5*f7+8*
x3^4*f4^2*f7*f3*f5-48*x3^3*x1*f7*f0*f6*f4^2-64*x3^3*x1*f0*f6*f5^3-8*x3^3*x2*f4
*f5*f7*f3^2-8*x2*x3^3*f0*f5^3*f7-64*x3^3*x2*f0*f6^3*f4+16*x3^3*x2*f1*f6^2*f7*
f2-12*x2*x3^3*f1*f5^2*f7*f4+16*x3^3*x2*f0*f6*f5*f7*f4-192*x3^2*x4^2*f4*f6*f1*
f7^2+36*x3^2*x4^2*f5^2*f1*f7^2-496*x3^2*x4^2*f5*f6^2*f1*f7-80*x3^2*x1*x4*f0*f6
*f5*f4*f7+48*x3^2*x1*x4*f3^2*f7*f5*f4+20*x3^2*x1*x4*f7^2*f1*f4*f3-24*x3^2*x1*
x4*f7*f3*f5^2*f2+8*x3^2*x1*x4*f7^2*f1*f5*f2+116*x3^2*x1*x4*f7*f4^2*f2*f5+68*x1
^2*x2*x4*f1*f7^2*f2^2+56*x1^2*x3*x4*f7^2*f2*f3*f1-16*x1^3*x5*f1*f3*f0*f7-8*x1^
3*x5*f2^2*f6*f1+60*x1^2*x2*x4*f7^2*f1^2*f3+104*x1^2*x2*x4*f5^2*f7*f1^2+16*x1^3
*x3*f0*f6*f1*f7*f3+20*x1^3*x3*f3^2*f5*f2*f4-24*x1^2*x2^2*f0*f5*f4^3+16*x1^3*x2
*f7^2*f1^2*f0+48*x1^3*x2*f0*f6*f4^2*f2+16*x1^3*x2*f0*f4^2*f7*f1-144*x1^2*x3*x4
*f0*f6*f5^2*f4-128*x1^2*x2*x4*f0*f7^2*f2*f3-40*x1^2*x3*x6*f3*f5*f2*f4+8*x1^3*
x3*f7*f2^3*f4-4*x1^2*x2*x7*f3^2*f7*f1-16*x1^3*x7*f3*f2^2*f6+16*x1^3*x7*f1^2*f6
*f5+16*x1^3*x7*f0*f6*f4*f3+16*x1^3*x7*f3^2*f5*f2-48*x1^2*x3*x7*f0*f6*f4*f5-16*
x1^3*x5*f1^2*f6*f3-32*x1^2*x3*x4*f0*f3^2*f7^2-24*x1^3*x4*f2*f5^3*f1-72*x1^2*x3
*x6*f3*f5^2*f1+56*x1^2*x3*x6*f1^2*f5*f7-24*x1^2*x3*x6*f0*f5*f2*f7+40*x1^3*x7*
f1*f5*f0*f7-8*x1^3*x7*f2*f1*f5^2-32*x1^3*x7*f0*f1*f6^2-16*x1^3*x7*f1^2*f4*f7-\
48*x1^2*x2*x6*f0*f4*f2*f7+56*x1^2*x2*x6*f0*f5*f4^2+8*x1^4*f1^2*f6*f0*f7-4*x1^4
*f2*f4*f3^3-32*x1^4*f0*f6^2*f2*f1+4*x1^4*f1*f5^2*f2^2+16*x1^4*f0*f6*f5*f3*f1-4
*x1^4*f1*f5*f3^3-18*x2^2*x1^2*f4^2*f7*f1^2-6*x2^2*x1^2*f3^2*f7*f2^2-8*x2^2*x1^
2*f3^2*f5^2*f1-6*x2^2*x1^2*f4^2*f3^3+16*x2^2*x1^2*f0*f6*f5*f4*f2-16*x2^2*x1^2*
f0*f6*f5^2*f1-8*x2^2*x1^2*f0*f5^3*f2+4*x2^2*x1^2*f7*f3^3*f1+4*x2^2*x1^2*f4^4*
f1+4*x2^2*x1^2*f5^3*f1^2+16*x2^2*x1^2*f7^2*f1^3+32*x2*x1*x3*x6*f3*f4^3-32*x2*
x1*x3*x6*f4^2*f6*f1-64*x2*x1*x3*x6*f2*f3*f6*f4+120*x2*x1*x4^2*f7*f5^2*f2*f3+12
*x2*x1^2*x4*f5^3*f2^2+16*x2*x1*x3^2*f0*f6*f4*f3*f7+80*x2*x1*x4^2*f7^2*f0*f6*f2
-480*x2*x1*x4^2*f0*f6*f5*f4*f7+8*x2*x1*x4^2*f3*f6*f1*f5*f7-80*x2*x1*x4^2*f7^2*
f6*f1^2-72*x2*x1*x4^2*f4^3*f5^2-176*x2*x1*x4^2*f7^2*f0*f5*f3-144*x2*x1^2*x4*f0
*f6*f5^2*f3-64*x2*x1^2*x4*f6^2*f0^2*f7+80*x2*x1^2*x4*f0*f7^2*f4*f1-24*x2*x1^2*
x4*f4*f5*f2^2*f6+36*x2*x1^2*x4*f3^3*f5^2+12*x2*x1^2*x4*f4^2*f5^2*f1+16*x2*x1*
x6*x8*f7*f0*f5-8*x2*x1*x7*x8*f7*f1*f5+176*x2*x1*x3*x4*f4*f5*f7*f2*f3+20*x2*x1*
x3*x4*f7*f4^2*f3^2+4*x2*x1^2*x5*f5*f3*f2^2+16*x2*x1*x3*x5*f2^2*f5^2-12*x2*x1*
x3*x5*f4^2*f3^2+4*x2*x1*x3*x5*f7*f3^2*f1+8*x2*x1*x3*x5*f1*f5^2*f3+40*x2*x1*x3*
x5*f4^2*f1*f5-8*x2*x1*x3*x5*f3*f7*f2^2-8*x2*x1*x3*x7*f7*f3^3+12*x2*x1*x3*x7*f3
^2*f5^2-8*x2*x1*x3*x7*f2^2*f5*f7+40*x2*x1*x3*x7*f2*f5^2*f4-4*x2^2*x1*x5*f7*f2^
3+12*x2*x1*x5^2*f2*f1*f5-8*x2*x1*x5^2*f2^2*f4+4*x2^2*x1*x6*f1*f5^2*f3-12*x2*x1
*x3*x6*f5*f3^2*f4-32*x2*x1*x3*x6*f4^2*f2*f5+16*x2^2*x4*x1*f0*f6*f5*f2*f7+28*x2
*x1*x3*x6*f4*f7*f3*f1-8*x2^2*x1*x7*f7*f2*f3^2-48*x2*x1*x3*x4*f4^4*f5-8*x2^2*x1
^2*f0*f6*f7*f2^2-24*x2^2*x1^2*f0*f5^2*f4*f3+4*x2^2*x1^2*f6*f2*f7*f1^2-16*x2*x1
*x3^2*f1*f6*f7*f4*f2+24*x2*x1*x3^2*f3^2*f4^2*f6+24*x2^2*x1*x7*f4*f7*f3*f1-16*
x2*x1*x3*x5*f4^3*f2-48*x2*x1*x3*x4*f5^4*f1+16*x2^2*x1*x6*f0*f6*f7*f1+32*x2*x1*
x3*x6*f5*f6*f2^2-240*x2*x1*x4^2*f7*f0*f5^3+32*x2*x1*x3*x5*f0*f5^2*f4+12*x2*x1*
x3*x5*f7*f2*f1*f4+16*x2*x1*x3*x5*f4^2*f6*f0+72*x2*x1*x4*x5*f4*f1*f5^2+88*x2*x1
*x4*x5*f0*f7^2*f1-16*x2*x1*x4*x5*f0*f6*f7*f2+16*x2*x1*x4*x5*f6*f7*f1^2+64*x2*
x1*x4*x5*f0*f5*f3*f7+48*x2*x1*x4*x5*f7*f4*f2^2+144*x2*x1*x4*x5*f0*f5*f6*f4-36*
x2*x1*x4*x5*f3^2*f4*f5+24*x2*x1^2*x6*f7*f4*f1^2-20*x2*x1^2*x6*f3^2*f5*f2-48*x3
*x6*x1*x2*f2*f6*f7*f0-8*x2*x1^2*x3*f3*f5*f2^2*f6-32*x2*x1^2*x3*f3^2*f5*f1*f6+
40*x2*x1^2*x3*f4*f6*f3^2*f2+32*x2*x1^2*x3*f0*f6^2*f4*f2-36*x2*x1^2*x3*f5*f4*f7
*f1^2-48*x2*x1^2*x3*f0*f5^3*f3+20*x2*x1^2*x3*f3^2*f5^2*f2-36*x2*x1^2*x3*f2*f4^
2*f7*f1+16*x2^2*x1*x3*f0*f5^2*f2*f7+32*x2^2*x1*x3*f0*f5*f7*f4*f3-8*x2*x1*x4^2*
f7*f4*f1*f5^2+88*x2*x1*x4^2*f7*f5*f3^2*f4-68*x2*x1*x4^2*f7^2*f4*f3*f1+28*x2*x1
*x4^2*f7^2*f1*f5*f2-32*x2*x1^2*x3*f7^2*f3*f0*f1+120*x2*x1*x3*x4*f4*f5^3*f2+16*
x2*x1*x3*x6*f3*f6*f1*f5+32*x2*x1*x5*x6*f2*f3*f4+80*x2*x1^2*x7*f0*f4*f3*f7-12*
x2^2*x1*x3*f3^2*f7*f2*f4-56*x2*x1*x7^2*f7*f0*f5+32*x2*x1^2*x4*f0*f6*f7*f3^2-48
*x2*x1*x4*x7*f4^3*f5+8*x2*x1*x3^2*f0*f7^2*f5*f1-44*x2*x1*x3^2*f1*f7*f5^2*f2-48
*x3*x6*x1*x2*f3*f5*f7*f0-60*x2*x1^2*x4*f4^2*f5*f3^2+36*x2*x1*x3^2*f7*f4^3*f1-\
72*x2*x1*x4^2*f5^3*f1*f6+24*x2*x1^2*x4*f4^3*f2*f5-40*x4^2*x3*x5*f3^2*f7*f6+48*
x4*x3*x6*x7*f7*f4^2-48*x4*x3*x6*x7*f5^3-48*x4*x3*x5*x6*f5*f4^2-24*x4*x3*x1*x5*
f4^2*f3*f5+24*x4*x3*x5^2*f5^2*f2-128*x4*x3*x5^2*f7*f0*f5-72*x1*x4^2*x6*f2*f6*
f5^2+36*x1*x4^2*x6*f3*f5^3-8*x1*x4^2*x6*f2*f6*f7*f3-16*x1*x4^2*x6*f1*f6*f7*f4+
36*x1*x4*x5*x6*f3^2*f5-144*x1^2*x4*x7*f0*f6*f7*f3-12*x1^2*x4*x7*f4^2*f3*f5-48*
x1^2*x4*x7*f3^2*f5^2+24*x1*x4*x2*x7*f2*f5^3+28*x1*x4*x3*x7*f4^2*f7*f3+96*x1*x4
*x3*x7*f5^2*f6*f2-44*x1*x4*x6*x7*f7*f2*f4-48*x1*x4*x6*x7*f6*f2*f5-28*x1*x4*x6*
x7*f7*f3^2+8*x1*x4*x2*x8*f7^2*f2^2+8*x1*x4*x2*x8*f7*f2*f4*f5-48*x1*x4*x6^2*f3*
f5*f4+144*x1*x4^2*x3*f2*f6*f5^3-12*x1^2*x4*x5*f1*f5*f4^2-8*x2*x4^2*x6*f4*f6*f2
*f7-16*x2*x4*x3*x8*f7*f3*f6*f4-60*x2*x4*x5*x7*f7*f2*f4-32*x6*x7*x2*x4*f7*f2*f5
-12*x2^2*x8*f7*x4*f5^2*f2+40*x3*x5*x2*x4*f7*f3*f5*f2+4*x4^2*x3*x5*f4^3*f7-8*x4
*x3*x7^2*f2*f7^2+36*x1^2*x4*x7*f3^3*f7+4*x1^2*x4^2*f7*f2*f4^3+32*x1^2*x4^2*f4*
f6*f7*f3*f1+32*x1^2*x4^2*f0*f6^2*f7*f2-256*x3*x4^2*x1*f3*f5*f2*f6*f7+16*x1*x4*
x5*x7*f7*f1*f4+24*x1^2*x4*x7*f4*f5^2*f2+24*x1*x4*x6*x7*f3*f5^2-8*x1^2*x4^2*f7*
f2^2*f6*f4-12*x1*x4*x5^2*f2*f3*f5-144*x1^2*x4^2*f0*f6*f5^3+112*x1^2*x4^2*f3^3*
f5*f7-62*x1^2*x4^2*f7*f2^2*f5^2-448*x1^2*x4^2*f0*f6*f7*f5*f3-32*x1^2*x4^2*f6^2
*f7*f1^2-8*x1^2*x4^2*f3^2*f6*f7*f2+52*x1^2*x4^2*f7*f4^2*f5*f1+36*x1^2*x4^2*f4*
f5^3*f2-18*x1^2*x4^2*f4^2*f5^2*f3-72*x1^2*x4^2*f4*f5^2*f1*f6-8*x1*x4^2*x2*f4^3
*f3*f7+36*x1*x4^2*x2*f2*f5^4-8*x1*x4*x7*x8*f1*f7^2+12*x2*x4*x6^2*f7*f2*f4-2*x2
^2*x4^2*f7*f4^4+4*x2*x4*x7^2*f1*f7^2-4*x1*x4^2*x3*f4^4*f7-4*x1*x4*x2*x6*f3^3*
f7+44*x4*x3*x7*x8*f7*f5^2+160*x3*x4*x5*x7*f7*f1*f6+96*x4*x3*x5*x6*f6*f2*f5+16*
x6*x8*f3*f7*x3*x4*f6-40*x4*x3*x5^2*f7*f1*f4-8*x7*x8*f4*f7*x3*x4*f6-36*x4*x3*x6
*x8*f7^2*f2-76*x4*x3*x5*x7*f7*f2*f5+16*x4*x3^2*x8*f7^3*f0-8*x3^2*x8*f7*x4*f4^2
*f6+36*x4*x3*x5*x6*f7*f2*f4-16*x1*x4*x6^2*f7*f1*f4+24*x1*x4*x5^2*f0*f5^2+216*
x1^2*x4^2*f3*f5^2*f6*f2-8*x1^2*x4^2*f0*f6*f4^2*f7-48*x3^2*x4*x6*f5^3*f4+12*x3^
3*x1*f7^2*f5*f1^2-8*x3^3*x2*f4^2*f7*f2*f5-72*x3^2*x1*x4*f4*f5^3*f3-832*x3^2*x4
^2*f0*f6*f5*f7^2+48*x3^3*x1*f0*f6*f5*f7*f3-8*x3^3*x6*f4^2*f5^2+16*x3^3*x6*f0*
f4*f7^2+8*x3^3*x2*f3^2*f7^2*f2-16*x3^4*f5*f4^3*f6+32*x3^2*x1*x5*f5^3*f0+8*x3^3
*x8*f7*f3*f6*f4-8*x3^3*x6*f3*f5^3+16*x3^2*x2*x7*f0*f4*f7^2+64*x3^2*x1*x6*f0*f6
^2*f4-8*x2*x3^3*f3*f6*f5*f7*f1-48*x3^2*x1*x4*f2*f6^2*f5*f3+48*x3^3*x6*f5^2*f1*
f7-8*x3^3*x7*f7^2*f4*f1-16*x3^3*x7*f3^2*f7*f6-16*x3^3*x5*f0*f5^2*f7+32*x3^3*x2
*f4^2*f6^2*f2+88*x3^3*x1*f7*f0*f5^2*f4-16*x3^3*x1*f7*f1*f6*f5*f2-8*x3^3*x2*f4^
4*f6-48*x3^2*x6^2*f7*f1*f5+32*x3^3*x1*f2*f6*f5^2*f3-48*x3^2*x5^2*f0*f5*f6+24*
x3^2*x7^2*f3*f6^2+12*x3^2*x4^2*f2^2*f7^3+38*x4^2*x7^2*f3*f7^2+4*x4^2*x6^2*f1*
f7^2-108*x4^3*x2*f5^5-72*x4^4*f5^4*f7+54*x4^2*x5^2*f3*f5^2+104*x4^4*f3^2*f7^3+
108*x4^3*x5*f5^4+34*x4^2*x7^2*f7*f5^2+108*x4^2*x5*x7*f5^3+36*x4^2*x3^2*f5^5+24
*x4*x3^2*x7*f5^4-36*x2*x4*x7^2*f5^3+8*x5^2*x1*x6*f2^2+4*x5^3*x7*f1-8*x5^2*x6*
x7*f2-8*x5^3*x6*f0+36*x4*x5*x7^2*f5^2-12*x1^2*x5*x7*f3^3+8*x2*x5*x7^2*f4^2-6*
x1^2*x6^2*f3^3-8*x6*x5*x7^2*f4+36*x6^2*x4^2*f5^3+8*x1*x6*x7^2*f4^2+480*x3^2*x4
*x5*f0*f6*f5*f7-88*x1^2*x4*x6*f7^2*f0*f1+40*x1^2*x4*x6*f7*f0*f5*f3+128*x1^2*x4
*x6*f7*f2*f5*f1-20*x1^2*x2*x7*f3*f7*f2^2-16*x1^2*x2*x7*f0*f5^2*f4+16*x1^2*x3*
x7*f3*f5*f1*f6-48*x1^2*x4*x7*f7*f2*f3*f4+84*x1^2*x4*x7*f7*f3*f1*f5+8*x1^2*x4*
x7*f7*f0*f4*f5-24*x1^2*x4*x8*f7^2*f2*f1+24*x1^3*x3*f0*f5*f3*f7*f2+88*x1^3*x3*
f0*f5*f4*f7*f1+16*x1^3*x6*f1^2*f4*f6-132*x1^2*x2*x4*f2*f5*f1*f4*f7+48*x1^3*x4*
f6*f5^2*f1^2-32*x1^4*f5*f6*f0^2*f4-16*x2^2*x3^2*f4*f6*f7*f2^2-16*x2^2*x3^2*f1*
f6*f0*f7^2+32*x2^2*x3^2*f4^2*f6*f2*f5-16*x2^2*x1*x3*f1*f4*f6*f3*f5+12*x2^2*x1*
x3*f4^2*f1*f3*f7-32*x2^2*x1*x3*f4*f6*f2^2*f5-64*x2^2*x1*x3*f0*f6*f5*f7*f1-60*
x2^2*x1*x3*f2*f7*f4*f1*f5-80*x2^2*x1*x3*f0*f6*f4^2*f5-24*x2^2*x1*x3*f0*f4*f7^2
*f1-4*x2^2*x1*x3*f3^2*f5*f7*f1-12*x2^3*x3*f4*f5*f7*f2^2+16*x2^3*x3*f4^2*f1*f5*
f6+8*x2^3*x3*f2*f5^2*f4^2-16*x2^3*x3*f0*f5*f7^2*f1-424*x2^2*x4^2*f0*f5*f7^2*f4
+112*x2^2*x4^2*f3*f7^2*f1*f5+4*x2^2*x4^2*f3^2*f5^2*f7+104*x2^2*x4^2*f4*f5^2*f7
*f2+52*x2^2*x1*x4*f4*f7^2*f1^2+72*x2^2*x1*x4*f4^2*f5^2*f2-24*x2^2*x1*x4*f0*f5*
f4^2*f7+28*x2^2*x1*x4*f4*f5*f1*f3*f7-48*x2^2*x1*x4*f0*f5^2*f3*f7+40*x2^2*x1*x4
*f0*f4*f7^2*f2-20*x2^2*x1*x4*f1*f4^3*f7+48*x2^2*x1*x6*f0^2*f7^2+8*x2^2*x4*x8*
f7^2*f0*f5-28*x2^2*x4^2*f3*f7^2*f2*f4-24*x2^2*x3*x7*f5^2*f1*f6-64*x2^2*x1*x3*
f5*f0^2*f7^2+16*x2^3*x5*f0^2*f7^2-24*x2^2*x4*x6*f5^3*f2-16*x2^2*x1*x3*f4^4*f3+
8*x2^2*x3^2*f4*f5^2*f1*f6-8*x2^3*x3*f0*f3^2*f7^2+16*x2^2*x5*x6*f1*f4*f5-8*x2^4
*f0*f5^3*f4+36*x2^2*x4*x6*f3*f7*f2*f5+32*x2^2*x4*x6*f0*f6*f7*f4-76*x2^2*x4*x6*
f4*f5*f1*f7-24*x2^2*x4^2*f0*f6*f7^2*f3+32*x2^2*x1*x5*f0*f7*f1*f5+16*x2^3*x3*f0
*f6*f5*f7*f2-48*x2^2*x1*x7*f0*f6*f5*f4+16*x2^2*x4^2*f7^2*f2*f1*f6-32*x2^2*x3*
x6*f4*f6*f1*f5+48*x2^2*x3*x6*f0*f6*f5^2+24*x2^2*x1*x3*f4^3*f2*f5-8*x2^3*x4*f5^
2*f7*f2^2-8*x2^3*x5*f0*f5*f7*f2-8*x2^3*x6*f0*f5*f7*f3+8*x2^3*x6*f3*f7*f1*f4-8*
x2^3*x3*f0*f5^4-8*x2^3*x8*f7^2*f2*f1+40*x2^2*x3*x4*f0*f4^2*f7^2+96*x2^2*x3*x4*
f5^2*f6*f2*f4+8*x2^2*x3*x6*f4^2*f1*f7-48*x2^2*x4*x7*f5^2*f7*f1-8*x2*x1^2*x6*f4
^3*f1+12*x2*x1^2*x6*f4*f3^3-20*x2*x1^2*x5*f3^2*f2*f4-16*x2*x1^2*x5*f0*f6*f4*f2
-160*x2*x1*x4*x7*f0*f7*f4*f6-48*x2*x1*x4*x7*f6*f1*f5^2-40*x2*x1*x4*x7*f7^2*f2*
f1+32*x2*x1*x3*x5*f4*f6*f2^2-16*x2*x1*x3*x7*f5^3*f1-96*x2*x1*x3*x7*f0*f6^2*f4+
8*x2*x1*x4*x6*f1*f6*f7*f2-2*x2^2*x1^2*f3*f5^2*f2^2+12*x2*x1*x3^2*f4*f5^2*f3^2-\
32*x2*x1*x3^2*f3*f5*f4^3-20*x2*x1*x3^2*f4*f5*f7*f2^2-16*x2*x1*x3^2*f1*f7^2*f3*
f2-4*x2*x1*x3^2*f3^3*f4*f7+36*x2*x1*x3^2*f4^2*f5^2*f2+4*x2*x1^2*x3*f2^2*f5^2*
f4-4*x2^2*x1*x3*f3*f5^3*f1-4*x2*x1^2*x4*f3^4*f7-64*x2*x1^2*x3*f6*f0^2*f7*f5-20
*x2*x1^2*x3*f3^2*f4^3-64*x2*x1^2*x7*f0^2*f7^2+144*x2*x1^2*x4*f4*f5*f1*f6*f3-16
*x2*x1*x3^2*f3*f5^2*f1*f6+60*x2*x1*x3*x7*f1*f7*f4^2+144*x2*x1*x3*x4*f2*f6*f7*
f5*f1-16*x2^2*x4*x1*f7*f6*f5*f1^2+8*x2*x1^2*x3*f4^4*f2+12*x2*x1^2*x7*f3^3*f5-\
16*x2*x1^2*x6*f0*f6*f5*f2-64*x2*x1^2*x3*f0*f6^2*f5*f1-80*x2*x1*x3*x4*f0*f6*f5*
f3*f7-12*x3^2*x6^2*f7*f2*f4-4*x3^3*x4*f4^2*f7^2*f2-4*x3^2*x1*x5*f4^3*f3+8*x3^2
*x1*x5*f7*f2^2*f4-4*x3^3*x5*f4^2*f7*f2+4*x3^3*x5*f3*f5*f2*f7-12*x3^2*x1*x7*f2*
f7^2*f1-4*x3^2*x7^2*f7*f3*f5+8*x3^2*x1*x7*f3^2*f4*f7-12*x3^2*x1*x5*f3^2*f4*f5-\
20*x3^2*x1*x5*f4^2*f2*f5+8*x3^2*x5^2*f2*f4*f5-12*x3^2*x2*x5*f4^2*f3*f5+16*x3^2
*x2*x5*f3*f7*f2*f4+12*x3^2*x2*x5*f1^2*f7^2+16*x3^2*x1*x6*f2^2*f7*f5+12*x3^2*x2
*x6*f4^2*f7*f2-4*x3^2*x2*x6*f3*f5*f2*f7-24*x3^2*x2*x6*f4*f5^2*f3-4*x3^3*x6*f4^
2*f7*f3+4*x3^3*x7*f4*f5*f7*f3+4*x3^3*x7*f3*f7^2*f2-12*x3^2*x4*x7*f7^2*f4*f2-32
*x3^2*x4*x7*f3^2*f7^2-8*x3^2*x5*x7*f7*f2*f4+6*x1^4*f4^2*f3*f2^2-24*x1^4*f6*f1^
2*f3*f4+16*x1^2*x4^2*f7^2*f0*f6*f1+48*x1^2*x3*x4*f6*f7*f1^2*f5-48*x1^3*x6*f5*
f0^2*f7+8*x1^3*x6*f1^2*f3*f7-48*x1^2*x2*x5*f7*f0^2*f5-12*x1^3*x4*f4^2*f5*f2*f3
+48*x1^3*x4*f0*f4*f6*f1*f7+16*x1^4*f4^2*f0^2*f7+16*x1^4*f0*f6*f4^2*f1+16*x1^4*
f4*f7*f2*f1^2+16*x1^2*x3^2*f0*f7*f4^3-8*x1^3*x2*f6*f2^3*f4+16*x1^3*x4*f6*f7*f1
^2*f3+48*x1^3*x4*f0*f6*f5*f4*f3-16*x1^3*x3*f0*f5*f4^3+8*x1^4*f6*f2^2*f1*f4+48*
x1^2*x4*x5*f3*f5^2*f1-4*x1^4*f5*f2^3*f4+24*x1^4*f0*f5*f2*f7*f1-16*x1^4*f5*f6*
f2*f1^2-4*x1^4*f7*f2^2*f3*f1-8*x1^2*x3*x5*f0*f5*f4^2-4*x1^4*f1*f4^3*f2-16*x1^4
*f0*f5^2*f4*f1+8*x1^4*f2*f6*f3^2*f1-8*x1^2*x2^2*f0*f5*f3*f7*f2+24*x1^2*x2^2*f0
*f3^2*f4*f7-32*x1^2*x2^2*f2*f6*f1*f4^2+8*x1^3*x2*f1*f6*f5*f2^2+24*x1^3*x2*f0*
f3*f7*f1*f5-16*x1^3*x2*f0*f5*f4^2*f3+16*x1^3*x2*f3*f4*f2^2*f5-16*x1^3*x2*f0*f6
*f5*f3*f2-12*x1^3*x6*f3*f1*f4^2-32*x1^3*x3*f2*f5*f1*f6*f3-12*x1^3*x3*f3^2*f7*
f2^2-8*x1^3*x3*f6*f1^2*f7*f2+16*x1^3*x3*f5^3*f1^2-28*x1^2*x2*x5*f7*f1^2*f3+38*
x1^2*x4^2*f7^2*f3*f2^2-24*x1^4*f0*f5^2*f2*f3+4*x1^4*f4^2*f1^2*f5-16*x1^2*x3^2*
f0*f6*f5*f4^2+76*x1^2*x4*x5*f3^2*f7*f1+40*x1^2*x3*x4*f0*f5*f1*f7^2-36*x1^2*x3*
x4*f4^2*f7*f2*f3+16*x1^3*x4*f0*f4^2*f7*f3-96*x1^3*x4*f0*f6^2*f5*f1+16*x1^2*x4^
2*f7*f2*f5*f1*f6-28*x1^2*x4^2*f7^2*f1^2*f5-28*x1^3*x4*f3^2*f4*f1*f7-16*x1^3*x4
*f0*f6*f3*f7*f2+32*x1^3*x4*f3*f4*f7*f2^2-12*x1^3*x4*f4*f5*f3^3-32*x1^3*x4*f7^2
*f0*f2^2+64*x1^3*x4*f0*f5^2*f7*f1-24*x1^3*x4*f5*f4*f7*f1^2-68*x1^3*x4*f2*f5*f1
*f3*f7+16*x1^3*x4*f0*f5*f3^2*f7-64*x1^3*x4*f6*f5*f0^2*f7+12*x1^3*x4*f4*f5^2*f2
^2-24*x1^3*x4*f0*f5^2*f4^2+216*x1^2*x2*x4*f0*f4*f3*f7*f5-68*x1^2*x2*x4*f3*f5*
f7*f2^2-256*x1^2*x2*x4*f0*f6*f5*f1*f7-64*x1^2*x2*x4*f3^2*f5*f7*f1-72*x2*x4*x5*
x7*f3*f5^2-24*x3*x8*f7*x2*x4*f6*f2*f5+136*x2*x4^2*x8*f7^3*f0+120*x4^2*x8*f7*x2
*f4*f5^2+12*x5*x8*f7*x2*x4*f2*f5-16*x6*x8*f7*x2*x4*f3*f5+32*x4^3*x1*f0*f6*f7^2
*f4-20*x4^3*x8*f7^3*f2+336*x4^2*x3*x6*f0*f6*f7^2+208*x4^3*x3*f7^2*f5^2*f2+8*x4
^3*x3*f7^2*f6*f4*f2-300*x4^3*x5*f5^2*f7*f3+504*x4^2*x3*x5*f0*f5*f7^2-20*x4^3*
x7*f4^2*f7^2-16*x4^3*x1*f1*f6*f7^2*f3+16*x4^4*f6^2*f1*f7^2+68*x4^2*x1*x6*f7^2*
f2^2+312*x4^2*x2*x6*f0*f5*f7^2-232*x4^3*x6*f7^2*f5*f2+16*x4^3*x1*f0*f5^2*f7^2-\
36*x4^3*x1*f4*f5*f1*f7^2-8*x3*x8*f7^2*x4^2*f4^2-324*x4^3*x1*f5*f3*f7^2*f2+240*
x4^3*x6*f7*f4*f5^2+216*x4^3*x2*f5^3*f6*f4+128*x4^3*x6*f0*f7^3-64*x4^3*x5*f3^2*
f7^2+148*x4^3*x1*f2*f7^3*f1-80*x4^3*x3*f7^3*f4*f1+112*x4^3*x3*f4*f7^2*f3*f5-96
*x4^3*x3*f0*f6^2*f7^2+80*x4^3*x3*f3*f7^3*f2+10*x2^2*x3^2*f7^2*f3*f2^2-2*x2^2*
x3^2*f3^2*f4^2*f7-8*x2^2*x1*x3*f3*f7^2*f1^2-8*x2^2*x1*x3*f1*f7^2*f2^2-8*x2^2*
x1*x3*f5^3*f2^2+28*x2^2*x1*x3*f3*f5^2*f2*f4+12*x2^2*x1*x3*f3^2*f5*f4^2+4*x2^3*
x3*f2^3*f7^2+4*x2^3*x4*f3*f7^2*f2^2+4*x2^3*x4*f1*f4*f7^2*f2+4*x2^3*x4*f4^3*f7*
f2+4*x2^3*x3*f2*f5^2*f7*f1-4*x2^3*x3*f4^2*f3*f7*f2+4*x2^3*x3*f4*f5^3*f1+4*x2^2
*x1*x4*f4*f7*f3^3-24*x2^2*x1*x4*f3^2*f5*f7*f2+4*x2^2*x4*x5*f5*f7*f2^2+12*x2^2*
x4*x5*f3*f7*f2*f4-32*x2^2*x4*x5*f3*f7*f1*f5+8*x2^2*x1*x6*f5^2*f2^2+16*x2^2*x1*
x5*f2^2*f4*f5+8*x2^2*x1*x5*f3*f4*f1*f5-12*x2^2*x1*x5*f2*f1*f5^2-16*x2^2*x3*x5*
f4^2*f2*f5-4*x2^2*x3*x5*f5^2*f1*f4+8*x2^2*x3*x5*f7*f4*f2^2-8*x2^2*x3*x5*f2*f5*
f7*f1-4*x2^2*x7^2*f7*f1*f5-4*x2^2*x1*x7*f5^2*f2*f3-8*x2^2*x1*x7*f7*f4*f2^2-4*
x2^3*x7*f5^3*f1+12*x4^3*x5*f4^2*f5*f7+8*x4^2*x2*x6*f4*f7*f3*f5-60*x2*x6*x4^2*
f4*f7^2*f1+24*x4^3*x6*f7*f3*f5*f6+152*x4^2*x5*x6*f7*f2*f5-136*x4^2*x1*x7*f0*f5
*f7^2-232*x4^2*x3*x7*f7^2*f6*f1+432*x4^2*x3*x7*f7*f3*f5*f6+48*x4^3*x7*f4*f5*f7
*f6-12*x4^3*x7*f5^3*f7-196*x4^2*x5*x7*f7*f3*f5+164*x4^2*x6*x7*f7*f4*f5-20*x4^3
*x8*f7^2*f4*f5-96*x4^2*x6*x8*f7*f5^2+24*x1^2*x4*x7*f5^3*f1-12*x1^2*x4*x5*f2^2*
f5^2+144*x1*x4*x6*x7*f7*f0*f6-96*x1*x4*x3*x6*f5^2*f1*f6+56*x1*x4*x6*x8*f7^2*f0
-12*x1*x4*x6*x8*f7*f2*f5+4*x1*x4^2*x7*f7^2*f1*f4-4*x1*x4^2*x7*f7*f4^3+48*x1*x4
*x5*x7*f7*f2*f3+4*x1*x4*x5*x8*f7*f2*f4-96*x3*x4*x1*x7*f3*f6*f2*f7+56*x4*x3*x6*
x7*f7*f3*f5-4*x4*x3*x6^2*f7*f2*f5-88*x3*x4*x6*x7*f7*f2*f6+72*x4*x3*x7^2*f3*f6*
f7-12*x4*x3*x6^2*f7*f3*f4-144*x4*x3*x5*x7*f3*f5*f6+40*x4^2*x3^2*f3^2*f6^2*f7+
32*x2*x4^2*x1*f7*f6*f5*f2^2+16*x1*x4^2*x2*f1*f6*f4^2*f7+8*x3*x4^2*x1*f4*f6*f7*
f3^2-32*x1*x4^2*x3*f6^2*f7*f2^2-36*x1*x4^2*x3*f3*f5^4+32*x1*x4^2*x3*f0*f6^2*f7
*f4+8*x1*x4^2*x6*f7*f4^2*f3-48*x1*x4*x2*x5*f0*f5^3-16*x1*x4^2*x8*f4*f7^2*f2-40
*x1*x4^2*x8*f7^2*f1*f5-48*x1^2*x4*x7*f1*f6*f5*f4+80*x1*x4^2*x3*f5*f7*f4^2*f3+
48*x1*x4*x3*x5*f3*f6*f2*f5-24*x1*x4*x5*x7*f5^2*f2-48*x1*x4*x5*x6*f1*f5^2-24*x1
*x4*x7^2*f7*f1*f6+44*x1*x4*x7^2*f7*f2*f5+48*x1*x4*x6*x7*f5*f4^2+24*x1*x4*x5*x7
*f7*f0*f5-80*x1^2*x4*x6*f0*f6*f7*f2+48*x1*x4*x5*x6*f2*f4*f5+80*x1*x4*x5*x6*f7*
f0*f4+16*x1*x4*x2*x6*f0*f6*f7*f3+128*x1^2*x4*x7*f7^2*f0*f2-56*x1^2*x4*x7*f7*f2
^2*f5-36*x1*x4*x7^2*f4*f5^2+16*x1*x4*x7^2*f7*f3*f4-104*x1*x4*x6*x7*f7*f1*f5-4*
x1^3*x6*f3^2*f2*f4+32*x1^2*x3*x4*f7^2*f2^3-4*x1^3*x5*f3*f4*f2^2-4*x1^3*x5*f2*
f3^3+4*x1^3*x5*f2^3*f5+4*x1^3*x5*f1^2*f2*f7+4*x1^3*x5*f2*f1*f4^2+8*x1^2*x3*x5*
f4^2*f2*f3+40*x1^2*x3*x5*f4*f5*f3*f1-16*x1^2*x3*x5*f7*f2*f3*f1-4*x1^3*x7*f4^2*
f2*f3-4*x1^3*x7*f3^3*f4+4*x1^3*x7*f4^3*f1+4*x1^3*x7*f7*f2^3-16*x1^2*x2*x7*f3*
f5^2*f1+16*x1^2*x2*x7*f3*f5*f2*f4-32*x1^2*x3*x7*f7*f2^2*f4-24*x1^2*x3*x7*f3^2*
f7*f2-24*x1^2*x3*x7*f7*f2*f1*f5+40*x1^2*x3*x7*f7*f3*f1*f4-16*x1^2*x2*x5*f7*f1*
f2^2+12*x1^2*x2*x6*f7*f2^3-100*x4^3*x7*f7^3*f1+180*x4^2*x3*x5*f5^3*f4-36*x4^2*
x3*x8*f7^3*f1-8*x4^2*x2*x5*f7^2*f2^2+64*x4^3*x5*f0*f6*f7^2-84*x4^2*x1*x6*f7*f5
*f3^2+36*x4^2*x3*x7*f7^2*f5*f2+36*x4^2*x3*x7*f7^2*f3*f4+28*x6*x8*f3*f7^2*x4^2-\
20*x2*x8*f7^2*x4^2*f3*f4+72*x4^2*x1*x6*f4^2*f5^2-140*x4^2*x1*x6*f7*f5*f4*f2-24
*x4^3*x2*f4*f6*f7*f3*f5+140*x4^2*x5*x7*f1*f7^2-216*x4^2*x3*x5*f5^2*f3*f6-108*
x4^2*x2*x5*f5^3*f3-36*x4^2*x3*x5*f3*f7^2*f2-8*x4^4*f4*f6*f3*f7^2+36*x4^4*f7^3*
f4*f2-436*x4^4*f7^3*f5*f1+32*x4^3*x1*f4^2*f7^2*f2-48*x4^3*x1*f7^2*f6*f2^2+156*
x4^3*x1*f4*f5^2*f7*f3+16*x4^3*x2*f7^2*f6*f3*f2-144*x4^3*x2*f5^2*f7*f2*f6-8*x4^
3*x2*f4^2*f7^2*f3+380*x4^3*x2*f7^2*f5*f4*f2-324*x4^3*x2*f1*f5^2*f7^2-376*x4^3*
x2*f0*f4*f7^3-252*x4^3*x2*f4^2*f7*f5^2-824*x4^3*x3*f5*f6*f1*f7^2-440*x4^3*x3*
f0*f5*f7^3+64*x4^2*x1*x5*f1*f5*f7*f4-176*x4^2*x1*x5*f7^2*f3*f0-36*x4^2*x1*x5*
f3*f4*f5^2+72*x4^2*x1*x5*f1*f5^2*f6-188*x4^2*x2*x5*f2*f5*f4*f7-40*x4^2*x2*x5*
f7^2*f3*f1-200*x4^2*x3*x5*f7*f5^2*f2+484*x4^3*x5*f7^2*f5*f1-16*x3^4*f5^2*f7*f2
*f4+4*x3^4*f3*f7^2*f2*f4+16*x3^3*x1*f0*f5*f7^2*f2+76*x3^2*x2*x4*f1*f7*f5^3-24*
x3^2*x2*x7*f4^2*f7*f3-160*x3^2*x1*x4*f7*f6*f5*f2^2+96*x3^2*x2*x5*f4*f6^2*f0-24
*x3^2*x4*x7*f5^2*f7*f3-16*x3^2*x2*x5*f7*f6*f2*f1+32*x3^2*x2*x7*f6^2*f2*f4-8*x3
^2*x2*x8*f7*f6*f1*f5-16*x3^3*x2*f1*f6^2*f4*f5-16*x3^3*x2*f6*f7^2*f1^2+52*x3^2*
x1*x7*f7*f1*f4*f5-72*x3^2*x4^2*f0*f4*f7^3+8*x3^2*x2*x8*f7*f2*f4*f6-16*x3^2*x6*
x7*f4*f5^2-32*x3^3*x7*f6^3*f1+32*x3^3*x2*f0*f6^2*f7*f3+64*x3^3*x6*f0*f6^3+76*
x3^2*x2*x4*f5^2*f7*f2*f4-80*x3^2*x1*x7*f0*f6*f4*f7-96*x3^3*x4*f1*f6^3*f5-16*x3
^4*f4*f6*f7*f3^2+120*x3^2*x4*x7*f7*f5*f2*f6-8*x3^2*x4*x7*f7^2*f5*f1+48*x3^2*x4
^2*f3*f6*f2*f7^2+344*x3^2*x4^2*f5^2*f7*f2*f6+48*x3^3*x5*f0*f6*f4*f7+32*x3^2*x5
*x6*f7*f0*f5-16*x3^2*x6*x8*f7*f2*f6-48*x3^2*x1*x5*f1*f6^2*f2-44*x3^2*x4*x5*f5^
2*f1*f7+36*x3^2*x1*x6*f5*f4^2*f3-32*x3^3*x1*f0^2*f7^3+8*x3^2*x5*x6*f7*f1*f4+24
*x3^3*x7*f5*f6*f1*f7+8*x3^2*x7*x8*f7*f3*f6+96*x3^3*x5*f0*f6^2*f5+28*x3^2*x5*x7
*f5*f4^2-16*x3^3*x6*f4*f6*f1*f7+12*x3^3*x6*f3*f7^2*f1-144*x3^2*x4*x7*f6^2*f1*
f7-64*x3^2*x1*x6*f2*f5*f3*f6-16*x3^3*x8*f7*f6^2*f1-96*x3^2*x5*x6*f0*f6^2-32*x3
^2*x2*x6*f4*f6*f5*f2-32*x3^2*x2*x6*f5^2*f1*f6-40*x3^2*x1*x7*f7*f2*f3*f5-16*x3^
2*x1*x7*f6^2*f2*f3-32*x3^2*x2*x5*f4^2*f2*f6+12*x1^3*x2*f1*f7*f3^2*f2-16*x1^3*
x2*f0*f4*f3*f7*f2+16*x1^3*x4*f0*f3*f1*f7^2-24*x1^2*x2^2*f0*f1*f7^2*f2+8*x1^3*
x6*f0*f4^3+48*x1^3*x4*f3^2*f5^2*f2+104*x1^2*x2*x3*f0*f5*f4*f7*f2-96*x1^2*x2^2*
f6*f0^2*f7*f4+20*x1^3*x4*f1^2*f7^2*f2+248*x1^2*x4^2*f7^2*f0*f5*f2+64*x1^2*x3*
x4*f0*f5^2*f3*f7+4*x3^4*f4^2*f5^3+8*x1^2*x6*x7*f2^2*f6-8*x1^2*x6^2*f7*f1^2+4*
x1^2*x6^2*f1*f4^2-4*x1^2*x6^2*f7*f0*f2+8*x3*x6^2*x7*f4*f5-72*x6*x4*x7^2*f5*f6-\
8*x6*x4*x3*x7*f1*f7^2-2*x6^2*x4^2*f7*f4^2+4*x6^2*x4*x8*f7*f4-8*x2*x6^2*x5*f1*
f5+16*x2*x6^2*x3*f6*f1*f5-40*x2*x6*x3*x7*f7*f1*f5-16*x3^2*x6*x7*f7*f1*f6-16*x3
*x6*x1*x7*f5^2*f2+24*x2*x6*x3*x7*f7*f3^2-2*x2^2*x6^2*f7*f2^2+4*x3*x6^2*x2*f7*
f2*f3+8*x6*x5*x3*x7*f7*f1+4*x6^2*x5^2*f1+4*x7^3*x5*f5-4*x7^3*x2*f5^2-12*x7^2*
x6*x8*f7-8*x7^3*x6*f6+4*x7^2*x3^2*f5^3+4*x7^2*x6^2*f5+4*x3*x8^3*f7^2-2*f7*x6^2
*x8^2+16*x3^2*x6^2*f6^2*f1+16*x1^2*x6*x7*f0*f5^2+20*x1^2*x6*x7*f3^2*f4-4*x6^2*
x8*f7*x3*f3-8*x1^2*x6*x7*f4^2*f2+8*x2*x6^2*x4*f7*f3^2-4*x7^3*x1*f4*f5+4*x7^3*
x1*f7*f2-4*x7^3*x2*f7*f3+16*x7^2*x2*x8*f7*f4+8*x7^2*x3*x8*f5*f7+4*x7^2*x3^2*f7
*f2*f6-16*x3*x8*f7^2*x2*x7*f1+4*x1^2*x7^2*f1*f5^2-8*x2^2*x7^2*f7*f0*f6+8*x2*x7
^2*x3*f7*f2*f5+8*x2^2*x8*f7*x7*f3*f4-28*x2*x7*x4*x8*f7^2*f2+20*x1^2*x7^2*f7*f3
*f1-12*x1^2*x7^2*f2^2*f7-8*x1^2*x7^2*f1*f4*f6+16*x1*x7^2*x3*f6*f2*f5+8*x1*x7*
x3*x8*f0*f7^2-8*x1*x7^2*x6*f2*f6+24*x1^2*x7^2*f2*f3*f6-16*x1^2*x7^2*f0*f5*f6-8
*x3*x8*f7*x2*x7*f2*f6+10*x2^2*x7^2*f7*f3^2-4*x7^2*x3*x5*f7*f2+8*x7^2*x4^2*f7*
f4*f6-2*x1^2*x7^2*f4^2*f3+4*x1*x7^2*x2*f5^2*f2-4*x1*x7^2*x3*f3*f5^2-8*x7^2*x3*
x6*f5^2-8*x7^2*x3*x6*f4*f6-16*x2*x7^2*x4*f7*f2*f6-8*x6*x8*f7*x2*x7*f3-8*x1^2*
x7^2*f3^2*f5+4*x1^2*x7^2*f2*f4*f5-4*x2^2*x7^2*f7*f2*f4-4*x2^2*x7*x8*f7*f2*f5+4
*x2*x7*x5*x8*f7*f2+8*x1*x7^2*x2*f2*f4*f6-4*x7*x3^2*x8*f2*f7^2-12*x7*x3*x6*x8*
f7*f4+36*x1*x7^2*x2*f7*f2*f3+24*x1^2*x3*x7*f5^2*f2*f3+12*x1^2*x3*x6*f3^3*f5-16
*x1*x3*x5*x6*f3*f1*f6-36*x1^2*x3*x7*f3^2*f5*f4-16*x1*x3*x7^2*f6^2*f1-72*x1*x3*
x4*x6*f6*f3^2*f5+48*x1*x3*x4*x6*f4^3*f5-128*x1*x3*x4*x6*f0*f7^2*f3+56*x1*x3*x4
*x6*f0*f5^2*f7+288*x1*x3*x4*x6*f0*f6^2*f5+120*x1*x3*x4*x6*f2^2*f6*f7-32*x1*x3*
x5*x6*f1*f4*f5+24*x1*x3^2*x7*f3*f6*f1*f7+48*x1*x3*x4*x7*f3*f5*f4*f6+76*x1*x3*
x4*x7*f5^2*f7*f1-208*x1*x3*x4*x7*f0*f6*f7*f5+56*x1*x3*x4*x7*f7*f3^2*f5+40*x1*
x3*x6*x7*f3*f5*f4+96*x1*x3*x6*x7*f0*f6^2-24*x1*x3*x6*x7*f6*f3^2-16*x1*x3*x2*x8
*f7*f0*f6*f4+12*x1*x3*x4*x8*f7^2*f2*f3+96*x1*x3*x4*x5*f4*f6*f1*f5-6*x1^2*x3^2*
f3^3*f5^2+80*x1*x3*x2*x4*f0*f5*f7^2*f2-40*x1*x3*x4*x5*f0*f5*f7*f4+20*x1*x3*x7^
2*f7*f1*f5+8*x2^2*x3^2*f2*f1*f7^2*f4+24*x2^2*x3^2*f0*f6*f4^2*f7+4*x2^2*x3^2*f4
^2*f5*f1*f7-8*x2^2*x3^2*f0*f4*f7^2*f3+16*x2^2*x3^2*f0*f6^2*f7*f2-4*x2^2*x3^2*
f2*f7*f4^3+16*x2^2*x3^2*f1*f6^2*f4^2+32*x2*x3*x4^2*f7^2*f6*f2^2+216*x2*x3*x4^2
*f5^3*f3*f6-108*x2*x3*x4^2*f5^4*f4-424*x2*x3*x4^2*f7^2*f0*f5^2+64*x2*x3*x4^2*
f7^3*f0*f3+60*x2*x3*x4*x8*f7*f5*f4^2-152*x2*x3*x4^2*f3^2*f5*f6*f7+8*x2^2*x3*x5
*f6*f7*f1^2-48*x2*x3*x5^2*f0*f6*f4+32*x2*x3*x5*x7*f7*f0*f5+84*x2*x3*x4*x7*f7*
f5^2*f2+320*x2*x3*x4*x6*f0*f6*f7*f5+20*x2*x3*x4^2*f7*f5^2*f3*f4-512*x3*x2*x4^2
*f7^2*f0*f6*f4+264*x2*x3*x4^2*f7*f2*f6*f4*f5-148*x2*x3*x4^2*f4^3*f7*f5+96*x2*
x3*x4*x7*f0*f6^2*f7-16*x2^2*x3*x5*f0*f6*f7*f2-8*x2^2*x3*x7*f7*f6*f2^2-32*x1^2*
x3*x6*f2*f0*f6^2-16*x1*x3*x4*x8*f7^2*f1*f4+48*x1^2*x3^2*f6^2*f5*f1^2+160*x1*x3
*x4*x7*f4*f5*f2*f7-32*x1*x3*x7^2*f7*f0*f6+8*x1*x3*x7^2*f3*f6*f4+16*x1*x3*x2*x6
*f7*f4*f2^2-32*x1^2*x3^2*f6^2*f0^2*f7-16*x1*x3^2*x2*f1*f6^2*f3*f4+64*x1*x3^2*
x4*f0*f6^2*f7*f3-20*x1*x3*x7^2*f5*f4^2-64*x1*x3*x4*x6*f0*f6*f7*f4+28*x1^2*x3*
x4*f4*f5*f1*f3*f7+24*x1^2*x3*x4*f4*f5^3*f1-24*x1*x3*x4*x7*f7^2*f2^2+8*x1*x3*x4
^2*f0*f5*f7^2*f4-144*x1*x3*x4^2*f5^2*f6^2*f1+240*x1*x3*x4^2*f7^2*f2*f1*f6+304*
x1*x3*x4^2*f0*f6*f7^2*f3-12*x1^2*x3*x4*f4^3*f3*f5+48*x1^2*x3*x4*f4^2*f5^2*f2+
16*x1^2*x3*x4*f1*f4^3*f7-92*x1^2*x3*x4*f2*f5^2*f7*f1+16*x2*x5*x6*x7*f2*f5+8*x2
*x5*x1*x7*f2*f3*f5+8*x2*x5^2*x3*f7*f0*f3+4*x3*x5^2*x4*f7*f2*f3-4*x5*x3*x2*x6*
f7*f2^2-4*x3^2*x5*x6*f7*f2*f3+24*x5*x3*x4*x6*f7*f3^2+24*x1^2*x5*x6*f7*f0*f1+24
*x1*x5*x4*x8*f7*f1*f5+40*x5*x1*x3*x6*f7*f0*f3+8*x1*x5*x7^2*f1*f6-8*x5*x4*x6^2*
f7*f1+10*x4^2*x5^2*f7*f3^2-16*x5*x4^2*x6*f7*f1*f6+8*x1*x5*x7*x8*f7*f1+4*x2*x5^
2*x3*f7*f2*f1+4*x4*x5^2*x2*f7*f3*f1+4*x4*x5^2*x2*f7*f2^2-4*x2*x5*x7^2*f1*f7-4*
x1*x5^2*x2*f1*f3*f4-4*x1*x5^2*x3*f3*f1*f5-4*x1^2*x5*x7*f5*f2^2-2*x1^2*x5^2*f2^
2*f3-32*x4*x5*x7^2*f7*f3-8*x5*x3^2*x8*f0*f7^2-8*x5^2*x3*x6*f1*f5+8*x1*x5^2*x2*
f0*f4^2+8*x1^2*x5*x6*f0*f4^2+16*x1^2*x5*x6*f6*f1^2+20*x1^2*x5*x6*f3^2*f2-8*x1^
2*x5*x6*f4*f2^2+24*x1*x5*x2*x6*f7*f1^2-24*x5*x3*x7^2*f3*f6+20*x5*x3*x7^2*f4*f5
-8*x4^2*x5^2*f7*f0*f6+12*x5*x4^2*x8*f7*f4*f5+48*x5*x4*x6*x7*f7*f2-48*x4*x5*x6*
x7*f4*f5-8*x2^2*x7*x5*f7*f3*f1-12*x2*x5*x4*x6*f7*f2*f3+8*x2^2*x5*x6*f7*f0*f3-\
12*x1*x5^2*x4*f1*f4*f5-48*x1^2*x5*x6*f0*f5*f3+8*x1*x5*x2*x8*f7*f0*f4+32*x5^2*
x1*x4*f7*f0*f3+16*x1*x5*x3*x7*f1*f5^2-4*x1*x5^2*x3*f1*f4^2+4*x4^2*x7*x5*f7*f4^
2+4*x5*x4*x3*x8*f7*f4^2-8*x6*x8*f3*f7*x4*x5+4*x5*x4*x7*x8*f4*f7-12*x3*x6*x2*x5
*f7*f3*f1-8*x2*x5^2*x6*f1*f4+32*x5*x3*x6*x7*f2*f6+4*x2^2*x7*x5*f7*f2^2+12*x2*
x5*x3*x7*f7*f2*f3-2*x2^2*x5^2*f7*f1^2-4*x2^2*x5*x8*f7*f1*f4+4*x2*x5*x6*x8*f7*
f1+4*x5^2*x3^2*f1*f5^2+4*x5^2*x3^2*f7*f3*f1-16*x5*x3*x1*x6*f0*f6*f4-16*x5*x3*
x6*x7*f4^2-4*x5*x3*x2*x8*f7*f2*f4-4*x5*x3^2*x8*f7*f3*f4-4*x5^2*x3*x8*f7*f1+8*
x5*x3*x6*x8*f7*f2-4*x5*x3*x7*x8*f7*f3+2*x1^4*f7*f2^4+4*x1^3*x6*f3^4+16*x1^4*f5
^3*f0^2+16*x1^4*f6^2*f1^3-272*x1^2*x4^2*f7^3*f0^2-4*x2^2*x3^2*f4^4*f5+6*x2^2*
x4^2*f3^3*f7^2+12*x2^2*x6^2*f4^2*f3-4*x2^2*x7^2*f5*f4^2+6*x2^2*x7^2*f3*f5^2+2*
x2^4*f4^4*f3+32*x2^2*x3^2*f0^2*f7^3+54*x2^2*x4^2*f5^4*f3-98*x2^2*x4^2*f7^3*f1^
2-36*x2^2*x4^2*f5^3*f4^2-8*x2*x1*x3^2*f4^5-8*x2*x1*x7^2*f4^3+2*x3^4*f1^2*f7^3+
2*x3^4*f7*f4^4+2*x3^4*f3*f5^4+6*x3^2*x5^2*f4^2*f3+8*x3^2*x2*x5*f4^4+12*x3^2*x6
^2*f3*f5^2+8*x3^2*x1*x6*f4^4-8*x3^2*x5*x6*f4^3+12*x3^2*x7^2*f7*f4^2+2*x3^4*f3^
3*f7^2-4*x3^2*x7^2*f1*f7^2-176*x1^2*x4*x5*f0*f4*f3*f7+160*x1^2*x4*x5*f0^2*f7^2
-24*x1^2*x4*x5*f1^2*f5*f7+48*x1^2*x4*x5*f0*f6*f1*f7-16*x1^3*x6*f3^2*f5*f1+16*
x1^3*x6*f2*f5*f1*f4-48*x1^3*x6*f0*f6*f4*f2-16*x1^3*x6*f5^2*f1^2+8*x1^3*x6*f2^3
*f6+32*x1^3*x6*f2*f1*f6*f3-8*x1^3*x6*f1*f4*f0*f7-12*x1^3*x6*f3*f5*f2^2+16*x1^3
*x6*f0*f5^2*f2+64*x1^2*x2*x6*f2*f6*f1*f4-48*x1^2*x2*x6*f4*f5*f3*f1-32*x1^2*x2*
x6*f0*f3^2*f7-16*x1^2*x2*x6*f4^2*f2*f3-8*x2^2*x7*x8*f0*f7^2+8*x2*x7^2*x3*f4^2*
f6+8*f7*x3^2*x8^2*f4*f6+8*f7^2*x3*x8^2*x4*f4+144*x3^2*x4*x5*f4*f6*f1*f7+84*x3^
2*x4*x5*f5^2*f4^2-96*x3^2*x4*x7*f4*f6*f5^2-32*x3^3*x6*f6^2*f2*f4+8*x3^2*x4^2*
f4^2*f7^2*f3-12*x3^3*x5*f4*f5*f1*f7-4*x3^4*f1*f4^2*f7^2+8*x3^3*x1*f7*f4^3*f2-\
16*x3^2*x7^2*f4*f5*f6-96*x3^2*x4*x7*f0*f6*f7^2+96*x3^3*x4*f4*f5*f7*f2*f6-80*x3
^2*x1*x4*f3*f1*f5*f6*f7-144*x3^2*x4^2*f5^3*f6*f4+24*x3^3*x2*f4^2*f3*f5*f6+8*x3
^2*x1*x7*f5^3*f2-16*x3^3*x5*f1*f6*f5^2-32*x3^3*x5*f4*f6*f5*f2-28*x3^2*x1*x4*f7
^2*f4*f2^2-16*x3^2*x4*x5*f3*f6*f2*f7-32*x3^2*x4*x5*f3*f7^2*f1-32*x3^2*x1*x5*f7
*f0*f3*f5+96*x3^2*x2*x6*f0*f6^2*f5-12*x3^2*x1*x4*f3^2*f7^2*f2+32*x3^4*f4*f6^2*
f2*f5-24*x3^4*f0*f5*f7^2*f4-4*x3^2*x2*x4*f5*f7^2*f2^2+24*x3^2*x1*x7*f3^2*f5*f6
-24*x3^3*x4*f3^2*f7^2*f4+72*x3^2*x2*x4*f4^2*f7*f2*f6+8*x3^3*x7*f4^3*f7-24*x3^2
*x5^2*f1*f4*f6-32*x3^2*x2*x7*f3^2*f5*f7+16*x3^3*x1*f1*f5^4+8*x3^3*x4*f4*f5^2*
f7*f3-8*x3^3*x5*f0*f3*f7^2-16*x3^2*x5^2*f7*f0*f4-64*x3^2*x1*x6*f7*f6*f0*f3+128
*x3^2*x1*x6*f0*f6*f5^2-48*x3^2*x5*x7*f3*f6*f4-24*x3^2*x1*x6*f3^2*f4*f6+80*x3^2
*x4*x5*f0*f4*f7^2+16*x3^3*x2*f1*f6*f5^3+16*x3^4*f1*f6^2*f5^2-32*x3^2*x2*x7*f0*
f6*f5*f7-152*x3^2*x1*x6*f7*f4*f5*f0-20*x3^2*x2*x5*f7*f4^2*f1-32*x3^2*x2*x5*f3*
f6*f0*f7+24*x3^2*x2*x7*f3*f7^2*f1+184*x4^2*x2*x5*f1*f5^2*f7+236*x4^3*x7*f7^2*
f5*f3+368*x4^3*x2*f0*f6*f5*f7^2+24*x4^3*x3*f4^2*f6*f7*f5+648*x4^3*x3*f5^2*f7*
f3*f6+116*x4^2*x3*x5*f7^2*f4*f1+12*x4^3*x6*f4*f7^2*f3-16*x4^3*x2*f7^3*f2^2-140
*x4^2*x5^2*f7*f1*f5+76*x4^2*x2*x5*f7*f5*f3^2-12*x4^3*x5*f7^2*f4*f2-216*x4^3*x3
*f5^3*f4*f7-56*x4^4*f4^2*f5*f7^2-16*x3*x4^3*f4^3*f7^2-216*x4^2*x6*x7*f6*f5^2-\
124*x4^2*x1*x7*f3*f7^2*f2+272*x4^3*x1*f0*f7^3*f3-264*x4^3*x1*f1*f5^2*f6*f7+92*
x4^3*x2*f3*f7^3*f1+448*x4^2*x1*x6*f0*f6*f5*f7-28*x4^2*x6^2*f7*f3*f5-168*x4^2*
x2*x7*f4^2*f5*f7-32*x4^3*x2*f4*f6*f1*f7^2-220*x4^3*x2*f7^2*f5*f3^2+72*x4^2*x2*
x5*f4^2*f5^2-84*x4^2*x2*x8*f7^2*f2*f5-68*x4^2*x6*x7*f2*f7^2+60*x4^2*x3*x8*f7*
f5^3-160*x4^2*x1*x6*f0*f4*f7^2+528*x4^2*x3*x5*f7*f1*f5*f6-108*x4^2*x1*x7*f5^3*
f4+16*x4^3*x6*f7^2*f6*f1-216*x4^3*x6*f5^3*f6+132*x4^2*x1*x5*f7*f3*f5*f2+264*x4
^3*x2*f5^3*f7*f3-112*x4^4*f0*f6*f7^3+120*x4^3*x3*f3^2*f7^2*f6+368*x4^4*f5^2*f7
^2*f3-4*x7*x8*f7^2*x4^2*f4-144*x4^2*x1*x5*f1*f7^2*f2+72*x4^4*f4*f6*f5^2*f7-72*
x4^2*x1*x5*f0*f7*f5^2-96*x4^2*x2*x7*f7*f6*f5*f2-168*x4^2*x5*x6*f0*f7^2-72*x4^2
*x5*x6*f4*f5^2+100*x4^2*x1*x7*f4*f7*f3*f5+156*x4^2*x1*x7*f7*f5^2*f2+144*x4^2*
x2*x7*f0*f6*f7^2+40*f7^2*x4^2*x8^2*f5+12*f7*x2*x8^2*x4*f5^2+4*f7^2*x2^2*x8^2*
f1+24*f7*x3*x8^2*x4*f5*f6-2*f7*x2^2*x8^2*f4^2-4*f7^2*x2*x8^2*x3*f2+4*f7*x2*x8^
2*x6*f4-4*f7*x8^2*x5*x7-2*f7*x3^2*x8^2*f5^2-4*f7*x3*x8^2*x5*f4+4*f7*x3*x8^2*x6
*f5-32*x1^3*x3*f0*f6*f5^2*f1+8*x1^3*x3*f2*f6*f3^3+16*x1^3*x3*f3^2*f5^2*f1-8*x1
^3*x3*f2*f6*f1*f4^2-32*x1^3*x3*f0*f6^2*f4*f1-32*x1^3*x3*f0*f6^2*f3*f2-8*x1^3*
x3*f3*f4*f2^2*f6+16*x1^3*x3*f4*f7*f2*f3*f1+48*x1^3*x3*f0*f6*f4^2*f3+16*x1^3*x3
*f5*f6*f1^2*f4-48*x1^3*x3*f0*f1*f7^2*f2-48*x1^3*x3*f0*f5^2*f3*f4+32*x1^2*x2*x3
*f3*f5^2*f1*f4-24*x1^2*x2*x3*f3*f4*f7*f2^2-16*x1^2*x2*x3*f0*f4*f6*f1*f7+40*x1^
2*x2*x3*f0*f5*f3^2*f7-48*x1^2*x2*x3*f0*f6*f3*f7*f2+32*x1^2*x2*x3*f4^2*f5*f2*f3
-96*x1^2*x2*x3*f4*f0^2*f7^2+52*x1^2*x4^2*f7*f3*f5^2*f1-16*x2*x1*x5*x7*f4^2*f2+
48*x2*x1*x4*x7*f7*f4^2*f2-64*x2*x1*x3^2*f4^2*f0*f6^2-32*x2*x1*x3^2*f0*f5^4-76*
x2^2*x1*x4*f4*f5*f7*f2^2-48*x2*x1^2*x4*f0*f6*f5*f4^2-32*x2*x1*x3*x4*f6^2*f7*f1
^2+32*x2*x1*x3*x4*f0*f6^2*f7*f2-40*x2^2*x1*x7*f1*f0*f7^2+32*x2^2*x1*x7*f4^2*f6
*f1+24*x2*x1^2*x5*f4^2*f3*f1-64*x2*x1*x3*x6*f4*f1*f5^2-16*x2*x1*x3*x7*f0*f6*f5
^2-48*x2*x1*x3*x7*f0*f6*f3*f7-36*x2*x1*x6^2*f7*f2*f1-20*x2*x1^2*x7*f4^2*f3^2+
32*x2^2*x1*x3*f3*f6*f4^2*f2-8*x2*x1^2*x3*f7*f3^3*f2-24*x2*x1*x3*x5*f4*f5*f2*f3
-96*x2*x1*x4*x7*f0*f7^2*f3-8*x2^2*x1*x8*f7*f4*f0*f5+20*x2^2*x1^2*f3^2*f4*f2*f5
-4*x2^2*x1^2*f4^2*f2^2*f5+24*x2^2*x1^2*f0*f6*f4^2*f3+4*x2^2*x1^2*f1*f5^2*f4*f2
+16*x2^2*x1^2*f6*f5*f4*f1^2+48*x2*x1*x3^2*f2*f6^2*f1*f5+48*x2*x1*x3^2*f4*f5*f2
*f3*f6-112*x2*x1*x3^2*f0*f6*f5^2*f4+32*x2*x1*x3^2*f0*f3*f5^2*f7-8*x2*x1*x3^2*
f7*f3^2*f1*f6+24*x2*x1*x3^2*f6*f7*f5*f1^2+32*x2*x1*x3^2*f0*f6*f5*f7*f2-8*x2*x1
*x3^2*f7*f2*f4^2*f3-4*x2*x1*x3^2*f4*f5*f7*f3*f1-28*x2*x1*x3^2*f7^2*f4*f1^2+16*
x2*x1*x3^2*f3*f6*f7*f2^2+32*x2*x1^2*x3*f6^2*f4*f1^2-16*x2*x1^2*x3*f2^2*f0*f7^2
+16*x2*x1*x3^2*f3*f5^3*f2+76*x2*x1*x3*x4*f1*f5*f4^2*f7-32*x2*x1*x3*x4*f2*f4*f7
^2*f1+16*x2^2*x1*x5*f0*f5*f4^2-24*x2^2*x1*x6*f0*f5*f2*f7-48*x2*x1*x3*x4*f0*f6*
f5^3+48*x2*x1*x3*x4*f5^2*f7*f3*f1-192*x2*x1*x4*x6*f1*f6*f5*f4+96*x2*x1*x4*x6*
f3*f5*f4^2-144*x2^2*x1*x4*f0*f6*f5^2*f4+48*x2*x1*x3*x7*f4^2*f6*f2+16*x2*x1^2*
x5*f2*f0*f5^2+12*x2^2*x1*x4*f7^2*f2^3+56*x2^2*x1*x6*f0*f5^2*f4-32*x2^2*x1*x6*
f4^2*f1*f5-8*x2^2*x3*x4*f5*f6*f7*f2^2-16*x2^2*x6^2*f7*f0*f4+24*x2^2*x3*x4*f5^4
*f2+36*x2^2*x4*x5*f7^2*f1^2+8*x2^4*f0*f5*f4*f3*f7-116*x2^2*x4^2*f5^3*f1*f7+8*
x2^3*x3*f0*f5*f4^2*f7+4*x2^4*f2^2*f7^2*f1-64*x2^2*x1*x4*f6*f0^2*f7^2+64*x2^2*
x1*x4*f4^2*f3*f7*f2+4*x2^4*f4^2*f1*f5^2+24*x2^2*x3*x5*f0*f5^3-8*x2^2*x3*x6*f0*
f7^2*f2+8*x2^3*x3*f4^3*f3*f5-40*x2^2*x3*x4*f6*f7^2*f1^2-8*x2^2*x3^2*f0*f5^2*f7
*f4-12*x2^3*x3*f4*f7*f3*f1*f5-48*x2^3*x3*f0*f6*f5^2*f4-8*x2^3*x3*f6*f5*f7*f1^2
-8*x2^4*f0*f3*f2*f7^2+20*x2^2*x4^2*f4^2*f7*f3*f5-8*x2^3*x3*f0*f4*f7^2*f2-12*x2
^3*x4*f5^4*f1-40*x2^2*x4*x5*f0*f7^2*f2+12*x2^2*x1*x3*f5^2*f7*f1^2+64*x2^2*x4^2
*f0*f6*f5^2*f7+104*x2^2*x4^2*f0*f7^3*f2+32*x2^2*x3*x7*f4*f5*f2*f6-16*x2^2*x3*
x4*f7^2*f4*f2^2+8*x2^3*x7*f0*f5*f7*f4+16*x2^2*x1*x7*f0*f7*f4^2-64*x2^3*x4*f0^2
*f7^3-104*x1^2*x3*x4*f2^2*f5*f7*f4+96*x1^2*x2*x3*f0*f4^2*f7*f3+16*x1^2*x2*x3*
f6*f7*f1^2*f3+24*x1^2*x4*x5*f3*f5*f2*f4+48*x1^3*x3*f0*f6*f5*f2*f4+64*x1^2*x3*
x6*f2*f5*f1*f6+8*x1^4*f1*f4^2*f3^2-16*x1^3*x5*f0*f4^2*f3-8*x1^4*f0*f4^3*f3-16*
x1^4*f2*f5*f3*f1*f4-16*x1^4*f7*f1^3*f5-24*x1^2*x2^2*f4*f7*f2*f3*f1+8*x1^2*x3^2
*f4^2*f6*f2*f3-32*x1^3*x5*f6*f5*f0^2+32*x1^3*x5*f4*f0^2*f7+40*x1^2*x2*x6*f7*f2
*f3*f1+128*x1^2*x2*x6*f6*f0^2*f7+8*x1^4*f0*f5*f4^2*f2+18*x1^4*f5^2*f3*f1^2+24*
x1^2*x2*x3*f2^2*f6*f1*f7-64*x1^3*x3*f6*f0^2*f7*f4-24*x1^2*x3*x4*f5*f6*f1*f4^2-\
48*x1^2*x3*x4*f0*f5^4+32*x1*x3*x6*x8*f7*f0*f6-48*x2*x3*x4*x5*f1*f4*f5*f7+8*x3*
x2*x4*x5*f7*f3^2*f4+4*x2*x3^2*x5*f7*f2^2*f5-8*x1*x3*x6^2*f7*f2^2-52*x1*x3*x6^2
*f7*f3*f1-4*x1^2*x3*x5*f2^3*f7-4*x1*x3^2*x5*f3^2*f7*f2+16*x1*x3*x7^2*f7*f2*f4+
4*x1^2*x3*x5*f2^2*f4*f5-4*x1^2*x3*x5*f4^3*f1-72*x1^2*x3^2*f0*f6*f5^2*f3-56*x1*
x3*x2*x7*f0*f5*f7*f4-96*x1*x3*x4*x5*f0*f6*f7*f3-16*x1*x3^2*x8*f7*f1*f4*f6-32*
x1*x3^2*x8*f7*f0*f5*f6-16*x1^2*x3*x7*f0*f5^3-120*x1*x3*x4*x7*f4^2*f5^2-16*x1*
x3^2*x6*f0*f7^2*f2+32*x1*x3*x4^2*f0*f7^3*f2-40*x1^2*x3*x4*f3*f6*f7*f2^2-36*x1*
x3*x4*x5*f3^2*f5^2-8*x1*x3*x4*x5*f3^3*f7+80*x1*x3*x2*x5*f1*f6*f0*f7+16*x1*x3*
x2*x5*f3*f4*f6*f1-28*x1*x3*x2*x5*f5*f7*f1^2-16*x1*x3^2*x5*f0*f6*f5*f4-16*x1*x3
*x4*x5*f0*f7^2*f2+20*x1^2*x3*x6*f4^2*f3^2-8*x1^2*x3*x6*f5^2*f2^2-8*x1^2*x3*x6*
f4^3*f2-40*x1^2*x3*x6*f2*f6*f3^2-32*x1^2*x3*x6*f6^2*f1^2-8*x1^2*x3*x6*f4^2*f1*
f5+16*x1*x3^2*x6*f3*f6^2*f1+4*x1^2*x3^2*f5^3*f2^2+24*x1^2*x3^2*f4*f6*f3^3-28*
x1^2*x3^2*f3^2*f5*f4^2+48*x1^2*x3^2*f4*f6*f0*f7*f2+16*x1^2*x3^2*f1*f7^2*f2^2-\
64*x1^2*x3^2*f0*f6^3*f1-32*x1^2*x3^2*f1*f6^2*f3^2+8*x1*x3^2*x2*f0*f3^2*f7^2-64
*x1*x3^2*x2*f0*f6^2*f7*f1+132*x1*x3*x4^2*f3^2*f5^2*f7-16*x2^2*x3*x5*f1*f6*f4^2
-16*x2*x3*x4*x5*f7*f6*f2^2-32*x3^2*x6*x2*f0*f4*f7*f6-48*x2*x3*x4*x5*f4^2*f2*f7
+140*x2*x3*x4^2*f7^2*f1*f4*f5-528*x2*x3*x4^2*f7*f1*f6*f5^2-16*x2^2*x3^2*f4*f5*
f7*f2*f3+80*x2*x3*x4^2*f7^2*f1*f6*f3-36*x2*x3*x4^2*f7^2*f3*f2*f5+32*x2*x3*x4*
x6*f5*f7*f3^2-12*x2*x3*x4*x7*f7^2*f2*f3+144*x2*x3*x4*x5*f1*f6*f5^2+24*x2*x3*x7
^2*f3*f5*f6-8*x2^2*x3^2*f3*f6*f1*f4*f7-8*x2^2*x3^2*f6^2*f7*f1^2+80*x1*x3*x4*x5
*f5*f7*f2^2+12*x1*x3*x4^2*f3^3*f7^2+64*x1^2*x3*x7*f0*f6*f7*f2-24*x1*x3^2*x2*f4
^2*f1*f5*f6+24*x1*x3^2*x2*f4*f5^3*f1-72*x1*x3*x6*x7*f7*f0*f5-108*x1^2*x3*x4*f5
^2*f3^2*f4+24*x1^2*x3*x6*f4*f2^2*f6-32*x1*x3^2*x2*f6*f0^2*f7^2-144*x1*x3*x4*x6
*f4*f5*f2*f6-96*x1*x3*x4*x7*f5*f6^2*f1+32*x1*x3*x5*x7*f1*f4*f6-144*x1*x3*x4*x5
*f7*f2*f1*f6+64*x1^2*x3*x4*f1*f4*f6*f7*f2-2*x1^2*x3^2*f4^4*f3+2*x6^4*f3-72*x1^
2*x3^2*f0*f4*f1*f7^2-16*x1^2*x3*x5*f2*f6*f1*f4+24*x1^2*x2*x3*f0*f5^2*f7*f1-160
*x1^2*x3*x4*f0*f1*f6^2*f7-8*x1^2*x2*x5*f7*f0*f4*f1+88*x1^2*x3*x7*f0*f7*f3*f5-\
48*x1^2*x2*x4*f5^3*f3*f1+40*x1^2*x2*x5*f7*f0*f2*f3+16*x1^2*x3*x4*f7*f2*f3^2*f5
-192*x1^2*x3*x4*f6*f0^2*f7^2-40*x1^2*x4*x5*f0*f5*f2*f7-24*x1^2*x4*x5*f7*f2*f1*
f4-48*x1^3*x4*f0*f5^3*f3+32*x1^2*x2*x7*f1^2*f5*f7+12*x1^3*x3*f3*f5*f1*f4^2+32*
x1^3*x3*f7^2*f1^3+96*x1^2*x3*x4*f4*f5*f2*f3*f6+32*x1^2*x3*x7*f3*f4*f2*f6-80*x1
^2*x3*x7*f0*f7^2*f1+16*x1^3*x5*f0*f6*f3*f2+8*x1^2*x2^2*f1*f5*f7*f2^2+4*x1^3*x2
*f2*f5*f3^3-4*x1^3*x2*f2^3*f5^2+4*x1^3*x2*f3^2*f4^2*f2+32*x1^2*x3^2*f5^2*f2*f3
*f4-16*x1^2*x3^2*f7*f3^2*f2*f4+36*x1^2*x3^2*f5^3*f3*f1-20*x1^2*x3^2*f7*f4^2*f2
^2+4*x1^3*x3*f2^2*f5*f4^2+4*x1^3*x3*f4^4*f1-4*x1^3*x3*f4^3*f2*f3-4*x1^3*x3*f3^
3*f4^2+4*x1^3*x3*f3^3*f7*f1+4*x1^3*x3*f1*f5*f7*f2^2-4*x1^3*x3*f3^4*f5+28*x1^2*
x2*x3*f1^2*f7^2*f2-20*x1^2*x2*x4*f7*f4^2*f2^2+76*x1^2*x2*x4*f7*f3^2*f2*f4-52*
x1^2*x2*x4*f7*f3*f1*f4^2-12*x1^2*x2*x3*f2^3*f5*f7-32*x1^2*x2*x3*f2*f5*f1*f3*f7
+16*x1^2*x3^2*f7*f3*f1*f4^2+4*x1^3*x4*f7*f2*f3^3-4*x1^3*x4*f2^3*f5*f7+12*x4^2*
x2*x6*f7^2*f2*f3-24*x4^2*x3*x6*f7^2*f4*f2+24*x4^2*x3*x8*f7^2*f3*f5+8*x4^2*x5*
x8*f7^2*f2-8*x1*x4*x3*x8*f7*f2*f4*f6+168*x1*x4^2*x6*f1*f7^2*f3+16*x3*x4^2*x1*
f4^2*f2*f6*f7+180*x1*x4^3*f7*f2*f5^3-32*x3*x4^2*x1*f1*f6^2*f7*f3-12*x1*x4^3*f4
^3*f7*f5-24*x1^2*x4*x6*f4^2*f2*f5+12*x1*x4*x3*x8*f7*f5^2*f2+72*x1*x4^2*x2*f2*
f6*f5^2*f4+8*x1*x4^2*x2*f3*f6*f2*f7*f4-36*x1^2*x4*x5*f3^3*f5-80*x1*x4^2*x6*f1*
f5^2*f7-24*x1*x4*x2*x8*f7^2*f0*f4+32*x3*x4^2*x6*f7*f6^2*f1-64*x4^2*x3*x6*f3^2*
f7^2+8*x3*x4^2*x6*f4*f6*f3*f7-288*x3*x4^2*x6*f7*f5*f2*f6-72*x4^2*x3*x6*f4*f6*
f5^2-48*x4^2*x3*x6*f7^2*f5*f1+144*x4^2*x3*x6*f4^2*f5*f7+104*x4^2*x3*x6*f5^2*f7
*f3+40*x4*x3*x5*x6*f7*f1*f5-24*x4^2*x3*x7*f0*f7^3+72*x4*x3*x5*x7*f0*f7^2-56*x4
*x3*x5*x7*f7*f3*f4-48*x4*x3*x6*x7*f4*f5*f6+16*x4*x3^2*x8*f7^2*f3*f4-24*x4^2*x8
*f7*f4*f5*x3*f6+24*x4*x3*x5*x8*f7^2*f1-40*x4*x3*x6*x8*f7*f4*f5+20*x4*x3*x7*x8*
f7^2*f3+24*x2*x4*x5^2*f2*f4*f5+56*x2*x4*x6*x7*f0*f7^2+320*x4^2*x5*x2*f0*f4*f7^
2-8*x3*x4^2*x2*f3*f6*f7*f4^2-108*x1*x4^3*f5^4*f4-32*x1^2*x4*x7*f7^2*f1^2+60*x1
*x4*x6^2*f7*f2*f3+24*x1*x4*x6^2*f5^2*f2-128*x2*x4^2*x5*f0*f6*f5*f7-104*x4^2*x6
*x2*f2*f7*f5^2+64*x2*x4^2*x6*f5*f6*f1*f7+36*x2*x4*x5*x6*f7*f1*f4+48*x2*x4*x3*
x7*f4^2*f6*f5+136*x4^2*x7*x2*f3*f5^2*f7+216*x2*x4^2*x7*f4*f6*f5^2-8*x2*x4^2*x7
*f4*f6*f3*f7-80*x4^2*x7*x2*f1*f7^2*f5+116*x2*x4^2*x7*f7^2*f4*f2-108*x2*x4^2*x7
*f5^4-92*x2*x4^2*x7*f3^2*f7^2+44*x5*x7*x2*x4*f7*f1*f5+48*x2*x4*x5*x7*f5*f4^2+8
*x1*x6^2*x2*f7*f0*f3-40*x1^2*x6*x7*f7*f0*f3-32*x1*x6*x3*x7*f6*f1*f5-4*x2^2*x6^
2*f7*f3*f1+4*x2^2*x6^2*f1*f5^2-16*x2*x6^2*x4*f7*f0*f6-24*x2^2*x6*x7*f7*f1*f4+
16*x2*x6*x3*x7*f7*f0*f6+16*x2*x6*x4*x7*f7*f1*f6+32*x6^2*x1*x7*f1*f6-16*x6^3*x1
*f1*f5-8*x6^3*x3*f3*f5+16*x6^2*x1*x7*f7*f0-16*x6^2*x1*x7*f3*f4-8*x6^3*x2*f3*f4
+4*x2^2*x5^2*f1*f4^2-12*x2*x5*x7^2*f3*f5+16*x6^2*x2*x7*f7*f1+16*x6^3*x3*f7*f1+
8*x6^2*x1*x7*f2*f5-8*x6^2*x4*x7*f7*f3+24*x3*x6^2*x4*f4*f5^2+4*x1^2*x6^2*f2^2*
f5+36*x1*x6*x3*x7*f7*f2*f3-24*x1^2*x6*x7*f2*f3*f5+8*x1*x6^2*x8*f7*f1+16*x1^2*
x6*x7*f0*f6*f4+12*x3^2*x6^2*f7*f3^2+16*x6*x3^2*x7*f0*f7^2+8*x3^2*x6*x7*f4^2*f6
-48*x1^2*x6*x7*f3*f1*f6+8*x2^2*x7*x6*f7*f2*f3-16*x2*x6*x5*x7*f7*f0-24*x3*x6^2*
x2*f7*f1*f4+8*x3*x6*x7^2*f7*f3+16*x1*x6^2*x3*f1*f4*f6-24*x1*x6*x7^2*f1*f7+4*x6
^2*x4^2*f7*f2*f6+8*x6*x4^2*x7*f3*f6*f7+24*x6^2*x4*x7*f5^2+4*x2*x6*x1*x7*f2^2*
f7-68*x6*x4*x7*x8*f7*f5+28*x6*x4*x7^2*f7*f4+4*x3^2*x6^2*f5*f4^2+16*x3^2*x6^2*
f7*f0*f6+16*x2^3*x3*f0*f6*f4*f3*f7-16*x2^3*x1*f0*f6*f4*f1*f7-8*x2^3*x1*f5^2*f2
^2*f4+16*x2^3*x3*f0*f5^2*f3*f7-8*x2^2*x1*x6*f5*f7*f1^2-48*x2^2*x1*x4*f4^3*f3*
f5+56*x2^2*x1*x4*f2*f5^2*f7*f1-24*x2^2*x4*x7*f4^2*f5^2+8*x2^2*x4*x7*f4^2*f7*f3
-8*x2^3*x7*f3*f7*f2*f4+36*x2^3*x4*f4^2*f1*f7*f5-60*x2^2*x1*x4*f4*f5^3*f1+8*x2^
3*x6*f0*f5^3+28*x2^3*x4*f5^2*f1*f3*f7-48*x2^3*x4*f0*f5^2*f7*f4+4*x2^2*x3*x4*f7
^2*f3^2*f2-20*x2^2*x1*x4*f2*f3*f7^2*f1-20*x2^2*x1*x5*f1^2*f7*f4+8*x2^3*x1*f4^3
*f1*f5-48*x2^2*x1*x3*f0*f5^3*f4-8*x2^3*x4*f3^2*f7^2*f1+32*x2^2*x1*x3*f4*f6*f0*
f7*f2-8*x2^4*f0*f4*f7^2*f1-416*x3^2*x2*x4*f0*f6*f5^2*f7-8*x3^2*x1*x6*f7^2*f1^2
-24*x3^3*x7*f0*f5*f7^2+32*x3^2*x1*x5*f2^2*f6*f5+16*x3^2*x1*x5*f1*f5*f3*f6+16*
x3^2*x1*x5*f7*f4^2*f0+8*x3^2*x2*x6*f2^2*f7*f6+4*x3^2*x2*x5*f3*f5*f1*f7+16*x3^2
*x1*x4*f7*f0*f5^3+32*x3^2*x5*x6*f6*f1*f5+128*x3^2*x1*x4*f1*f6^2*f7*f2-64*x3^2*
x1*x4*f1*f6*f4^2*f7+72*x3^2*x1*x4*f6*f5^2*f3^2+128*x3^2*x4*x7*f4*f6*f3*f7+20*
x3^2*x4*x6*f4^3*f7+68*x3^2*x2*x4*f3*f5*f1*f7^2+32*x3^3*x7*f5*f6^2*f2+48*x3^3*
x7*f6^2*f3*f4+32*x3^2*x5*x6*f2*f4*f6-8*x3^2*x1*x5*f7*f3*f4*f1-144*x3^2*x2*x4*
f1*f6^2*f5^2-448*x3^3*x4*f0*f6^2*f5*f7-48*x3^2*x2*x7*f5*f6^2*f1-32*x3^3*x7*f0*
f6^2*f7-12*x3^3*x1*f3^2*f1*f7^2-44*x3^2*x2*x4*f3*f7^2*f2*f4+8*x3^2*x1*x5*f1*f7
^2*f0+32*x3^2*x4*x8*f7^2*f2*f5+216*x3^2*x4^2*f6^2*f3*f5^2-16*x3^3*x1*f0*f6*f7^
2*f1+128*x3^2*x1*x4*f0*f5*f3*f7^2-84*x3^2*x1*x4*f4^3*f5^2+40*x2*x6*x3^2*f1*f7*
f4*f5-8*x3^2*x1*x7*f0*f3*f7^2+64*x3^2*x1*x7*f2*f6*f4*f5+24*x3^2*x1*x4*f5^4*f2+
24*x3^2*x2*x6*f0*f5^2*f7+32*x3^3*x2*f4*f5^2*f6*f2-24*x3^2*x1*x7*f5^2*f3*f4+8*
x3^2*x4*x7*f4^2*f5*f7-24*x3^2*x1*x4*f7^2*f0*f4^2+8*x3^3*x7*f5^3*f4-48*x3^2*x4*
x6*f3^2*f7*f6-28*x3^2*x4^2*f3^2*f5*f7^2-32*x3^4*f0*f6^2*f7*f4-32*x3^3*x1*f7*f3
*f5^2*f1-32*x3^3*x1*f2^2*f5*f6^2-16*x3^3*x1*f1*f6*f5^2*f4+384*x3^2*x4^2*f4*f6*
f7*f3*f5+56*x3^2*x4^2*f3*f7^3*f1-4*x3^2*x4^2*f4*f5*f7^2*f2+24*x3^3*x4*f5^4*f4-\
128*x3^3*x4*f4*f6^2*f1*f7-32*x3^3*x4*f3*f5*f2*f7^2-4*x2^3*x7*f5*f7*f2^2+12*x2^
2*x3*x7*f5^2*f3*f4+12*x2^2*x3*x7*f1*f7^2*f2-20*x2^2*x3*x7*f3*f7*f2*f5-4*x2^2*
x3*x7*f7*f3^2*f4+8*x2^2*x3*x7*f5^3*f2+32*x2^2*x3*x7*f7*f4*f1*f5+4*x2^3*x5*f5*
f7*f1^2+4*x2^3*x6*f7*f4*f2^2-24*x2^2*x3*x6*f4^2*f3*f5-8*x2^2*x3*x6*f4*f5^2*f2-\
12*x2^2*x4*x6*f4^2*f2*f7-12*x2^2*x4*x6*f1*f7^2*f2+12*x2^2*x1*x7*f3^2*f5*f4+8*
x2^2*x1*x7*f2*f5*f7*f1-16*x2^2*x5*x7*f2*f4*f5+12*x2^2*x5*x7*f1*f5^2-8*x2^2*x6*
x7*f5^2*f2+4*x2^3*x8*f5*f7*f1*f4-8*x2^2*x3*x8*f7^2*f3*f1-4*x2^2*x6*x8*f1*f5*f7
+48*x2*x4*x5*x6*f5^2*f2+8*x2^2*x4*x8*f7^2*f2*f3-48*x2*x4*x3*x5*f0*f3*f7^2-36*
x2*x4*x5^2*f1*f5^2+4*x2^2*x4^2*f4^2*f7*f2*f6+60*x2^2*x4^2*f4^2*f1*f7^2-28*x2^2
*x4*x5*f7*f4^2*f1+40*x2*x4*x6^2*f7*f1*f5+88*x7*x8*f7*x2*x4*f4*f5-28*x2*x4*x7^2
*f7*f4^2+16*x2^2*x8*f7*x4*f3*f5*f4-48*x3*x6*x2*x4*f2*f7*f5*f4+8*x5^3*x3*f0*f5+
36*x5^2*x4*x7*f3*f5-16*x5^2*x3*x7*f7*f0+12*x5^3*x4*f1*f5-24*x5^2*x3*x7*f1*f6+
12*x5^2*x3*x7*f3*f4-44*x5^2*x4*x7*f1*f7-16*x1^2*x5^2*f7*f0^2-16*x1*x5*x6^2*f2*
f3+8*x1*x5*x3*x8*f7*f1*f4+4*x5*x1*x3*x6*f7*f2*f1+4*x1*x5^2*x6*f3*f1-4*x1^2*x5*
x7*f1*f4^2-4*x1*x5^2*x7*f1*f4+16*x1*x5*x6*x7*f2*f4+12*x1*x5*x6*x7*f3^2-4*x1*x5
*x7^2*f3*f4+4*x1^2*x5^2*f2*f1*f4-12*x5*x3^2*x7*f7*f1*f5+16*x5*x3*x1*x7*f2*f3*
f6-16*x1^2*x5^2*f0*f6*f1+8*x1*x5*x6^2*f1*f4-24*x1*x5^2*x2*f7*f0*f1-8*x1^2*x5^2
*f1*f3^2+4*x1^2*x5^2*f5*f1^2+16*x1^2*x5*x6*f0*f6*f2-24*x1^2*x5*x6*f3*f1*f4-16*
x1*x5*x6*x8*f7*f0+24*x1^2*x5^2*f0*f4*f3-24*x1*x5*x4*x7*f3*f5*f4-8*x1*x5^2*x6*
f0*f4+16*x1*x5*x7^2*f7*f0-8*x1*x5*x3*x7*f4^2*f3+32*x1*x5*x3*x7*f7*f0*f4+48*x1*
x5*x4*x7*f6*f1*f5-16*x1*x5*x6*x7*f1*f5-48*x1*x5*x6*x7*f0*f6+32*x1*x5*x6^2*f0*
f5+40*x5*x1*x2*x7*f7*f0*f3+4*x5^3*x3*f1*f4-4*x5^2*x1*x7*f2*f3+8*x5^2*x2*x7*f2*
f4-12*x5^2*x2*x7*f1*f5+8*x5^2*x3*x7*f2*f5-4*x5^3*x1*f2*f1-8*x5^2*x3*x6*f2*f4-\
32*x1^2*x5*x7*f7*f0*f2-8*x1^2*x5^2*f0*f5*f2+8*x5*x3^2*x7*f7*f3^2+4*x2^2*x5^2*
f7*f0*f2+24*x2*x5^2*x6*f0*f5-16*x1*x5*x2*x6*f4^2*f1+48*x1^2*x5*x7*f0*f6*f3+8*
x2*x5*x1*x6*f7*f0*f2-16*x2*x5*x1*x7*f0*f5^2+32*x2*x5*x4*x7*f7*f3^2-48*x2*x5*x4
*x7*f7*f0*f6+64*x5^2*x4*x6*f7*f0-24*x5^2*x4*x6*f2*f5+8*x5^2*x1*x7*f0*f5+48*x5^
2*x3*x6*f0*f6+8*x5^3*x2*f0*f4-12*f7^2*x2*x8^2*x4*f3-12*f7*x4*x8^2*x5*f5+12*f7^
2*x4*x8^2*x7+8*f7*x3*x8^2*x7*f6-6*f7^2*x3^2*x8^2*f3+4*f7*x2*x8^2*x7*f5+12*x3^2
*x1*x4*f4^3*f3*f7+192*x3^2*x1*x4*f4*f6*f5^2*f2-64*x3^2*x1*x4*f3*f6*f2*f7*f4-80
*x3^2*x2*x4*f3*f5*f2*f6*f7+32*x3^2*x2*x4*f4^2*f1*f7^2-16*x3^2*x2*x4*f4*f6*f7*
f3^2-40*x3^2*x2*x4*f4^2*f7*f3*f5+104*x3^2*x2*x4*f0*f5*f7^2*f4-288*x3^2*x2*x4*
f0*f6^2*f7*f4+8*x3^2*x2*x4*f1*f6*f7^2*f2-64*x3^2*x2*x4*f5^2*f7*f3^2+72*x3^3*x4
*f5^2*f1*f6*f7+144*x3^3*x4*f4*f5*f3*f6^2+56*x3^3*x4*f3*f6*f7*f4^2+48*x3^3*x4*
f3*f6*f1*f7^2+12*x3^3*x4*f2*f7^3*f1+16*x3^3*x4*f3*f6^2*f2*f7-16*x3^3*x4*f4*f5*
f1*f7^2-24*x3^3*x4*f5^3*f7*f2-96*x3^3*x4*f4^2*f5^2*f6+16*x3^3*x4*f0*f3*f7^3+96
*x3^3*x4*f5^2*f6^2*f2+40*x3^3*x4*f0*f5^2*f7^2+24*x3^2*x1*x5*f1*f6*f4^2+24*x3^2
*x1*x5*f1*f4*f5^2-16*x3^3*x5*f3*f6*f1*f7+12*x3^3*x5*f4^3*f5+8*x3^3*x5*f3^2*f7*
f4+48*x3^3*x5*f4*f6^2*f1-24*x3^3*x5*f3*f4^2*f6-64*x3^2*x4*x5*f4*f5*f7*f2-24*x3
^2*x4*x5*f4^2*f7*f3+144*x3^2*x4*x5*f5*f6^2*f1-144*x3^2*x4*x5*f4*f6*f3*f5+84*x3
^2*x1*x6*f7*f3*f1*f5-40*x3^2*x1*x6*f4^2*f6*f2+32*x3^2*x1*x6*f7*f2*f3*f4-28*x3^
2*x1*x6*f1*f4^2*f7-8*x3^2*x2*x6*f0*f3*f7^2-24*x3^3*x6*f5*f7*f3^2+8*x3^3*x6*f3*
f6*f2*f7-32*x3^3*x6*f0*f6*f5*f7+28*x3^3*x6*f4*f5*f7*f2-4*x3^2*x4*x6*f7^2*f4*f1
+288*x3^2*x4*x6*f0*f6^2*f7-128*x3^2*x4*x6*f0*f5*f7^2-28*x3^2*x1*x7*f4^3*f5-288
*x2*x1*x3*x4*f0*f6^2*f5*f4-16*x2*x1^2*x5*f1^2*f6*f4+32*x2*x1*x6*x7*f4^2*f3+160
*x2*x1*x4^2*f7*f4^2*f2*f5+48*x2*x1*x3^2*f0*f5*f7*f4^2-24*x2*x1*x4*x8*f7*f1*f5^
2-8*x2*x1*x3*x6*f0*f7^2*f1-8*x2*x1^2*x5*f5^2*f1^2+4*x3*x6*x1*x2*f3^2*f2*f7+36*
x2*x1*x4*x6*f7*f1*f4^2-8*x2*x1*x5*x6*f3*f1*f5-16*x2*x1*x5*x6*f2^2*f5+4*x2*x1^2
*x7*f4^2*f1*f5+4*x2*x1^2*x7*f5^2*f2^2+28*x2*x1*x4*x7*f7*f3^2*f4+144*x2*x1*x4*
x7*f7*f2*f3*f5+24*x2*x1*x5*x7*f1*f4*f5-12*x2*x1*x5*x7*f3^2*f4-12*x2*x1*x6*x7*
f3^2*f5-36*x2*x1*x6*x7*f7*f3*f1-32*x2*x1*x6*x7*f2*f4*f5+4*x2^2*x1*x8*f7*f4^2*
f1-4*x2^2*x1*x8*f7*f3*f1*f5+12*x2*x1*x3*x8*f7^2*f2*f1+4*x2*x1*x5*x8*f7*f3*f1-\
12*x2*x1*x6*x8*f7*f1*f4+72*x2*x1*x3*x4*f3^2*f4*f5*f6-88*x2*x1*x3*x4*f4*f6*f1*
f3*f7+32*x2*x1*x3*x4*f0*f7^2*f4*f3-104*x2*x1*x3*x4*f4*f6*f7*f2^2+4*x2*x1*x3*x4
*f3*f7^2*f2^2+48*x2*x1*x3*x4*f4^3*f7*f2-84*x2*x1*x3*x4*f5^2*f7*f2^2-288*x2*x1*
x3*x4*f0*f5^2*f7*f4-20*x2*x1*x3*x4*f7^2*f5*f1^2+144*x2*x1*x3*x4*f4^2*f5*f2*f6+
4*x2*x1*x3*x4*f3^2*f7^2*f1-12*x2*x1*x3*x4*f3^3*f5*f7+32*x2*x1^2*x5*f0*f6*f5*f1
-8*x2*x1^2*x5*f0*f4^3-16*x2*x1^2*x3*f0*f6*f5^2*f2-16*x2*x1*x4*x8*f7^2*f1*f3+8*
x2^2*x1*x6*f3*f7*f2^2-80*x2*x1*x3*x6*f0*f7*f4^2+76*x2*x1*x3*x6*f1*f5*f7*f2-32*
x2*x1*x3^2*f5^2*f6*f2^2+44*x2*x1*x4*x5*f4*f7*f3*f1+40*x2*x1*x3*x7*f3*f7*f1*f5-\
48*x2*x1*x4*x5*f0*f7*f4^2-48*x2*x1*x4*x5*f1*f5*f7*f2+24*x2*x1*x3*x7*f2*f4*f3*
f7-16*x2*x1*x3*x7*f4^4-32*x2*x1*x3*x7*f7^2*f1^2-32*x2*x1*x4^2*f7^3*f0*f1-84*x2
*x1*x4^2*f7^2*f4*f2^2+64*x2*x1*x4^2*f7^2*f0*f4^2+12*x2*x1*x4^2*f7^2*f3^2*f2-16
*x2*x1^2*x6*f6*f5*f1^2-48*x2*x1^2*x6*f0*f6*f4*f3+144*x2*x1*x3*x6*f0*f5*f6*f4-\
64*x2*x1*x6*x7*f1*f4*f6+96*x2*x1^2*x4*f0*f6*f7*f4*f2-8*x2^2*x1*x4*f1*f6*f7*f4*
f2-24*x2*x1^2*x3*f4^2*f2^2*f6-96*x2*x1*x4*x6*f2*f5^2*f4-32*x2*x1*x6^2*f0*f5^2+
40*x2*x1*x6^2*f1*f4*f5-8*x2*x1^2*x7*f4*f6*f2^2-248*x2*x1*x4*x7*f7*f0*f5^2-48*
x2*x1*x5*x6*f0*f5*f4-8*x2*x1*x3*x8*f7*f3*f1*f6-16*x2*x1*x3*x8*f7*f0*f5^2-16*x3
*x6*x1*x2*f6*f7*f1^2+48*x2*x1*x6*x7*f0*f5*f6-32*x2*x1*x3*x6*f5^2*f2*f3+64*x2*
x1*x3*x6*f0*f5^3-124*x2*x1*x4*x6*f2*f4*f3*f7+112*x2*x1*x4*x6*f7*f0*f4*f5+48*x2
*x1*x4*x6*f5^3*f1-36*x2*x1*x4*x6*f3^2*f5^2+64*x2*x1*x4*x6*f7*f2^2*f5-32*x2*x1*
x4*x6*f7*f3*f1*f5+48*x2*x1^2*x7*f4*f6*f1*f3+8*x2*x1^2*x7*f4^3*f2-16*x2*x1^2*x7
*f0*f6*f4^2-48*x2*x1^2*x7*f0*f6*f5*f3+24*x2*x1*x3*x7*f3^2*f4*f6+68*x2*x1*x4*x7
*f7*f1*f4*f5+48*x2*x1*x5*x7*f0*f6*f4+8*x2*x1^2*x5*f4^2*f2^2+8*x2*x1*x5*x7*f7*
f2*f1+16*x2*x1*x6^2*f2*f3*f5+32*x2*x1^2*x3*f6*f5^2*f1^2+12*x2*x1^2*x3*f4^3*f1*
f5+8*x2^2*x1*x3*f2^3*f6*f7+8*x2*x1*x3*x7*f7*f2*f1*f6+8*x2*x1*x4*x7*f3*f7*f1*f6
-32*x2*x1*x3^2*f4*f6^2*f2^2-8*x2*x1^2*x5*f1*f5*f4*f2+16*x2*x1^2*x5*f3^2*f5*f1+
144*x2*x1*x4*x6*f0*f6*f5^2-40*x2*x1^2*x4*f1*f6*f7*f3*f2+32*x2*x1^2*x4*f6*f7*f4
*f1^2+32*x2*x1^2*x7*f0*f5*f7*f2+48*x2*x1^2*x6*f0*f5^2*f3-16*x2*x1*x6*x7*f7*f0*
f4+16*x2*x1*x6*x7*f1*f5^2-8*x2*x1*x7^2*f6*f1*f5+36*x2*x1*x3*x4*f3^2*f5^3-16*x2
*x1*x3*x4*f0*f6*f7*f4^2-192*x2*x1*x3*x4*f0*f6*f7^2*f1+16*x2^2*x1*x3*f1*f6*f4^3
+20*x2*x1*x7^2*f7*f1*f4-16*x2^2*x1^2*f0*f6*f3*f7*f1-96*x2*x1^2*x4*f5*f0^2*f7^2
-32*x1^3*x2*f1*f6*f3*f2*f4-24*x1^3*x3*f3^2*f4*f1*f6-32*x1^3*x4*f4*f0^2*f7^2+12
*x1^3*x4*f4^3*f5*f1+48*x1^2*x2*x4*f5^2*f2*f3*f4-48*x1^2*x2*x4*f0*f5^3*f4+16*x1
^4*f0*f6*f4*f2*f3+16*x1^4*f0*f6*f2^2*f5-16*x1^4*f0*f4*f3*f7*f1+208*x1^2*x3*x4*
f6*f7*f0*f5*f2+240*x1^2*x3*x4*f0*f6*f4*f3*f7+24*x1^3*x2*f0*f2^2*f5*f7-16*x1^3*
x2*f0*f5^3*f1-16*x1^3*x2*f0*f5^2*f2*f4-28*x1^3*x2*f4*f7*f1^2*f3-48*x1^3*x4*f3*
f5*f2^2*f6+56*x1^3*x4*f0*f5*f4*f7*f2+2*x7^4*f7+2*x1^4*f7*f1^2*f3^2-8*x1^2*x2^2
*f7*f2^3*f4+12*x1^2*x2^2*f3*f5*f1*f4^2+8*x1^2*x2^2*f4^3*f2*f3-4*x1^3*x2*f3^4*
f4+20*x3^2*x6*x7*f7*f2*f5+4*x3^2*x6*x7*f7*f3*f4+8*x3^2*x2*x8*f7*f5^2*f2+4*x2*
x8*f7*x3^2*f3*f5*f4-4*x3^2*x2*x8*f7^2*f2*f3-4*x3^3*x8*f7^2*f2*f4-4*x3^3*x8*f7*
f5*f4^2-4*x3^3*x8*f7*f3*f5^2-8*x3^2*x5*x8*f7*f2*f5+8*x6*x8*f7*x3^2*f3*f5-4*x3^
2*x6*x8*f7^2*f1+4*x7*x8*f7*x3^2*f4*f5-8*x1^2*x3^2*f4*f6*f7*f1^2+12*x1^2*x3^2*
f4^3*f2*f5-16*x1^2*x3^2*f4*f6*f2^2*f5-32*x1^2*x3*x5*f1^2*f6*f5-48*x1*x3*x6*x7*
f2*f4*f6-64*x1*x3^2*x7*f0*f6^2*f5+56*x1*x3^2*x7*f0*f5^2*f7+24*x1^2*x3*x7*f3^3*
f6-16*x1*x3^2*x6*f4*f5^2*f2+56*x1^2*x3*x4*f0*f5*f4^2*f7+32*x1*x3*x4^2*f5^3*f1*
f7-12*x1*x3^3*f4^4*f5-16*x1*x3*x7*x8*f7*f1*f6-48*x1^2*x3*x5*f3*f0*f6*f4+96*x2*
x3^2*x4*f2*f6*f5^3-32*x2*x3*x6*x7*f6*f2*f5+48*x2*x3*x4*x7*f7^2*f1*f4+24*x2*x3^
3*f1*f6*f4^2*f7-8*x2*x3^3*f5*f6*f7*f2^2-8*x2*x3^2*x5*f7*f4*f0*f5-104*x2*x3*x4*
x6*f1*f5^2*f7-8*x2^2*x3*x6*f5^3*f1+4*x2^2*x3^2*f1*f5^4-96*x2*x3^3*f0*f6^2*f5^2
-8*x2*x3^2*x7*f4^3*f6+96*x2*x3^2*x5*f0*f6*f5^2-8*x2*x3^3*f0*f4^2*f7^2+8*x2*x3*
x4*x7*f0*f5*f7^2+96*x2*x3^2*x4*f0*f6*f7^2*f3+28*x2*x3*x4*x8*f7*f3*f5^2-68*x2*
x3*x4*x8*f7^2*f1*f5+48*x2*x3*x4*x8*f7^2*f0*f6+24*x2*x3*x5*x6*f7*f0*f4+16*x2*x3
^2*x4*f6^2*f7*f2^2+8*x1*x3^3*f3^2*f6*f7*f2+24*x1*x3^3*f4*f6*f1*f3*f7-20*x1*x3^
3*f4^2*f5^2*f3+16*x1*x3^3*f0*f7^2*f3*f4-12*x1*x3^3*f1*f4*f7^2*f2-16*x1*x3^3*f3
*f6^2*f1*f5-32*x1*x3^3*f1*f6^2*f4^2+8*x1*x3^3*f4^3*f3*f6+28*x1*x3^3*f4^2*f1*f7
*f5+24*x1*x3^3*f3^2*f5*f6*f4+48*x1*x3^3*f4^2*f6*f2*f5-8*x1*x3^3*f4*f6*f7*f2^2+
40*x1^2*x3^2*f3^2*f5*f2*f6-24*x1*x3*x5*x7*f2*f4*f5+16*x1*x3*x5*x7*f0*f5*f6-288
*x1^2*x3*x4*f0*f6^2*f5*f3+20*x1^2*x3*x6*f3*f7*f2^2-88*x1*x3^2*x4*f1*f0*f7^3-48
*x1*x3^2*x6*f5^3*f1-96*x1*x3*x2*x4*f4^2*f5^2*f3+28*x1^2*x3*x4*f4*f7*f3^3+32*x1
*x3^3*f2*f6^3*f1+8*x1*x3*x6^2*f2*f4*f5+48*x1*x3*x6^2*f1*f5^2+8*x1^2*x3*x5*f7*
f3^2*f0+84*x1*x3^2*x4*f5^2*f7*f1*f4-16*x1*x3^3*f3*f6^2*f2*f4+24*x2*x3^2*x6*f3*
f6*f1*f7-96*x2*x3*x4*x6*f2*f6*f5^2+32*x2*x3*x5*x6*f1*f4*f6-96*x2*x3*x5*x6*f0*
f5*f6-24*x2*x3*x7^2*f7*f3*f4-24*x2*x3^2*x7*f2*f6*f7*f3+16*x2*x3^2*x7*f1*f6*f7*
f4+28*x2*x3^2*x7*f1*f5^2*f7-72*x2*x3*x4*x7*f5^3*f4-184*x2*x3*x4*x7*f7*f6*f1*f5
-64*x2*x3*x4*x7*f3^2*f6*f7-24*x2*x3*x5*x7*f7*f1*f4-24*x2*x3*x5*x7*f3*f5*f4+8*
x2^2*x3*x8*f7*f1*f4*f6-8*x2*x3*x6*x8*f1*f6*f7+16*x2*x3*x6*x8*f7^2*f0-16*x3^2*
x2*x4*f0*f7^3*f2+24*x1^3*x6*f0*f3*f7*f2+4*x1^2*x3^2*f7^2*f1^2*f3-8*x1^4*f6*f3*
f2^3+8*x1^4*f0*f4*f3^2*f5-16*x1^4*f0*f2^2*f7*f4-24*x1^3*x3*f4^2*f7*f1^2+32*x1^
3*x3*f6^2*f1^2*f3+8*x1^4*f5*f3^2*f2^2-8*x1^2*x3*x8*f7*f2*f1*f6+56*x1^2*x2*x4*
f0*f5^2*f2*f7+16*x1^3*x3*f1*f6^2*f2^2-24*x1^3*x3*f2*f5^2*f1*f4-16*x1^3*x3*f0*
f5^3*f2-32*x1^3*x6*f0*f6*f3^2-96*x1^2*x3*x6*f0*f4*f3*f7+96*x1^2*x3*x6*f0^2*f7^
2-16*x1^3*x7*f7*f2*f3*f1+8*x1^3*x7*f0*f3^2*f7+296*x1^2*x4^2*f7^2*f0*f4*f3+48*
x1^2*x4*x6*f0*f5^3-48*x1*x4*x3*x6*f5^3*f2+16*x1*x4*x2*x7*f7*f6*f2^2+24*x1*x4*
x2*x5*f3*f5^2*f2-16*x1*x4^2*x5*f0*f6*f7*f4-36*x1*x4^2*x5*f2*f5^3+16*x1*x4^2*x5
*f7*f6*f2^2-8*x1*x4^2*x5*f4^2*f2*f7-72*x1*x4*x6^2*f7*f0*f5-72*x1^2*x4*x6*f2*f5
^2*f3+60*x1^2*x4*x6*f4*f5*f3^2+48*x1^2*x4*x6*f0*f6*f5*f4-144*x1^2*x4*x6*f3*f1*
f6*f5-56*x1*x4*x2*x6*f7^2*f1^2-48*x1*x4*x2*x6*f0*f7^2*f2-20*x3*x6*x1*x4*f7*f4*
f3^2+120*x4*x3*x5*x7*f4*f5^2-32*x3^2*x4^2*f6^3*f7*f0-72*x4*x3*x5^2*f6*f1*f5-72
*x4^2*x3*x6*f5^4+72*x2*x4^2*x3*f4^2*f5^2*f6-88*x2*x4*x5^2*f7*f0*f4-32*x2*x4^2*
x3*f4*f6^2*f1*f7-48*x2*x4*x5*x8*f7^2*f0+16*x4^2*x5*x1*f3*f6*f7*f1-76*x1*x4*x5*
x6*f7*f3*f1-48*x1*x4*x5*x6*f7*f2^2+144*x1^2*x4*x5*f3*f0*f6*f5-48*x1*x4*x7^2*f0
*f7^2-44*x3*x6*x1*x4*f1*f7^2*f2+24*x1^2*x4*x6*f2^2*f6*f5+20*x1^2*x4*x7*f7*f1*
f4^2+144*x1^2*x4*x7*f3*f6*f2*f5+96*x1*x4*x6^2*f6*f1*f5-4*x4^2*x1*x5*f7*f3^2*f4
-160*x5*x6*x2*x4*f7*f0*f5+16*x4^2*x5*x2*f1*f6*f7*f4-16*x2*x4^2*x8*f7^2*f1*f6+8
*x4^2*x3*x7*f7*f4^2*f6-272*x3*x4*x5*x6*f7*f0*f6-72*x4^2*x3*x7*f7*f4*f5^2-4*x2^
2*x7*x4*f2^2*f7^2+4*x2*x4^2*x6*f4^3*f7+4*x2^2*x4*x8*f7*f4^3+16*x2*x4*x3*x8*f7^
2*f2*f4+8*x2*x4*x5*x8*f7*f3*f4+12*x2*x4*x6*x8*f7^2*f1-8*x2*x4*x6*x8*f7*f4^2-40
*x4^2*x3^2*f5^3*f7*f3-84*x4^2*x3^2*f4^2*f5^2*f7+36*x4*x3*x5^2*f3*f5*f4-172*x3*
x4^2*x5*f4*f7*f3*f5+32*x3*x4^2*x5*f0*f6^2*f7+72*x4*x3*x6^2*f0*f7^2+24*x4*x3^2*
x6*f4^2*f6*f5+32*x3^2*x4*x6*f5^2*f7*f2-96*x1^2*x4*x7*f0*f6*f5^2+36*x1^2*x4^2*
f5^4*f1-72*x1^2*x4^2*f3^2*f5^3-16*x1^2*x4*x6*f6*f7*f1^2+40*x1*x4*x5^2*f7*f2*f1
-24*x1*x4*x3*x7*f3*f5^3-160*x1*x4^2*x7*f7*f6*f1*f5-4*x4*x3*x5*x8*f7*f3*f5+48*
x1*x4*x3*x5*f5^3*f1-6*x1^2*x4^2*f3^2*f7*f4^2-144*x1*x4*x5*x6*f0*f5*f6+48*x1*x4
*x2*x7*f2*f6*f4*f5-80*x1*x4*x3*x7*f0*f4*f7^2+72*x2*x4*x7^2*f4*f5*f6+4*x2*x4*x7
^2*f7*f3*f5+6*x5^2*x7^2*f3-12*x2^2*x1*x3*f4^2*f7*f2^2+96*x2^2*x1*x4*f5*f6*f1*
f4^2+16*x2^3*x1*f0*f5*f4*f7*f2+20*x2^2*x3*x6*f3*f7*f1*f5+12*x2^2*x1*x3*f4^2*f1
*f5^2-4*x2^2*x3*x4*f3^2*f5*f7*f4+40*x2^2*x3*x4*f4^2*f7*f2*f5+8*x2^2*x1*x3*f4*
f6*f7*f1^2+48*x2^2*x3^2*f0*f6*f5*f7*f3-48*x2^2*x3^2*f0*f6*f5^3-12*x2^2*x3^2*f5
^2*f1*f3*f7+16*x2^2*x1*x4*f0*f3^2*f7^2+36*x2^2*x4*x7*f5^3*f3+8*x2^2*x5*x7*f7*
f0*f4+96*x2^2*x3*x5*f0*f6*f5*f4+8*x2^3*x6*f1*f0*f7^2+8*x2^3*x6*f0*f7*f4^2-8*x2
^3*x6*f5^2*f1*f4-184*x2^2*x1*x4*f0*f5*f7^2*f1-24*x2^2*x3*x4*f4^3*f5^2+8*x2^3*
x7*f3*f7*f1*f5+8*x7^3*x2*f4*f6+16*x7^3*x4*f5*f7+8*x7^3*x3*f7*f4+4*x1*x7^2*x3*
f7*f3^2-4*x1*x7^2*x5*f2*f5+4*x1*x7^2*x6*f3*f5+4*x1*x7*x2*x8*f7*f2*f4+4*x1*x7*
x3*x8*f7*f2*f5-4*x1*x7*x6*x8*f7*f2+24*x7^2*x3*x4*f7*f4*f5-8*x6^2*x3*x7*f7*f2-4
*x6^3*x4*f7*f2+24*x1^2*x6^2*f0*f6*f3-16*x6^2*x3*x5*f7*f0-16*x3*x6^2*x5*f1*f6+8
*x2*x6^3*f7*f0-16*x2^2*x1*x4*f0*f6*f7*f3*f4+36*x2^2*x1*x4*f5^2*f3^2*f4-20*x2^3
*x4*f5*f7^2*f1^2+24*x2^3*x4*f0*f7^2*f3*f4-16*x2^3*x4*f0*f6*f4^2*f7-36*x2^3*x4*
f3*f5*f7*f2*f4-4*x2^2*x3*x4*f3*f7^2*f1*f4-72*x2^2*x3*x4*f1*f0*f7^3+80*x2^2*x3*
x4*f0*f5*f7^2*f3-64*x2^2*x3*x4*f0*f5^3*f7+64*x2^2*x3*x4*f0*f6*f7^2*f2-368*x2^2
*x3*x4*f0*f6*f5*f4*f7+24*x2^2*x3*x4*f4^2*f7*f1*f6-72*x2^2*x3*x4*f5^3*f1*f6+80*
x2^2*x3*x4*f5^2*f7*f1*f4+4*x2^2*x3*x4*f4^3*f7*f3-24*x2^2*x5^2*f0*f5*f4-16*x2^2
*x1*x5*f3*f4^2*f2-48*x2^2*x4*x5*f4*f5^2*f2+8*x2^2*x1*x5*f4^3*f1-32*x2^3*x1*f0^
2*f7^2*f4+24*x2^3*x5*f0*f5^2*f4-8*x2^3*x5*f4^2*f1*f5+40*x2^2*x3*x4*f2*f5*f7^2*
f1-68*x2^2*x3*x4*f5^2*f7*f2*f3+36*x2^2*x3*x4*f3*f5^3*f4-24*x2^2*x3*x4*f4*f6*f7
*f2*f3+184*x2^2*x4*x5*f0*f5*f7*f4+8*x2^2*x3*x7*f0*f7^2*f3-8*x2^2*x3*x7*f4^3*f5
-16*x2^2*x3*x7*f0*f6*f7*f4+64*x2^2*x3*x4*f5*f6*f1*f3*f7-4*x2^2*x4*x8*f7^2*f1*
f4+8*x2^3*x7*f4^2*f1*f7-24*x2^2*x3*x5*f0*f5*f7*f3+24*x2^2*x3*x5*f1*f0*f7^2+4*
x2^4*f0*f5^2*f2*f7-8*x2^3*x1*f0*f5^2*f1*f7-24*x2^3*x1*f0*f5^2*f4^2-8*x2^3*x1*
f0*f3*f1*f7^2+16*x2^3*x1*f0*f4^2*f3*f7-8*x2^3*x1*f7^2*f2^2*f0-96*x2^2*x3^2*f0*
f5*f6^2*f4+4*x3^3*x1*f7*f3^2*f4^2-4*x3^3*x1*f2^2*f7^2*f3+4*x1*x3^3*f7*f3^3*f5-\
12*x3^2*x2*x4*f1^2*f7^3+4*x3^3*x2*f7^2*f4*f2^2-4*x3^3*x2*f4^3*f5^2-4*x3^3*x2*
f4^3*f7*f3+4*x3^3*x2*f1*f4*f7^2*f3-2*x2^4*f4^2*f7*f2^2-2*x2^4*f5^2*f7*f1^2+2*
x2^4*f3*f7^2*f1^2+4*x2^3*x1*f7^2*f2*f1^2+4*x2^3*x1*f7*f2^3*f5+4*x2^3*x1*f1*f5^
3*f2+4*x2^3*x1*f4*f5*f7*f1^2-4*x2^3*x1*f3*f5^2*f4*f1-8*x2^2*x3^2*f5*f7^2*f1^2+
18*x2^2*x3^2*f4^2*f5^2*f3+8*x2^2*x3^2*f4*f5^3*f2+4*x2^2*x3^2*f3^2*f7^2*f1, -16
*x1^3*x5*f1*f3*f0*f6+32*x1^3*x5*f0*f5*f3*f2-144*x1^2*x3*x4*f1*f6*f5*f4*f3-48*
x1^2*x3*x4*f2*f6*f5^2*f1-6*x1^4*f5^2*f1^2*f2-176*x1^2*x3*x4*f1*f6*f5*f0*f7-24*
x1^2*x2*x6*f0*f4^3-32*x1^2*x2*x6*f1^2*f4*f6+48*x1^2*x3*x7*f0*f6*f4^2-96*x1^3*
x4*f0*f6*f5*f3^2+20*x1^3*x4*f1*f7*f2^2*f5-96*x1^3*x4*f0*f6*f2*f5*f4-16*x1^3*x2
*f0*f6*f4*f3*f2-16*x1^2*x3*x4*f2^3*f6*f7+32*x1^2*x3*x7*f7*f2*f1*f4-48*x1^2*x3*
x7*f3*f4*f1*f6+20*x2^2*x1*x5*f4^2*f3*f1+4*x2^4*f2*f4^2*f7*f1-12*x2^2*x1*x4*f5^
3*f3*f1-144*x2^2*x1*x4*f0*f6*f5*f4^2+112*x2^2*x1*x4*f2*f4*f7*f1*f5+32*x2^2*x1*
x3*f0*f6*f4^3+48*x2^2*x3^2*f4^2*f0*f6^2+12*x2^3*x4*f3*f5*f4^3-64*x2^2*x4^2*f7*
f4^2*f2*f5+44*x2^2*x4^2*f7*f5^2*f2*f3-116*x2^2*x4^2*f7*f4*f1*f5^2+32*x2^3*x4*
f4*f5*f7*f3*f1-16*x2^3*x1*f0*f4^2*f7*f2-20*x2^3*x1*f3*f5*f1*f4^2+8*x2^3*x1*f3*
f4^3*f2-4*x2^2*x1*x3*f3^2*f7*f4*f1+72*x2^2*x4^2*f7^3*f0*f1-56*x2^2*x4^2*f7^2*
f0*f5*f3-32*x2^3*x4*f7*f4^3*f1-52*x2^2*x1*x6*f7*f4*f1^2-24*x2^2*x5*x6*f1*f4^2+
48*x2^2*x5*x6*f0*f5*f4+32*x1^3*x7*f0*f3*f2*f7+4*x1^4*f0*f4^2*f3^2-4*x1^4*f5*f2
^3*f3+640*x1^2*x2*x4*f6*f0^2*f7*f5+48*x1^2*x2*x4*f2*f4*f0*f7*f5-8*x1^3*x5*f2*
f1*f4*f3-144*x1^2*x4^2*f7^2*f1^2*f4+176*x1^2*x4^2*f7^2*f6*f0^2+24*x1^3*x3*f1^2
*f6*f3*f5+8*x1^2*x3*x5*f0*f4^3-32*x1^2*x2*x7*f1*f5*f0*f7-32*x1^2*x2*x7*f0*f3^2
*f7-16*x1^2*x3*x7*f1*f6*f2*f5-20*x1^2*x6^2*f1*f4*f3+64*x1^2*x3*x7*f1^2*f6^2-16
*x1^3*x3*f0*f6*f4*f3^2+16*x1^3*x6*f3^2*f4*f1-96*x1^2*x4*x5*f1^2*f6*f5+144*x1^2
*x3*x4*f2*f3*f6*f1*f7-4*x1^2*x3*x6*f5*f2^2*f4+60*x1^2*x3*x6*f1*f4*f5*f3+32*x1^
3*x7*f0*f5*f4*f3+40*x1^2*x2*x3*f3*f4*f7*f1*f2+160*x1^2*x4*x6*f7^2*f0^2-20*x1^2
*x3^2*f7^2*f1^2*f2-24*x1^2*x3^2*f1^2*f7*f6*f3+40*x1^3*x4*f0*f3^2*f7*f4-80*x1^3
*x4*f2*f0*f7^2*f1-72*x1^3*x4*f2*f6*f7*f1^2-36*x1^3*x4*f3^2*f5^2*f1+8*x2^2*x3*
x7*f4^4+32*x1^3*x3*f0*f4^2*f7*f1-16*x1^3*x3*f0*f5*f7*f2^2-32*x1^3*x3*f0*f7^2*
f1^2+32*x1^3*x3*f0*f6^2*f3*f1-16*x1^3*x3*f4*f1*f7*f2^2-28*x1^3*x3*f1*f5*f4*f3^
2-8*x1^3*x3*f4^4*f0+32*x1^3*x3*f0*f5*f7*f3*f1-8*x1^3*x3*f1*f6*f3^3-8*x1^3*x3*
f2*f4^2*f3^2+8*x1^3*x3*f3*f7*f2^3+96*x1^3*x3*f5^2*f6*f0^2-16*x1^3*x3*f0*f5^3*
f1+16*x1^3*x3*f1^2*f5^2*f4+24*x1^3*x3*f1*f6*f2^2*f5+48*x1^3*x3*f0*f5*f4^2*f3-\
128*x1^3*x3*f5*f0^2*f7*f4-16*x1^3*x3*f4^2*f5*f2*f1+48*x1^3*x3*f3*f6*f4*f2*f1-\
12*x1^2*x2*x3*f5^2*f4*f2*f1+12*x2^2*x6^2*f4^2*f2+64*x4^3*x7*f7^2*f5*f2-92*x4^2
*x1*x6*f1*f7^2*f2-432*x4^2*x2*x6*f0*f4*f7^2+36*x4^3*x5*f7^2*f4*f1-12*x4^3*x6*
f4^2*f5*f7+192*x4^2*x7*x8*f7*f5^2+140*x4^2*x1*x6*f2*f5*f7*f3-800*x4^3*x5*f0*f5
*f7^2-24*x4^3*x3*f2^2*f7^3-180*x4^3*x3*f4^2*f5^2*f7-112*x4^2*x3*x7*f7*f5*f2*f6
+200*x4^2*x3*x8*f7^3*f0+16*x4^3*x8*f7^2*f3*f5+28*x4^2*x5*x7*f7*f2*f5+184*x4^3*
x7*f0*f7^3+48*x4^3*x7*f7^2*f6*f1-68*x4^2*x7^2*f7*f4*f5+192*x4^2*x3*x8*f7*f4*f5
^2+8*x4^3*x2*f2^2*f6*f7^2-220*x4^2*x2*x7*f5^2*f7*f2-72*x4^2*x2*x7*f0*f5*f7^2+
48*x4^2*x2*x7*f7^2*f4*f1-36*x4^4*f3*f7^3*f2+144*x4^4*f5*f6*f1*f7^2+4*x4^4*f3^2
*f7^2*f6+108*x4^3*x1*f5^4*f3+20*x4^3*x1*f3^3*f7^2-152*x4^3*x1*f0*f5*f4*f7^2+
560*x4^3*x1*f0*f7^3*f2+48*x4^3*x1*f1*f6*f7^2*f2+332*x4^3*x1*f3*f5*f1*f7^2+108*
x4^3*x2*f4*f5^4-24*x4^3*x2*f7*f4*f6*f2*f5+136*x4^3*x2*f4*f5*f1*f7^2+32*x4^3*x2
*f3^2*f7^2*f4+12*x4^3*x2*f3*f5*f2*f7^2-32*x4^3*x3*f3*f6*f2*f7^2-24*x4^3*x3*f4*
f6*f1*f7^2+120*x4^3*x3*f4*f5*f7^2*f2+1648*x4^3*x3*f0*f6*f5*f7^2+432*x4^3*x3*f5
^3*f6*f4+272*x4^2*x1*x5*f7^2*f1^2-48*x4^2*x1*x5*f1*f5*f7*f3-272*x4^2*x1*x5*f0*
f7^2*f2+68*x4^2*x2*x5*f1*f7^2*f2-160*x4^2*x2*x5*f0*f3*f7^2-48*x4^3*x5*f5*f6*f1
*f7+48*x4^3*x5*f5^2*f7*f2-72*x4^2*x1*x6*f4*f5^2*f3-176*x4^2*x1*x6*f0*f7^2*f3+
88*x4^2*x2*x6*f5^2*f7*f1+4*x7^4*f6+2*x6^4*f2-16*x1^3*x7*f0*f6*f5*f1-32*x1^3*x7
*f2*f4*f6*f0-32*x1^2*x2^2*f5*f7*f1^2*f2-8*x1^4*f0*f5^2*f3*f1-160*x1^2*x2*x4*f0
*f5*f7*f3^2-48*x1^2*x3*x4*f0*f4^3*f7-8*x1^3*x5*f0*f4*f3^2-16*x2^2*x1*x3*f2^2*
f6*f1*f7+32*x2^2*x1*x3*f0*f6*f3*f7*f2+40*x2^2*x1*x7*f1^2*f5*f7+48*x2^2*x3*x4*
f2*f4*f7^2*f1-20*x2^2*x3*x7*f1*f7*f4^2+8*x2^2*x3^2*f4*f5*f7*f2^2-96*x2^2*x3*x7
*f0*f7*f4*f5-8*x2^4*f0*f4^2*f7*f3+16*x2^4*f4*f0^2*f7^2+4*x2^4*f2^2*f0*f7^2-16*
x2^2*x3^2*f0*f5*f7*f4^2+12*x2^3*x1*f1*f5^2*f4*f2+52*x2^2*x3*x6*f4*f1*f5^2+24*
x2^3*x4*f0*f5^4-16*x2^2*x1*x4*f0*f6*f7*f4*f2+12*x2^2*x1*x3*f3^2*f4^3+128*x2^2*
x4^2*f7*f0*f5^3-48*x2^2*x1*x7*f0*f6*f4^2-8*x2^3*x5*f7*f0*f5*f1-24*x2^3*x6*f0*
f5^2*f4-8*x1^3*x3*f4^2*f6*f1^2+8*x1^3*x2*f1*f5*f2*f3*f4+16*x1^3*x2*f3*f6*f1^2*
f4+16*x1^3*x2*f0*f6*f5*f3*f1-16*x1^3*x3*f2^3*f4*f6-48*x1^3*x3*f2*f6^2*f1^2-20*
x1^3*x4*f1*f7*f3^3+24*x1^2*x4*x5*f0*f5*f4^2+12*x1^3*x4*f3^4*f5-80*x1^2*x2*x4*
f3^2*f4*f7*f1+36*x1^2*x2*x4*f4*f5^2*f2^2+16*x1^4*f5^2*f0^2*f4-16*x1^4*f0*f6^2*
f1^2+32*x1^2*x2*x3*f1*f5*f0*f7*f4-144*x1^2*x3*x4*f0*f6*f3^2*f7+20*x1^2*x3*x4*
f1*f4^2*f7*f3+144*x1^2*x3*x4*f0*f6*f4^2*f5+8*x1^4*f0*f4^3*f2-24*x1^2*x4*x5*f5*
f2^2*f4-32*x1^2*x2*x3*f2*f3*f0*f7*f5-96*x1^2*x2*x3*f6*f0^2*f7*f4-20*x1^2*x2*x7
*f1*f4*f5*f3-192*x1^2*x3*x4*f5*f0^2*f7^2-8*x1^3*x3*f0*f5^2*f3^2+32*x1^3*x6*f0^
2*f7*f4+32*x1^3*x7*f1*f6*f2*f3-8*x1^3*x7*f0*f4^3-12*x1^3*x7*f3^2*f1*f5-56*x1^2
*x4*x7*f7*f0*f4^2+16*x1^2*x4*x7*f7*f2^2*f4+12*x1^2*x4*x7*f7*f2*f5*f1+24*x1^2*
x4*x7*f7*f1*f4*f3-32*x1^2*x5*x7*f1^2*f6+8*x1^2*x5*x7*f0*f4^2+8*x1^2*x3*x8*f7*
f6*f1^2+24*x3^4*f2*f6*f0*f7^2+48*x3^4*f0*f6^2*f5^2+16*x3^4*f0*f4^2*f7^2-8*x3^4
*f4^3*f7*f3-12*x3^4*f6*f7^2*f1^2+24*x3^4*f0*f5^3*f7-12*x3^4*f3^2*f5*f4*f7+40*
x3^4*f7^2*f3*f0*f5-4*x3^4*f1*f6*f4^2*f7-16*x3^4*f1*f6^2*f4*f5+4*x3^4*f1*f7^2*
f2*f5+8*x3^4*f3*f6*f2*f7*f4-16*x3^3*x1*f1*f6^2*f4*f3+12*x3^3*x1*f3^2*f5^2*f4-\
16*x3^3*x1*f7*f3*f6*f0*f4-24*x3^3*x1*f3*f5*f2*f4*f6-16*x3^3*x1*f4^3*f2*f6+12*
x3^3*x1*f7^2*f2*f1*f3+28*x3^3*x1*f7*f3*f5*f1*f4-8*x3^3*x2*f2*f7*f4^3+8*x3^3*x2
*f3*f6*f1*f4*f7-16*x3^3*x2*f0*f6*f4^2*f7+16*x3^3*x2*f0*f4*f7^2*f3-20*x2*x3^3*
f7*f3*f5^2*f1-8*x3^3*x2*f4^2*f5*f1*f7-36*x1*x4^2*x3*f5^4*f2-72*x2*x4^2*x3*f2*
f6*f5^3-48*x2*x4*x3*x7*f5^2*f6*f2-8*x2*x4*x7^2*f7*f3*f4-4*x2*x4*x5*x7*f7*f1*f4
-24*x2*x4*x5*x6*f2*f4*f5+68*x6*x7*f7*f1*x2*x4*f5-8*x2*x4^2*x7*f7*f2*f4*f6-24*
x2*x4*x5*x6*f1*f5^2+64*x4^2*x2*x3*f0*f6^2*f7*f4+36*x3*x4*x6^2*f3*f5^2-16*x4*x3
*x5*x8*f7*f1*f6-96*x3*x4*x5*x8*f7^2*f0+8*x3*x4*x5*x8*f7*f2*f5-28*x3*x4*x6*x8*
f7*f3*f5+36*x3*x4*x6*x8*f7^2*f1-8*x3*x4*x6*x8*f7*f2*f6+48*x3*x4*x6*x7*f7*f2*f5
+48*x3^2*x4*x6*f5*f6^2*f1+328*x3*x4*x5*x6*f7*f0*f5-24*x1^2*x4*x6*f0*f5^2*f4+
144*x1^2*x4*x6*f0*f6*f5*f3+64*x1^2*x4*x6*f0*f6*f7*f1-32*x1^2*x4*x6*f0*f5*f7*f2
+60*x1^2*x4*x6*f5^2*f1*f3-24*x1^2*x4*x6*f5*f6*f1*f2-12*x1^2*x4*x6*f5^2*f2^2+16
*x1*x4*x2*x6*f0*f6*f7*f2+48*x1*x4*x3*x6*f4*f5^2*f2+36*x1*x4^2*x6*f5^3*f2-8*x1*
x4^2*x6*f2^2*f6*f7-192*x1^2*x4*x7*f0*f6*f7*f2-28*x3*x4*x6^2*f7*f2*f4-4*x3*x4^2
*x6*f4^3*f7-4*x3*x4*x5*x6*f7*f1*f4+16*x3*x4*x6*x7*f7*f3*f4+64*x3^2*x4^2*f3*f5*
f2*f7^2-16*x3*x4^2*x7*f4*f6*f3*f7-48*x3*x4*x5*x6*f6*f1*f5+8*x3*x4*x2*x8*f7*f2*
f4*f6-64*x4^2*x3*x6*f0*f6^2*f7+80*x3*x4*x5^2*f7*f0*f4+16*x3*x4*x7^2*f1*f7^2-18
*x2^2*x4^2*f2*f5^4+32*x2*x4*x3*x5*f2*f0*f7^2+12*x4^2*x2*x5*f4^2*f2*f7-48*x3*x4
*x2*x6*f4^3*f5-80*x4*x3^2*x6*f0*f4*f7^2+32*x4^2*x3*x7*f6^2*f1*f7+48*x3*x4*x5*
x7*f6*f2*f5-320*x4*x3*x5*x7*f7*f0*f6+8*x4*x3*x6*x7*f7*f1*f6-120*x3*x4*x6*x7*f4
*f5^2+72*x2*x4*x5^2*f0*f5^2-20*x1*x4*x6*x7*f7*f1*f4+4*x1*x4*x7^2*f7*f2*f4-4*x1
*x4*x5*x8*f7*f1*f4+4*x1*x4*x6*x8*f7*f2*f4-4*x1*x4*x2*x8*f7*f4^2*f2+72*x1*x4*x5
*x6*f0*f5^2+36*x1*x4^2*x2*f5^4*f1-16*x1*x4*x7*x8*f7^2*f0-24*x1*x4*x3*x5*f5^2*
f1*f4+16*x4^2*x2*x3*f3^2*f6*f4*f7+12*x2^2*x4*x6*f5^3*f1-8*x2*x4^2*x6*f7*f4^2*
f3+8*x2*x4^2*x6*f1*f6*f7*f4-16*x2*x4*x6*x8*f7*f2*f5-12*x2^2*x4*x7*f2*f5^3-8*x6
^3*x5*f1+8*x1^3*x3*f6*f7*f1^3-8*x1^2*x3^2*f0*f5*f7*f3^2+16*x1^3*x2*f0*f5*f2*f4
^2-32*x1^3*x2*f0*f5^2*f1*f4+96*x1^3*x4*f0*f6*f2^2*f7-32*x1^3*x4*f2*f3*f0*f7*f5
+44*x1^2*x2*x5*f7*f2*f1^2+64*x1^3*x3*f0*f6^2*f2^2-128*x1^2*x2*x4*f7^2*f1^2*f2+
40*x1^2*x2^2*f0*f5*f7*f2^2-16*x1^4*f0*f4*f3*f5*f2+16*x1^4*f0*f6*f4*f3*f1-4*x1^
4*f2*f4^2*f1*f3+72*x1^2*x3^2*f0*f5^2*f1*f7-36*x1^2*x3^2*f1^2*f7*f4*f5+32*x1^3*
x2*f5^3*f0^2+8*x1^3*x2*f3^2*f1^2*f7+192*x1^3*x4*f5*f6^2*f0^2-8*x1^3*x7*f3^2*f4
*f2+24*x1^2*x3*x7*f7*f1*f3^2-8*x1^3*x7*f2^3*f6+12*x1^3*x4*f3*f5^2*f2^2+96*x1^2
*x4*x7*f7*f1^2*f6-32*x1^3*x6*f6*f5*f0^2-16*x1^3*x6*f1^2*f6*f3+8*x1^3*x6*f0*f5*
f3^2+24*x1^3*x4*f1^2*f5^3-2*x1^4*f4^2*f2^3+4*x1^3*x7*f3^4-10*x1^2*x4^2*f7^2*f2
^3+12*x1^2*x2^2*f4^4*f0+12*x1^2*x6^2*f0*f4^2+4*x1^4*f6*f2^4+16*x1^2*x6^2*f1^2*
f6+36*x2^2*x4^2*f4^3*f5^2+12*x2^2*x6^2*f0*f5^2-8*x2^2*x6^2*f7*f0*f3-8*x3^2*x6^
2*f2*f4*f6-8*x3*x6^2*x7*f2*f6+8*x6*x4*x7^2*f7*f3+4*x6^2*x4^2*f7*f3*f4-4*x6^2*
x4^2*f7*f1*f6+12*x6^2*x4*x5*f2*f5+4*x2^2*x6^2*f7*f2*f1-16*x6*x2^2*x7*f7*f3*f1+
80*x6*x2^2*x7*f7*f0*f4+16*x3^2*x6*x7*f6^2*f1-4*x6*x4^2*x7*f7*f4^2-4*x6^2*x4*x8
*f3*f7+12*x3*x6^2*x4*f7*f3^2-20*x3*x6*x7^2*f4*f5-8*x7^3*x2*f7*f2-8*x7^3*x3*f7*
f3+16*x7^3*x3*f4*f6-8*x7^3*x1*f2*f6-8*x7^3*x4*f7*f4+16*x7^2*x1*x2*f7*f2^2+8*x1
^2*x7^2*f7*f2*f1-24*x1^2*x7^2*f3*f1*f6+32*x1^2*x7^2*f0*f6*f4-32*x1^2*x7^2*f7*
f0*f3-8*x1*x7^2*x2*f2*f4*f5-4*x1^2*x7^2*f2*f3*f5+4*x1^2*x7^2*f1*f4*f5-8*x2*x7*
x3*x8*f7*f1*f6+4*x1*x7^2*x2*f1*f5^2+4*x2*x7^2*x5*f2*f5+4*x2*x7*x5*x8*f7*f1-4*
x2*x7*x6*x8*f7*f2-4*x7^2*x8*f7*f3*x2-4*x2^2*x7*x8*f7*f1*f5+4*x2^2*x7*x8*f7*f2*
f4+4*x3*x8*f7*f3*f4*x2*x7-4*x1*x7^2*x3*f5^2*f2-2*x1^2*x7^2*f4^2*f2+4*x1*x7^2*
x5*f2*f4-4*x1*x7^2*x5*f1*f5-16*x4^4*f0*f6^2*f7^2+16*x4^2*x3*x5*f4*f5*f7*f2-40*
x4^3*x2*f4^2*f7^2*f2+52*x4^2*x3*x5*f3*f7^2*f1-248*x4^2*x3*x5*f0*f4*f7^2+16*x4^
2*x3*x5*f3^2*f5*f7-40*x4^2*x2*x6*f2^2*f7^2-16*x4^2*x3*x7*f3^2*f7^2+48*x4^3*x1*
f0*f6*f5^2*f7+172*x4^3*x3*f5^2*f7^2*f1-32*x4^2*x2*x6*f0*f6*f5*f7+96*x4^3*x2*f0
*f6*f4*f7^2+16*x4^2*x3*x6*f5*f6*f1*f7+224*x4^3*x3*f0*f4*f7^3-20*x4^3*x3*f3^2*
f5*f7^2-16*x4^3*x2*f3*f6*f7^2*f1+60*x4^2*x3*x7*f7^2*f4*f2+4*x4^2*x7*x8*f7^2*f3
-24*x4^2*x2*x8*f7*f3*f5^2+4*x4^2*x2*x8*f7^2*f1*f5+104*x4^3*x8*f7^3*f1-12*x4^2*
x2*x5*f4*f5*f1*f7-4*x4^2*x2*x5*f2*f5*f7*f3+96*x4^2*x3*x7*f7^2*f5*f1+480*x4^2*
x3*x7*f0*f6*f7^2-64*x4^3*x6*f0*f6*f7^2+12*x4^3*x2*f4^3*f5*f7-80*x4^3*x1*f0*f6*
f7^2*f3+20*x4^4*f4*f7^2*f3*f5+136*x4^3*x2*f0*f5^2*f7^2-48*x4^2*x5*x8*f7^2*f1-\
12*x4^2*x5*x8*f7*f3*f5+16*x4^2*x2*x6*f3^2*f5*f7-72*x4^2*x2*x6*f4^2*f5^2-72*x4^
2*x1*x7*f0*f4*f7^2-244*x4^2*x3*x7*f5^2*f7*f3-132*x4^2*x3*x7*f4^2*f5*f7+84*x4^3
*x6*f5^2*f7*f3+36*x4^3*x6*f7^2*f4*f2-84*x4^3*x1*f5^2*f7*f3^2-84*x4^3*x3*f3*f7^
3*f1+16*x2^2*x4*x5*f4*f7*f3*f1-104*x2^2*x4*x5*f0*f7*f4^2+48*x2^2*x3*x6*f4^2*f6
*f1-8*x2^4*f4^3*f1*f5+12*x2^4*f0*f5^2*f4^2-12*x2^3*x4*f5^3*f1*f4-6*x2^4*f2*f7^
2*f1^2+16*x2^3*x1*f0*f5*f3*f7*f2-32*x2^3*x1*f0*f4*f5*f7*f1+24*x2^3*x1*f0*f5*f4
^3+32*x2^3*x1*f5^2*f0^2*f7+40*x2^2*x4^2*f7^2*f4*f2^2+208*x2^2*x4^2*f7^2*f0*f4^
2-36*x2^2*x3*x4*f4*f5^3*f2+16*x2^2*x3*x4*f4*f6*f7*f2^2-24*x2^3*x5*f0*f5*f4^2+8
*x2^4*f0*f3*f1*f7^2+8*x2^3*x7*f0*f5^3-4*x2^2*x1*x3*f4^4*f2-8*x2^3*x3*f6*f7*f4*
f1^2-28*x2^3*x3*f4^2*f5^2*f1-32*x2^3*x7*f0*f7*f5*f3+12*x2^2*x3^2*f0*f5^4+8*x1^
4*f5*f4*f2^2*f1+4*x1^4*f4*f2^2*f3^2+4*x1^4*f0*f5^2*f2^2-8*x1^4*f0*f5*f1*f4^2+
16*x1^4*f0*f6*f5*f1*f2-16*x1^4*f0*f4*f7*f1*f2+28*x1^2*x2^2*f7*f3*f4*f1^2-20*x1
^2*x2^2*f3*f4^3*f1-8*x1^2*x2^2*f0*f4^2*f7*f1+16*x1^2*x2^2*f4^2*f6*f1^2-32*x1^3
*x2*f4^2*f0^2*f7+32*x1^3*x2*f0*f5*f2*f7*f1-8*x1^3*x2*f2^3*f4*f5+8*x1^3*x2*f1*
f5^2*f2^2+2*x2^4*f4^4*f2+12*x1*x6*x7*x8*f7*f1+8*x2*x6^3*f1*f5+16*x1*x6*x2*x7*
f7*f0*f3+12*x6^2*x2*x7*f3*f4+12*x6^2*x3*x7*f3*f5-20*x6^2*x4*x7*f2*f7-4*x6^3*x3
*f3*f4-48*x1^2*x5*x7*f0*f5*f3+64*x1*x5*x4*x6*f7*f0*f3-8*x1*x5*x7*x8*f7*f0-8*x5
*x2^2*x7*f7*f2*f1+32*x5*x2^2*x7*f7*f0*f3-4*x1*x5^2*x7*f3*f1-12*x5^2*x1*x6*f2*
f1-32*x1^2*x5*x6*f1*f6*f0-12*x1*x5*x6*x7*f2*f3+32*x5*x1*x3*x6*f7*f0*f2-12*x4^2
*x5*x6*f7*f2*f4+32*x4^2*x5*x6*f7*f0*f6-18*x4^2*x5^2*f5^2*f2-4*x4^2*x5^2*f7*f1*
f4+8*x5^2*x1*x7*f0*f4-24*x5^2*x2*x6*f0*f4-24*x5^2*x3*x6*f0*f5-16*x3^3*x4*f2*f6
*f7^2*f1+52*x3^2*x4*x6*f2*f5*f7*f4+12*x3^2*x4*x6*f5*f7*f3^2-640*x3^2*x4*x6*f0*
f6*f7*f5+288*x3^2*x2*x4*f0*f6^2*f5^2+100*x3^2*x4*x6*f1*f5^2*f7+352*x3^3*x4*f0*
f6*f5^2*f7-76*x3^3*x4*f5*f7*f4^2*f3+48*x3^3*x4*f2*f0*f7^3+36*x3^2*x2*x6*f5*f1*
f7*f3-80*x2*x6*f7*f0*f4*x3^2*f5-96*x3^3*x6*f0*f6^2*f5-40*x3^2*x4*x7*f7*f6*f1*
f5-24*x3^3*x4*f7*f5^2*f2*f4-48*x3^3*x4*f0*f6*f7^2*f3-24*x3^3*x4*f5^2*f7*f3^2+8
*x3^3*x1*f2*f3*f5^3-8*x1*x7*f2^2*f7*x3^2*f5+8*x3^3*x5*f5^3*f1+16*x3^2*x1*x6*f1
*f6*f4^2+48*x3^2*x1*x6*f0*f5^3+16*x3^2*x2*x5*f6*f7*f1^2+24*x3^2*x2*x6*f5^3*f1+
8*x3^2*x2*x6*f7*f4^2*f1+8*x3^3*x6*f1*f4*f5*f7+12*x3^3*x8*f7*f3*f5*f4-12*x3^2*
x2*x7*f1*f4*f5*f7-28*x3^2*x2*x7*f2*f7*f4^2-32*x3^2*x2*x7*f0*f7^2*f3+4*x3^2*x2*
x7*f3^2*f7*f4-48*x3^2*x1*x6*f2*f6^2*f1-12*x3^2*x6*x8*f7*f3*f4+32*x3^2*x6*x8*f7
^2*f0+8*x3^2*x2*x8*f7^2*f3*f1+8*x3^2*x2*x8*f7*f4^2*f3-24*x3^2*x7^2*f7*f3*f4-\
240*x3^2*x4^2*f7*f5^2*f3*f4-40*x3^2*x4^2*f7^3*f2*f1+144*x3^2*x4*x7*f4^2*f5*f6+
64*x3^3*x7*f0*f6^3-24*x3^2*x5*x6*f1*f5^2+96*x3^2*x5*x6*f0*f5*f6-32*x3^2*x1*x5*
f0*f6*f4^2+12*f7*x4*x8^2*x6*f5-12*f7^2*x2^2*x8^2*f0-12*f7*x3*x8^2*x4*f5^2+24*
x1^2*x3^2*f7*f2*f1*f4^2-48*x1^3*x3*f0*f6*f5*f4*f1-80*x1^3*x3*f0*f6*f5*f2*f3+32
*x1^2*x3*x7*f4*f6*f2^2-4*x1^2*x4*x6*f7*f2*f1*f4-36*x1^3*x4*f5^2*f4*f2*f1-48*x1
^3*x4*f1*f6*f5^2*f0-24*x1^2*x3^2*f3*f4^2*f1*f6+48*x1^2*x2*x3*f5*f6*f1^2*f4-60*
x1^2*x2*x3*f3*f4^2*f1*f5-72*x1^2*x2*x3*f2*f6*f7*f1^2+48*x1^2*x2*x6*f0*f3*f2*f7
+24*x1^2*x4*x8*f7^2*f1^2+12*x1^3*x4*f3*f4^2*f1*f5+4*x1^3*x6*f2*f1*f4^2-4*x1^3*
x6*f2*f3^3+4*x1^3*x6*f2^3*f5-4*x1^3*x6*f4*f2^2*f3+4*x1^3*x6*f1^2*f2*f7-4*x1^2*
x6^2*f2*f5*f1-16*x1^2*x2*x6*f1*f7*f2^2-48*x1^2*x3*x4*f1*f7^2*f2^2-4*x1^3*x5*f1
^2*f3*f5+4*x1^3*x5*f1^2*f4^2+4*x1^3*x5*f1*f3^3-4*x1^3*x5*f7*f1^3+4*x1^3*x5*f2^
3*f4+4*x1^2*x3*x5*f2*f5*f4*f1-8*x1^2*x3*x5*f4^2*f2^2+16*x1^2*x3*x5*f1^2*f7*f3+
12*x1^2*x4*x5*f7*f2^3-12*x1^2*x2*x7*f2*f5^2*f1+12*x1^2*x2*x7*f5*f2^2*f4-12*x2^
2*x1*x7*f4*f5*f2*f3+20*x2^2*x1*x7*f1*f4*f7*f2-4*x2^2*x1*x7*f5^2*f3*f1-16*x2^2*
x7^2*f7*f1*f4+8*x2^2*x5*x7*f1*f4*f5-12*x2^2*x6*x7*f4^2*f3+8*x2^2*x6*x7*f2*f4*
f5+4*x2^2*x3*x8*f7*f1*f4*f5-8*x2^2*x6*x8*f7*f1*f4+4*x2^3*x8*f7*f4^2*f1+12*x2^2
*x3*x8*f7^2*f2*f1-32*x2^2*x1*x6*f0*f5*f4^2+272*x2*x1*x4^2*f7*f0*f5^2*f4-32*x2*
x1^2*x3*f3^2*f4*f1*f6-48*x2*x1^2*x3*f0*f5*f6*f3^2-8*x2*x1^2*x3*f2^3*f5*f6+16*
x2*x1*x3*x7*f3*f4^3-12*x2*x1*x7*x8*f7*f1*f4+8*x2*x1*x7*x8*f7*f0*f5+8*x2*x1*x3*
x8*f7*f2*f1*f6+24*x2*x1*x4*x8*f7*f0*f5^2-48*x4^2*x1*x2*f1*f3^2*f7^2+224*x4^2*
x1*x2*f5*f7^2*f1^2-16*x2*x1*x7^2*f1*f4*f6+172*x2*x1*x4*x6*f7*f3*f1*f4-16*x2*x1
*x4*x6*f7*f0*f5*f3-8*x2^2*x1*x3*f2^2*f4^2*f6+128*x2*x1*x3*x4*f0*f6*f4*f3*f7+8*
x3^2*x1*x2*f7*f3*f2^2*f5+20*x2^2*x1*x4*f7^2*f1^2*f3-40*x2*x1*x5*x7*f0*f4*f5-56
*x2*x1*x5*x7*f7*f1^2+48*x2*x1^2*x3*f0*f6*f4^2*f3-12*x2*x1^2*x3*f4^3*f2*f3+12*
x2*x1^2*x3*f3^3*f4^2+8*x2*x1^2*x3*f5^3*f1^2+8*x2*x1^2*x3*f3^2*f7*f2^2+80*x2*x1
^2*x3*f0*f6*f1*f7*f3-16*x2*x1^2*x3*f0*f5^3*f2-8*x2*x1^2*x3*f3*f4*f2^2*f6-80*x2
^2*x1*x3*f0*f5*f4*f7*f2+4*x1^2*x2*x4*f7*f2*f1*f4^2+192*x1^2*x2*x4*f0*f4^2*f3*
f7+512*x1^2*x3*x4*f6^2*f0^2*f7+96*x1^2*x3*x4*f1*f4*f0*f7^2+208*x1^2*x3*x4*f0*
f3*f7^2*f2+12*x1^2*x3*x4*f2^2*f4^2*f7+96*x1^2*x3*x4*f2^2*f6*f5*f4-80*x1^2*x3*
x4*f1^2*f7^2*f3+72*x1^2*x3*x4*f2*f5*f4*f1*f7-12*x1^2*x3*x4*f1*f5*f3^2*f7-24*x1
^2*x3*x4*f2^2*f5*f3*f7-16*x1^3*x5*f0*f4^2*f2-32*x1^3*x5*f0*f6*f2^2+32*x1^3*x5*
f4*f0^2*f6-8*x1^3*x5*f1*f2^2*f5+36*x1^2*x4*x5*f2*f5^2*f1-64*x1^2*x4*x5*f1*f7*
f2*f3+4*x2^2*x7^2*f4^3+32*x1^2*x2*x7*f1^2*f6*f5-144*x1^2*x2*x4*f0*f5^2*f1*f7+
224*x1^2*x2*x4*f1*f7*f2*f3*f5-160*x1^2*x4^2*f7*f0*f5*f4^2-44*x1^2*x4^2*f7^2*f0
*f3^2-176*x1^2*x4*x6*f7*f0*f4*f3-32*x1^2*x3*x6*f0*f4*f2*f7+64*x1^2*x3*x6*f6*f0
^2*f7-60*x1^2*x2*x4*f1*f5^2*f4*f3-16*x1^3*x6*f0*f7*f3*f1+8*x1^3*x3*f2^2*f5*f3*
f4-24*x1^2*x3*x7*f7*f5*f1^2-8*x1^2*x3*x7*f7*f2^2*f3+12*x1^2*x3*x6*f1^2*f7*f4-8
*x1^2*x3*x6*f7*f2^3-4*x1^2*x4*x6*f7*f2^2*f3+4*x1^3*x7*f2^2*f5*f3-4*x1^3*x7*f1*
f7*f2^2+4*x1^3*x7*f3*f4^2*f1+4*x1^3*x7*f4^2*f2^2+12*x1^2*x5*x7*f2*f5*f1-8*x1^2
*x5*x7*f2^2*f4-4*x1^2*x6*x7*f7*f1^2+24*x5^2*x2*x7*f0*f5-24*x5^3*x4*f0*f5+80*x5
^2*x4*x7*f7*f0+48*x5^2*x3*x7*f0*f6-8*x5^3*x3*f0*f4+20*x1*x5*x6^2*f3*f1+12*x1*
x5*x2*x7*f2*f3*f4+12*x1*x5*x3*x7*f2*f3*f5+24*x1*x5*x6*x7*f0*f5-16*x1*x5*x3*x8*
f0*f4*f7-12*x4*x5^2*x7*f2*f5-112*x6^2*x4*x5*f7*f0-8*x4*x5*x3*x6*f7*f2*f3+32*x5
*x3^2*x6*f7*f0*f4+24*x3*x5*x6^2*f1*f5+24*x3*x5*x6*x7*f7*f0-40*x1*x5*x6^2*f0*f4
+16*x1*x5*x3*x7*f7*f0*f3+32*x5^2*x1*x4*f7*f0*f2+12*x1^2*x5^2*f2*f3*f1-4*x1^2*
x5*x6*f3*f2^2+4*x1*x5^2*x3*f2^2*f4-4*x2*x5^2*x7*f1*f4-8*x2*x5*x6*x7*f2*f4-32*
x1*x4^2*x8*f7^2*f0*f5+32*x1*x4*x3*x7*f0*f6*f7*f4+72*x1^2*x4^2*f6*f5^2*f2^2+176
*x4^3*x2*f7^3*f0*f3-32*x4^2*x2*x3*f7*f4^2*f2*f6-52*x2*x4^2*x7*f7*f3*f5*f4+36*
x2*x4^2*x5*f2*f5^3+36*x2*x4*x6^2*f3*f5*f4-88*x2*x4*x6^2*f7*f1*f4-12*x1^3*x7*f2
*f5*f4*f1+16*x1^3*x3*f5*f7*f1^2*f2+16*x1^3*x5*f1*f5*f0*f4-32*x1^2*x3*x6*f0*f5*
f4^2+16*x1^3*x7*f1*f4*f0*f7+16*x1^2*x2*x3*f2*f4^2*f0*f7+96*x1^2*x2*x4*f5^2*f6*
f1^2-32*x1^3*x7*f0*f6*f3^2+192*x1^2*x3*x4*f1^2*f6^2*f5-28*x3^2*x6*x7*f5*f4^2-\
12*x3^2*x6*x7*f3*f5^2-4*x3^2*x6*x7*f7*f2*f4+4*x3^3*x8*f7^2*f2*f3+4*x3^3*x8*f7^
2*f1*f4+4*x3^2*x5*x8*f7*f2*f4+12*x7*x8*f7*f3*x3^2*f5+48*x1*x3*x4*x8*f7*f0*f5*
f6-8*x2*x7*x1*x3*f2*f7*f3^2-40*x1*x3^2*x7*f4^2*f6*f2-56*x1*x3^2*x7*f0*f7*f4*f5
-24*x1*x3^2*x7*f5*f6*f2*f3-64*x1*x3^2*x7*f0*f7^2*f2-16*x1*x3^2*x7*f0*f6*f3*f7-\
64*x1*x3^2*x5*f0*f5^2*f4-48*x3^2*x1*x6*f0*f5*f3*f7-12*x1*x3^2*x8*f7*f1*f4*f5-\
32*x1*x3^3*f1^2*f6^3+32*x1*x3^3*f4^2*f0*f6^2+36*x1*x3^2*x7*f3*f7*f1*f5-32*x1*
x3^2*x5*f0^2*f7^2+12*x1^2*x3*x6*f4^2*f2*f3+16*x1*x3*x6*x7*f1*f5^2-32*x1*x3*x5*
x7*f0*f6*f4+12*x1*x3^2*x2*f5^2*f2*f3*f4+20*x1*x3*x7^2*f3*f5*f4-8*x1*x3*x7^2*f6
*f1*f5-12*x1*x3*x7*x8*f7*f1*f5-16*x1*x3*x7*x8*f7*f2*f4+16*x1*x3*x7*x8*f7*f0*f6
-96*x1^2*x3^2*f0*f6^2*f4*f2-72*x1*x3*x4*x6*f3^2*f5^2+48*x1*x3*x4*x5*f3*f6*f1*
f5+24*x1*x3*x6*x7*f2*f3*f6+4*x1^2*x3^2*f3^2*f4^3-48*x1^2*x3^2*f0*f6^2*f3^2+10*
x1^2*x3^2*f3^2*f5^2*f2+4*x1^2*x3^2*f7*f3^3*f2-32*x1^2*x3^2*f3^2*f5*f1*f6-8*x1^
2*x3^2*f3*f5*f2^2*f6-24*x1^2*x3^2*f0*f6*f5^2*f2+136*x3^2*x4*x7*f0*f5*f7^2+40*
x3^2*x1*x6*f5^2*f1*f4-32*x3^4*f0*f6^2*f3*f7-8*x3^3*x2*f1*f5^4-32*x3^3*x2*f0^2*
f7^3-8*x3^4*f2*f6^2*f4^2-4*x3^4*f0*f7^3*f1-16*x3^4*f1*f6*f5^3-64*x3^2*x4^2*f4^
3*f7*f5-48*x3^2*x6^2*f6*f1*f5+16*x3^2*x1*x6*f2^2*f6*f5+12*x3^3*x1*f7*f4^2*f2*
f3-48*x3^3*x1*f7^2*f2*f4*f0+8*x3^3*x1*f7*f3^2*f2*f5-16*x3^3*x1*f7*f6*f1^2*f5+8
*x3^3*x2*f2^2*f6*f7*f4+12*x3^3*x2*f3*f5^2*f4^2-8*x3^2*x2*x4*f1*f6*f4^2*f7+32*
x3^3*x8*f7*f0*f6^2+8*x3^2*x4*x6*f7*f4^2*f3+48*x3^2*x4*x6*f2*f6*f5^2-32*x3^3*x6
*f0*f7^2*f3-136*x3^2*x2*x4*f2*f5*f4^2*f7-20*x3^2*x2*x4*f3*f5^2*f7*f2+32*x3^3*
x5*f0*f6*f7*f3+44*x3^2*x2*x4*f3*f7^2*f1*f4-8*x3^3*x4*f4^4*f7+24*x3^2*x7*x8*f7*
f4^2+20*x3^3*x1*f7^2*f1^2*f4-16*x3^3*x1*f4*f5^3*f1-36*x3^2*x4*x6*f3*f5^3-28*x3
^2*x1*x6*f7*f3*f1*f4+192*x3^3*x2*f0*f6^2*f5*f4-16*x3^2*x4*x7*f7*f2*f4*f6-48*x3
^2*x1*x5*f1*f6*f2*f5+16*x3^2*x1*x5*f3*f4*f1*f6-12*x1*x3^3*f7*f2^2*f4*f5-40*x3^
2*x2*x7*f0*f5^2*f7+16*x3^2*x5*x7*f2*f4*f6+48*x2*x1*x3*x5*f1^2*f5*f6-36*x2*x1*
x3*x6*f3*f5*f2*f4+24*x2*x1^2*x3*f2*f6*f1*f4^2-48*x2*x1^2*x3*f0*f1*f7^2*f2-64*
x2*x1^2*x3*f0*f6*f5^2*f1-48*x2*x1*x3*x5*f2*f6*f1*f4-120*x2*x1*x3*x5*f0*f5*f4^2
+4*x2*x1*x3*x5*f7*f2*f3*f1+24*x2*x1*x3*x7*f3^2*f5*f4-24*x2*x1*x3*x7*f4^2*f2*f5
-4*x2*x1*x4*x7*f3^3*f7+20*x2*x1*x4*x7*f7*f1*f4^2+4*x2*x1^2*x5*f3*f4*f2^2+4*x2^
2*x1*x5*f2^2*f4^2-4*x2^2*x1*x6*f7*f2^3-24*x2*x1*x3*x6*f3^2*f4^2+8*x2*x1*x3*x6*
f2*f4^3+12*x2*x1*x3*x6*f3^2*f7*f1-8*x2*x1*x5*x6*f4*f2^2-40*x2*x1*x5*x6*f4*f3*
f1+4*x2*x1^2*x7*f4^3*f1-40*x2*x1*x7^2*f7*f3*f1-8*x2*x1*x5*x7*f2^2*f5+24*x2*x1*
x4*x5*f3*f5^2*f1+48*x2*x1^2*x7*f0*f5^2*f3-48*x2*x1^2*x7*f0*f6*f4*f3-120*x2*x1*
x4*x5*f0*f5^2*f4+16*x2*x1^2*x6*f3^2*f5*f1+88*x2*x1*x3*x4*f2^2*f5*f7*f4-20*x2*
x1*x3*x4*f7*f2*f3^2*f5+16*x2*x1*x7^2*f7*f0*f4-16*x2*x1*x3*x7*f3*f5*f1*f6-32*x2
*x1*x3*x7*f7*f3*f1*f4-80*x4*x5*x1*x2*f3*f4*f7*f0+24*x2*x1*x5*x6*f5*f2*f1-32*x2
*x1*x3*x7*f1*f4^2*f6-12*x2*x1*x3*x7*f5^2*f2*f3-256*x2*x1*x4*x7*f2*f0*f7^2+12*
x2*x1*x3*x7*f7*f2*f1*f5+8*x2*x1*x5*x7*f3*f1*f5+12*x2*x1^2*x7*f3^3*f4-12*x2*x1^
2*x7*f4^2*f2*f3+8*x2*x1^2*x4*f2^2*f6*f1*f7-48*x2*x1^2*x5*f0*f4^2*f3+24*x2*x1^2
*x5*f0*f3^2*f5+16*x2*x1*x3^2*f0*f5^2*f2*f7-48*x2*x1*x3*x4*f5^2*f6*f3*f1+8*x2*
x1*x4*x8*f7^2*f2*f1-36*x2*x1*x3*x4*f2*f5^3*f3-72*x2*x1*x3*x4*f2*f5^2*f4^2-96*
x2*x1*x3*x4*f0*f5*f1*f7^2+128*x2*x1*x3*x4*f1*f7*f2*f4*f6+8*x2*x1*x3*x4*f3*f6*
f7*f2^2-24*x2*x1^2*x4*f3^2*f5^2*f2+96*x2^2*x1*x4*f0*f5^3*f4-8*x2*x1*x3*x6*f0*
f5^2*f4-16*x2^2*x1^2*f1*f5*f3^2*f4-32*x2^2*x1^2*f6*f1*f0*f5*f4+24*x2*x1*x3*x7*
f0*f5^3-8*x2*x1*x3*x7*f5^2*f1*f4+16*x2*x1^2*x6*f0*f5^2*f2+16*x2*x1*x4*x7*f0*f6
*f3*f7+152*x2*x1*x4*x7*f7^2*f1^2+16*x2*x1*x3^2*f0*f5^3*f4-24*x2*x1*x3*x4*f1*f5
^3*f4+48*x2*x1*x3*x4*f4^3*f5*f3+32*x2*x1*x4^2*f0*f6*f5*f3*f7+28*x4^2*x1*x2*f3*
f7^2*f2^2+256*x4^2*x1*x2*f0*f4*f3*f7^2+24*x2*x1^2*x4*f1*f5*f2*f4*f6+16*x2*x1*
x3*x6*f2^2*f4*f6-8*x2*x1*x3*x7*f0*f7*f4^2-144*x2*x1*x4^2*f4*f6*f1*f5^2-8*x2*x1
^2*x7*f3^2*f5*f2+208*x2*x1*x4*x5*f0*f5*f2*f7-52*x2*x1*x4*x5*f7*f2*f1*f4+64*x3*
x6*x1*x2*f7*f1*f0*f6+12*x2*x1*x6*x7*f2*f3*f5+72*x2*x1*x4^2*f3*f4^2*f5^2-8*x2*
x1*x4^2*f3^3*f7*f5+60*x2*x1*x4^2*f1*f7*f5*f4^2-24*x2*x1*x6^2*f1*f4^2+1056*x3^2
*x4^2*f0*f6^2*f5*f7-32*x3^2*x4^2*f3^2*f5*f6*f7+216*x3^2*x4^2*f4^2*f6*f5^2-44*
x3^2*x1*x4*f7*f4^2*f5*f1+232*x3^2*x1*x4*f7*f1*f6*f2*f5+4*x3^2*x1*x4*f7*f2*f3*
f4*f5-120*x3^2*x1*x4*f4^2*f6*f2*f5-48*x3^2*x1*x4*f4*f5^2*f1*f6+48*x3^2*x1*x4*
f0*f6*f4^2*f7+16*x3^2*x1*x4*f7*f2^2*f6*f4+4*x3^2*x1*x4*f7*f1*f5^2*f3-48*x3^2*
x1*x4*f3*f6^2*f1*f5-36*x3^2*x1*x4*f4*f5^3*f2+24*x3^2*x1*x4*f7^2*f1*f3^2+8*x3^2
*x1*x4*f7*f2*f4^3+96*x3^2*x1*x4*f0*f5*f6^2*f4+624*x3^2*x2*x4*f0*f6*f5*f7*f4-\
128*x3^2*x2*x4*f7^2*f3*f0*f5-16*x3^2*x2*x4*f3*f6*f5*f7*f1+20*x3^2*x2*x4*f3^2*
f5*f4*f7+36*x3^2*x2*x4*f4*f5^3*f3-32*x3^2*x2*x4*f0*f6*f7^2*f2+16*x3^2*x2*x4*f2
^2*f7^2*f4-8*x3^2*x2*x4*f4^3*f3*f7-32*x3^2*x2*x4*f0*f4^2*f7^2+48*x3^2*x2*x4*f0
*f7^3*f1+12*x3^3*x4*f3*f5^4+8*x3^3*x4*f2*f5*f6*f7*f3+12*x3^3*x4*f1*f4^2*f7^2-\
48*x3^3*x4*f6^2*f1*f5^2-32*x3^3*x4*f1*f6^2*f7*f3+192*x3^3*x4*f0*f6^3*f5+8*x3^3
*x4*f2^2*f5*f7^2+20*x3^3*x4*f5*f1*f7^2*f3+320*x3^3*x4*f0*f6^2*f7*f4-36*x3^3*x4
*f1*f5^3*f7+128*x3^3*x4*f0*f5*f7^2*f4-16*x3^3*x4*f3^2*f6*f4*f7-16*x3^2*x1*x5*
f7*f2*f1*f4+16*x3^2*x1*x5*f7*f4*f0*f3-16*x3^3*x5*f2*f0*f7^2-96*x3^3*x5*f0*f6^2
*f4-48*x3^3*x5*f0*f6*f5^2+16*x3^3*x5*f4*f6*f1*f5+8*x3^3*x5*f2*f6*f4^2-192*x3^2
*x4*x5*f0*f5^2*f7+32*x3^2*x4*x5*f1*f4*f5*f7+8*x3^2*x4*x5*f7*f3^2*f4+80*x3^2*x1
*x6*f3*f1*f6*f5+32*x2*x1^2*x6*f1*f6*f0*f5-48*x2*x1*x3*x6*f2*f5*f1*f6+64*x2*x1*
x3*x6*f1*f5*f4^2+40*x2*x1*x3*x6*f3*f5^2*f1-48*x2*x1*x3*x6*f1^2*f5*f7+24*x2*x1*
x4*x6*f4^2*f2*f5+8*x2*x1*x4*x6*f7*f2^2*f4-4*x2*x1*x4*x6*f7*f3^2*f2+288*x2*x1*
x4*x6*f0*f6*f4*f5+48*x2*x1*x4*x6*f5^2*f1*f4-72*x2*x1*x4*x6*f3^2*f5*f4-72*x2*x1
*x4*x6*f0*f5^3-280*x2*x1*x4*x6*f7*f0*f4^2-2*x2^2*x1^2*f2^3*f5^2+8*x2*x1*x6*x7*
f2*f4^2-8*x2*x1*x6*x7*f7*f2*f1-24*x2*x1*x6*x7*f3^2*f4+8*x2*x1*x7^2*f4^2*f3-12*
x2*x1*x3*x8*f7^2*f1^2-8*x2*x1*x3*x8*f7*f3*f1*f5-4*x2*x1*x5*x8*f7*f2*f1+4*x2*x1
*x6*x8*f7*f3*f1-4*x2^2*x1*x8*f7*f4*f3*f1+4*x2^2*x1*x8*f2*f5*f1*f7+8*x4*x5*x1*
x2*f7*f1*f3^2-16*x2*x1*x3*x7*f0*f7*f3*f5-32*x2^2*x1*x6*f6*f0^2*f7+16*x2^2*x1*
x6*f0*f4*f2*f7-48*x2*x1*x3*x4*f0*f6*f5^2*f4+12*x2*x1^2*x4*f4^3*f5*f1+12*x2^2*
x1^2*f1*f5^2*f2*f3+4*x2^2*x1^2*f3*f7*f2^3-8*x2^2*x1^2*f0*f5^2*f2*f4-36*x2*x1*
x3^2*f1*f5^2*f4^2-48*x2*x1*x3^2*f1^2*f6^2*f5-20*x2*x1*x3^2*f5^3*f3*f1-64*x3^2*
x1*x2*f5*f0^2*f7^2-16*x2*x1*x3^2*f4^3*f1*f6+48*x2*x1*x3^2*f2*f5^2*f1*f6-8*x2*
x1*x3^2*f7*f2*f1*f6*f3+192*x2*x1^2*x3*f0^2*f6^2*f5-16*x2*x1*x3^2*f2*f5*f4^3-12
*x3^2*x1*x2*f7*f1*f5*f3^2+12*x3^2*x1*x2*f7*f1*f5*f2*f4+8*x2*x1*x3^2*f4^4*f3+4*
x2*x1^2*x3*f4^4*f1-4*x2*x1^2*x3*f3*f5^2*f2^2-4*x2*x1^2*x3*f3^3*f7*f1+36*x4^2*
x1*x2*f1*f4*f7^2*f2+4*x2*x1^2*x4*f7*f2*f3^3+12*x2*x1*x5^2*f1*f2*f4-12*x2*x1*x5
^2*f1^2*f5-96*x1^2*x3^2*f0*f6^2*f5*f1-12*x1^2*x3^2*f1*f6*f2^2*f7+48*x1*x3*x4*
x6*f5^3*f1-8*x1*x3^2*x8*f7^2*f2*f1+192*x1^2*x3^2*f6^3*f0^2-20*x1*x3^2*x4*f7^2*
f5*f1^2+32*x1^2*x3*x6*f3^2*f6*f1+16*x1^2*x3*x6*f0*f6*f5*f2+56*x1*x3^2*x4*f0*f5
^2*f7*f4-20*x1^2*x3*x6*f3^2*f5*f2+180*x2*x3*x4^2*f5^3*f4^2-32*x2*x3^2*x7*f4*f5
*f2*f6-48*x2*x3^2*x4*f5^3*f1*f6+40*x2*x3^2*x4*f0*f5^3*f7-96*x2*x3^2*x4*f5^2*f6
*f2*f4+48*x2*x3*x5^2*f0*f5*f4+48*x1*x3^2*x5*f1^2*f6^2-8*x1*x3^3*f5^2*f6*f2^2-\
96*x1^2*x3*x5*f0*f5*f4*f3-8*x1*x3^2*x4*f7*f4^2*f3^2-48*x1*x3*x4*x7*f7*f0*f5^2+
12*x3^2*x6^2*f5^2*f2+2*x3^4*f2*f5^4+16*x3^2*x7^2*f0*f7^2+4*x3^4*f4^4*f6+48*x3^
2*x6^2*f0*f6^2+8*x3^4*f4^3*f5^2+16*x3^2*x7^2*f4*f5^2+144*x3^2*x4^2*f5^4*f4+12*
x3^2*x5^2*f0*f5^2+24*x3^2*x7^2*f4^2*f6-8*x3^2*x2*x6*f4^4+128*x1^2*x3*x7*f0^2*
f7^2-8*x1^3*x3*f7*f3*f4*f1^2-16*x1^3*x4*f1*f5*f0*f7*f4+80*x1^3*x4*f1*f0*f7*f6*
f3+96*x1^3*x4*f3*f6*f5*f1*f2+112*x1^2*x2*x4*f0*f7^2*f2^2-36*x1^2*x2*x4*f2*f5^3
*f1-384*x1^2*x2*x4*f0^2*f7^2*f4-16*x1^2*x2*x4*f1^2*f7*f4*f5+4*x2^2*x3^2*f4^5+
16*x1^4*f0*f5*f7*f1^2-24*x1^3*x4*f4^3*f5*f0+16*x1^2*x3^2*f0*f7^2*f2^2-72*x1^2*
x3^2*f0*f4^2*f3*f7+4*x3^2*x6^2*f4^3+8*x2^2*x3*x6*f0*f7*f4^2+16*x2^2*x3^2*f1*f6
*f7*f4*f2+48*x2^2*x3*x7*f0*f6*f5^2-16*x2^2*x3*x7*f4*f5*f1*f6-24*x2^2*x3*x4*f4^
3*f7*f2+8*x2^2*x3*x4*f5^2*f7*f2^2-16*x2^2*x4*x7*f7*f4^2*f2-96*x2^2*x1*x7*f0*f5
*f7*f2-8*x2^3*x3*f1*f2^2*f7^2+16*x2^2*x4^2*f7^2*f6*f1^2-16*x2^2*x4^2*f7*f5*f3^
2*f4-28*x2^2*x3^2*f5^3*f1*f4+40*x2^2*x4*x7*f7*f0*f5^2+48*x2^2*x4*x6*f7^2*f0*f2
-32*x2^2*x4*x6*f7*f3*f1*f5+92*x2^2*x4*x6*f7*f1*f4^2+24*x2^2*x4*x5*f4*f1*f5^2+
24*x2^2*x4*x7*f4^3*f5-88*x2^2*x4*x7*f7*f1*f4*f5+4*x2^2*x3*x4*f3^2*f7^2*f1+48*
x2^2*x3*x4*f5^2*f7*f3*f1-8*x2^2*x3*x4*f3*f7^2*f2^2-4*x2^2*x3*x4*f4*f5*f7*f2*f3
+4*x2^2*x3*x4*f7*f4^2*f3^2+12*x2^2*x1*x5*f5^2*f1^2+12*x2^2*x3*x5*f1^2*f7*f5-8*
x2^2*x3*x5*f7*f2*f1*f4-4*x2^3*x7*f4^2*f2*f5-4*x2^3*x7*f4*f1*f5^2+4*x2^3*x7*f3*
f4^3-4*x2^3*x7*f7*f4*f2^2-12*x2^2*x3*x7*f2*f5^2*f4+24*x2^2*x3*x7*f3*f7*f1*f5-\
12*x2^2*x3*x7*f7^2*f1^2+12*x2^2*x3*x7*f3*f5*f4^2+20*x2^2*x4*x7*f7^2*f2*f1+28*
x2^2*x4*x7*f7*f2*f3*f5-8*x2^2*x4*x7*f7*f3^2*f4+4*x2^3*x5*f7*f4*f1^2-4*x2^2*x3*
x6*f7*f4*f2^2-8*x2^2*x3*x6*f1*f5*f7*f2-16*x2^2*x3*x6*f4^2*f2*f5-12*x2^2*x3*x6*
f3*f4^3-8*x2^2*x1*x7*f4^2*f1*f5+12*x2^2*x5^2*f0*f4^2-8*x1^4*f1*f6*f2^2*f3+32*
x1^3*x2*f0*f6*f5*f2^2+8*x1^3*x2*f7*f2^4-16*x1^2*x2*x7*f7*f2^3-64*x1^3*x7*f5*f0
^2*f7+56*x1^2*x2*x7*f1*f7*f2*f3+56*x1^2*x4*x5*f0*f3^2*f7-56*x1^2*x2*x4*f2^3*f5
*f7+80*x1^3*x4*f2*f4^2*f0*f7+24*x1^2*x2*x3*f4^3*f5*f0+8*x1^2*x3*x6*f2*f5^2*f1-\
32*x1^3*x2*f0*f5^2*f3*f2-16*x1^3*x2*f0*f4*f2^2*f7-112*x1^2*x3*x7*f0*f4*f3*f7+8
*x1^3*x4*f7*f3^2*f2^2+24*x1^3*x5*f2*f1^2*f6+16*x1^3*x5*f1*f0*f7*f2+8*x1^3*x7*
f1^2*f5^2+52*x1^2*x4^2*f7^2*f1*f2*f3-16*x1^2*x2^2*f0*f7^2*f1^2+16*x1^3*x2*f0*
f4*f3*f7*f1+28*x1^3*x4*f1^2*f7*f3*f5-24*x1^2*x2*x3*f0*f3^2*f7*f4+96*x1^2*x2*x3
*f0*f6*f2^2*f7+12*x1^2*x2*x3*f5*f4^2*f2^2+72*x1^2*x4^2*f7*f1*f4*f5*f3+312*x1^2
*x4^2*f7^2*f0*f4*f2-56*x1^2*x4^2*f7^2*f1*f5*f0+12*x1^3*x4*f7^2*f1^3-12*x1^3*x4
*f2^3*f7*f4+12*x1^3*x4*f5*f4^2*f2^2-64*x1^3*x4*f5^2*f0^2*f7+96*x1^3*x4*f0*f5^2
*f3*f4-160*x1^3*x4*f6*f0^2*f7*f4-24*x1^3*x4*f2^3*f5*f6-32*x1^3*x5*f5^2*f0^2+
128*x1^2*x2*x7*f6*f0^2*f7+64*x1^3*x7*f6^2*f0^2-48*x1^2*x3*x6*f1^2*f6*f5-48*x1^
2*x2*x5*f7*f2^2*f0-16*x1^3*x6*f0*f4^2*f3+288*x1^2*x4^2*f7*f1^2*f6*f5-28*x1^2*
x2*x6*f1^2*f7*f3-64*x1^2*x2*x6*f5*f0^2*f7-32*x1^3*x3*f0*f6*f7*f1*f2+48*x1^3*x3
*f0*f4*f3*f7*f2+40*x1^2*x2*x6*f3*f4^2*f1-12*x1^2*x3*x6*f4*f3^3-48*x1^2*x3*x6*
f0*f6*f4*f3+32*x1*x3*x6^2*f0*f6*f4-40*x1*x3*x6^2*f3*f1*f6-4*x1*x3*x6^2*f4^2*f2
-32*x1*x3*x6^2*f1*f4*f5-52*x1*x3*x4*x8*f7*f2*f4*f5+12*x1*x3^2*x2*f4^2*f7*f2^2-\
16*x1^2*x3*x4*f5^2*f7*f1^2-192*x1*x3*x4*x7*f2*f4*f5*f6-24*x1*x3^2*x2*f3*f6*f4^
2*f2+32*x1*x3^2*x2*f0*f5*f7*f4*f3+16*x1*x3^2*x2*f0*f6*f7*f3^2-288*x1*x3*x4^2*
f2*f5^2*f4*f6+80*x4^2*x1*x3*f0*f5*f3*f7^2+16*x1*x3*x4^2*f7*f0*f5^3+180*x1*x3*
x4^2*f3*f5^3*f4-72*x1*x3*x4^2*f5^3*f1*f6+80*x1*x3*x4^2*f3*f6*f1*f5*f7-48*x1^2*
x3*x4*f0*f5^3*f4+16*x1*x3^2*x7*f2^2*f6^2+68*x3*x1*x4^2*f7^2*f4*f3*f1+224*x3*x1
*x4^2*f7^2*f1*f5*f2+48*x1*x3*x2*x5*f7*f0*f4*f2+12*x1*x3*x6^2*f3^2*f4+72*x1*x3*
x4*x6*f2*f5*f3*f6+16*x1*x3*x5*x7*f3*f1*f6-160*x1*x3*x4*x6*f7^2*f0*f2+32*x2*x3*
x4*x6*f3*f6*f1*f7-8*x2*x3^2*x4*f7^2*f3^2*f2-72*x2*x3*x4*x7*f5^2*f7*f1+8*x3*x2*
x4*x5*f3*f7*f1*f5+96*x2*x3*x5*x6*f0*f6*f4-20*x3*x2*x4*x5*f5*f7*f2^2-112*x2*x3*
x4^2*f0*f7^3*f2+12*x2*x3*x4*x8*f7^2*f2*f3+40*x3^2*x2*x4*f5*f6*f7*f2^2+48*x2*x3
*x4*x5*f4*f6*f1*f5+8*x2*x3^2*x7*f2^2*f6*f7+52*x2*x3*x4*x6*f4^2*f2*f7+2*x2^2*x3
^2*f2*f5^2*f4^2-2*x2^2*x3^2*f2^3*f7^2+12*x2*x3*x6^2*f4^2*f3+64*x1^2*x3*x6*f0*
f6^2*f1-24*x1^2*x3*x6*f1*f6*f2*f4+24*x1*x3^2*x6*f2*f3*f6*f4+24*x3^2*x1*x6*f6*
f7*f1^2-8*x3^2*x1*x6*f3^2*f7*f2+96*x1*x3*x4*x6*f1*f6*f5*f4-48*x1*x3*x4*x6*f3*
f5*f4^2-24*x2^2*x3*x4*f4^2*f6*f2*f5-8*x3^2*x2*x4*f4*f6*f7*f2*f3-48*x2*x3^2*x4*
f4*f6^2*f1*f5-48*x3^2*x2*x4*f2*f6^2*f1*f7+128*x3^2*x2*x4*f0*f6^2*f7*f3-16*x2^2
*x3*x5*f1*f6*f0*f7+48*x2*x3*x4*x5*f4*f5^2*f2+108*x4^2*x3*x7*f5^4+14*x4^2*x7^2*
f2*f7^2+108*x4^3*x3*f5^5-108*x4^2*x6*x7*f5^3-108*x4^3*x6*f5^4+324*x4^4*f5^4*f6
+36*x4^2*x6^2*f4*f5^2+216*x4^2*x7^2*f6*f5^2+212*x4^2*x6^2*f0*f7^2+36*x3*x4*x7^
2*f5^3+4*x5^3*x1*f1^2-8*x5^3*x7*f0-2*x1^2*x5^2*f2^3-4*x6^3*x7*f3+12*x6^2*x1*x7
*f3^2+8*x6^2*x3*x7*f4^2+32*x2^2*x4^2*f0*f6*f5*f4*f7+24*x2^2*x3^2*f0*f4*f7^2*f2
-64*x2^2*x3^2*f5*f6*f1*f4^2-16*x2^3*x3*f1*f6*f4^3-4*x2^4*f5*f4*f7*f1^2+16*x2^2
*x3*x6*f4*f7*f3*f1+12*x2^2*x1*x3*f2*f4^2*f7*f1+84*x2^2*x1*x3*f5*f4*f7*f1^2-48*
x2^2*x1*x3*f0*f5^2*f7*f1-40*x2^3*x7*f0*f7*f4^2-32*x2^2*x3*x4*f4*f6*f1*f3*f7-72
*x2^2*x4*x5*f0*f5^3-16*x2*x1*x3*x7*f0*f6*f4*f5+32*x2*x1*x3*x7*f0*f7^2*f1+16*x2
*x1*x3*x7*f2^2*f6*f5-212*x2*x1*x4*x7*f7*f3*f1*f5-96*x2*x1*x4*x7*f1*f5*f4*f6+
128*x2*x1*x4*x7*f7*f0*f4*f5-8*x2*x1*x4*x7*f7*f2*f1*f6+108*x2*x1*x4*x7*f7*f2^2*
f5+96*x2*x1*x6*x7*f0*f6*f4+16*x2*x1*x6*x7*f1*f4*f5-12*x2*x1*x3*x8*f7*f1*f4^2+
64*x2*x1*x3*x4*f7^2*f1^2*f4+8*x2^2*x1*x5*f7*f1*f2^2-16*x2^2*x1*x5*f7*f0*f2*f3-\
96*x2*x1*x3*x4*f1*f5*f4^2*f6-16*x2*x1^2*x6*f0*f6*f4*f2+88*x2*x1*x3*x7*f7*f6*f1
^2+80*x2*x1*x5*x6*f0*f4^2-24*x2*x1*x6*x7*f0*f5^2+80*x2*x1*x3*x6*f1*f6*f3*f4+32
*x2^2*x1*x7*f0*f5^2*f4-4*x2^2*x1^2*f3*f4*f2^2*f5-44*x2^2*x1*x3*f3*f5^2*f1*f4+
48*x2*x1*x4*x7*f3*f4^2*f5-32*x2*x1^2*x5*f1*f3*f0*f7-136*x2*x1*x4^2*f7*f3*f5*f2
*f4+144*x2*x1*x3^2*f0*f6*f5*f4^2-4*x2^2*x1^2*f6*f7*f1^3+10*x2^2*x1^2*f3^2*f4^2
*f2-192*x2*x1^2*x4*f0*f6*f5^2*f2-512*x4^2*x1*x2*f0*f5*f7^2*f2+36*x2*x1*x4*x6*
f5^2*f2*f3-16*x2*x1*x3*x6*f0*f5*f2*f7-12*x2*x1*x3*x6*f7*f2*f1*f4-48*x2*x1*x3*
x6*f0*f4*f3*f7+96*x2*x1*x3*x6*f0^2*f7^2+144*x2*x1^2*x4*f0*f5^3*f3-12*x3*x6*x1*
x2*f7*f3*f2^2+16*x2*x1^2*x5*f3^2*f4*f1+24*x2*x1*x6^2*f2*f3*f4-8*x2*x1*x6^2*f0*
f4*f5+4*x2*x1^2*x6*f3*f5*f2^2+8*x2*x1*x3*x4*f3^3*f7*f4+16*x2*x1*x3*x4*f1*f7*f4
^3+4*x2*x1^2*x5*f2^3*f5-4*x2*x1*x4*x5*f7*f2^2*f3+4*x2^2*x1*x7*f5^2*f2^2-4*x2^2
*x1*x7*f3*f7*f2^2+16*x2*x1^2*x4*f6*f7*f1^2*f3-144*x2*x1^2*x4*f0*f6*f5*f4*f3-36
*x2*x1^2*x4*f4^2*f5*f2*f3-96*x2*x1^2*x4*f0*f4*f6*f1*f7-16*x2*x1^2*x4*f0*f6*f3*
f7*f2+36*x2*x1^2*x4*f4*f5*f3^3+112*x2*x1^2*x4*f0*f3*f1*f7^2-8*x2^2*x1*x4*f3*f5
*f7*f2^2+12*x2^2*x1*x4*f5^3*f2^2-44*x2*x1*x3*x4*f4^2*f7*f2*f3+48*x2*x1*x3*x4*
f5^2*f6*f2^2-272*x2*x1*x3*x4*f3*f4*f1*f7*f5+88*x2*x1*x3*x4*f6*f7*f1^2*f5+416*
x2*x1*x3*x4*f6*f0^2*f7^2+336*x2*x1*x3*x4*f0*f5*f4^2*f7+112*x2*x1*x3*x4*f2*f5^2
*f1*f7+8*x2*x1^2*x5*f4*f1^2*f5-96*x2*x1^2*x5*f6*f5*f0^2-8*x2*x1^2*x5*f2*f1*f4^
2+16*x2*x1^2*x5*f0*f5^2*f1-24*x2*x1^2*x5*f1*f2*f3*f5+32*x2*x1^2*x5*f0*f6*f1*f4
-36*x2*x1*x3*x5*f7*f1^2*f4+48*x2*x1*x3*x5*f4*f5*f3*f1-20*x2*x1*x6^2*f3*f1*f5+
68*x2^2*x1*x4*f5^2*f7*f1^2-4*x2^2*x1*x4*f4^2*f7*f2^2-160*x2^2*x1*x4*f0*f7^2*f4
*f1-8*x2^3*x6*f2*f4*f7*f1-8*x2^2*x4*x6*f7*f0*f4*f5+16*x2^3*x7*f4*f7*f3*f1+8*x2
^3*x7*f1*f5*f7*f2-64*x2^2*x3*x4*f0*f5*f7^2*f2-64*x2^2*x3*x4*f0*f6*f5*f3*f7+36*
x2^2*x1*x4*f4^2*f5*f3^2+8*x2^3*x8*f7^2*f1^2-8*x2^3*x8*f7*f4*f0*f5-48*x2^2*x3*
x5*f4^2*f6*f0-4*x2^2*x1*x7*f4^3*f2+36*x2^2*x3*x4*f3*f5^2*f4^2-4*x2^2*x4*x8*f7^
2*f1*f3-40*x2^2*x1*x5*f0*f4^3-80*x2^2*x4*x7*f0*f7^2*f3-24*x2^2*x6^2*f1*f4*f5+
12*x2^2*x1*x7*f4^2*f3^2+16*x2^2*x1*x3*f1^2*f7^2*f2+4*x2^2*x3^2*f1*f7*f5^2*f2-8
*x2^2*x3^2*f7^2*f4*f1^2+12*x2^2*x1*x3*f4^2*f2*f3*f5+8*x2^2*x1*x3*f3*f7*f4*f2^2
-4*x2^2*x1*x3*f2*f5*f7*f3*f1+12*x2^2*x1*x3*f2*f5^3*f1-4*x2^2*x1*x3*f2^2*f5^2*
f4-4*x2^3*x3*f1^2*f3*f7^2+4*x2^3*x3*f3*f4^4+4*x2^3*x3*f4^3*f2*f5-4*x2^3*x4*f4*
f5*f7*f2^2-4*x2^3*x4*f7^2*f2^3-2*x2^2*x4^2*f7^2*f3^2*f2-16*x2^2*x1*x4*f1*f2^2*
f7^2+16*x2^2*x1*x4*f3^2*f5*f1*f7+4*x2^2*x1*x4*f3^2*f7*f2*f4+40*x2^2*x1*x6*f3*
f4*f1*f5+8*x2^2*x1*x6*f4*f5*f2^2-12*x2^2*x1*x6*f1*f5^2*f2+4*x2^3*x6*f1^2*f5*f7
-192*x3^2*x1*x4*f6^2*f7*f1^2+32*x3^4*f0*f6*f5*f7*f4+68*x3^2*x4*x8*f7*f5*f4^2+
32*x3^3*x2*f0*f6*f7^2*f1-24*x3^3*x2*f4^2*f6*f2*f5-12*x3^3*x7*f5*f7*f3^2-28*x3^
2*x4*x7*f7*f5^2*f2+48*x3^3*x1*f1*f6^2*f5*f2-8*x3^3*x1*f3*f6*f7*f2^2-8*x3^3*x1*
f6*f1*f5*f4^2+48*x3^2*x4*x5*f1*f6*f5^2+48*x3^3*x6*f5^2*f1*f6-28*x3^2*x4*x8*f7^
2*f1*f5-32*x3^2*x5*x8*f7*f0*f6-16*x3^2*x1*x7*f6^2*f1*f3+48*x3^2*x4*x5*f2*f6*f4
*f5+16*x3^2*x2*x5*f0*f4^2*f7+40*x3^2*x1*x6*f7^2*f0*f1-96*x3^2*x5*x7*f0*f6^2+16
*x3^3*x1*f2^2*f6^2*f4+320*x3^2*x4*x7*f0*f6^2*f7-16*x3^2*x4*x7*f3^2*f6*f7+16*x3
^2*x2*x5*f1*f6*f4^2+32*x3^2*x2*x5*f1*f5^2*f4+568*x3^2*x4^2*f7^2*f0*f5^2+16*x3^
3*x6*f2*f6*f4*f5-72*x3^2*x1*x4*f3*f5^2*f6*f2+12*x3^2*x1*x5*f3*f4*f2*f5+16*x1*
x3^3*f0*f5^2*f7*f3+32*x3^2*x1*x7*f0*f6^2*f4+12*x3^2*x4*x8*f7^2*f3^2-12*x3^2*x1
*x7*f4*f5^2*f2-16*x3^3*x7*f2*f6^2*f4+16*x3^3*x4*f3*f2*f7^2*f4+48*x3^3*x4*f4^3*
f5*f6+40*x3^2*x1*x6*f7*f4^2*f0+12*x3^3*x1*f4^3*f3*f5-16*x3^3*x2*f1*f6^2*f4^2-\
24*x3^3*x5*f7*f0*f4*f5+40*x3*x2*x4^2*f7^3*f1^2+120*x2*x3*x4*x7*f4^2*f5^2-12*x2
^2*x3*x4*f5^4*f1-288*x2*x3*x4*x5*f0*f6*f5^2-8*x2^2*x3^2*f4^3*f2*f6+16*x2^2*x3^
2*f0*f6^2*f7*f1+12*x2^2*x3^2*f4^3*f3*f5+8*x3*x2*x4^2*f3*f7^2*f2*f4+456*x3*x2*
x4^2*f0*f5*f7^2*f4+320*x3*x2*x4^2*f0*f6*f7^2*f3-384*x2*x3*x4^2*f4*f5^2*f7*f2-\
36*x1*x3*x6*x7*f7*f3*f1+8*x1*x3*x6*x7*f7*f2^2+4*x1*x3*x5*x8*f7*f3*f1-4*x1*x3*
x5*x8*f7*f2^2+12*x1*x3*x6*x8*f7*f1*f4+4*x1*x3*x6*x8*f7*f2*f3+4*x1*x3*x2*x8*f7*
f5*f2^2-4*x1*x3*x2*x8*f7*f2*f3*f4-4*x1*x3^2*x8*f7*f2*f3*f5+104*x1*x3*x5*x6*f0*
f5*f4+128*x1^2*x3*x5*f5*f0^2*f7+8*x1^2*x3*x5*f3^2*f2*f4+32*x1*x3^2*x8*f7*f0*f6
*f4-24*x1*x3*x2*x7*f2*f6*f3*f4+76*x1*x3*x4*x6*f7*f3*f1*f5+48*x1*x3*x4*x6*f2*f4
*f3*f7+128*x3^2*x1*x4*f0*f6^2*f7*f2-32*x1*x3*x4*x8*f7^2*f1*f3-96*x1*x3^2*x2*f0
*f6*f7*f4*f2+8*x1^2*x3*x5*f2^3*f6+16*x1^2*x3*x5*f2*f0*f5^2-56*x2*x3*x5*x6*f1*
f4*f5+48*x2*x3*x5*x6*f0*f5^2-44*x2*x3*x4^2*f4^2*f7*f3*f5+8*x2*x3*x4^2*f4*f6*f1
*f5*f7-8*x2^2*x3*x7*f4^2*f6*f2+16*x2*x3^2*x6*f4^2*f6*f2+16*x2*x3*x5*x7*f1*f4*
f6+16*x2*x3*x4*x7*f3*f7^2*f1+32*x2*x3*x4*x7*f7*f3^2*f5-64*x2*x3*x4*x7*f0*f7^2*
f4+8*x2^2*x3*x6*f6*f7*f1^2+228*x2*x3*x4*x6*f4*f5*f1*f7+48*x3*x2*x4*x5*f7*f2*f1
*f6-16*x2^2*x3*x6*f1*f0*f7^2-12*x2*x3^2*x4*f5^4*f2+32*x2*x3*x4^2*f3^2*f5^2*f7-\
16*x2^2*x3*x8*f7*f0*f6*f4+24*x2*x3*x4*x5*f5^3*f1-100*x2*x3*x4^2*f5^3*f1*f7+20*
x2*x3*x7^2*f5*f4^2+48*x2*x3*x4*x6*f4*f5*f2*f6-464*x2*x3*x4*x6*f0*f6*f7*f4+24*
x2*x3*x4*x6*f5^3*f2-64*x3*x2^2*x7*f0*f6*f7*f3+48*x2*x3*x5*x7*f7*f0*f4-24*x2*x3
*x6*x7*f3*f5*f4+72*x2*x3*x6*x7*f7*f0*f5+16*x2*x3*x6*x7*f2*f4*f6-4*x1*x3^2*x2*
f2^2*f5^3+4*x1*x3^2*x2*f1^2*f3*f7^2-2*x1^2*x3^2*f4^4*f2+4*x1^2*x3*x4*f3^4*f7-4
*x1^2*x3*x6*f4^3*f1-216*x1*x4^3*f5^3*f6*f2-12*x4^3*x1*f4^2*f1*f7^2+4*x6^2*x7^2
*f4+72*x1^2*x4*x5*f1^2*f7*f4-112*x1^2*x4*x5*f0*f4*f2*f7-224*x1^2*x4*x5*f6*f0^2
*f7+64*x1^2*x4*x5*f1*f5*f0*f7-8*x1^3*x6*f1*f6*f2^2+16*x1^3*x6*f0*f5^2*f1+16*x1
^3*x6*f0*f6*f3*f2-80*x1^2*x3*x6*f1*f5*f0*f7-4*x1^2*x3*x6*f1*f7*f2*f3-8*x2^3*x1
*f1*f5*f7*f2^2+32*x2^3*x1*f6*f0^2*f7*f4+16*x2^3*x1*f0*f1*f7^2*f2+24*x2^3*x1*f4
^2*f7*f1^2-8*x2^3*x1*f7*f3^2*f0*f4+16*x2^2*x3^2*f6*f0^2*f7^2-8*x2^2*x3^2*f7*f4
^3*f1+12*x2^2*x3^2*f0*f3^2*f7^2+32*x2^2*x3^2*f0*f7^2*f5*f1-12*x2^2*x3^2*f4*f5*
f7*f3*f1+192*x2^2*x1*x3*f6*f0^2*f7*f5-48*x2^2*x1*x3*f0*f6*f4*f7*f1+48*x2^2*x1*
x3*f1*f6*f5*f4*f2-16*x2^2*x1*x3*f7^2*f3*f0*f1+64*x2^2*x1*x3*f0*f5^2*f4^2-40*x2
^2*x1*x3*f4^2*f6*f3*f1-4*x3^3*x2*f2*f1*f7^2*f4-4*x3^2*x1*x4*f7^2*f2^2*f3-8*x3^
2*x1*x6*f4^3*f3-20*x3^2*x1*x6*f7*f2*f1*f5+12*x3^2*x1*x6*f7*f2^2*f4-4*x3^2*x6^2
*f7*f1*f4+12*x3^2*x6^2*f3*f5*f4-24*x3^2*x1*x6*f4*f5*f3^2+12*x3^2*x1*x6*f4^2*f2
*f5-8*x2*x6*f7*f2^2*x3^2*f5-16*x3^2*x2*x6*f2*f5^2*f4-24*x3^2*x2*x6*f5*f4^2*f3-\
4*x3^3*x4*f3^3*f7^2+4*x3^3*x5*f7*f4^2*f1+4*x3^3*x5*f4*f5^2*f2+4*x3^3*x5*f5*f1*
f7*f3-4*x3^3*x5*f7*f4*f2*f3+12*x3^2*x4*x5*f2*f7^2*f1+28*x3^2*x2*x7*f4^3*f5+4*
x3^3*x7*f3*f5^3+4*x3^3*x7*f2*f5*f7*f4-4*x3^3*x7*f1*f7^2*f3+28*x3^2*x4*x7*f7^2*
f1*f4+20*x3^2*x4*x7*f7^2*f2*f3-4*x3^2*x2*x5*f3*f7*f1*f4+12*x3^2*x2*x5*f5*f2*f4
^2-4*x3^2*x2*x5*f2^2*f7*f4-4*x3^3*x6*f2*f7*f4^2-4*x3^3*x6*f1*f7^2*f2-8*x3^2*x5
*x6*f2*f4*f5+20*x3^2*x1*x7*f7*f3*f4*f2+8*x3^2*x5*x7*f7*f1*f4-20*x3^2*x1*x7*f7*
f1*f4^2-8*x3^3*x1*f4^2*f5^2*f2-28*x3^2*x4*x6*f1*f7^2*f3+16*x3^2*x4*x6*f1*f6*f7
*f4-24*x3^2*x2*x5*f0*f7^2*f1+12*x3^3*x6*f7*f3^2*f4+12*x3^2*x2*x7*f5^2*f3*f4+20
*x3^2*x1*x5*f1*f5^2*f3-32*x1*x4*f7*f5^2*f2^2*x3^2-72*x3^2*x4^2*f7*f1*f6*f5^2+
64*x1*x3^3*f2*f7*f6*f0*f5+80*x3^3*x1*f0*f6*f5^2*f4-16*x3^2*x4*x8*f4*f7^2*f2+48
*x3^2*x5^2*f0*f6*f4+16*x3^2*x1*x4*f4*f6*f7*f3*f1+40*x3^3*x2*f0*f5^2*f4*f7+16*
x3^3*x1*f2*f1*f6*f7*f4-24*x3^2*x1*x6*f2*f5^2*f3-24*x3^2*x4^2*f7^2*f3^2*f4+44*
x3^2*x4^2*f7^2*f2*f4^2+60*x3^2*x4^2*f7^2*f1*f4*f5-8*x3^2*x4^2*f7^3*f0*f3-80*x3
^2*x4^2*f7^2*f1*f6*f3-288*x3^2*x4*x5*f0*f6^2*f5-12*x2^3*x4*f4^2*f5^2*f2-8*x2^3
*x4*f0*f3^2*f7^2+32*x2^3*x4*f6*f0^2*f7^2-64*x2^3*x4*f0*f5^2*f7*f3-28*x2^2*x3*
x4*f7^2*f5*f1^2+144*x2^2*x3*x4*f0*f6*f5^3-156*x2^2*x3*x4*f1*f5*f4^2*f7+224*x2^
2*x3*x4*f0*f6*f7*f4^2+48*x2^2*x3*x4*f0*f6*f7^2*f1-48*x2^2*x3*x4*f5^2*f1*f4*f6-\
80*x2^2*x3*x4*f0*f7^2*f4*f3-96*x2^2*x1*x5*f5*f0^2*f7-72*x2^2*x3*x5*f0*f5^2*f4+
32*x2^2*x3*x5*f4^2*f1*f5+32*x2^2*x4*x5*f0*f5*f3*f7-32*x2^2*x4*x5*f0*f7^2*f1+40
*x2^2*x1*x6*f1*f5*f0*f7+4*x1^2*x2^2*f4^2*f5*f2*f1+8*x1^2*x2^2*f4*f1*f7*f2^2+4*
x1^3*x2*f1^2*f5*f4^2+4*x1^3*x2*f1^2*f5^2*f3-4*x1^3*x2*f2*f4^3*f1+4*x1^3*x2*f2*
f4*f3^3-4*x1^3*x2*f1*f5*f3^3+4*x1^3*x2*f3*f4^2*f2^2+44*x4^2*x3*x6*f4*f7*f3*f5-\
32*x4^3*x6*f3^2*f7^2+8*x4^2*x5*x6*f7*f1*f5-52*x4^2*x1*x7*f3^2*f5*f7-216*x4^2*
x1*x7*f5^2*f6*f2+8*x4^3*x7*f7^2*f3*f4-192*x4^3*x7*f7*f4*f5^2-240*x4^2*x5*x7*f0
*f7^2+52*x4^2*x6*x7*f7*f3*f5+24*x4^2*x3*x8*f7*f3*f5*f6+24*x1^2*x4*x7*f5^2*f1*
f4+28*x1*x4^2*x3*f4^2*f7*f2*f5+8*x4^2*x1*x3*f3^3*f6*f7+36*x1^2*x4^2*f4*f5^3*f1
+36*x1*x4*x6^2*f3^2*f5-4*x1^2*x4^2*f4^2*f3*f7*f2-72*x4*x2*x7^2*f7*f2*f5+36*x2*
x4*x7^2*f4*f5^2+48*x2*x4*x3*x6*f5^2*f1*f6-32*x4^2*x2*x5*f0*f6*f7*f4-8*x4^2*x2*
x5*f7*f3^2*f4-8*x4*x2^2*x8*f7*f1*f5^2-16*x2^2*x4*x8*f7^2*f0*f4+32*x4*x2*x3*x6*
f3*f7*f2*f5+24*x1*x4*x5^2*f0*f5*f4+8*x1*x4*x3*x8*f7*f1*f4*f6-36*x1*x4*x5*x6*f2
*f3*f5-36*x1^2*x4*x6*f3^3*f5-24*x1^2*x4*x7*f3^2*f7*f2+24*x1*x4*x2*x7*f5^3*f1-\
16*x1*x4*x3*x7*f0*f7^2*f3+24*x1*x4*x5*x7*f2*f4*f5-16*x1*x4*x5*x7*f7*f0*f4+24*
x1*x4*x6*x7*f5^2*f2+44*x1*x4*x6*x7*f7*f2*f3+24*x1*x4^2*x8*f7^2*f1*f4-8*x1*x4^2
*x8*f7^2*f2*f3-72*x1*x4^2*x8*f7*f5^2*f2+32*x1*x4*x6*x8*f1*f5*f7+36*x1*x4*x3*x5
*f5^2*f2*f3+96*x1*x4*x6*x7*f6*f1*f5-24*x1*x4*x3*x7*f5^3*f2-16*x1*x4^2*x2*f4*f6
*f1*f3*f7+8*x1*x4^2*x2*f4^2*f7*f3^2-48*x1*x4*x2*x7*f4*f5^2*f2-36*x1^2*x4^2*f3*
f5^3*f2-18*x1^2*x4^2*f4^2*f5^2*f2+48*x1*x4*x3*x8*f7^2*f0*f4-32*x2*x4*x7^2*f0*
f7^2+4*x4*x2*x5*x8*f7*f1*f5+216*x2*x4*x5*x6*f7*f0*f4-16*x3^2*x4*x8*f7*f6*f2*f5
+32*x4^2*x3*x6*f4*f6*f2*f7+16*x3^2*x4^2*f4*f6^2*f1*f7+240*x4*x3*x6^2*f7*f0*f6-\
8*x3^2*x4^2*f2^2*f6*f7^2+136*x3*x4*x7*x8*f7*f4*f5+12*x3^2*x4*x5*f5^3*f2+8*x3*
x4^2*x5*f2^2*f7^2-76*x3*x4*x7^2*f7*f3*f5+36*x1^2*x4^2*f5^2*f3^2*f4+192*x1^2*x4
*x7*f0*f6*f5*f4+4*x3^2*x7*x8*f1*f7^2+4*x3*x7*x5*x8*f7*f2-20*x3*x7*x4*x8*f7^2*
f2-2*x2^2*x7^2*f5^2*f2+4*x2^2*x7^2*f7*f2*f3+8*x3*x7^2*x5*f2*f6+4*x3*x7^2*x5*f7
*f1-8*x4^2*x7^2*f3*f6*f7-4*x3^2*x7^2*f7*f1*f6-8*x3^2*x7*x8*f7*f2*f6-12*x2*x7*
x4*x8*f1*f7^2+4*x1*x7^2*x6*f2*f5-8*x2*x7^2*x3*f6*f2*f5+8*x3*x7^2*f7*f3^2*x2+32
*x2*x7*x3*x8*f0*f7^2-8*x3^2*x7^2*f6^2*f2-12*f7*x2*x8^2*x4*f4*f5+4*f7*x8^2*x6*
x7-4*f7^2*x2*x8^2*x4*f2-4*f7*x2*x8^2*x7*f4-4*f7*x2*x8^2*x3*f4^2-4*f7^2*x2*x8^2
*x3*f1-2*f7^2*x3^2*x8^2*f2+4*f7*x3*x8^2*x6*f4-4*f7*x3*x8^2*x7*f5-12*f7^2*x3*x8
^2*x4*f3-4*f7*x3^2*x8^2*f4*f5-8*f7^2*x4^2*x8^2*f4-8*x1*x7^2*x8*f7*f2-32*x3^2*
x2*x6*f0*f6*f7*f3-16*x3^2*x2*x6*f0*f7^2*f2+112*x3^2*x2*x6*f4*f6*f1*f5-96*x3^2*
x2*x6*f0*f6^2*f4-96*x3^2*x2*x6*f0*f6*f5^2-12*x3^3*x6*f5^2*f3*f4-48*x3^3*x6*f0*
f6*f7*f4-8*x3^3*x6*f5^3*f2+16*x3^3*x6*f1*f6^2*f4+28*x3^2*x1*x7*f7^2*f1^2+28*x3
^2*x1*x7*f4^2*f3*f5-16*x3^2*x1*x7*f1*f6*f5*f4+96*x3^2*x2*x7*f0*f6^2*f5-4*x3^2*
x2*x7*f3*f7*f2*f5-48*x3^2*x2*x7*f0*f6*f7*f4+16*x3^2*x2*x7*f1*f6*f7*f3+8*x3^3*
x7*f2*f6*f7*f3+96*x3^2*x4*x7*f5^3*f4-152*x3^2*x4*x7*f7*f3*f5*f4-24*x3^2*x4*x7*
f7*f4^3-16*x5*x7*f7*f0*x3^2*f5+16*x3^2*x5*x7*f6*f1*f5-32*x3^2*x6*x7*f7*f0*f6+
16*x3^2*x6*x7*f6*f2*f5+8*x3^3*x8*f7*f4^3-8*x3^3*x8*f7*f2*f4*f6-40*x3^3*x8*f7^2
*f0*f5-48*x1*x3*x6^2*f0*f5^2+48*x1^2*x3*x6*f0*f5^2*f3-168*x1*x3*x4*x6*f1*f6*f7
*f2+24*x1*x3^2*x2*f3^2*f5*f4^2-64*x1*x3*x2*x6*f0*f6*f4^2+120*x1*x3*x4*x7*f3*f5
^2*f4-496*x3*x1*x4^2*f7^2*f6*f1^2-60*x1^2*x3*x4*f5^2*f2*f3*f4-128*x3*x2*x4^2*
f7^2*f2*f1*f6-24*x2*x3*x4*x6*f1*f7^2*f2-72*x2*x3*x4*x6*f0*f5^2*f7+640*x2*x3*x4
^2*f0*f6*f5^2*f7+36*x1^2*x3*x4*f4^2*f5^2*f1-124*x3*x1*x4*x5*f1*f5*f7*f2-192*x1
^2*x3*x5*f6^2*f0^2-24*x1^2*x3^2*f0*f5^3*f3-24*x1*x3*x5^2*f1^2*f6+24*x1*x3*x6^2
*f2*f3*f5+48*x1^2*x3*x5*f0*f6*f3^2+12*x1^2*x3*x5*f7*f2^2*f1+144*x1^2*x3*x4*f0*
f6*f5^2*f3+48*x1*x3*x5*x6*f2*f1*f6-24*x1*x3^2*x4*f5^4*f1+208*x3*x1*x4*x5*f6*f7
*f1^2-8*x3*x1*x4*x5*f7*f4*f2^2-8*x3*x1*x4*x5*f4*f7*f3*f1+24*x1*x3^2*x2*f5^2*f7
*f1^2+12*x1^2*x3*x4*f5^3*f2^2-48*x1^2*x3*x4*f6*f7*f4*f1^2+32*x1*x3*x4*x7*f7^2*
f2*f1-20*x1^2*x3*x7*f4*f5*f2*f3-16*x1^2*x3*x7*f3^2*f6*f2-32*x2^2*x3*x5*f0^2*f7
^2+16*x2^3*x4*f0*f7^2*f5*f1+8*x2^3*x4*f7^2*f4*f1^2-12*x2^2*x3^2*f1*f7^2*f3*f2-\
32*x2^3*x4*f0*f4*f7^2*f2+48*x2^2*x1*x5*f1*f4*f0*f7-16*x2^2*x1*x4*f0*f5*f4*f3*
f7-32*x2^3*x3*f0*f5*f7*f4*f3+144*x2^2*x1*x4*f0*f4^3*f7-12*x2^2*x1*x4*f4^3*f2*
f5-36*x2^2*x1*x4*f5^2*f2*f3*f4-32*x2^2*x3^2*f0*f6*f4*f3*f7-8*x2^2*x4*x5*f7*f4*
f2^2-72*x4^4*f5^2*f7*f3*f6-92*x4^3*x2*f1*f7^3*f2+24*x4^3*x6*f7*f5*f2*f6+76*x4^
2*x2*x6*f3*f7^2*f1+128*x4^2*x2*x6*f4*f5*f7*f2+248*x4^2*x5^2*f7*f0*f5-180*x4^4*
f5^3*f4*f7+432*x4^3*x7*f5^3*f6+16*x4^2*x1*x7*f0*f6*f5*f7-48*x4^3*x7*f7*f3*f5*
f6+108*x4^2*x2*x7*f4*f5^3+12*x4^3*x1*f3*f4^2*f5*f7-12*x4^2*x3*x6*f7^2*f4*f1+
152*x4^2*x3*x6*f5^2*f7*f2-792*x4^2*x3*x6*f0*f5*f7^2+40*x4^2*x3*x5*f5^2*f7*f1+
144*x4^2*x1*x6*f1*f5^2*f6-264*x4^3*x3*f5^3*f7*f3+24*x4^3*x5*f3*f7^2*f2+108*x4^
2*x1*x7*f5^3*f3-32*x4^3*x1*f2*f7^2*f4*f3+736*x4^4*f0*f5*f7^3-72*x4^4*f7^3*f4*
f1+68*x4^4*f5^2*f7^2*f2-140*x4^3*x6*f7^2*f5*f1+432*x4^2*x3*x7*f4*f6*f5^2-40*x4
^2*x6*x7*f1*f7^2-60*x4^3*x1*f1*f5^3*f7-84*x4^3*x2*f4*f5^2*f7*f3-48*x4^3*x3*f4*
f6*f7*f3*f5-180*x4^2*x3*x6*f5^3*f4-1024*x4^2*x3*x5*f0*f6*f5*f7-420*x4^3*x1*f7^
3*f1^2+4*x4^2*x6*x8*f7^2*f2+180*x4^3*x8*f7*f5^3-8*x4^3*x8*f7^2*f2*f6-160*x4^2*
x2*x5*f0*f5^2*f7+48*x2^3*x3*f0*f6*f5*f4^2-16*x2^3*x3*f0*f4^3*f7-8*x2^3*x3*f5^2
*f7*f1^2+16*x2^3*x3*f2*f4*f7*f1*f5+16*x2^3*x3*f0*f6*f5*f7*f1+32*x2^3*x3*f5*f0^
2*f7^2+16*x2^3*x3*f0*f3*f2*f7^2+16*x2^3*x3*f0*f7^2*f4*f1-240*x2^2*x1*x4*f0*f5^
2*f2*f7+24*x2^2*x1*x4*f6*f7*f4*f1^2+416*x2^2*x1*x4*f5*f0^2*f7^2-24*x2^2*x1*x4*
f4^2*f5^2*f1-92*x2^2*x1*x4*f4^2*f7*f3*f1+12*x2^3*x4*f1*f7*f5^2*f2-4*x1^2*x5*x8
*f7*f1^2+4*x1^2*x2*x8*f5*f1^2*f7+4*x1^4*f1^2*f5*f4*f3-224*x1^2*x3^2*f6*f0^2*f7
*f5+64*x1^2*x3^2*f2*f4*f0*f7*f5+4*x1^4*f2*f5*f1*f3^2-8*x1^3*x6*f1^2*f4*f5-48*
x1^2*x2^2*f0*f4*f3*f7*f2-24*x1^3*x4*f3^2*f5*f4*f2+4*x1^4*f3^2*f6*f1^2+20*x1^2*
x3^2*f3^2*f4*f7*f1-16*x1^4*f6*f4^2*f0^2+48*x1^2*x4^2*f7*f5*f2^2*f4-32*x1^2*x4^
2*f7*f2*f5^2*f1-64*x1^2*x4*x6*f7*f5*f1^2+72*x1^2*x4*x6*f7*f1*f3^2-4*x1^4*f1*f3
^3*f4-12*x1^3*x4*f1^2*f7*f4^2+12*x2^2*x4*x5*f5*f2*f4^2+16*x2^2*x4*x8*f7*f2*f4*
f5-16*x4*x2*x3*x6*f7*f3^2*f4+16*x4^2*x2*x7*f7*f6*f1*f5+24*x2*x4*x5*x7*f5^2*f2+
36*x2*x4*x6*x7*f7*f2*f4+4*x2*x4*x3*x8*f7*f5^2*f2-8*x4*x2*x3*x8*f7*f6*f1*f5+8*
x3*x8*f7*f3*f4*x2*x4*f5+24*x2*x4*x6*x8*f7^2*f0-24*x3*x4*x7^2*f7*f4^2+16*x4*x3^
2*x6*f3*f6*f2*f7-16*x4^2*x6*f7*f3^2*x3*f6-4*x1*x4^2*x2*f4^3*f7*f2-72*x3^2*x4^2
*f5^2*f6^2*f2-88*x3^2*x4^2*f5^3*f7*f2-24*x3*x4*x5*x6*f5^2*f2-96*x3*x4*x6*x7*f0
*f7^2+8*x4*x3*x7*x8*f7*f3*f6-48*x3^2*x4*x7*f5*f6^2*f2+16*x3*x4^2*x5*f3*f6*f2*
f7-16*x7^2*f2*f7*x3*x4*f6+144*x3*x4*x7^2*f4*f5*f6-8*x1^2*x5^2*f1^2*f4+12*x1*x5
^2*x4*f2^2*f5+64*x1*x5^2*x2*f0^2*f7+96*x2*x7*x1*x5*f7*f0*f2+4*x1*x5^2*x7*f2^2+
64*x1^2*x5*x7*f2*f6*f0-8*x1^2*x5^2*f1*f0*f5-48*x3*x5*x6^2*f0*f6-12*x3*x5^2*x4*
f1*f5^2-12*x3*x5^2*x4*f2*f4*f5-56*x1*x5*x2*x6*f7*f1*f0-24*x1*x5*x3*x7*f0*f5^2+
8*x1^2*x5*x6*f5*f1^2-4*x2^2*x5*x6*f7*f1^2-4*x2*x5^2*x3*f1*f4^2-4*x2*x5^2*x3*f7
*f1^2+4*x2^2*x5*x7*f2*f4^2-4*x2*x5*x3*x7*f7*f2^2-8*x2*x5*x3*x7*f7*f3*f1-4*x2*
x5*x4*x7*f7*f2*f3+8*x1^2*x5^2*f0*f4*f2+48*x1^2*x5*x6*f0*f4*f3+48*x1^2*x5^2*f6*
f0^2-16*x2*x5*x4*x6*f7*f3*f1-24*x2*x5*x6^2*f0*f5-12*x5^2*x2*x4*f7*f2*f1+8*x3*
x5^2*x8*f7*f0-16*x1^2*x5*x6*f0*f5*f2+8*x1^2*x5*x6*f4*f2*f1-20*x3*x6*x1*x5*f7*
f1^2-2*x3^2*x5^2*f4^2*f2+4*x3^2*x5*x7*f5^2*f2-4*x3^2*x5*x7*f7*f2*f3+8*x3*x5*x4
*x7*f7*f3^2-4*x5*x3^2*x6*f7*f3*f1+4*x3*x5^2*x6*f1*f4-4*x3*x5^2*x7*f2*f4-4*x3*
x5^2*x7*f1*f5-8*x3*x5*x6*x7*f2*f5-4*x3^2*x5^2*f1*f4*f5-8*x3^2*x5^2*f7*f0*f3+4*
x2^2*x5^2*f7*f0*f1-20*x1^2*x3*x7*f5^2*f3*f1-72*x1*x3*x4*x7*f7*f1*f4*f5+32*x1*
x3*x4*x7*f3*f7*f1*f6-16*x1*x3*x5*x7*f7*f2*f1-16*x1*x3*x5*x7*f2^2*f6+48*x1*x3*
x6*x7*f0*f5*f6+80*x1*x3*x6*x7*f7*f0*f4+32*x1*x3*x6*x7*f1*f4*f6-8*x1*x3^2*x8*f7
*f3*f1*f6+80*x1^2*x3^2*f0*f6*f3*f7*f2-44*x1*x3*x4^2*f7*f5*f3^2*f4+24*x1^2*x3*
x4*f4^2*f5*f3^2-32*x1*x3*x4*x8*f7*f1*f5^2-16*x1*x3^2*x4*f0*f5*f7^2*f2+16*x1^2*
x3^2*f0*f6*f4*f7*f1-4*x1*x3*x4*x7*f7*f2*f3*f5-64*x3*x1*x4^2*f7^3*f0*f1+12*x1^2
*x3^2*f4*f5*f3^3-64*x1*x3*x4^2*f7*f4*f1*f5^2+104*x1*x3*x4^2*f7*f5*f6*f2^2-12*
x1^2*x3*x4*f4^3*f2*f5+128*x1^2*x3*x4*f0*f5^2*f2*f7-16*x1*x3*x4*x7*f7*f3^2*f4-\
48*x1*x3*x4*x7*f6*f1*f5^2+8*x1^2*x3*x6*f3*f6*f2^2+8*x1^2*x3^2*f4^3*f1*f5+32*x1
^2*x3*x5*f0*f6*f4*f2-16*x2*x3*x7^2*f7*f0*f6-8*x2*x3*x5*x8*f7*f0*f5+48*x2*x3*x6
^2*f0*f5*f6+4*x3*x2*x4*x5*f3*f7*f2*f4-76*x3*x2*x4^2*f3*f7^2*f1*f5-224*x3*x2*x4
*x5*f0*f5*f7*f4-128*x3*x2*x4*x5*f0*f6*f7*f3-24*x2*x3*x6^2*f1*f5^2-8*x2*x3^2*x7
*f1*f7^2*f2-48*x2*x3*x4*x8*f7^2*f1*f4+144*x2*x3*x4*x8*f7^2*f0*f5+16*x3*x2^2*x7
*f7*f2*f1*f6-8*x1*x3^2*x7*f5^3*f1+32*x3*x1*x2*x7*f7*f4*f2^2+8*x1^2*x3*x7*f4^2*
f3^2-12*x1*x3*x4*x6*f7*f3^3-36*x3*x1*x4^2*f7^2*f4*f2^2-32*x3*x1*x4^2*f7^2*f0*
f4^2+24*x4^2*x1*x3*f3^2*f7^2*f2-80*x1*x3*x4*x6*f7*f6*f0*f3+144*x1*x3*x4*x6*f0*
f6*f5^2+12*x1*x3*x4*x8*f7^2*f2^2+8*x1*x3*x2*x6*f2^2*f5^2+4*x1^2*x3*x5*f5*f3*f2
^2+12*x1*x3*x5^2*f2*f1*f5+4*x1*x3^2*x5*f3*f7*f2^2+4*x1*x3^2*x5*f2^2*f5^2+4*x1*
x3^2*x5*f4^3*f2-4*x1*x3^2*x5*f4^2*f1*f5-28*x2*x3*x7^2*f7*f2*f4-12*x2*x3*x7^2*
f7*f1*f5+8*x2*x3*x5*x7*f1*f5^2+16*x2*x3*x5*x7*f2*f4*f5+8*x2*x3*x6*x7*f5^2*f2+
12*x2*x3*x6*x7*f7*f1*f4+4*x2*x3^2*x8*f7^2*f2^2+4*x2*x3*x5*x8*f7*f1*f4-4*x2*x3*
x6*x8*f7*f2*f4-8*x2*x3*x6*x8*f1*f5*f7+4*x2^2*x3*x8*f7*f4^2*f2+4*x2*x3^2*x8*f7*
f1*f5^2+36*x1^2*x3*x4*f3^3*f5^2-4*x1*x3*x2*x4*f7^2*f2^3+8*x1*x3*x2*x4*f0*f3^2*
f7^2+48*x1*x3^2*x4*f6^2*f2^2*f5+16*x2^2*x3*x5*f0*f4*f3*f7-24*x2^2*x5*x7*f0*f5^
2-72*x2^2*x4^2*f7^2*f4*f3*f1-12*x2^2*x4^2*f7^2*f1*f5*f2+24*x2^2*x1*x6*f4^3*f1+
8*x2^2*x6*x8*f7*f0*f5+8*x2^3*x5*f4^3*f1+32*x2^2*x3*x4*f0*f5^2*f7*f4+4*x2^4*f0*
f5^2*f7*f1+24*x2^3*x6*f4^2*f1*f5+8*x2^3*x4*f1*f7^2*f3*f2+32*x2^3*x3*f0*f5^3*f4
-24*x2^2*x1*x6*f4^2*f2*f3+128*x2^2*x3*x4*f0^2*f7^3-40*x2^2*x4^2*f7^2*f0*f6*f2+
24*x2^2*x4*x6*f2*f5^2*f4+144*x2^2*x3^2*f0*f6*f5^2*f4-24*x2^2*x3^2*f6*f7*f5*f1^
2+24*x2^2*x3*x4*f4^4*f5+16*x2^3*x6*f0*f4*f3*f7-8*x2^3*x6*f4^3*f2-32*x2^3*x6*f0
^2*f7^2-24*x2^2*x3*x6*f0*f5^3-96*x2^2*x3*x6*f0*f5*f6*f4-16*x2^2*x4*x6*f7^2*f1^
2-36*x2^2*x4*x6*f3*f5*f4^2-32*x2^2*x1*x7*f0*f4*f3*f7+64*x2^2*x1*x7*f0^2*f7^2+
28*x2*x1*x6^2*f7*f1^2-8*x2*x1*x4^2*f7*f2*f5*f1*f6+32*x4^2*x1*x2*f0^2*f7^3+32*
x4^2*x1*x2*f0*f6*f7^2*f1+12*x2*x1^2*x3*f3^2*f5*f2*f4+48*x2*x1^2*x3*f0*f5^2*f3*
f4+48*x2*x1^2*x3*f2*f5*f1*f6*f3-8*x2*x1^2*x6*f5^2*f1^2+16*x2^2*x1^2*f0*f6*f7*
f2*f1+32*x2^2*x1^2*f0*f3*f7*f1*f5+16*x2*x1*x3*x8*f7*f0*f5*f4-80*x3^2*x1*x2*f7*
f1*f0*f6*f5-16*x2*x1*x3^2*f0*f7*f4^3+180*x2*x1*x4^2*f5^2*f7*f2^2-96*x2*x1*x3^2
*f3*f5*f1*f4*f6+48*x2*x1*x3^2*f2*f6^2*f1*f4+64*x2*x1*x3^2*f7*f1^2*f4*f6-4*x2^2
*x1^2*f1*f7*f3^2*f2-16*x3*x4*x1*x2*f3^2*f6*f1*f7-20*x2*x1^2*x6*f3^2*f2*f4-64*
x2*x1^2*x3*f0*f6^2*f4*f1-12*x2*x1^2*x3*f4^2*f7*f1^2+48*x2^2*x1^2*f6*f5^2*f0^2-\
8*x2^2*x1^2*f0*f5^3*f1+8*x2^2*x1*x6*f0*f3^2*f7-64*x2*x1^2*x7*f0*f6*f5*f2+8*x2*
x1^2*x7*f2*f4*f1*f6+8*x2^2*x1*x7*f3^2*f7*f1+16*x3^3*x7*f7*f0*f6*f5+32*x3^3*x7*
f0*f4*f7^2-84*x3^2*x4*x6*f5^2*f4^2-8*x3^3*x7*f1*f6*f7*f4+72*x6^2*f7*f0*x3^2*f5
+64*x3^3*x1*f7^2*f6*f0^2-4*x3^4*f3*f7^2*f1*f4+4*x3^4*f7*f2*f4^2*f5-64*x3^2*x1*
x4*f7^2*f0*f4*f3+12*x3^2*x1*x7*f3^2*f5^2-8*x3^3*x1*f7*f4^3*f1+4*x3^4*f4*f5^3*
f3-16*x3^3*x1*f0*f5^4-16*x3^2*x2*x8*f7^2*f0*f4-192*x3^2*x2*x5*f0*f6*f5*f4-72*
x3^3*x6*f0*f5^2*f7-16*x3^2*x2*x4*f6*f7^2*f1^2+16*x3^2*x1*x5*f7*f1^2*f5-88*x3^2
*x4^2*f7*f2*f6*f4*f5-48*x3^3*x1*f7^2*f0*f5*f1-144*x3^2*x2*x4*f1*f5^2*f7*f4+16*
x3^2*x2*x8*f7*f0*f5*f6-4*x3^4*f1*f5^2*f7*f4+20*x3^3*x7*f5^2*f4^2+32*x3^2*x4*x5
*f0*f7^2*f3+16*x3^3*x7*f4^3*f6-16*x3^3*x7*f1*f5*f6^2-24*x3^3*x7*f4^2*f7*f3-4*
x3^2*x4*x5*f4^2*f2*f7-64*x3^3*x2*f1*f5^2*f6*f4+32*x3^3*x2*f2*f5*f0*f7^2-48*x3^
3*x4*f1*f6*f5*f7*f4+144*x3^2*x4*x8*f7^2*f0*f6+32*x4*x8*f7*f3*f5^2*x3^2+8*x3^3*
x6*f3*f6*f1*f7-32*x1*x5*f7*f0*f2*x3^2*f5-8*x3^4*f2*f6*f5^2*f4-24*x3^2*x2*x5*f0
*f5^3-8*x1^2*x3*x5*f5^2*f1^2-16*x1^2*x3*x5*f1*f4*f0*f7+16*x1^2*x3*x5*f3^2*f5*
f1-48*x1^2*x3*x5*f0*f3*f7*f2-48*x1^2*x3*x5*f1*f6*f3*f2-224*x1*x3*x2*x5*f7*f6*
f0^2-8*x1*x3*x2*x5*f7*f0*f3^2+64*x1*x3*x2*x5*f7*f0*f5*f1-128*x3*x1*x4*x5*f0*f6
*f7*f2+24*x1*x3*x4*x5*f4^2*f2*f5-96*x1*x3*x4*x5*f0*f5*f6*f4-48*x1*x3*x4*x5*f5*
f6*f2^2+32*x3*x1*x4*x5*f0*f7^2*f1-24*x3*x1*x4*x5*f0*f7*f4^2+144*x1^2*x3^2*f0*
f6*f5*f4*f3+108*x1*x3*x4*x6*f7^2*f1^2+544*x4^2*x1*x3*f0*f6*f2*f7^2+8*x1*x3^2*
x8*f6*f7*f2^2+12*x1*x3*x6^2*f7*f2*f1-64*x3^2*x1*x6*f0*f6*f7*f2-60*x1^2*x3*x4*
f5^3*f3*f1+48*x1^2*x3^2*f1*f6^2*f3*f2-16*x1^2*x3^2*f4*f6*f3^2*f2+16*x1^2*x3^2*
f7^2*f3*f0*f1-4*x1*x3^2*x7*f7*f3^3-4*x1*x3*x5^2*f1*f3*f4+4*x1*x3*x2*x5*f7*f2^3
+12*x1*x3*x2*x5*f4^2*f2*f3+36*x1*x3*x4*x6*f7*f2^2*f5-8*x1*x3*x5*x6*f2^2*f5-12*
x1*x3*x5*x6*f2*f3*f4-40*x1*x3*x5*x6*f3*f1*f5+4*x1^2*x3*x7*f5^2*f2^2-4*x1^2*x3*
x7*f4^3*f2+8*x1*x3*x7^2*f7*f2*f3-16*x1*x3*x7^2*f7*f1*f4+8*x1*x3*x5*x7*f4^2*f2-\
16*x1*x3*x6*x7*f4^2*f3-24*x1*x3*x6*x7*f3^2*f5-16*x3*x1*x4*x5*f0*f5*f3*f7-112*
x1*x3*x4*x6*f7*f0*f4*f5-16*x1^2*x3*x7*f0*f5^2*f4+12*x1^2*x3*x7*f4^2*f1*f5-8*x1
*x3^2*x8*f7*f2*f4^2+32*x1*x3*x4*x7*f7*f2^2*f6-16*x1*x3*x4*x6*f7*f1*f4^2-72*x1*
x3*x2*x4*f2*f5*f3*f6*f4-192*x2*x7*x1*x3*f2*f7*f6*f0+64*x1^2*x3*x5*f0*f6*f5*f1+
12*x1*x3^2*x2*f1*f2^2*f7^2+8*x1*x3*x5^2*f0*f4^2+16*x1*x3^2*x7*f7*f2*f1*f6-8*x1
^2*x3^2*f2^3*f6^2-16*x1^2*x3^2*f4^2*f2*f3*f5-72*x2*x3*x4*x6*f5^2*f3*f4-4*x2^2*
x3^2*f4^2*f3*f7*f2-8*x2*x3^2*x8*f7*f1*f4*f6-48*x2*x3*x6^2*f1*f4*f6+24*x3*x2*x4
^2*f4^2*f1*f7^2+72*x3*x2*x4^2*f5*f7^2*f2^2+144*x2*x3*x4*x7*f0*f6*f7*f5-204*x2*
x3*x4*x7*f4*f5*f2*f7-16*x2*x3^2*x7*f6^2*f1*f4+32*x2*x3*x6^2*f7*f0*f4+20*x2*x3*
x6^2*f2*f4*f5+8*x2*x3*x4^2*f3*f6*f7*f2*f5+8*x2*x3*x4*x7*f3*f6*f2*f7+8*x3^2*x2*
x6*f7*f3*f4*f2+16*x2*x3*x6*x8*f7*f0*f6-96*x2*x3*x5*x7*f0*f5*f6-4*x2^2*x3*x7*f5
^3*f1-4*x2*x3^2*x7*f5^3*f2-16*x2*x3*x4*x7*f4^2*f7*f3+12*x2*x3*x4*x7*f7^2*f2^2+
4*x2^2*x3*x5*f4^3*f2-8*x2*x3*x5*x6*f4^2*f2-128*x1^2*x3*x7*f0*f6^2*f2-24*x1^2*
x3*x4*f3^2*f7*f2*f4-384*x1^2*x3*x4*f0*f6^2*f5*f2-48*x1^2*x3*x4*f3^2*f5*f2*f6-\
32*x1*x3*x7^2*f2*f4*f6-112*x1*x3^2*x6*f0*f5*f6*f4+48*x1^2*x3*x7*f0*f6*f5*f3+64
*x1^2*x3*x7*f0*f5*f7*f2+12*x1^2*x3*x7*f3^3*f5-16*x1*x3*x7^2*f7*f0*f5+192*x1*x3
^2*x2*f6^2*f0^2*f7-8*x1*x3^2*x2*f2^3*f6*f7-48*x2*x6*x4*x7*f5*f4^2-32*x1^2*x6*
x7*f7*f0*f2+48*x1^2*x6*x7*f0*f6*f3-8*x1*x6^2*x7*f1*f5+8*x1*x6*x3*x8*f7*f0*f5+8
*x6*x4^2*x7*f7*f2*f6+4*x6^2*x5*x7*f2+8*x3*x6*x2*x7*f7*f2*f3+12*x3^2*x6*x7*f7*
f3^2+16*x1*x6*x7^2*f1*f6-4*x1*x6^2*x2*f2^2*f5+12*x2*x6*x7^2*f1*f7-8*x2*x6*x5*
x7*f1*f5-4*x2*x6^2*x7*f2*f5+4*x2*x6^2*x8*f7*f1+16*x1*x6*x3*x7*f2*f4*f5+4*x1*x6
^2*x5*f2^2-4*x1^2*x6*x7*f1*f4^2-4*x1^2*x6*x7*f5*f2^2-8*x1*x6*x7^2*f3*f4-8*x1^2
*x6*x7*f2*f1*f6-8*x1*x6^2*x8*f7*f0+8*x1*x6*x2*x8*f7*f0*f4-12*x7*x8*f7*f3*x3*x6
+4*x2^2*x6*x7*f1*f5^2+4*x6*x2^2*x7*f7*f2^2+8*x2*x6*x4*x7*f7*f3^2+4*x6^2*x2*x3*
f7*f2^2-8*x1^2*x6*x7*f0*f5*f4+12*x1^2*x6*x7*f2*f3*f4+20*x1^2*x6*x7*f3*f1*f5-12
*x2*x6^2*x4*f5^2*f2-16*x6^2*x2*x3*f7*f3*f1+16*x2*x6*x3*x7*f6*f1*f5-16*x2*x6*x3
*x7*f4^3-16*x3*x6*x5*x7*f1*f6-24*x1^2*x6^2*f0*f5*f3+8*x1^2*x6^2*f0*f6*f2+10*x1
^2*x6^2*f3^2*f2+12*x1^2*x6^2*f7*f0*f1-8*x1*x6^2*x3*f2^2*f6+32*x1*x6^2*x3*f7*f0
*f3-24*x1*x6^2*x4*f1*f5^2+4*x3*x6^2*x5*f2*f4-24*x3*x6^2*x4*f6*f2*f5-80*x1*x4*
x6^2*f7*f3*f1+4*x1*x4^2*x3*f4^3*f7*f3-4*x4^2*x1*x5*f3^3*f7+4*x4^2*x1*x5*f4^2*
f1*f7+8*x2*x4*x6*x8*f7*f3*f4-20*x4*x2*x7*x8*f7*f3*f5+4*x2^2*x4*x8*f7^2*f2^2-4*
x2^2*x4*x8*f7*f4^2*f3-72*x1*x4^2*x2*f4*f5^3*f2-276*x4^2*x1*x2*f5^2*f1*f3*f7-32
*x4^2*x1*x3*f0*f6^2*f7*f3-16*x4^2*x1*x3*f4*f6*f7*f2*f3+24*x1^2*x4*x5*f3^2*f2*
f5-72*x1*x4*x3*x5*f0*f5^3-16*x4^2*x5*x1*f2*f7*f6*f1-36*x1*x4^2*x5*f5^3*f1+36*
x1*x4^2*x5*f4*f5^2*f2+16*x4^2*x1*x5*f0*f6*f7*f3-144*x1*x4*x6^2*f0*f5*f6-56*x1*
x4*x5^2*f7*f1^2-12*x1*x4*x5^2*f3*f1*f5+4*x1*x4^2*x6*f4^2*f2*f7-4*x1*x4*x6^2*f7
*f2^2+4*x1*x4^2*x7*f4^2*f7*f3-24*x1*x4*x5*x7*f1*f5^2+20*x1*x4^2*x7*f4*f5*f2*f7
-8*x1*x4^2*x6*f3^2*f7*f4+48*x1^2*x4*x7*f5*f6*f2^2-8*x1*x4*x7^2*f7*f3^2+144*x4^
2*x1*x3*f0*f6*f5*f4*f7+160*x1*x4*x2*x6*f1*f0*f7^2+12*x1*x4*x3*x7*f4^2*f2*f7+36
*x1*x4*x7^2*f3*f5^2+36*x1*x4*x2*x5*f3*f5*f2*f4-4*x3*x4*x5*x8*f7*f3*f4+28*x3*x4
*x5*x7*f7*f1*f5+8*x3^2*x8*f7*f3*f4*x4*f6+16*x4*x3^2*x8*f7*f6^2*f1-92*x3*x4*x6^
2*f7*f1*f5-16*x3^2*x4^2*f3*f6^2*f2*f7-16*x4*x3*x2*x6*f2^2*f7*f6-8*x3^2*x4*x6*
f2^2*f7^2-8*x3^2*x4^2*f3*f6*f7*f4^2+144*x3*x4*x5^2*f0*f5*f6+72*x3*x4^2*x5*f5^2
*f2*f6+24*x3*x4*x6^2*f5*f4^2+152*x1^2*x4^2*f0*f5^2*f3*f7+32*x1^2*x4^2*f0*f6^2*
f7*f1+192*x1^2*x4*x5*f5*f6*f0*f2+16*x1*x4^2*x6*f3*f6*f1*f7+32*x1^2*x4*x7*f1*f0
*f7^2-12*x1^2*x4*x7*f4^2*f2*f5-12*x1^2*x4*x6*f4^2*f1*f5+8*x1^2*x4^2*f3*f6*f7*
f2^2-72*x1*x4*x7^2*f6*f2*f5+8*x4*x2*x6^2*f7*f0*f5-4*x2^2*x4^2*f1*f6*f4^2*f7+4*
x2^2*x4^2*f4^3*f3*f7+24*x5*x7*f7*f0*x2*x4*f5+4*x4*x2^2*x6*f7*f2^2*f5+4*x2*x4^2
*x3*f4^4*f7+4*x2*x4^2*x7*f7*f4^3+36*x1^2*x4*x6*f3*f5*f2*f4-32*x1*x4*x7^2*f7*f1
*f5+8*x1*x4^2*x2*f4*f6*f2^2*f7-24*x1^2*x4*x7*f5^2*f2*f3-48*x1^2*x4*x7*f0*f5*f7
*f3+24*x1^2*x4*x7*f3^2*f5*f4-8*x1^2*x4^2*f3^2*f6*f7*f1-12*x1*x4*x6^2*f2*f4*f5-\
108*x1^2*x4^2*f0*f5^4-76*x1^2*x4^2*f3^2*f5*f7*f2-216*x1^2*x4^2*f3*f5^2*f1*f6-\
16*x1^2*x4^2*f0*f6*f7*f3*f4-592*x1^2*x4^2*f0*f6*f5*f7*f2+288*x1^2*x4^2*f0*f5^2
*f6*f4-8*x4^2*x1*x3*f4^2*f7*f1*f6+136*x1*x4*x6^2*f7*f0*f4-16*x1*x4*x5*x7*f7*f3
*f1-24*x1*x4*x5*x8*f7*f0*f5+8*x4^2*x1*x5*f3*f7*f2*f4-92*x1*x4^2*x3*f5^2*f7*f2*
f3+12*x5^2*x6^2*f0-12*x2*x5^2*x4*f1*f4*f5+24*x2*x5*x6^2*f1*f4+8*x4^2*x6*f7*f3^
2*x5+16*x5*x2*x3*x6*f7*f0*f3+8*x4*x5*x2*x6*f7*f2^2-16*x4^2*x5*x7*f7*f1*f6-4*x4
^2*x5^2*f7*f2*f3-4*x4*x5*x7*x8*f7*f3+8*x1^2*x5*x7*f2*f3^2-32*x1^2*x5*x6*f0^2*
f7-16*x1^2*x5*x6*f1*f3^2-12*x1^2*x5^2*f0*f3^2+32*x5^2*x2*x4*f7*f0*f3+24*x2*x5*
x7^2*f7*f0-8*x2*x5*x6*x8*f7*f0+8*x2^2*x5*x8*f7*f0*f4-8*x3*x5*x1*x7*f1*f4*f5+4*
x7^2*f2*f7*x4*x5+4*x4*x5^2*x8*f7*f1+4*x4*x5*x6*x8*f7*f2-4*x4*x5*x2*x8*f7*f2*f4
+12*x4*x5^2*x6*f1*f5-8*x5^2*x3*x4*f7*f3*f1+32*x1*x6*x7^2*f7*f0-40*x6^2*x2*x7*
f7*f0-8*x6^3*x2*f2*f4-4*x6^2*x1*x7*f2*f4+16*x6^3*x3*f1*f6+28*x6^3*x4*f1*f7+24*
x6^2*x4*x7*f4*f5-24*x6^3*x3*f7*f0-12*x6^3*x4*f3*f5-8*x6^3*x1*f2*f3+16*x6^3*x1*
f0*f5+8*x6^3*x1*f1*f4-8*x6^3*x3*f2*f5-48*x6^2*x1*x7*f0*f6-12*x1^2*x6*x7*f3^3+4
*x6*x5^2*x7*f1-36*x6*x4*x7^2*f5^2-8*x2*x6*x7^2*f4^2+4*x7^3*x3*f5^2-4*x7^3*x6*
f5+8*x7^3*x8*f7-2*x5^2*x7^2*f2+4*x4*x8^3*f7^2+16*x1^3*x2*f0*f4^3*f3-16*x1^3*x2
*f1*f4^2*f3^2-24*x1^3*x2*f6*f5*f1^2*f2+8*x1^3*x2*f6*f4*f2^2*f1-16*x1^3*x2*f3*
f1*f7*f2^2-32*x1^3*x2*f0*f6*f1^2*f7+32*x1^2*x3^2*f5^2*f6*f1^2+24*x1^2*x3^2*f2^
2*f6*f4^2+96*x1^2*x3^2*f0^2*f7^2*f4+32*x1^2*x3^2*f4*f6^2*f1^2-40*x1^2*x3^2*f1*
f5^2*f4*f3+16*x1^2*x3^2*f0*f6*f4^3+8*x1^2*x3^2*f0*f5^2*f4^2-8*x1^3*x3*f2*f7*f1
*f3^2-4*x1^2*x3^2*f2*f5^3*f1+4*x1^2*x3^2*f4*f5^2*f2^2-12*x1^2*x3^2*f4*f7*f2^2*
f3+8*x1^2*x3^2*f2^3*f5*f7-12*x1^2*x2*x3*f2^3*f7*f4+4*x1^2*x2*x3*f7^2*f1^3-4*x1
^3*x3*f2^3*f5^2+4*x1^3*x3*f3^4*f4+4*x1^3*x3*f3^3*f5*f2+4*x1^3*x3*f3*f4^3*f1+4*
x1^3*x3*f2^2*f4^3+20*x1^2*x2*x3*f1^2*f7*f3*f5+12*x1^2*x2*x3*f1*f7*f2^2*f5-2*x3
^4*f3^2*f7^2*f2-4*x3^3*x1*f3^3*f4*f7+4*x2*x3^3*f7*f5^2*f2^2-4*x3^3*x2*f5*f7^2*
f1^2+4*x3^3*x2*f4*f5^3*f2-4*x3^3*x2*f1*f3^2*f7^2-4*x3^3*x2*f4^2*f3^2*f7-4*x2*
x3^3*f3*f4*f7*f2*f5-4*x3^3*x2*f2^2*f7^2*f3-432*x2*x1*x3*x4*f6*f7*f0*f5*f2+96*
x2*x1^2*x5*f4*f0^2*f7-28*x2*x1*x4*x8*f7*f1*f4*f5+8*x2^2*x1^2*f0*f6*f4^2*f2-12*
x2^2*x1^2*f0*f3^2*f5^2+24*x2^2*x1^2*f0*f5*f4^2*f3+72*x2*x1*x3*x4*f3^2*f4*f5^2-\
112*x2*x1*x3*x4*f0*f4*f2*f7^2+16*x2*x1*x3*x4*f0*f5^2*f3*f7-224*x4*x5*x1*x2*f7^
2*f0^2-24*x2*x1*x4*x5*f5^2*f2^2-24*x2*x1*x4*x6*f7*f1^2*f6-32*x2^2*x1*x3*f1*f5*
f4^3-92*x2*x1*x4*x6*f7*f2*f5*f1-40*x2*x1*x4*x7*f7*f2*f3*f4-24*x2^2*x1*x3*f1^2*
f6*f5^2-8*x2^3*x1*f4^4*f1-24*x2*x1*x3*x5*f2*f5^2*f1+72*x2*x1*x3*x4*f0*f5^4-24*
x2^2*x1*x5*f1*f2*f4*f5-16*x2*x1^2*x3*f3^2*f5^2*f1-48*x2*x1^2*x3*f0*f6*f5*f2*f4
-4*x2^3*x1*f5^3*f1^2-4*x2^3*x1*f7^2*f1^3+4*x2^3*x1*f7*f4*f2^3-4*x2^3*x1*f4^2*
f2^2*f5-4*x4^3*x1*f7^2*f5*f2^2+4*x4^3*x3*f4^2*f7^2*f3+12*x4^2*x2*x7*f3*f7^2*f2
+4*x4^3*x8*f7^2*f4^2+4*x4^2*x2*x8*f7^2*f2*f4-60*x4^2*x3*x8*f7^2*f2*f5+68*x1*x4
*x5*x6*f7*f2*f1-60*x1*x4*x2*x5*f5*f7*f1^2+4*x1^2*x4^2*f4*f7*f3^3-144*x1^2*x4*
x7*f3*f5*f1*f6-48*x1*x4*x7*x8*f7*f2*f5+32*x3*x4^2*x1*f1*f6^2*f7*f2+152*x1*x4^2
*x6*f0*f5^2*f7-64*x1*x4^2*x6*f4*f5*f1*f7+152*x1*x4*x6*x7*f7*f0*f5-48*x1*x4*x6*
x7*f3*f5*f4-72*x1^2*x4*x7*f0*f5^3-16*x1*x4*x5*x7*f7*f2^2-144*x1^2*x4*x5*f3*f0*
f5^2-64*x4^2*x1*x5*f0*f5*f7*f4-48*x4^2*x1*x5*f5*f7*f2^2+24*x4^3*x1*f2*f7*f4*f5
^2-64*x4^2*x6^2*f7*f2*f5+116*x4^2*x1*x7*f3*f7^2*f1-4*x4^2*x1*x7*f2^2*f7^2-228*
x4^3*x2*f2*f7*f5^3+48*x4^3*x2*f1*f5^2*f6*f7-192*x4^3*x3*f5^2*f7*f2*f6+96*x4^3*
x3*f5*f6^2*f1*f7-80*x4^2*x1*x7*f5^2*f7*f1-8*x4^2*x3*x6*f3*f7^2*f2+20*x4^2*x3*
x8*f7^2*f3*f4+64*x4^2*x3*x8*f7^2*f1*f6+48*x3^3*x2*f0*f6*f5^3+8*x3^3*x1*f7*f2*
f5^2*f1-32*x3^3*x1*f7*f0*f4^2*f5+60*x3^3*x4*f4^2*f5^3-28*x3^3*x4*f1^2*f7^3-24*
x3^3*x4*f2*f6*f5^3+8*x3^3*x5*f7^2*f1^2+32*x3^2*x1*x4*f0*f6*f7*f5*f3+84*x3^2*x1
*x4*f4^2*f5^2*f3+84*x3^2*x2*x4*f4^3*f5^2-16*x3^2*x2*x7*f1*f6*f5^2+64*x3^4*f0*
f6^3*f4-40*x3^3*x1*f3*f1*f6*f5^2-12*x3^3*x6*f4^3*f5+480*x3^2*x4^2*f7^2*f0*f6*
f4+12*x3^3*x2*f5*f4^4-16*x3^3*x2*f6^2*f7*f1^2-64*x3^2*x1*x4*f0*f6*f7^2*f1+36*
x3^2*x1*x4*f3^2*f5^3+160*x3^2*x1*x4*f7^3*f0^2-16*x3^2*x1*x5*f4*f2^2*f6-8*x3^4*
f3*f6*f5*f7*f1-4*x3^2*x4*x5*f3*f7*f2*f5-320*x3^2*x4*x5*f0*f6*f7*f4+32*x3^2*x4*
x5*f1*f6*f7*f3-8*x3^3*x7*f5^2*f6*f2+28*x3^2*x1*x4*f7^2*f2*f1*f4-48*x3^3*x4*f2*
f6^2*f5*f4-16*x3^2*x5*x6*f1*f4*f6+4*x1^2*x7^2*f3^2*f4+4*x7^3*x2*f4*f5-4*x7^3*
x1*f7*f1+4*x7^3*x1*f3*f5-12*x1^2*x7^2*f0*f5^2+8*x1^2*x7^2*f2^2*f6+48*x4*x7^3*
f5*f6+24*x7^2*x3*x8*f7*f4+68*x7^2*x4*x8*f5*f7, 128*x1^2*x2*x7*f0*f5^2*f3*f7+8*
x1^2*x2*x7*f7*f2*f3^2*f5-56*x1^2*x2*x7*f7*f2^2*f3*f6-64*x1^2*x2*x7*f0*f4*f2*f7
^2-64*x1^2*x2*x7*f0*f6*f5^2*f4-128*x1^2*x2*x7*f0*f6^2*f1*f7-108*x1^2*x2*x7*f7*
f3*f4*f1*f5+32*x1^2*x2*x7*f1^2*f7^2*f4-48*x1^2*x2*x7*f1*f5*f0*f7^2+16*x1^2*x2*
x7*f3*f5^2*f1*f6-32*x1^2*x2*x7*f7^2*f2^3-8*x1^2*x3*x7*f2^2*f3*f7^2+68*x1^2*x3*
x7*f7*f4^2*f5*f1+384*x1^2*x3*x4*f3*f5^2*f6^2*f1+192*x1^2*x3*x4*f3*f6^2*f2*f4*
f5-104*x1^2*x3*x4*f7^3*f1*f2^2-192*x1^2*x3*x4*f1^2*f7^3*f3+112*x1^2*x3*x4*f7*
f2^2*f5^3+736*x1^2*x3*x4*f0*f6*f5^2*f3*f7+1280*x1^2*x3*x4*f6^2*f0^2*f7^2-480*
x1^2*x3*x4*f0*f5*f6^2*f2*f7+96*x1^2*x3*x4*f7^2*f2^2*f4^2-832*x1^2*x3*x4*f5*f0^
2*f7^3-48*x1^2*x3*x4*f6^2*f2^2*f5^2+192*x1^2*x2*x6*f6^2*f0^2*f7-88*x1^2*x2*x6*
f0*f4^3*f7-24*x1^2*x2*x6*f0*f5^3*f4+96*x1^2*x2*x6*f0*f5^2*f2*f7+24*x1^2*x2*x6*
f7*f2^3*f6-48*x1^2*x2*x6*f1^2*f7*f4*f6+64*x1^2*x2*x6*f0*f5*f4*f3*f7+24*x1^3*x6
*f0*f5*f2*f7*f4+64*x1^3*x6*f6^2*f2*f1*f3+128*x1^3*x6*f0*f6*f3*f7*f2-16*x1^3*x6
*f1^2*f5^2*f6+68*x1^3*x6*f7*f3^2*f1*f4-40*x1^3*x6*f1^2*f5*f7*f4+32*x1^3*x6*f1*
f5*f2*f4*f6+32*x1^3*x6*f1*f4*f6*f0*f7-36*x1^3*x6*f7*f2*f5*f3*f1-8*x1^3*x3*f3*
f6*f4^3*f2+144*x1^3*x3*f0*f4*f3*f7^2*f2-64*x1^3*x3*f0*f6^3*f4*f1+8*x1^3*x3*f5*
f7^2*f1^2*f2+64*x1^3*x3*f0*f4^2*f1*f7^2-40*x1^3*x3*f4*f1*f7^2*f2^2-192*x1^3*x3
*f0*f6*f7^2*f1*f2+128*x1^3*x3*f0*f6^2*f7*f1*f3-64*x1^3*x3*f0*f6^3*f2*f3+48*x1^
3*x3*f3^2*f5*f6*f2*f4-16*x1^3*x3*f0*f3^3*f7^2-48*x1^3*x3*f0*f6*f4^2*f2*f7-16*
x1^3*x3*f0*f4^4*f7+224*x1^3*x3*f0*f5*f4^2*f3*f7-16*x1^3*x3*f0*f5*f6*f1*f7*f4+8
*x1^3*x3*f4^4*f6*f1-28*x1^3*x3*f7*f3^2*f2*f4^2+192*x1^3*x3*f0*f6^2*f7*f2^2-448
*x1^3*x3*f5*f0^2*f7^2*f4-296*x1^2*x4^2*f7*f3*f5*f4*f6*f2+24*x1^2*x4^2*f7^2*f2*
f1*f4*f6-80*x1^2*x4^2*f7*f3*f5^2*f1*f6-4*x1^2*x3^2*f2^2*f3*f7^2*f4-88*x1^2*x3^
2*f7*f3^2*f2*f4*f6+16*x1^2*x3^2*f3*f6^2*f1*f4*f5+44*x1^2*x3^2*f4^2*f6*f7*f2^2+
40*x1^2*x3^2*f4*f5^2*f2*f3*f6+56*x1^2*x3^2*f1^2*f5^2*f7*f6+288*x1^2*x3^2*f4*f0
^2*f7^3-832*x1^2*x3^2*f6*f5*f0^2*f7^2+232*x1^2*x3^2*f0*f5^2*f1*f7^2-8*x1^2*x3^
2*f6*f5^2*f1*f4^2+160*x1^2*x3*x6*f0*f5^2*f3*f7-96*x1^2*x3*x6*f0*f5*f4^2*f7-80*
x1^2*x3*x6*f1^2*f7*f6*f5-32*x1^2*x3*x6*f0*f5^4+128*x1^2*x3*x6*f0*f6*f5^2*f4+32
*x1^2*x3*x6*f7*f2^2*f3*f6+320*x1^2*x3*x6*f6*f0^2*f7^2-128*x1^2*x3*x6*f0*f4*f2*
f7^2-36*x1^2*x3*x6*f7^2*f2*f1*f3-16*x1^2*x3*x6*f7*f2*f5^2*f1+36*x1^2*x3*x6*f1^
2*f7^2*f4+144*x1^2*x3*x6*f6^2*f2*f1*f5-136*x1^2*x3*x6*f3*f5^2*f1*f6+128*x1^2*
x3*x6*f0*f6^2*f1*f7-40*x1^2*x3*x6*f7*f2^2*f5*f4+260*x1^2*x3*x6*f7*f3*f4*f1*f5-\
128*x1^3*x3*f6^3*f0^2*f5+16*x1^4*f0*f4^3*f7*f2-8*x1^4*f1*f6*f5*f3^3+176*x1^3*
x2*f0*f5*f2*f7^2*f1-64*x1^3*x2*f6*f0^2*f7^2*f2-32*x1^2*x2^2*f0*f6*f7^2*f1*f2-\
232*x1^2*x2*x3*f5*f4^2*f1*f3*f7+48*x1^2*x2*x3*f0*f4^2*f2*f7^2-352*x1^2*x2*x3*
f6*f0^2*f7^2*f4-64*x1^2*x2*x3*f0*f6*f5*f2*f7*f4-28*x1^2*x2*x3*f5^3*f2*f3*f4+
128*x1^2*x2*x3*f5^2*f0^2*f7^2-32*x1^3*x3*f0*f6*f5^3*f2+12*x2^2*x6^2*f4^3*f5+72
*x1^2*x2*x3*f1^2*f5*f7*f4*f6-48*x1^2*x2*x3*f3*f6*f4*f7*f2^2-56*x1^2*x6^2*f0*f5
*f4*f6-72*x1^2*x6^2*f7*f3*f4*f1-64*x1^2*x6^2*f6^2*f2*f1-40*x1^3*x6*f3*f5*f2^2*
f6+128*x1^3*x6*f6^3*f0^2-80*x1^3*x6*f0*f4^2*f7*f3-8*x1^3*x6*f3^2*f2*f4*f6+8*x1
^3*x6*f3^4*f6-24*x1^2*x2^2*f7*f2^3*f4*f6+16*x1^2*x2^2*f0*f5*f4^2*f3*f7+32*x1^3
*x3*f0*f5^3*f4^2-16*x1^4*f7*f0*f3*f1*f4*f6+24*x1^4*f2*f6*f1^2*f7*f4+80*x1^2*x3
^2*f7^2*f2*f1*f4^2-80*x1^2*x3^2*f0*f6^2*f5*f4^2+32*x1^2*x3^2*f6^3*f2*f1*f4+16*
x1^2*x3^2*f6^2*f2*f4^2*f3+12*x1^2*x3^2*f5^3*f6*f2^2+16*x1^3*x2*f0*f4*f3*f7^2*
f1-32*x1^3*x2*f0*f6*f3^3*f7-20*x1^4*f5^2*f7*f1^2*f2-8*x1^3*x3*f7*f3^2*f2^2*f6+
4*x3^2*x6^2*f4^3*f7+336*x1^2*x4*x6*f7*f0*f5*f6*f3-8*x1^2*x3*x5*f1^2*f7*f4*f6+
12*x1^2*x3*x5*f3*f7*f1*f4^2+32*x1^2*x3*x5*f1^2*f7^2*f3-32*x1^2*x3*x5*f2*f4*f6^
2*f1+24*x1^2*x3*x5*f2^2*f5*f4*f6+8*x1^2*x3*x5*f0*f4^3*f7+16*x1^2*x3*x5*f0*f6*
f5*f4^2+44*x1^2*x2*x3*f7^3*f1^3-16*x1^2*x2*x3*f0*f5*f6*f7*f3^2-144*x1^2*x2*x3*
f0*f6*f4^2*f5^2+40*x1^2*x2*x3*f5*f4^2*f2*f3*f6+32*x1^3*x5*f2*f5*f1*f6*f3+16*x1
^3*x5*f1*f0*f7^2*f2+96*x1^3*x5*f4*f0^2*f7*f6+44*x1^2*x6^2*f0*f7*f4^2+48*x1^2*
x6^2*f1^2*f7*f6+20*x1^2*x6^2*f2^2*f6*f5-20*x1^2*x6^2*f2*f5^2*f3+16*x1^2*x6^2*
f3*f6*f2*f4+48*x1^2*x6^2*f5*f1*f6*f3-4*x1^2*x4*x5*f4^3*f7*f1+4*x1^3*x6*f5*f4^3
*f1+20*x1^2*x2*x6*f7*f2^2*f4^2-44*x1^2*x2*x6*f7*f2*f3^2*f4-72*x1^2*x2*x6*f7*f2
*f1*f4*f5+8*x1^2*x3*x6*f7^2*f2^3+4*x2^3*x1*f3^2*f7^2*f2^2+4*x2^3*x1*f5^3*f4^2*
f1+4*x2^3*x1*f3*f5^2*f2^2*f7-4*x2^3*x1*f1*f3^3*f7^2-4*x2^3*x1*f5^2*f4^3*f2-4*
x2^3*x1*f3*f5^4*f1-12*x2^2*x3^2*f7^2*f2*f5*f3^2-56*x2^2*x3^2*f5^2*f4^2*f2*f7-4
*x2^3*x3*f7^2*f3^2*f1*f5-4*x2^3*x3*f7*f3^2*f5*f4^2-4*x2^3*x3*f7*f2^2*f5^3-4*x2
^3*x3*f1*f5^5+4*x2^3*x3*f7*f3*f4^4+8*x2^2*x1*x3*f3*f5^4*f2+8*x2^2*x1*x3*f7^2*
f3^3*f2+32*x2^2*x3*x4*f7^3*f3^2*f1+4*x2^3*x4*f7*f4^5+12*x2^2*x1*x4*f7*f3^2*f5*
f4^2+16*x2^2*x6^2*f2*f7^2*f1+12*x2^2*x6^2*f7*f2*f4^2+8*x2^2*x6^2*f7*f2*f5*f3-\
10*x2^2*x6^2*f7*f3^2*f4-12*x2^2*x5*x6*f5^3*f1-12*x2^2*x5*x6*f7*f2^2*f5+24*x1^3
*x4*f2*f7*f3^3*f6+64*x1^3*x4*f3*f6*f4*f7*f2^2-24*x1^3*x4*f5*f4^2*f1*f3*f7-132*
x1^3*x4*f7*f3^2*f5^2*f1+24*x1^3*x4*f0*f4*f7^2*f3^2-96*x1^3*x4*f6^2*f2^2*f3*f5+
20*x1^3*x4*f7*f3^4*f5-416*x1^3*x4*f6*f0^2*f7^2*f4-272*x1^3*x4*f0*f7^3*f1*f2-24
*x1^3*x4*f4^2*f5^3*f1+68*x1^3*x4*f1^2*f7^2*f3*f5-144*x1^3*x4*f0*f6*f4^2*f5^2+
72*x1^3*x4*f1*f7^2*f2^2*f5-32*x1^3*x7*f0*f5^2*f2*f7-16*x1^3*x7*f1^2*f7*f4*f6+
12*x1^3*x7*f7*f3^4+32*x1^3*x7*f0*f5*f6^2*f2+36*x1^3*x7*f7*f2^2*f5*f3+128*x1^3*
x7*f6^2*f0^2*f7-16*x1^3*x7*f7*f2^3*f6-52*x1^3*x2*f7*f3^2*f1*f4^2-64*x1^2*x3^2*
f0*f5*f6^2*f1*f7-12*x1^2*x3^2*f7^2*f2*f5*f3*f1+20*x1^2*x3^2*f7*f2*f5^2*f3^2-32
*x1^2*x2^2*f0*f7^3*f1^2-64*x1^3*x2*f3*f0^2*f7^2*f5-64*x1^3*x2*f0*f6*f1^2*f7^2-\
192*x1^2*x3^2*f0*f6*f5^2*f2*f7-80*x1^2*x3^2*f0*f6*f4*f1*f7^2+4*x1^3*x4*f7*f4^2
*f3^3+16*x1^2*x3*x5*f5^2*f4^2*f1-24*x1^2*x3*x5*f7*f2^2*f4^2-8*x1^2*x3*x5*f5*f4
^3*f2+20*x1^2*x3*x5*f7*f2^2*f5*f3+20*x1^2*x3*x5*f7*f2*f1*f4*f5+48*x1^2*x4*x5*
f7^2*f2^3-8*x1^2*x2^2*f5^2*f4^3*f1-16*x1^2*x3^2*f5^3*f4^2*f2-68*x1^2*x3^2*f2*
f5*f7*f4^2*f3-12*x1^2*x3^2*f4*f5^4*f1+4*x1^3*x3*f7*f3*f4^3*f1-16*x1^2*x3^2*f7*
f4^4*f2-4*x1^3*x3*f4*f5^3*f3*f1-4*x1^3*x3*f5^2*f4^2*f2*f3+12*x1^2*x2*x3*f7*f3*
f5^2*f2^2+12*x1^2*x2*x3*f7*f4^4*f1+24*x1^2*x2*x3*f7*f2*f3^2*f4*f5+32*x1^4*f6^3
*f1^3+288*x1^2*x2*x3*f0*f6*f4^2*f3*f7-44*x1^2*x2*x3*f7*f3*f4^3*f2-128*x1^2*x2*
x3*f0*f6^2*f2*f7*f3-40*x1^2*x2*x3*f7*f2^3*f5*f6+320*x1^2*x2*x3*f6^2*f0^2*f7*f5
-32*x1^2*x2*x3*f1*f6*f5^2*f0*f7+88*x1^2*x2*x3*f4*f5^2*f1*f6*f3-192*x1^2*x2*x3*
f0*f6^2*f1*f7*f4+56*x1^2*x2*x3*f0*f5^4*f4-32*x1^2*x2*x3*f4^2*f5^3*f1-128*x1^2*
x2*x3*f0*f5^3*f2*f7-120*x1^2*x2*x3*f1*f4*f6*f7*f3^2+64*x1^2*x2*x3*f1^2*f6^2*f7
*f3+48*x1^2*x2*x3*f6^2*f1*f7*f2^2-44*x1^2*x2*x3*f1^2*f7^2*f4^2+64*x1^3*x7*f0*
f3*f2*f7^2+32*x1^3*x7*f1^2*f7^2*f3+24*x1^3*x7*f0*f5^3*f4-8*x1^3*x7*f5^2*f4^2*
f1-20*x1^3*x7*f7*f2*f3^2*f4-48*x1^3*x7*f7*f2*f1*f4*f5-160*x1^3*x7*f5*f0^2*f7^2
-64*x1^3*x7*f0*f6^3*f1-32*x1^3*x7*f6^2*f2^2*f3+40*x1^3*x7*f1^2*f7*f5^2-8*x1^3*
x7*f3^3*f6*f4-8*x1^3*x7*f0*f4^3*f7-192*x1^2*x2*x4*f0*f6*f3*f2*f7^2+192*x1^2*x3
*x4*f4^2*f5^2*f2*f6+656*x1^2*x3*x4*f1^2*f6^2*f7*f5-104*x1^2*x3*x4*f1^2*f7^2*f4
*f6+416*x1^2*x3*x4*f0*f3*f2*f7^3+172*x1^2*x3*x4*f5^2*f4^2*f7*f1-24*x1^2*x3*x4*
f6*f5^3*f1*f4-96*x1^2*x3*x4*f0*f4^3*f7^2-96*x1^2*x3*x4*f7*f2*f3^2*f5*f6+40*x1^
2*x3*x4*f4^3*f6*f1*f7-88*x1^2*x3*x4*f7*f3*f6*f2*f4^2-160*x1^2*x2*x5*f7^2*f0*f2
^2+132*x1^2*x2*x5*f7^2*f2*f1^2+64*x1^2*x2*x5*f7*f0*f6*f3*f2-4*x1^2*x5*x8*f7*f2
^2*f5-4*x1^3*x7*f3*f7*f1*f4^2-24*x1^2*x2*x7*f7*f2*f5^2*f1+44*x1^2*x2*x7*f7*f2^
2*f5*f4-20*x1^2*x2*x7*f4*f5^3*f1-88*x1^2*x3*x7*f7*f2*f3*f5*f4-24*x1^2*x3*x7*f4
^3*f7*f2+20*x1^2*x4*x6*f7*f2*f3*f5*f4-12*x1^3*x7*f1*f7^2*f2^2-32*x1^2*x2*x7*f7
*f3*f4^2*f2-64*x1^2*x2*x7*f0*f6*f5*f2*f7+96*x1^2*x2*x7*f1^2*f7*f6*f5+32*x1^2*
x2*x7*f0*f5*f4^2*f7-4*x1^4*f2^2*f5^2*f3*f4-32*x1^3*x2*f0*f6^2*f5*f3*f2-4*x1^2*
x2^2*f1^2*f6*f7*f4^2-8*x1^4*f2*f4*f6*f3^3+160*x1^2*x3^2*f6^2*f2*f1*f3*f7+16*x1
^3*x2*f0*f6*f4^2*f7*f1-128*x1^3*x2*f0*f6^2*f2*f7*f1+96*x1^3*x2*f0*f6^2*f4^2*f2
-92*x1^2*x2^2*f5*f7^2*f1^2*f2-16*x1^3*x2*f2*f1^2*f7^2*f4+128*x1^3*x2*f6*f5*f0^
2*f7*f4-32*x1^4*f0*f6^2*f1^2*f7-16*x1^4*f6^2*f2^3*f3-8*x1^4*f4^2*f7*f2^3-16*x1
^4*f0*f6*f5^2*f4*f1+12*x1^4*f4^2*f3*f6*f2^2-192*x1^3*x3*f0*f6*f5^2*f3*f4+40*x1
^3*x2*f3^2*f1^2*f7^2+4*x1^4*f1*f2*f5^3*f3+8*x2^3*x1*f5*f4^4*f3-20*x2^4*f7^3*f2
*f1^2-24*x2^3*x1*f0*f4*f3^2*f7^2+8*x2^3*x1*f6*f5*f7*f4*f1^2-32*x2^2*x1*x3*f1*
f6^2*f5*f4*f3+24*x2^2*x1*x3*f7^3*f2*f1^2+128*x2^2*x3^2*f0*f6^2*f5*f3*f7+48*x2^
3*x1*f0*f5*f4^3*f7+64*x2^2*x1*x3*f0*f6*f5*f4*f3*f7-4*x2^4*f2^3*f5*f7^2-16*x2^4
*f0*f6*f3*f2*f7^2-40*x2^3*x1*f3*f5*f7*f1*f4^2+12*x2^4*f7^2*f2*f4^2*f1+16*x2^4*
f0*f2^2*f7^3-12*x2^3*x1*f7^3*f1^3+8*x2^3*x1*f3*f5^3*f2*f4+32*x2^3*x1*f3*f6*f5*
f2*f4^2+4*x2^4*f6*f7^2*f3*f1^2+24*x2^2*x3^2*f7^2*f2*f4^2*f3+96*x2^2*x1*x3*f0*
f6*f5^2*f2*f7+112*x2^2*x1*x3*f0*f6*f3*f2*f7^2-12*x2^3*x1*f3^2*f5^2*f4^2+400*x2
^2*x3^2*f0*f6*f4*f5^2*f7+64*x2^2*x1*x3*f6^2*f2*f4^2*f3+64*x2^3*x1*f7^2*f0^2*f5
^2-4*x2^4*f1*f4*f5^4+48*x2^3*x1*f0*f5*f3*f2*f7^2-8*x2^2*x1*x3*f3^3*f7*f5*f4-16
*x2^2*x1*x3*f0*f6*f5^3*f4-128*x1^2*x3^2*f1^2*f7^2*f4*f5-120*x1^2*x3^2*f7*f3^2*
f5*f1*f6+264*x1^2*x3^2*f0*f5*f2*f7^2*f4+128*x1^4*f0*f6*f5*f2*f7*f1-32*x1^4*f5*
f2*f7^2*f0^2-384*x1^2*x2*x4*f2*f7^3*f1^2-896*x1^2*x2*x4*f4*f0^2*f7^3-60*x1^2*
x2*x4*f4*f5^4*f1-192*x1^2*x2*x4*f0*f6*f5^3*f4+304*x1^2*x2*x4*f0*f6*f5*f4*f3*f7
-272*x1^2*x2*x4*f4*f5^2*f1*f3*f7+400*x1^2*x2*x4*f0*f4^2*f3*f7^2-128*x1^2*x2*x4
*f7^2*f2^3*f5+32*x1^2*x2*x4*f0*f6*f4^3*f7-576*x1^2*x2*x4*f0*f5*f6^2*f1*f7+112*
x1^2*x2*x4*f0*f5^2*f4^2*f7+224*x1^2*x2*x4*f0*f5^3*f3*f7-32*x1*x2*x4*x6*f0*f5*
f3*f7^2-16*x2^2*x1*x3*f2^3*f5*f7^2-20*x2^3*x1*f1*f7^2*f2^2*f5+8*x2^4*f1*f6*f7^
2*f2^2+128*x2^2*x3^2*f6*f0^2*f7^3+32*x2^3*x1*f0*f6*f4^2*f3*f7-14*x2^4*f1^2*f5*
f7^2*f4+4*x2^2*x3^2*f7*f2*f5^3*f3-16*x2^3*x1*f6*f2^2*f5^2*f4+128*x2^2*x1*x3*f0
*f6*f4^3*f7-64*x2^3*x1*f0*f5*f4*f1*f7^2-24*x2^2*x3^2*f1*f7^3*f2*f3-224*x1^2*x3
^2*f0*f4^2*f3*f7^2+32*x1^4*f6*f7*f1^2*f3^2+16*x1^2*x2^2*f7*f2^2*f5*f3*f4+4*x1^
2*x2^2*f4^2*f6*f2^2*f5+16*x1^2*x2^2*f3*f6*f4^3*f2-72*x1^2*x3^2*f7*f3*f4^2*f1*
f6-32*x1^2*x3^2*f3*f5*f6*f7*f2^2+8*x1^2*x2^2*f4*f1*f7^2*f2^2-88*x1^2*x2^2*f0*
f5^2*f2*f7*f4+96*x1^2*x2^2*f5*f0^2*f7^2*f4+24*x1^2*x2^2*f1^2*f5*f7*f6*f3-64*x1
^2*x2^2*f6^2*f2*f1*f4^2-40*x1^2*x2^2*f0*f6*f5*f4^3-160*x1^2*x2^2*f6^2*f0^2*f7*
f4+16*x1^4*f6*f5^3*f0^2+4*x1^4*f2*f4^2*f3^2*f5+4*x2^2*x3^2*f2*f5^5+8*x1^3*x7*
f4^3*f6*f1-80*x1^3*x7*f0*f6*f3^2*f7+32*x1^3*x7*f0*f6^2*f4*f3+32*x1^3*x7*f3*f5*
f1*f4*f6-80*x1^3*x7*f0*f6*f4*f2*f7+48*x1^2*x6*x7*f7*f2*f1*f6-44*x1^2*x6*x7*f7^
2*f1^2+56*x1^2*x3^2*f7*f4*f5^2*f2^2+64*x1^3*x3*f6^3*f1^2*f3-16*x1^3*x3*f3^4*f5
*f6-48*x1^2*x2^2*f0*f6*f5*f7*f2*f3-44*x1^2*x2^2*f7*f3^2*f1*f4*f5-12*x1^2*x3*x6
*f4^3*f7*f1+4*x1^3*x5*f4^2*f2^2*f5+4*x1^3*x5*f1^2*f7*f3*f5+4*x1^3*x5*f3^4*f5+4
*x1^3*x5*f7*f3^3*f1-4*x1^3*x6*f3^3*f4*f5+4*x1^3*x6*f4*f5^2*f2^2+16*x1^2*x6^2*
f7*f2*f5*f1+4*x1^3*x7*f5*f4^3*f2-4*x1^3*x7*f3*f5^3*f1+12*x1^2*x5*x7*f5^2*f1*f4
-8*x1^2*x5*x7*f2*f5*f4^2-20*x1^2*x5*x7*f7*f2^2*f4+40*x1^2*x5*x7*f7*f2*f5*f1+
192*x1^2*x2*x3*f7^2*f2*f1*f3*f4+8*x1^2*x2*x3*f4*f5^2*f2^2*f6+20*x1^2*x2*x3*f7*
f2*f5^2*f1*f4-60*x1^2*x2*x3*f7^2*f2^3*f4+96*x1^2*x2*x3*f0*f5*f4^3*f7-136*x1^2*
x2*x3*f0*f4*f7^2*f3^2+52*x1^2*x2*x3*f5*f4^2*f7*f2^2+32*x1^2*x2*x3*f1*f7^2*f2^2
*f5+52*x1^2*x2*x3*f1^2*f7^2*f3*f5-208*x1^2*x2*x3*f1^2*f7^2*f6*f2+320*x1^2*x2*
x3*f0*f6*f7^2*f2^2-112*x1^2*x2*x3*f6^2*f2*f1*f4*f5+16*x1^3*x3*f6^2*f2*f3^3+32*
x1^3*x2*f6*f5^2*f1^2*f4-32*x1^3*x2*f6*f2*f5^2*f3*f1+64*x1^3*x2*f6^2*f0^2*f7*f3
-16*x1^4*f6^2*f5*f1^2*f2+28*x1^4*f6*f5^2*f1^2*f3-4*x1^4*f1*f4^3*f5*f3-64*x1^4*
f0*f5*f4*f3*f7*f2+32*x1^3*x2*f6^2*f5*f1^2*f3-384*x1^2*x3*x4*f0*f6^2*f5^2*f4+
180*x1^2*x3*x4*f1*f4*f7^2*f2*f5-272*x1^2*x3*x4*f3^2*f6^2*f1*f7-272*x1^2*x3*x4*
f0*f6*f4*f2*f7^2+480*x1^2*x3*x4*f0*f6^2*f4*f3*f7+304*x1^2*x3*x4*f0*f5^2*f2*f7^
2+2*x1^4*f4*f3^2*f7*f2^2+36*x1^2*x4*x5*f4*f5^3*f1-480*x1^2*x4*x5*f0*f5^2*f3*f7
-96*x1^2*x4*x5*f0*f5^4+304*x1^2*x4*x5*f0*f6*f5*f2*f7-512*x1^2*x4*x5*f6*f0^2*f7
^2+48*x1^2*x4*x5*f3*f5*f4*f6*f2-296*x1^2*x4*x5*f1^2*f7*f6*f5+4*x1^3*x5*f3*f5^2
*f2^2+4*x1^3*x5*f4^2*f5*f3*f1+16*x1^2*x2*x5*f7*f2^2*f3*f4+28*x1^2*x2*x5*f7*f3^
2*f1*f4-2*x1^4*f7*f1^2*f4^3-2*x1^4*f4^3*f2^2*f5-32*x1^3*x3*f0*f5^2*f7*f3^2+16*
x1^4*f1*f6*f4^2*f3^2+20*x1^4*f6*f5*f3^2*f2^2-24*x1^3*x2*f3*f6*f7*f2^3+40*x1^2*
x2^2*f0*f4^4*f7-16*x1^3*x3*f3^2*f5^3*f2-112*x1^3*x2*f6*f5*f7*f1^2*f2-16*x1^4*
f0*f6*f3^2*f7*f2-40*x1^4*f0*f5^2*f3*f7*f1+16*x1^4*f6*f7*f2^4-32*x1^3*x2*f5*f7^
2*f1^3+96*x1^3*x3*f0*f6^2*f5*f3^2-16*x1^3*x3*f6^2*f2^3*f5-8*x1^3*x3*f6*f2*f5^2
*f1*f4-80*x1^3*x3*f0*f5^2*f2*f7*f4+80*x1^3*x3*f0*f5*f7^2*f1*f3-136*x1^3*x3*f7*
f3^2*f1*f4*f5+80*x1^3*x3*f1*f5*f7*f2^2*f6+12*x1^3*x2*f1*f5^2*f7*f2^2+28*x1^3*
x2*f1^2*f5*f7*f4^2+192*x1^3*x3*f0*f6^2*f5*f2*f4-56*x1^2*x2^2*f0*f4^2*f1*f7^2-\
48*x1^3*x3*f3^2*f6^2*f4*f1+16*x1^3*x3*f0*f5^4*f3+16*x1^2*x2^2*f1*f5*f7*f2^2*f6
+48*x1^2*x3^2*f5*f4^3*f6*f2+32*x1^4*f0*f3^2*f7^2*f1-64*x1^4*f4*f3*f7^2*f0^2-24
*x1^4*f0*f4*f6*f2^2*f7-16*x1^3*x2*f0*f6*f4^4+128*x1^3*x2*f5^3*f0^2*f7+16*x1^3*
x2*f0*f5^2*f4^3+24*x1^3*x2*f7^2*f2^4-6*x1^4*f5^3*f4*f1^2+4*x1^4*f1*f4^2*f7*f2*
f3+88*x1^2*x3^2*f5^3*f6*f3*f1+104*x1^2*x3^2*f1^2*f6^2*f7*f4-56*x1^2*x3^2*f4*f6
^2*f2^2*f5+24*x1^3*x3*f7^2*f2*f1*f3^2+96*x1^3*x3*f0*f6^2*f4^2*f3-16*x1^3*x3*f4
^2*f6*f2^2*f5-64*x1^3*x2*f1*f6^2*f3*f4*f2+72*x1^3*x2*f6*f1*f4*f7*f2^2-8*x1^3*
x2*f3^4*f6*f4-80*x1^3*x2*f3*f1*f7^2*f2^2+768*x1^2*x3^2*f0*f6*f5*f4*f3*f7-16*x1
^4*f0*f6*f4^3*f3+16*x1^4*f0*f6^2*f5*f2^2-4*x1^4*f2*f5^2*f3^3+72*x1^3*x4*f3^2*
f5^2*f6*f2+24*x1^3*x4*f5*f4^3*f1*f6-176*x1^3*x4*f1*f5*f0*f7^2*f4+56*x1^3*x4*f7
*f2*f5*f3*f1*f6+48*x1^3*x6*f0*f5*f3^2*f7-32*x1^3*x6*f0*f5*f6^2*f1-288*x1^3*x6*
f6*f5*f0^2*f7+160*x1^3*x6*f4*f0^2*f7^2-48*x1^3*x6*f1*f7*f2^2*f6-32*x1^3*x6*f0*
f2^2*f7^2+80*x1^3*x6*f0*f5^2*f1*f7-24*x1^3*x6*f3*f4^2*f1*f6-96*x1^3*x6*f0*f6^2
*f4*f2+32*x1^3*x6*f0*f6*f5^2*f2-40*x1^2*x3*x6*f7*f2*f1*f4*f6-56*x1^2*x3*x6*f3*
f5*f4*f6*f2+40*x1^2*x3*x6*f2*f5^3*f3+16*x1^2*x3*x6*f4*f5^3*f1-32*x1^2*x3*x6*f2
^2*f5^2*f6-48*x1^2*x4*x6*f7*f0*f5^2*f4+232*x1^2*x4*x6*f7*f2*f5*f1*f6+448*x1^2*
x4*x6*f7^3*f0^2-80*x1^2*x4*x6*f7^2*f1*f4*f2+152*x1^2*x4*x6*f7*f3*f1*f4*f6-480*
x1^2*x4*x6*f7^2*f0*f4*f3-136*x1^2*x4*x6*f7*f2*f3^2*f6-24*x1^2*x3*x5*f0*f5^3*f4
-12*x1^2*x3*x5*f4*f5^2*f2*f3-160*x1^2*x3*x5*f1*f7*f2*f3*f6-40*x1^2*x2*x5*f7*f1
^2*f6*f3+8*x1^3*x5*f7*f3^2*f2^2+12*x1^3*x5*f1^2*f7*f4^2+44*x1^3*x4*f5*f4^2*f7*
f2^2-240*x1^3*x4*f1^2*f7^2*f6*f2+288*x1^3*x4*f0*f6*f7^2*f2^2-20*x1^3*x4*f7^2*
f3^3*f1-24*x1^3*x4*f5^3*f2*f3*f4-52*x1^3*x4*f1^2*f7^2*f4^2-60*x1^3*x4*f7^2*f2^
3*f4+100*x1^3*x4*f7^3*f1^3+12*x1^3*x4*f5^2*f4^3*f2-12*x1^3*x4*f3*f5^4*f1+96*x1
^3*x4*f0*f6^2*f5*f3*f4+32*x1^3*x4*f0*f6^2*f1*f7*f4+96*x1^3*x4*f1^2*f6^2*f7*f3+
48*x1^3*x4*f6^2*f1*f7*f2^2+100*x1^3*x4*f7*f3*f5^2*f2^2-160*x1^3*x4*f0*f5*f6*f7
*f3^2+12*x1^3*x4*f5^4*f2^2-24*x1^3*x4*f3^3*f5*f6*f4-144*x1^3*x4*f0*f6*f5^3*f3+
16*x1^3*x4*f1^2*f5*f7*f4*f6+12*x1^3*x4*f3^3*f5^3+96*x1^3*x4*f0*f6^2*f5^2*f2+
240*x1^3*x4*f1*f6*f0*f7^2*f3-160*x1^3*x4*f0*f5*f2*f7^2*f3-96*x1^3*x4*f0*f6^2*
f2*f7*f3-40*x1^3*x4*f7*f2*f6*f1*f4^2+144*x1^3*x4*f0*f4^2*f2*f7^2+72*x1^3*x4*f0
*f5^4*f4-24*x1^3*x4*f5*f4^2*f2*f3*f6-48*x1^3*x4*f7*f2*f3^2*f4*f5+136*x1^3*x4*
f7^2*f2*f1*f3*f4-24*x1^3*x4*f4*f5^2*f2^2*f6+320*x1^3*x4*f6^2*f0^2*f7*f5-184*x1
^2*x2*x4*f7*f3*f4^2*f1*f6-192*x1^2*x2*x4*f7*f2*f5*f1*f4*f6-144*x1^2*x2*x4*f7^2
*f3^2*f1*f4+120*x1^2*x2*x4*f1*f7^2*f2^2*f6+384*x1^2*x2*x4*f0*f2^2*f7^3+80*x1^2
*x2^2*f4*f7^2*f1^2*f3-20*x1^3*x2*f7*f2^3*f4*f5+48*x1^3*x2*f3*f6*f4*f2^2*f5-12*
x1^4*f5*f2^3*f3*f7+32*x1^4*f0*f6^2*f4^2*f1-48*x1^4*f6^2*f3*f4*f1^2-64*x1^2*x3^
2*f7*f2*f5*f1*f4*f6-56*x1^3*x3*f1^2*f6*f7*f4^2+24*x1^2*x2*x3*f7*f2*f5*f3*f1*f6
+80*x1^2*x2*x3*f1*f5*f0*f7^2*f4-112*x1^2*x2*x3*f0*f5*f2*f7^2*f3+96*x1^2*x2*x3*
f0*f5^2*f3*f7*f4-24*x1^2*x4*x5*f5^2*f4^2*f2+136*x1^2*x4*x5*f3^2*f6*f7*f1-384*
x1^2*x4*x5*f0*f6*f4*f3*f7-60*x1^2*x4*x5*f7*f2^2*f5*f4+96*x1^2*x4*x5*f7*f3*f4*
f1*f5+196*x1^2*x4*x5*f1^2*f7^2*f4-48*x1^2*x4*x5*f0*f5*f4^2*f7+160*x1^2*x4*x5*
f1*f5*f0*f7^2-144*x1^2*x4*x5*f0*f4*f2*f7^2-240*x1^2*x4*x5*f7^2*f2*f1*f3-24*x2^
2*x1*x6*f4^3*f3*f5+16*x2^2*x1*x6*f0*f6*f4*f5^2+32*x2^2*x1*x6*f0*f3^2*f7^2+88*
x2^2*x1*x6*f7*f3*f5*f1*f4-64*x2^2*x1*x6*f6*f4*f5*f2*f3-20*x2^2*x1*x6*f1*f7^2*
f2*f3-32*x2^2*x1*x6*f0*f6*f5*f2*f7-16*x2^2*x1*x6*f1^2*f6*f7*f5+56*x2^2*x1*x6*
f0*f4*f2*f7^2-140*x2^2*x1*x6*f7^2*f1^2*f4+68*x2^2*x1*x6*f7*f1*f4^3-16*x2^2*x1*
x6*f5*f4^2*f1*f6+16*x2^2*x1*x6*f2^2*f6*f5^2-12*x2^2*x1*x6*f1*f5^3*f4+16*x2^2*
x1*x6*f0*f5^4-68*x2^2*x4*x6*f1*f5*f7^2*f3-60*x2^2*x4*x6*f7^2*f2*f3*f4-32*x2^2*
x4*x6*f7^2*f2*f6*f1-48*x2^2*x4*x6*f2*f5^3*f6+20*x2^2*x5*x6*f7*f2*f3*f4+32*x2^2
*x5*x6*f1*f5*f4*f6+168*x2^2*x5*x6*f0*f7*f4*f5-48*x2^2*x5*x6*f0*f6*f5^2-76*x2^2
*x5*x6*f7*f1*f4^2+224*x2^2*x4*x6*f0*f6*f7*f5^2-48*x2^2*x4*x6*f5^3*f4^2-48*x2^2
*x4*x6*f1^2*f7^3+32*x2^2*x4*x6*f5^3*f7*f1+16*x2^2*x4*x6*f7*f2*f4^2*f6+144*x2^2
*x4*x6*f7*f2*f5^2*f4+40*x2^2*x4*x6*f7^2*f2^2*f5-64*x2^2*x3*x6*f6^2*f4*f5*f1-40
*x2^2*x3*x6*f7*f2*f4*f3*f6+48*x2^2*x3*x6*f1*f7*f3*f5*f6-336*x2^2*x3*x6*f0*f6*
f7*f4*f5+12*x2^3*x6*f5^2*f4^2*f3-16*x2^3*x6*f0*f6*f4^2*f7-16*x2^3*x6*f4^3*f3*
f6-64*x2^2*x1*x6*f0*f6*f4*f3*f7+104*x2^2*x1*x6*f0*f5*f1*f7^2-28*x2^2*x1*x6*f1*
f7*f5^2*f2-40*x2^2*x1*x6*f7*f2*f4^2*f3+16*x2^2*x1*x6*f5^2*f4^2*f2+24*x2^2*x7^2
*f0*f7^2*f5-32*x2^2*x7^2*f7*f3*f4*f5-16*x2^2*x7^2*f7*f6*f1*f5+12*x2^2*x7^2*f3*
f6*f5^2-32*x2^2*x1*x7*f3*f4^3*f6+8*x2^2*x1*x7*f3*f4^2*f5^2-16*x2^2*x1*x7*f7*f4
*f2^2*f6+128*x2^2*x1*x7*f0*f4*f5^2*f7-8*x2^2*x1*x7*f3*f5^2*f6*f2+32*x2^2*x1*x7
*f1*f7*f3*f5^2-112*x2^2*x1*x7*f0*f6*f5*f3*f7+224*x2^2*x1*x7*f0^2*f7^3-96*x2^2*
x1*x7*f0*f6*f4^2*f7+64*x2^2*x1*x7*f1*f7*f3*f6*f4+8*x1^2*x3*x6*f5^2*f4^2*f2+192
*x1^3*x3*f7*f2*f4*f1*f6*f3-68*x1^3*x3*f7*f2*f5*f1*f4^2+32*x1^3*x3*f3*f5^2*f6*
f2^2+20*x1^3*x3*f7*f2^2*f4^3+16*x1^4*f0*f6*f5*f4^2*f2+16*x1^4*f2*f6^2*f1*f3^2-\
32*x1^4*f1*f7*f2^2*f3*f6+24*x1^4*f5*f7*f3*f4*f1^2+16*x1^3*x3*f0*f5*f7^2*f2^2-\
80*x1^3*x3*f0*f5^3*f1*f7-184*x1^2*x3^2*f4*f5^2*f1*f3*f7-8*x1^2*x3^2*f0*f5*f3^2
*f7^2+60*x1^3*x2*f1*f5*f7*f2*f3*f4-32*x1^2*x3^2*f1^2*f7^2*f6*f3-64*x1^2*x3^2*
f6^2*f2*f1*f5^2-16*x1^3*x3*f6^2*f2*f1*f4^2-24*x1^3*x3*f4*f7^2*f1^2*f3+8*x1^3*
x3*f4*f5^2*f3^3-16*x1^3*x3*f7*f3^3*f1*f6-8*x1^3*x3*f3*f7^2*f2^3+92*x1^3*x3*f1^
2*f5^2*f7*f4+48*x1^3*x3*f3*f5*f6*f1*f4^2-48*x1^2*x4*x8*f7^2*f2*f1*f6+24*x1^2*
x4*x8*f7^2*f2^2*f5-12*x1^2*x5*x8*f7^2*f1^2+8*x1^2*x5*x8*f7*f2*f1*f6+72*x1^2*x4
*x8*f7^3*f1^2-16*x1^3*x3*f6^2*f2^2*f3*f4+32*x1^3*x3*f1*f6^3*f2^2+44*x1^3*x3*f7
*f2^2*f5*f3*f4-16*x1^3*x3*f7*f2^3*f5^2-12*x1^3*x3*f5^2*f4^3*f1-40*x1^3*x3*f7*
f2^3*f4*f6+512*x1^3*x3*f6*f5^2*f0^2*f7+88*x1^3*x3*f6*f7^2*f1^3-128*x1^3*x3*f6^
2*f2*f3*f1*f5-64*x1^3*x3*f0^2*f7^3*f2+64*x1^3*x3*f6*f0^2*f7^2*f3-40*x1^3*x2*f6
*f2*f5*f1*f4^2+24*x1^3*x2*f3*f6*f4^3*f1+8*x1^3*x2*f6*f2*f5*f3^3+16*x1^2*x2^2*
f0*f5^3*f4^2-32*x1^4*f0*f6*f5^2*f3*f2+12*x1^4*f6*f4^2*f5*f1^2+8*x1^4*f2*f5^2*
f4^2*f1-128*x1^3*x2*f0*f5^2*f4*f7*f1-8*x1^3*x2*f3^2*f5^2*f2*f4+8*x1^3*x3*f1*f5
^4*f2+64*x1^3*x2*f0^2*f7^3*f1-128*x1^3*x2*f4^2*f0^2*f7^2+4*x1^4*f2*f7*f3^4-160
*x1^3*x3*f6^2*f7*f1^2*f2-24*x1^3*x2*f7*f3^3*f1*f5+64*x1^3*x2*f0*f6^2*f3^2*f4-\
16*x1^3*x2*f0*f5*f4^2*f7*f2-8*x1^3*x2*f5^4*f1^2+80*x1^3*x4*f0*f6*f4^2*f3*f7+96
*x1^3*x4*f4*f5^2*f1*f6*f3+48*x1^4*f0*f5*f1^2*f7^2+16*x1^4*f0*f5^2*f2^2*f7+24*
x1^4*f0*f4^2*f3^2*f7-8*x1^4*f1*f4^3*f6*f2+4*x1^4*f1*f5^2*f4*f3^2-48*x1^4*f6*f5
*f7*f1^3-8*x1^4*f0*f3^3*f5*f7+80*x1^4*f5^2*f4*f7*f0^2-64*x1^4*f0*f6^3*f2*f1-64
*x1^4*f6^2*f5*f4*f0^2+16*x1^4*f0*f6*f5*f4*f3^2-48*x2^2*x7*x1*f3*f5*f7*f2*f4+24
*x2^2*x7*x1*f4^2*f7*f3^2+88*x2^2*x7*x1*f5*f7^2*f1^2+24*x2^2*x7*x1*f1*f3^2*f7^2
+16*x1*x2^2*x7*f0*f6*f5^3-96*x2^2*x7*x1*f0*f4*f3*f7^2-16*x2^2*x7*x1*f2*f6*f3^2
*f7-48*x2^2*x7*x1*f0*f6*f7^2*f1-224*x2^2*x7*x1*f0*f5*f7^2*f2-96*x1*x2^2*x7*f0*
f6^2*f4*f5+60*x1*x2*x3*x7*f7*f4^3*f3+68*x1*x2*x3*x7*f7^2*f2^2*f4+232*x1*x2*x3*
x7*f1^2*f7^2*f6+48*x1*x2*x3*x7*f1*f5*f6^2*f4+152*x1*x2*x3*x7*f7*f3*f5*f1*f6+
256*x3*x4*x1*x2*f1*f5*f7*f6^2*f2+52*x1*x2*x3*x4*f7^2*f3^3*f4-576*x1*x2*x3*x4*
f0*f6^3*f5*f4-56*x1*x2*x3*x4*f2^3*f7^3+72*x1*x2*x3*x4*f5^3*f4^3-176*x2*x1*x3*
x4*f3*f6^2*f7*f1*f4-288*x1*x2^2*x4*f0*f6^2*f5^2*f4+32*x1*x2*x7^2*f3*f7*f4^2-44
*x1*x2*x7^2*f7*f3^2*f5+12*x1*x2*x7^2*f7*f5^2*f1-2*x2^4*f7*f2^2*f4*f5^2-2*x2^4*
f7*f3^2*f4^3-4*x2^3*x1*f3^2*f5*f7*f2*f4-256*x2^2*x1*x4*f0*f6*f5^2*f3*f7-12*x2^
2*x1*x4*f7*f2^2*f5^3+144*x2^2*x1*x4*f1^2*f6*f7^2*f4-152*x2^2*x1*x4*f4^2*f5^2*
f1*f7+104*x2^2*x1*x4*f3*f5*f6*f1*f4*f7+72*x2^2*x1*x4*f3^2*f6*f5^2*f4-248*x2^2*
x1*x4*f7^2*f3*f4^2*f1+112*x2^2*x1*x4*f7*f2*f4^2*f3*f6+32*x2^2*x1*x4*f7^2*f3^2*
f1*f5+352*x2^2*x1*x4*f0*f4^3*f7^2-68*x2^2*x1*x4*f7^3*f2^2*f1-272*x2^2*x1*x4*f0
*f6*f5*f1*f7^2-144*x2^2*x1*x4*f7*f2^2*f4*f6*f5+24*x2^2*x1*x4*f6*f2*f5^2*f4^2+
40*x2^2*x1*x4*f1*f6*f7^2*f2*f3-40*x2^2*x1*x4*f7*f3^2*f6*f2*f5-80*x2^2*x1*x4*f0
*f5*f4*f3*f7^2-24*x2^2*x1*x4*f3*f5^3*f6*f2+40*x2^2*x1*x4*f3^3*f5^2*f7-96*x2^2*
x1*x4*f6*f4^3*f5*f3+8*x2^2*x1*x4*f3^3*f6*f7*f4-160*x2^3*x4*f0*f6*f4*f5^2*f7+12
*x2^3*x4*f1^2*f7^3*f4-24*x2^3*x4*f7^3*f2^3-48*x2^3*x4*f6*f4*f5*f7*f2*f3+320*x2
^2*x4*x6*f7^2*f1*f4^2+48*x2^2*x4*x6*f7*f2*f3*f5*f6-296*x2^2*x4*x6*f4*f7*f6*f1*
f5+44*x2^2*x5^2*f0*f4^2*f7+48*x2^2*x1*x5*f7*f0*f6*f1*f5-16*x2^2*x1*x5*f0*f6*f5
*f4^2+20*x2^2*x1*x5*f7*f2^2*f4^2+8*x2^2*x1*x5*f7^2*f3*f1^2+12*x2^2*x1*x5*f3^2*
f5*f4^2-24*x2^2*x1*x5*f2*f5^2*f6*f1+32*x2^2*x1*x5*f2^2*f5*f4*f6-68*x2^2*x1*x5*
f2*f5*f7*f1*f4-32*x2^2*x1*x5*f2*f3*f6*f4^2-32*x2^2*x1*x5*f0*f7*f5^2*f2+44*x2^2
*x1*x5*f1^2*f7*f5^2-16*x2^2*x1*x5*f7*f2*f0*f4*f6+16*x2^2*x1*x5*f1*f6*f4^3-256*
x2^2*x1*x5*f7^2*f0^2*f5-104*x2^2*x1*x5*f0*f4^3*f7+48*x2^2*x1*x5*f1*f7*f3*f4^2-\
24*x2^2*x1*x5*f1^2*f6*f7*f4-64*x2^2*x1*x5*f7^2*f0*f2*f3-48*x2^2*x4^2*f0*f6^2*
f3*f7^2-236*x2^2*x4^2*f7*f4*f5^3*f3+168*x2^2*x4^2*f7^4*f0*f1+40*x2^2*x4^2*f7^2
*f1*f3*f5*f6-16*x2^2*x4^2*f7*f3*f5*f4^2*f6+108*x2^2*x4^2*f3*f5^4*f6+52*x2^2*x4
^2*f7^3*f2^2*f4-264*x2^2*x4^2*f7*f5^3*f6*f1+24*x2^2*x4^2*f7^2*f2*f4*f3*f6-664*
x2^2*x4^2*f7^2*f0*f6*f4*f5-176*x2^2*x4^2*f7^2*f4*f5^2*f1-2*x2^2*x4^2*f7^2*f3^2
*f5*f4+80*x2^2*x3^2*f6^2*f2*f5*f4^2-4*x2^2*x3^2*f5*f4^3*f7*f3-44*x2^2*x3^2*f1^
2*f6*f7^2*f5+80*x2^2*x3^2*f0*f5^2*f3*f7^2+48*x2^2*x3^2*f0*f5^4*f7+32*x2^2*x3^2
*f1*f6^2*f7*f2*f5-24*x2^2*x3^2*f6^2*f4*f7*f2^2-28*x2^2*x3^2*f5^2*f7*f3^2*f4+24
*x2^2*x3^2*f0*f4*f2*f7^3-16*x2^2*x3^2*f1*f6*f5^4-16*x2^4*f0*f6*f5^3*f4+4*x2^4*
f7^2*f2^2*f4*f3-20*x2^4*f5*f4^3*f1*f7+4*x2^4*f0*f5*f3^2*f7^2+8*x2^4*f0*f5^3*f3
*f7-8*x2^4*f3*f6*f4^2*f1*f7-16*x2^4*f6*f5*f0^2*f7^2-8*x2^4*f3*f5^2*f1*f4*f7+4*
x2^4*f3*f4^4*f6+36*x2^4*f0*f5^2*f4^2*f7+8*x2^4*f0*f6*f4^3*f7+64*x1*x2*x3*x5*f6
^2*f4*f2^2-8*x1*x2*x3*x5*f2^2*f6*f7*f3-8*x1*x2*x3*x5*f7*f3^2*f2*f5+72*x1*x2*x3
*x5*f5*f4^2*f1*f6-336*x1*x2*x3*x5*f0*f5*f4^2*f7+136*x1*x2*x3*x5*f1^2*f7*f5*f6+
24*x1*x2*x3*x5*f2^3*f7^2-64*x1*x2^2*x3*f0*f6^2*f5*f4^2+12*x1*x2^2*x3*f7^2*f3*
f4*f2^2-32*x1^2*x2*x5*f2*f0*f6^2*f4+224*x1^2*x2*x5*f4*f0^2*f7^2+24*x1^2*x2*x5*
f1^2*f5*f7*f4+16*x1^2*x2*x5*f1*f5^2*f7*f0-288*x1^2*x2*x5*f0^2*f6*f7*f5+32*x1*
x2*x6^2*f3*f5*f6*f2-40*x1*x2*x6^2*f0*f5*f7*f4-72*x1*x2*x6^2*f1*f7*f4^2+16*x4*
x5*x1*x2*f3*f7^2*f2^2+4*x1*x2*x4*x7*f7*f4^4+8*x1*x2*x5*x7*f1*f5^3-4*x1*x2^2*x6
*f2^3*f7^2-16*x1^2*x2*x4*f2*f6^2*f7*f1*f3-16*x1*x2*x7^2*f6^2*f1*f5-88*x1*x2*x7
^2*f1*f7^2*f3-28*x1*x2*x7^2*f7*f2*f5*f4-16*x1^2*x2*x7*f6^2*f4*f2^2-48*x1^2*x2*
x7*f2*f6*f7*f1*f4-96*x1^2*x2*x7*f0*f6^2*f5*f3+36*x1^2*x2*x7*f7*f4*f3^3+56*x1^2
*x2*x3*f3^2*f5^2*f2*f6+48*x1^2*x2*x3*f7*f3^3*f4^2+28*x1^2*x2*x3*f5^2*f4^2*f3^2
-8*x1^2*x2^2*f0*f7^2*f3^3+64*x3^2*x1*x2*f0*f5^3*f4*f7+32*x1^2*x2^2*f6^2*f5*f1^
2*f4+20*x1^2*x2^2*f6*f7^2*f1^3+16*x1*x2*x5*x6*f2*f5^2*f3-24*x1*x2*x5*x6*f3^2*
f4*f5+8*x1*x2*x5*x6*f4*f5^2*f1+8*x1*x2*x5*x6*f4^2*f5*f2+8*x1*x2*x5^2*f2*f3*f5*
f4-16*x1*x2*x3*x5*f5^2*f4^2*f2-16*x1*x2*x3*x5*f3*f5^3*f2-20*x1*x2*x3^2*f4*f5^4
*f2+56*x1*x2*x3^2*f4^2*f5^3*f3-4*x1^2*x2*x3*f7*f3^4*f5+4*x1^2*x2*x3*f5*f4^4*f3
+4*x1^2*x2*x3*f7^2*f3^3*f1+48*x3^2*x1*x2*f7*f3^2*f5*f4^2-4*x1^2*x2*x3*f5^4*f2^
2-24*x1*x2^2*x3*f7*f2*f5*f4^2*f3+32*x1*x2^2*x3*f1*f6^2*f4^3+16*x1^3*x3*f7*f3^4
*f4-8*x1^3*x3*f4^2*f6*f3^3-96*x1^2*x2^2*f0*f4*f3*f7^2*f2+96*x1^2*x2^2*f0*f6*f4
^2*f2*f7-20*x1^2*x3^2*f3*f5^4*f2+48*x1^2*x3^2*f0*f2^2*f7^3+128*x1^3*x2*f0*f6*
f5*f2^2*f7-48*x1^3*x2*f0*f6*f5*f4^2*f3+20*x1^4*f2*f5*f1*f7*f3^2+16*x2^3*x4*f0*
f6*f4*f3*f7^2+80*x2^3*x4*f0*f5*f1*f7^3-16*x2^3*x4*f5*f4^3*f7*f3-112*x2^3*x4*f1
*f7^2*f4^3-24*x2^3*x4*f1*f6*f5^4+20*x2^3*x4*f7^2*f2*f4^2*f3-16*x2^3*x4*f1*f6*
f7^2*f3^2-32*x2^3*x4*f7*f2*f5^3*f3+92*x2^3*x4*f7^2*f3*f5*f1*f4+8*x2^3*x4*f7*f3
^2*f4^2*f6+8*x2^3*x4*f7^2*f3^3*f4+8*x2^3*x4*f3*f5^2*f6*f7*f1-8*x2^3*x4*f7^2*f2
*f5*f3^2+48*x2^3*x4*f1*f7^3*f2*f3-8*x2^3*x4*f7*f2*f4^3*f6+136*x2^3*x4*f1*f5*f7
*f4^2*f6+112*x2^3*x4*f0*f5*f4^2*f7^2-16*x2^3*x4*f4*f5^3*f7*f1-64*x2^3*x4*f5^2*
f4^2*f2*f7-224*x2^3*x4*f0*f5^2*f3*f7^2-16*x2^3*x4*f7^2*f2^2*f4*f5+64*x2^3*x4*
f0*f5^4*f7+60*x2^3*x4*f1*f7^2*f5^2*f2+48*x2^3*x4*f5^2*f7*f3^2*f4+16*x2^3*x4*f0
*f6*f5*f7^2*f2+48*x2^3*x4*f4*f5^3*f6*f2+40*x2^2*x3*x4*f5*f4^4*f7+236*x2^2*x3*
x4*f7^3*f2*f1*f4+32*x2^2*x3*x4*f0*f6*f5*f3*f7^2+448*x2^2*x3*x4*f0^2*f7^4+60*x2
^2*x3*x4*f5^4*f4^2+48*x2^2*x3*x4*f6*f2*f5^4-144*x2^2*x3*x4*f1*f6^2*f5^3+64*x2^
2*x3*x4*f7^2*f2*f3*f5*f4-272*x2^2*x3*x4*f0*f5*f2*f7^3-336*x2^2*x3*x4*f0*f4*f3*
f7^3+32*x2^2*x3*x4*f7*f3^2*f5^3-8*x2^2*x3*x4*f7^2*f3^2*f6*f2-356*x2^2*x3*x4*f1
*f7^2*f5*f4^2-832*x2^2*x3*x4*f0*f6^2*f5*f4*f7+32*x2^2*x3*x4*f7^2*f2^2*f5^2+68*
x2^2*x3*x4*f7^2*f3^2*f4^2-20*x2^2*x3*x4*f1^2*f5*f7^3+32*x1^3*x5*f0*f5^2*f3*f4-\
12*x1^3*x5*f1^3*f7^2-16*x1^3*x5*f0*f6*f5*f3^2+32*x1^3*x5*f3^2*f1*f4*f6+16*x1^3
*x5*f1*f6*f5^2*f0+32*x1^3*x5*f0*f6^2*f2*f3-8*x1^3*x5*f2*f3^2*f4*f5+48*x1^3*x5*
f1*f4*f0*f7*f5-48*x1^3*x5*f1*f6*f0*f7*f3-12*x1^3*x5*f2*f5^2*f1*f4+8*x1^3*x5*f2
*f4^2*f1*f6-192*x1^3*x4*f0*f6^3*f1*f5-16*x1^3*x4*f7^2*f3^2*f2^2-104*x1^3*x4*f1
*f4*f6*f7*f3^2-48*x1^2*x2*x4*f4*f5^2*f2*f3*f6-464*x1^2*x2*x4*f0*f5*f3^2*f7^2+
120*x1^2*x2*x4*f1^2*f7^2*f6*f3-96*x1^2*x2*x4*f0*f6*f4*f1*f7^2+280*x1^2*x2*x4*
f1^2*f5^2*f7*f6-32*x2^2*x3^2*f7*f2*f4^3*f6+16*x2^3*x1*f0*f5^3*f2*f7-8*x2^3*x1*
f3^2*f5^2*f1*f7-20*x2^3*x1*f7*f1*f4^4-96*x2^2*x3^2*f7^2*f3*f5*f1*f4+8*x2^3*x1*
f3*f4^3*f7*f2-4*x2^4*f5^2*f4^3*f3+8*x2^4*f0*f5*f4*f2*f7^2+8*x2^3*x1*f1*f6*f5*
f7*f2*f3-8*x2^3*x1*f3^2*f6*f1*f7*f4-48*x2^2*x3^2*f0*f6*f5*f2*f7^2-104*x2^2*x1*
x3*f3*f6*f4^2*f1*f7-112*x2^2*x1*x3*f0*f6*f4*f1*f7^2+48*x2^2*x1*x3*f1*f6^2*f5^2
*f2+48*x2^2*x1*x3*f6^2*f7*f4*f1^2+448*x2^2*x1*x3*f6*f5*f0^2*f7^2-16*x2^2*x1*x3
*f7^2*f3^2*f1*f4+88*x2^2*x1*x3*f3*f6*f4*f5^2*f2-4*x2^2*x1*x3*f7*f2*f4^4-32*x2^
2*x1*x3*f3^2*f6*f1*f5*f7-224*x2^2*x1*x3*f0*f5*f4*f2*f7^2-56*x2^2*x1*x3*f2^2*f6
*f7^2*f1-32*x2^2*x1*x3*f0*f5^3*f3*f7-64*x2^2*x1*x3*f6^2*f2^2*f5*f4+20*x1^3*x2*
f1*f5^3*f2*f4-8*x1^3*x2*f3*f6*f1^2*f7*f4-16*x1^3*x2*f0*f5^3*f3*f4-80*x1^2*x3^2
*f0*f5^3*f3*f7+48*x1^3*x2*f0*f3^2*f7^2*f2-16*x1^3*x2*f1*f6*f0*f5^3+8*x1^3*x2*
f3^2*f4^2*f6*f2+16*x1^4*f6^2*f1*f4*f2^2-52*x1^2*x2^2*f7*f3*f4^3*f1+144*x1^2*x2
^2*f0*f5*f7^2*f2^2+64*x1^3*x7*f1*f6*f5*f0*f7+128*x1^3*x7*f0*f5*f4*f3*f7-8*x1^3
*x7*f4*f5^2*f2*f3-8*x1^3*x7*f3*f6*f2*f4^2-8*x1^3*x7*f2^2*f5*f4*f6+16*x1^3*x7*
f3^2*f6^2*f1+16*x1^3*x7*f7*f2^2*f4^2+24*x1^3*x7*f3^2*f6*f2*f5+64*x1^3*x7*f1*f7
*f2*f3*f6-48*x1^3*x7*f0*f6*f5*f4^2-48*x1^3*x7*f0*f6*f5^2*f3-8*x1^2*x2*x8*f5*f7
*f2*f1*f6+12*x1^2*x2*x8*f5*f7^2*f1^2+24*x1^2*x3*x8*f6*f7^2*f1^2-16*x1^2*x3*x8*
f6^2*f7*f2*f1+8*x1^2*x3*x8*f6*f7*f2^2*f5-200*x1^2*x4*x7*f7*f2*f5^2*f3-8*x1^2*
x4*x7*f7^2*f3*f4*f1-8*x1^2*x4*x7*f7*f2^2*f6*f5+288*x1^2*x4*x7*f7^2*f1^2*f6+84*
x1^2*x4*x7*f7^2*f2^2*f4-40*x1^2*x4*x7*f7*f2*f5*f4^2+120*x1^2*x4*x7*f7*f5^2*f1*
f4-16*x1^2*x3*x7*f2^2*f6^2*f5+176*x1^2*x3*x7*f0*f6*f4^2*f7+48*x1^2*x3*x5*f3*f5
*f1*f4*f6+16*x1^2*x3*x5*f3*f6*f2*f4^2-48*x1^2*x4*x5*f3*f5^2*f1*f6-32*x1^2*x4*
x5*f7*f2*f1*f4*f6+208*x1^2*x4*x5*f0*f3^2*f7^2+192*x1^2*x4*x5*f0*f6*f5^2*f4+112
*x1^2*x4*x5*f7*f2*f5^2*f1+160*x1^2*x4*x5*f0*f6^2*f1*f7+48*x1^2*x4*x5*f7*f2*f3^
2*f5-24*x1^2*x2*x5*f7*f1*f2^2*f6+56*x1^2*x2*x5*f7*f0*f5*f2*f4-36*x1^2*x2*x5*f7
*f2*f5*f3*f1+48*x1^2*x2*x5*f7*f0*f5*f3^2-32*x1^2*x4^2*f7*f0*f6*f5^2*f4+132*x1^
2*x4^2*f7*f4*f5^3*f1-288*x1^2*x4^2*f7*f0*f5^4-40*x1^2*x4^2*f7*f5^2*f4^2*f2-56*
x1^3*x4*f7*f2^3*f5*f6+4*x1^3*x3*f5*f4^4*f2-4*x1^2*x2*x4*f7*f4^4*f2-36*x1^2*x3*
x4*f2*f7^2*f3^2*f4+4*x1^2*x2*x4*f5*f4^3*f1*f7+132*x1^2*x2*x4*f7*f4*f5^2*f2^2-4
*x1^2*x6^2*f5^2*f1*f4-10*x1^2*x6^2*f7*f2^2*f4+4*x1^3*x6*f7*f2*f1*f4^2-4*x1^3*
x6*f5*f4^2*f2*f3+4*x1^2*x4*x6*f7*f4^3*f2+64*x1^4*f7^3*f0^3-56*x1^2*x3*x7*f1^2*
f7^2*f5+40*x1^2*x3*x7*f1*f7^2*f3^2+192*x1^2*x3*x7*f1^2*f7*f6^2-8*x1^2*x2*x7*f3
^2*f6*f7*f1-16*x1^2*x2*x7*f3*f5*f4*f6*f2-112*x1^2*x2*x7*f0*f3^2*f7^2+32*x1^2*
x2*x7*f0*f5^4+320*x1^2*x2*x7*f6*f0^2*f7^2+168*x1^2*x2*x7*f7^2*f2*f1*f3-60*x1^3
*x7*f7*f3^2*f5*f1+4*x2^2*x6^2*f5^3*f2-272*x1^2*x4^2*f7*f2*f5^3*f3+268*x1^2*x4^
2*f7^3*f2*f1*f3-1088*x1^2*x4^2*f7^2*f0*f6*f5*f2-472*x1^2*x4^2*f7^3*f1*f5*f0-\
156*x1^2*x4^2*f7^2*f3*f4*f1*f5-32*x1^2*x4^2*f7*f2^2*f5^2*f6+496*x1^2*x4^2*f7^3
*f0*f4*f2+1024*x1^2*x4^2*f7^2*f0*f5^2*f3-346*x1^2*x4^2*f7^3*f1^2*f4-16*x1^2*x4
^2*f7^2*f4^3*f1+60*x1^2*x4^2*f7^2*f3*f4^2*f2-64*x1^2*x4^2*f7^2*f0*f5*f4^2+320*
x1^2*x4^2*f7^3*f6*f0^2-200*x1^2*x4^2*f7^3*f0*f3^2+608*x1^2*x4^2*f7^2*f0*f6*f4*
f3-244*x1^2*x4^2*f7^2*f2*f5^2*f1-64*x1^2*x4^2*f7^2*f0*f6^2*f1+246*x1^2*x4^2*f7
^2*f2^2*f5*f4-32*x2^2*x3*x4*f7*f3*f6*f4^3-216*x2^2*x3*x4*f1*f7^2*f3*f6*f4-48*
x2^2*x3*x4*f1*f6*f0*f7^3-8*x2^2*x3*x4*f7^2*f4*f2^2*f6-192*x2^2*x3*x4*f3*f5^2*
f6*f2*f7-128*x2^2*x3*x4*f7*f3*f4^2*f5^2+32*x2^2*x3*x4*f1*f6^2*f7*f3*f5+320*x2^
2*x3*x4*f0*f4*f5^2*f7^2-48*x2^2*x3*x4*f7^3*f2^2*f3-24*x2^2*x3*x4*f1*f5^4*f7+
144*x2^2*x3*x4*f1*f7^2*f6*f2*f5-92*x2^2*x3*x4*f7^2*f2*f4^3+32*x2^2*x3*x4*f6*f7
*f3^2*f5*f4+80*x2^2*x3*x4*f1*f7^2*f3*f5^2+192*x2^2*x3*x4*f6^2*f4*f5^2*f2+352*
x2^2*x3*x4*f0*f6*f5^3*f7+96*x2^2*x3*x4*f7*f2*f5*f4^2*f6+96*x2^2*x3*x4*f1*f5^2*
f7*f4*f6+832*x2^2*x3*x4*f0*f6*f4^2*f7^2-184*x2^2*x3*x4*f4*f5^3*f2*f7-64*x2^3*
x4*f0*f4*f2*f7^3-32*x2^3*x4*f0*f3^2*f7^3+8*x2^3*x4*f7^2*f2^2*f6*f3-16*x2^3*x4*
f1^2*f6*f7^2*f5+16*x2^3*x4*f7^2*f2*f6*f1*f4+12*x2^3*x4*f4^3*f5^3-432*x2^2*x1*
x4*f0*f5^2*f2*f7^2-192*x2^2*x1*x4*f0*f6*f5*f4^2*f7+336*x2^2*x1*x4*f0*f5^3*f7*
f4+32*x2^2*x1*x4*f3*f5^3*f7*f1-32*x2^2*x1*x4*f0*f6*f3^2*f7^2+12*x2^2*x1*x4*f3^
2*f7^2*f2*f4+100*x2^2*x1*x4*f5^2*f7^2*f1^2-72*x2^2*x1*x4*f1*f6*f7*f4^3+280*x2^
2*x1*x4*f7^2*f2*f5*f1*f4-352*x2^2*x1*x4*f0*f4*f1*f7^3-48*x2^2*x5^2*f0*f6*f4*f5
+8*x2^3*x5*f7*f2^2*f4*f5-24*x2^3*x5*f0*f5*f1*f7^2-16*x2^3*x5*f0*f5^2*f3*f7+32*
x2^3*x5*f6*f0^2*f7^2-16*x2^3*x5*f0*f6*f4*f3*f7-8*x2^3*x5*f0*f4*f7^2*f2-16*x2^3
*x5*f0*f5^4+16*x2^3*x7*f2*f5^2*f4*f6-8*x2^3*x7*f5^3*f6*f1-96*x2^3*x7*f0*f7^2*
f4^2-36*x2^3*x7*f7*f2*f5*f4^2+28*x2^3*x7*f1*f7^2*f2*f5-12*x2^3*x7*f7*f2*f5^2*
f3-128*x2^3*x7*f0*f7^2*f5*f3+32*x2^3*x7*f4^2*f6*f1*f7+20*x2^3*x7*f7*f3^2*f5*f4
+12*x2^2*x3*x7*f7*f4^4-32*x2^2*x3*x7*f0*f7^3*f2+44*x2^2*x3*x7*f7^2*f2*f3*f4+72
*x2^2*x3*x7*f7^2*f2*f1*f6-92*x2^2*x3*x7*f7*f2*f5^2*f4-208*x2^2*x3*x7*f0*f7^2*
f4*f5+16*x2^2*x3*x7*f6*f5^3*f2+24*x2^2*x3*x7*f7^2*f2^2*f5-208*x2^2*x3*x7*f0*f7
^2*f6*f3+16*x2^2*x3*x7*f7*f3^2*f6*f4+48*x2^2*x3*x7*f0*f6*f5^2*f7+44*x2^2*x3*x7
*f1*f5*f7^2*f3-48*x2^2*x3*x7*f5^2*f6^2*f1-64*x2^2*x3*x7*f0*f6^2*f7*f4-24*x2^2*
x3*x7*f7^2*f1*f4^2-64*x2^2*x4*x7*f7^2*f2*f4^2-80*x2^2*x4*x7*f7^2*f1*f4*f5-304*
x2^2*x4*x7*f0*f7^3*f3-128*x2^2*x4*x7*f7*f5^2*f6*f1+104*x2^2*x4*x7*f7^3*f2*f1+
96*x2^2*x4*x7*f7*f2*f5*f4*f6+12*x2^2*x4*x7*f7^2*f3^2*f4+8*x2^2*x4*x7*f7*f2*f5^
3+72*x2^2*x4*x7*f3*f5^3*f6-8*x2^2*x4*x7*f7^2*f1*f3*f6+104*x2^2*x1*x6*f7*f2*f6*
f1*f4-80*x2^3*x6*f0*f4*f5^2*f7-8*x2^3*x6*f4*f5^3*f2+68*x2^3*x6*f1*f7*f5*f4^2+8
*x2^3*x6*f7*f3^2*f4^2-16*x2^3*x6*f0*f6*f5*f3*f7+12*x2^3*x6*f1^2*f5*f7^2+48*x2^
3*x6*f0*f4*f3*f7^2-12*x2^3*x6*f7*f2*f3*f5*f4+16*x2^3*x6*f1*f7*f3*f6*f4-16*x2^3
*x6*f1*f5^2*f4*f6+16*x2^3*x6*f0*f6*f5^3-96*x2^3*x6*f0^2*f7^3-8*x2^3*x6*f5*f4^4
-28*x2^3*x6*f7^2*f2*f1*f4+8*x2^3*x6*f1*f7*f3*f5^2-40*x2^2*x3*x6*f4^3*f5^2-96*
x2^2*x3*x6*f0*f5^3*f7+24*x2^2*x3*x6*f7*f2^2*f6*f5-8*x2^2*x3*x6*f5^4*f2+148*x2^
2*x3*x6*f7*f4*f5^2*f1+28*x2^2*x3*x6*f7*f3^2*f5*f4-16*x2^2*x3*x6*f0*f4^2*f7^2+8
*x2^2*x3*x6*f5^3*f6*f1-32*x2^2*x3*x6*f0*f7^2*f5*f3-16*x2^2*x3*x6*f1*f7^2*f2*f5
+120*x2^2*x3*x6*f4^2*f6*f1*f7-48*x2^2*x3*x6*f2*f5^2*f4*f6-28*x2^2*x3*x6*f2^2*
f7^2*f4-16*x2^2*x3*x6*f7*f3*f4^3+96*x2^2*x3*x6*f0*f6^2*f5^2-8*x2^2*x3*x6*f1^2*
f7^2*f6+72*x2^2*x3*x6*f1*f7^2*f3*f4-12*x2^2*x3*x6*f7*f2*f5^2*f3+112*x2^2*x4*x6
*f0*f7^3*f2-16*x2^2*x4*x6*f7*f3^2*f6*f4-288*x2^2*x4*x6*f0*f7^2*f4*f5+16*x2^2*
x4*x6*f0*f7^2*f6*f3-40*x2^2*x4*x6*f7*f3^2*f5^2-96*x1*x2*x4*x7*f5^2*f6^2*f1+24*
x1*x2*x4*x7*f5^4*f3-184*x1*x2*x4*x7*f7^2*f2*f3*f4-336*x1*x2*x4*x7*f7^2*f5*f1*
f3-672*x1*x2*x4*x7*f2*f0*f7^3+56*x1*x2*x4*x7*f3^2*f7*f6*f4+8*x1*x2*x3*x7*f7^2*
f2*f1*f5+8*x1*x2*x3*x7*f7*f3^3*f6+48*x1*x2*x3*x7*f3^2*f6^2*f4-192*x1*x2*x3*x7*
f0*f6^2*f3*f7-80*x1*x2*x3*x5*f3*f5*f6*f2*f4+80*x1*x2*x3*x5*f1*f7*f3*f5*f4-32*
x1*x2*x3*x5*f4^3*f2*f6-24*x1*x2*x3*x5*f3^2*f6*f4^2+32*x1*x2*x3*x5*f2^2*f5^2*f6
-96*x1*x2*x3*x5*f6^2*f2*f5*f1+16*x1*x2*x3*x5*f7*f2^2*f4*f5+12*x1*x2*x3*x5*f7^2
*f2*f1*f3-64*x1*x2*x3*x5*f7*f2*f1*f5^2+16*x1*x2*x3*x5*f3^2*f7*f1*f6+60*x1*x2*
x3*x5*f7*f3*f4^2*f2+32*x1*x2*x3*x5*f0*f5^4+24*x1*x2*x4*x5*f5^4*f1+288*x1*x2*x4
*x5*f0*f6^2*f5*f4-128*x4*x5*x1*x2*f1*f6*f5*f7*f2-132*x4*x5*x1*x2*f5*f7^2*f1^2+
32*x4*x5*x1*x2*f4^2*f7*f1*f5+48*x4*x5*x1*x2*f3*f5^2*f7*f1-44*x4*x5*x1*x2*f2^2*
f5^2*f7-112*x4*x5*x1*x2*f0*f6*f4^2*f7+8*x1*x2^2*x5*f0*f5^3*f4-496*x4^2*x1*x2*
f3*f5^2*f1*f7^2-104*x4^2*x1*x2*f7^2*f2^2*f4*f6-336*x4^2*x1*x2*f0*f6*f5*f7^2*f3
-404*x4^2*x1*x2*f7^2*f2*f4*f3*f5+864*x1*x2*x4^2*f0*f5^2*f4*f7^2+176*x1*x2*x4^2
*f7*f3^2*f5*f6*f4+232*x1*x2*x4^2*f7*f2*f5*f4^2*f6+128*x1*x2*x4^2*f0*f6*f5^3*f7
+4*x1*x2^2*x3*f5*f4^5+8*x1*x2*x3*x4*f7*f4^5+4*x1^2*x2*x6*f5^3*f2^2+24*x1*x2*x3
*x7*f5^2*f4^3-32*x1*x2*x3*x7*f4^4*f6-16*x1*x2^2*x7*f6*f5^2*f1*f4-40*x1^2*x2*x7
*f3^2*f6*f4^2-960*x1*x2*x4^2*f0*f6^2*f4*f5*f7+220*x4^2*x1*x2*f7^3*f2*f4*f1-16*
x4^2*x1*x2*f0*f6*f7^3*f1-144*x1*x2*x4^2*f6^2*f5^3*f1-8*x1*x2*x4^2*f7^2*f2*f4^3
+92*x1*x2*x4^2*f5^4*f1*f7+208*x4^2*x1*x2*f0*f6*f4^2*f7^2-24*x4^2*x1*x2*f5*f4^2
*f1*f7^2+96*x1^2*x2*x3*f0*f6^2*f5*f4*f3+16*x1^2*x2*x3*f1^2*f5^3*f7-12*x1^2*x2*
x3*f3^3*f5^3-16*x1*x2*x3^2*f6^2*f7*f3^2*f1-256*x1*x2*x3^2*f0*f6*f4*f2*f7^2-68*
x1*x2*x3*x7*f4*f5^2*f1*f7-16*x1*x2*x3*x7*f1*f7*f4^2*f6+48*x1*x2*x4*x7*f5^3*f4^
2+472*x1*x2*x4*x7*f1^2*f7^3+432*x1*x2*x4*x7*f3*f5*f6*f2*f7+16*x1*x2*x4*x7*f3*
f6^2*f1*f7+156*x1*x2*x4*x7*f5*f4^2*f7*f3-232*x1*x2*x4*x7*f7*f3^2*f5^2+16*x1*x2
*x4*x7*f7^2*f3^3-256*x1*x2*x4*x7*f0*f6*f3*f7^2-48*x1*x2*x4*x7*f7^2*f2*f1*f6+
208*x1*x2*x4*x7*f0*f5*f4*f7^2-320*x1*x2*x4*x7*f0*f6^2*f4*f7+48*x1*x2*x4*x7*f0*
f6*f5^2*f7-12*x1^2*x2*x5*f4*f5^2*f1*f3-36*x1^2*x2*x5*f4^2*f2*f7*f1+8*x1^2*x2*
x5*f2^2*f5^2*f4+16*x1^2*x2*x5*f4^2*f6*f2^2-8*x1^2*x2*x5*f0*f5^2*f4^2-40*x1^2*
x2*x5*f3^2*f4*f6*f2+12*x1^2*x2*x5*f3^3*f5*f4-12*x1^2*x2*x5*f3*f5*f4^2*f2+32*x1
^2*x2*x5*f3^2*f1*f5*f6-8*x1^2*x2*x5*f3^2*f2*f5^2+48*x1^2*x2*x5*f3*f0*f5^3-48*
x1^2*x2*x5*f3*f0*f5*f6*f4-32*x1^2*x2*x5*f0*f6*f5^2*f2-2*x1^2*x2^2*f5^2*f7*f1^2
*f4+400*x1*x2*x4*x6*f1*f0*f7^3-352*x1*x2*x4*x6*f0*f5^3*f7-736*x1*x2*x4*x6*f0*
f4^2*f7^2+68*x1*x2*x4*x6*f7^2*f2^2*f4+112*x3*x6*x1*x2*f0*f6*f7^2*f1+32*x3*x6*
x1*x2*f0*f5*f7^2*f2-272*x3*x6*x1*x2*f0*f6*f4^2*f7+256*x3*x6*x1*x2*f0^2*f7^3+96
*x1*x2*x3*x6*f0*f6^2*f4*f5-16*x1*x2*x7^2*f4^3*f6+64*x1^2*x2*x3*f6^3*f0*f4*f2-\
128*x1^2*x2*x3*f0*f6^3*f5*f1+192*x1*x2*x3^2*f1^2*f6*f7^2*f4-80*x1*x2*x3^2*f3*
f6^2*f1*f5^2+10*x1^2*x2^2*f5*f4^3*f3^2+16*x1^2*x2^2*f0*f6*f5^3*f2+80*x1^2*x2*
x3*f3^2*f6^2*f4*f2-512*x1*x2*x3*x7*f0*f6*f2*f7^2-192*x1*x2*x3*x7*f0*f6^3*f4+96
*x1*x2*x3*x7*f2*f6^2*f4^2+96*x1*x2*x3*x7*f1*f0*f7^3+160*x1*x2*x3*x7*f0*f5^3*f7
-64*x1*x2*x3*x7*f0*f4^2*f7^2-32*x1*x2*x3*x7*f0*f6*f5*f4*f7-48*x1*x2*x3*x7*f7*
f2*f5^2*f3-88*x1*x2*x3*x7*f7^2*f3*f4*f1-24*x1*x2*x3*x7*f6*f5^3*f1+36*x1*x2*x3*
x7*f3*f5^3*f4-72*x1*x2*x3*x7*f7*f4^2*f5*f2+16*x1*x2*x3*x7*f2*f6^2*f7*f1-60*x1*
x2*x6*x7*f3^2*f7*f4+64*x1*x2*x6*x7*f4^2*f6*f3-88*x1*x2*x6*x7*f3*f7*f1*f6+96*x1
*x2*x5*x7*f0*f6^2*f4-32*x1*x2*x5*x7*f4^2*f2*f6+24*x1*x2*x5*x7*f4*f6*f1*f5+4*x1
*x2*x5*x7*f1*f7*f4^2-152*x1*x2*x5*x7*f1^2*f7^2+56*x1*x2*x5*x7*f7*f2*f3*f4-28*
x1*x2*x5*x7*f7*f5*f1*f3-6*x1^2*x2^2*f5^3*f2^2*f4+4*x1^2*x2^2*f3*f2^3*f7^2+16*
x1*x2*x4*x8*f7^2*f2*f3*f5-48*x1*x2*x4*x8*f7*f5^2*f6*f1-32*x1*x2*x4*x8*f7^2*f6*
f1*f3-96*x1*x2*x4*x8*f7^2*f1*f4*f5-24*x1*x2*x3*x8*f7^2*f5*f1*f3+12*x1*x2*x3*x8
*f7*f5^2*f2*f4-16*x1*x2*x3*x8*f7*f0*f6*f5^2-8*x1*x2*x3*x8*f7*f4*f6*f1*f5-16*x1
*x2^2*x8*f7*f0*f6*f5*f4-12*x1*x2^2*x8*f7^2*f3*f4*f1+12*x1*x2^2*x8*f7^2*f2*f1*
f5+16*x1*x2*x3^2*f3*f6^2*f7*f2^2-200*x3^2*x1*x2*f3*f6*f4*f7*f1*f5+336*x3*x4*x1
*x2*f0*f6*f4*f3*f7^2-896*x3*x4*x1*x2*f0*f6*f5*f7^2*f2-200*x3*x4*x1*x2*f1*f6*f4
^2*f7*f5-64*x1*x2*x3*x4*f7*f3^2*f4*f5^2+156*x1*x2*x3*x4*f7^2*f2^2*f4*f5-40*x1*
x2*x3*x4*f7*f3*f5^3*f2-12*x1*x2*x3*x4*f1*f7^2*f4^3+320*x1*x2*x3*x4*f0*f5^4*f7+
880*x1*x2*x3*x4*f0*f5*f4^2*f7^2-144*x1*x2*x4^2*f5^2*f4^3*f6-288*x1*x2*x4^2*f3^
2*f5^3*f7+144*x1*x2*x3*x4*f5*f4*f6^2*f3^2+320*x3*x4*x1*x2*f3*f6*f4*f7*f2*f5+96
*x1*x2*x3*x4*f0*f5^2*f3*f7^2-208*x1*x2*x3*x4*f5^2*f4^2*f7*f2+96*x1*x2*x3*x4*f0
*f6*f5^2*f4*f7-288*x3*x4*x1*x2*f0*f6^2*f7^2*f1+376*x3*x4*x1*x2*f7^2*f2*f4*f1*
f6-352*x3*x4*x1*x2*f0*f6^2*f5*f3*f7-96*x1*x2*x3*x4*f5*f4^4*f6-48*x1*x2^2*x4*f4
*f5^3*f1*f6+72*x1^2*x2*x4*f5^2*f4^2*f1*f6-8*x1*x2*x6*x7*f5*f4^3+4*x1^2*x2*x7*
f4^3*f3*f5+8*x1*x2*x7^2*f5^2*f4^2+4*x1*x2*x7^2*f5^3*f3+4*x1*x2^2*x8*f7*f2*f5^2
*f3+4*x1*x2^2*x8*f7*f4^2*f5*f2+8*x1*x2*x3*x8*f7^2*f2^2*f5-32*x1^2*x2*x5*f6^2*
f1^2*f4-16*x1^2*x2*x5*f0*f4^3*f6-8*x1^2*x2*x5*f1*f5^3*f2+8*x1^2*x2*x5*f1^2*f5^
2*f6-8*x1^2*x2*x5*f1*f5*f2*f4*f6+168*x1*x2*x4^2*f5^2*f4^2*f7*f3+36*x1*x2*x4^2*
f3*f5^5+320*x4^2*x1*x2*f0^2*f7^4-256*x1*x2*x4^2*f7*f2*f5^3*f4+12*x4^2*x1*x2*f7
^2*f3^2*f4^2+244*x4^2*x1*x2*f5^2*f7^2*f2^2+56*x4^2*x1*x2*f1*f5*f7^2*f2*f6+760*
x4^2*x1*x2*f1^2*f5*f7^3+64*x4^2*x1*x2*f7^2*f3^2*f2*f6+6*x1^2*x2^2*f7*f3^4*f4-\
48*x1^2*x2*x3*f4^2*f6^2*f2^2+16*x1*x2^2*x6*f0*f5^2*f3*f7+8*x1*x2^2*x6*f3^2*f7*
f1*f6-64*x1*x2*x3^2*f6^3*f2^2*f4-48*x1*x2*x3^2*f7^2*f2^3*f6+32*x3^2*x1*x2*f7*
f3^2*f6*f2*f5+512*x3^2*x1*x2*f0*f6*f5*f4^2*f7+32*x3^2*x1*x2*f0*f6*f5^2*f7*f3-\
20*x1^2*x2*x6*f3*f5^3*f1-16*x1^2*x2*x6*f4^3*f1*f6-32*x1^2*x2*x6*f0*f6^2*f5*f2+
48*x1^2*x2*x6*f0*f6*f5^2*f3+44*x1^2*x2*x6*f7*f3^2*f1*f5-40*x1^2*x2*x6*f3^2*f6*
f2*f5+8*x1^2*x2*x6*f1*f5^2*f6*f2-24*x1*x2*x4*x6*f5^2*f4^3+72*x1*x2*x5*x6*f7*f2
*f1*f5-32*x1*x2*x5*x6*f0*f5^3-128*x1*x3^2*x7*f3*f5*f6*f2*f7-36*x1*x3^2*x7*f5^3
*f7*f1-160*x1*x3^2*x7*f0*f7^3*f2+124*x1*x3^2*x7*f1*f5*f7^2*f3-8*x1*x3^2*x7*f7^
2*f2^2*f5+112*x1*x3^2*x7*f0*f6*f5^2*f7+352*x1*x3^2*x4*f0*f6^2*f5*f4*f7-96*x1*
x3^2*x4*f6^2*f2^2*f7*f5-32*x1*x3^2*x4*f7^2*f2^2*f5^2+8*x1*x3^2*x4*f7^3*f2^2*f3
-56*x1*x3^2*x4*f7^2*f3^2*f6*f2-64*x1*x3*x2*x6*f0*f6^2*f7*f2-72*x1*x3*x2*x6*f1*
f5^2*f4*f6-64*x1*x3*x2*x6*f1^2*f6^2*f7+48*x1^2*x3*x6*f4*f6^2*f2^2-64*x1*x3*x7^
2*f0*f6^2*f7+44*x1*x3*x7^2*f7*f3*f4*f5+4*x3^3*x1*f7*f4^5-4*x3^3*x2*f7^2*f3^3*
f5-4*x3^3*x2*f1*f7^3*f3^2-4*x3^3*x2*f3*f5^5-4*x3^3*x1*f4*f7^2*f3^3+44*x3^2*x2*
x4*f7^3*f2*f1*f5+4*x3^2*x6^2*f7^2*f2*f3+8*x3^2*x5*x6*f7*f3*f4^2-4*x3^2*x5*x6*
f7*f5*f3^2-4*x3^2*x5*x6*f5^2*f4^2-12*x3^2*x5*x6*f5^3*f3-6*x3^2*x5^2*f3^2*f4*f7
+8*x3^2*x2*x5*f5^2*f4^3+4*x3^3*x5*f3*f5^4+4*x3^3*x5*f7*f3*f4^2*f5+4*x3^3*x5*f7
^2*f3^3+12*x3^2*x2*x6*f3*f5^4-32*x3^2*x2*x6*f1^2*f7^3-48*x1^4*f2*f6*f3*f4*f1*
f5+32*x1^4*f0*f6^2*f4*f3*f2-52*x1^2*x3^2*f2*f7^3*f1^2+96*x1^2*x3^2*f0*f6*f4^3*
f7+64*x1^2*x3*x7*f6^2*f2*f3*f4-120*x1^2*x4*x7*f7*f5*f1*f6*f3-64*x1^2*x4*x7*f7^
2*f0*f4^2+208*x1^2*x4*x7*f7*f0*f5*f4*f6-16*x1^2*x4*x7*f7^2*f2*f5*f1-96*x1^2*x4
*x7*f7*f3*f6*f2*f4-288*x1^2*x4*x7*f7*f0*f5^3-128*x1^3*x5*f5^2*f0^2*f7+8*x1^3*
x5*f5^3*f1^2+80*x1^3*x5*f7*f1^2*f2*f6-8*x1^3*x5*f2*f3^3*f6-96*x1^3*x5*f0*f6*f7
*f2^2-32*x1^3*x5*f0*f6*f5*f4*f2-16*x1^3*x5*f2^2*f6^2*f1-8*x1^3*x5*f4*f6*f2^2*
f3-16*x1^3*x5*f1^2*f5*f4*f6-20*x1^3*x5*f1*f7*f2^2*f5-32*x1^3*x5*f0*f6*f4^2*f3-\
12*x1^3*x5*f3^2*f5^2*f1+8*x1^2*x2^2*f7*f3^2*f2*f4^2+4*x1^3*x2*f7*f3^2*f2^2*f5-\
4*x1^3*x2*f7*f2*f4^3*f1+4*x1^3*x2*f3^3*f4*f7*f2-4*x1^3*x2*f3^4*f5^2+4*x1^3*x2*
f7*f3^5+4*x1^3*x2*f5*f4^2*f3^3-4*x1^3*x2*f3*f5^3*f2^2-4*x1^3*x2*f5*f4^4*f1-4*
x1^3*x2*f3*f5^2*f4^2*f1+4*x1^3*x2*f3*f5*f4^3*f2-48*x1^2*x3*x6*f7*f2*f3^2*f5+
144*x1^2*x3*x6*f0*f6*f5*f2*f7-240*x1^2*x3*x6*f1*f5*f0*f7^2+128*x1^2*x3*x6*f3^2
*f6*f7*f1-272*x1^2*x3*x6*f0*f6*f4*f3*f7+48*x1^2*x2*x6*f1*f4*f0*f7^2-48*x1^2*x2
*x6*f3*f5*f1*f4*f6+24*x1^2*x2*x7*f3^3*f6*f5+8*x1^2*x2*x7*f5^2*f3^2*f4+16*x1^2*
x2*x7*f2*f6*f4^3+16*x1^2*x2*x7*f0*f6*f4*f3*f7+12*x1*x2^2*x4*f4*f5^4*f2+20*x1*
x2^2*x4*f1^2*f7^3*f3-56*x2^2*x4*x1*f3*f5^2*f7*f2*f4+160*x1*x2*x3*x4*f5*f4^3*f3
*f7-164*x1*x2*x3*x4*f1*f5^3*f7*f4+56*x1*x2*x3*x4*f6*f4^3*f7*f2-80*x3*x4*x1*x2*
f6*f2^2*f5^2*f7+24*x3*x4*x1*x2*f7*f3^3*f5*f6+8*x3*x4*x1*x2*f3*f6*f2^2*f7^2+288
*x3*x4*x1*x2*f1^2*f5*f7^2*f6-176*x3*x4*x1*x2*f7*f2^2*f4*f6^2+16*x3*x4*x1*x2*f7
*f3^2*f6^2*f2-352*x1*x2*x3*x4*f0*f4*f7^3*f2+108*x1*x2*x3*x4*f3*f5^4*f4-88*x1*
x2*x3*x4*f7^2*f3^2*f2*f5+168*x1*x2*x3*x4*f7^2*f2*f1*f5^2-44*x1*x2*x5^2*f1^2*f7
*f5+24*x1*x2*x5^2*f2*f1*f5*f6-4*x1*x2*x5*x8*f7*f2*f3*f5-4*x1*x2*x6*x8*f7*f2*f4
*f5-4*x1*x2^2*x7*f5^4*f1+4*x1*x2^2*x7*f5*f4^4+4*x1*x2^2*x7*f2*f5^3*f4+20*x3*x6
*x1*x2*f1*f3^2*f7^2+40*x1*x2*x3*x6*f2*f5^3*f4+24*x1^2*x2*x7*f5*f4^2*f1*f6-12*
x2^2*x7*x1*f3*f7^2*f2^2+56*x2^2*x7*x1*f1*f4*f7^2*f2+24*x3^2*x1*x2*f5*f7^2*f2^2
*f3-40*x3^2*x1*x2*f7^2*f3^2*f1*f5+128*x1^2*x2^2*f6*f5^2*f0^2*f7+32*x1^2*x2^2*
f6*f0^2*f7^2*f3-24*x1^2*x2^2*f0*f5^4*f3+96*x1*x2*x3^2*f6^3*f2*f1*f5+48*x1*x2*
x3^2*f3^2*f6^2*f4^2-24*x1*x2*x3^2*f3^2*f5^2*f6*f4-40*x3^2*x1*x2*f3*f5^3*f7*f1-\
24*x2*x1*x3^2*f3^3*f5^2*f7+128*x1*x2*x3^2*f3*f6^2*f2*f4*f5-16*x1*x2*x3^2*f7^2*
f2*f6*f1*f3+8*x1^2*x2^2*f1*f4^4*f6+64*x1^2*x2^2*f0*f5*f7^2*f3*f1+4*x1^2*x2^2*
f1*f5^4*f2-192*x3^2*x1*x2*f5*f0^2*f7^3-88*x1*x2*x3^2*f5*f4^3*f3*f6-120*x1*x2*
x5*x7*f0*f5*f7*f4-24*x1*x2*x5*x7*f6*f3^2*f4-32*x1*x2*x5*x7*f0*f5^2*f6-8*x1*x2*
x5*x7*f7*f2^2*f5-8*x1*x2*x5*x7*f2*f7*f1*f6-128*x1*x2*x6*x7*f4*f6^2*f1+8*x1*x2*
x6*x7*f5^2*f6*f1+96*x1*x2*x6*x7*f0*f6^2*f5-160*x1*x2*x6*x7*f0*f5^2*f7+120*x1*
x2*x6*x7*f1*f7*f4*f5-8*x1*x2*x6*x7*f2*f7^2*f1-24*x1*x2*x6*x7*f3^2*f5*f6+40*x1*
x2*x6*x7*f7*f2*f3*f5+240*x1*x2*x6*x7*f0*f6*f7*f4-8*x1*x2*x6*x7*f7*f2*f4^2+64*
x1^2*x2*x3*f3*f0^2*f7^3-8*x1*x2*x3*x6*f5*f4^4+4*x1^2*x2*x5*f4^3*f5*f1-12*x1*x2
*x5^2*f3*f5^2*f1+4*x1^2*x2*x7*f7*f4^3*f1-24*x1*x2^2*x3*f3^2*f5^3*f4-160*x1*x2*
x3*x4*f7^2*f3*f4^2*f2+1280*x3*x4*x1*x2*f6*f0^2*f7^3+80*x3*x4*x1*x2*f3*f5^2*f7*
f1*f6-32*x3*x4*x1*x2*f7^2*f3^2*f1*f6+16*x3*x4*x1*x2*f7*f3^2*f4^2*f6+16*x1*x2*
x3*x4*f0*f3^2*f7^3+292*x1*x2*x3*x4*f1^2*f7^3*f4-72*x1*x2*x3*x4*f6*f5^4*f1-224*
x1*x2*x3*x4*f0*f5*f7^3*f1+144*x1*x2*x3*x4*f4*f6^2*f1*f5^2+288*x1*x2*x3*x4*f5*
f6^2*f2*f4^2+72*x1*x2*x3*x4*f7^3*f2*f1*f3-712*x1*x2*x3*x4*f1*f7^2*f3*f5*f4-96*
x1*x2*x4*x5*f0*f6*f5^3+88*x4*x5*x1*x2*f6*f7*f4*f2^2-240*x4*x5*x1*x2*f0*f4*f3*
f7^2-8*x4*x5*x1*x2*f2*f6*f3^2*f7+88*x4*x5*x1*x2*f1*f6*f7*f4*f3+88*x4*x5*x1*x2*
f3*f5*f7*f2*f4+224*x4*x5*x1*x2*f0*f6*f5*f3*f7-72*x1*x2*x4*x5*f5*f4*f6*f3^2-96*
x1*x2*x4*x5*f5*f4^2*f6*f2-416*x1*x2*x4*x5*f0*f5^2*f4*f7+16*x1*x2^2*x3*f0*f2^2*
f7^3+4*x1^2*x2*x5*f7*f2^3*f5+4*x1^2*x2*x5*f7*f2*f3^3-4*x1*x2^2*x5*f3*f5*f7*f2^
2-64*x1^2*x2*x3*f6^2*f3^2*f1*f5-16*x1^2*x2^2*f3^2*f5^2*f1*f6-4*x1^2*x2^2*f3*f5
^2*f2^2*f6+40*x1^2*x2^2*f3^2*f6*f4*f2*f5+16*x1^2*x2*x3*f6^2*f5^2*f1^2+64*x1^2*
x2*x3*f6^3*f1^2*f4-8*x1^2*x2*x3*f3^3*f6*f7*f2-8*x1^2*x2^2*f0*f5^3*f1*f7+32*x1^
2*x2^2*f0*f6^2*f4*f5*f2-104*x1*x2*x3^2*f4^2*f6*f7*f2*f3-8*x1^2*x2^2*f3^3*f7*f2
*f5+4*x1^2*x2^2*f3^2*f7^2*f2*f1-144*x1^2*x2*x3*f0*f6*f5^3*f3+80*x1*x2*x3^2*f6^
2*f4^3*f2+44*x1*x2*x3^2*f7^2*f2^2*f4^2+8*x3^2*x1*x2*f1*f5^2*f7*f6*f2+4*x3^2*x1
*x2*f3*f5^2*f7*f2*f4-24*x3^2*x1*x2*f1*f5*f7^2*f2*f4+128*x1^2*x2*x4*f6^2*f7*f1^
2*f4-48*x1^2*x2*x4*f6^2*f2^2*f4*f5-72*x1^2*x2*x4*f7*f2*f5^3*f1+16*x1^2*x2*x4*
f7*f3^2*f4^3+12*x1^2*x2*x4*f5^2*f4^3*f3+288*x1^2*x2*x4*f0*f3*f1*f7^3-32*x1^2*
x2*x6*f1^2*f6^2*f5-8*x1^2*x2*x6*f1^2*f7*f5^2-96*x1^2*x2*x6*f0*f6^2*f4*f3-20*x1
^2*x2*x6*f4^2*f3^2*f5-76*x1*x2*x3*x6*f3*f5^2*f4^2-96*x1*x2*x3*x6*f3*f5^2*f6*f2
+64*x1*x2*x3*x6*f6^2*f2^2*f5+96*x1*x2*x3*x6*f0*f6*f5^3-48*x1*x2*x3*x6*f0*f5^2*
f4*f7-128*x1*x2*x3*x6*f6^2*f2*f3*f4+32*x2*x1*x3*x6*f7*f2*f1*f5*f6+168*x1*x2*x4
*x6*f7*f2^2*f6*f5+316*x1*x2*x4*x6*f4*f5^2*f1*f7+32*x1*x2*x4*x6*f7*f2*f5^2*f3-\
28*x1*x2*x4*x6*f7*f4^2*f5*f2-180*x1*x2*x4*x6*f7^2*f2*f1*f5-24*x1*x2*x4*x6*f7*
f4^3*f3+192*x1*x2*x4*x6*f3*f5*f4^2*f6+120*x1*x2*x4*x6*f1*f7*f4^2*f6-384*x1*x2*
x4*x6*f1*f5*f6^2*f4+672*x1*x2*x4*x6*f0*f6*f5*f4*f7+24*x1*x2*x3*x5*f3^2*f4*f5^2
-64*x1*x2*x3*x5*f0*f6*f5^2*f4-104*x1*x2*x3*x5*f1^2*f7^2*f4+32*x1*x2*x3*x5*f6^2
*f0*f4^2-144*x1*x2*x3*x5*f7*f2*f4*f1*f6+64*x1*x2*x3*x5*f3*f5^2*f6*f1-8*x1*x2^2
*x5*f2*f6*f7*f3*f1-128*x1^2*x2*x4*f0*f5^2*f1*f7^2-288*x1^2*x2*x4*f0*f6^2*f5^2*
f3+288*x1^2*x2*x4*f5*f4*f6^2*f1*f3-96*x1^2*x2*x4*f0*f6^2*f5*f4^2-120*x1^2*x2*
x4*f3^2*f6*f4^2*f5+24*x1^2*x2*x4*f5^3*f3^2*f4+72*x1^2*x2*x4*f3^3*f5^2*f6+48*x1
^2*x2*x4*f7*f3^3*f5*f4+48*x1*x2^2*x4*f0*f6*f5^4-12*x1*x2^2*x4*f5^5*f1+16*x1^2*
x2*x3*f4^2*f6*f2*f7*f1-4*x1^2*x2^2*f1^2*f5^3*f6-24*x4*x5*x1*x2*f3^3*f5*f7+16*
x4*x5*x1*x2*f1*f3^2*f7^2+72*x1*x2*x4*x5*f6*f5^2*f1*f4+144*x4*x5*x1*x2*f0*f6*f7
^2*f1+416*x4*x5*x1*x2*f0*f5*f7^2*f2-184*x4*x5*x1*x2*f1*f4*f7^2*f2-704*x4*x5*x1
*x2*f0^2*f7^3-32*x1*x2^2*x6*f6*f0^2*f7^2+8*x1*x2^2*x6*f3*f5^2*f6*f1-128*x3*x6*
x1*x2*f0*f6*f5*f3*f7-72*x3*x6*x1*x2*f4^2*f7*f3^2-144*x3*x6*x1*x2*f5*f7^2*f1^2+
16*x1^2*x2*x3*f2*f4^4*f6+32*x1^2*x2*x3*f1*f6*f4^3*f5+96*x1^2*x2*x3*f0*f6^2*f5^
2*f2+16*x1*x2*x4*x8*f7*f5^3*f2+8*x1*x2*x5*x8*f7*f1*f3*f6-24*x1*x2*x6*x8*f7*f1*
f4*f6+32*x1*x2*x6*x8*f7*f0*f5*f6+12*x1*x2*x6*x8*f7^2*f3*f1-16*x1*x2*x7*x8*f7*
f6*f1*f5+4*x1*x2*x7*x8*f7*f5^2*f2+24*x1*x2*x7*x8*f7^2*f0*f5-36*x1*x2*x7*x8*f7^
2*f1*f4-20*x1*x2*x5*x8*f7^2*f2*f1+32*x1*x2*x4*x8*f7^3*f2*f1+96*x1*x2*x4*x8*f7^
2*f0*f5^2-24*x1^2*x2*x3*f5*f4*f6*f3^3-8*x1^2*x2^2*f7*f2^2*f4^3+48*x1^2*x2^2*f0
*f6^2*f3*f4^2-12*x1*x2*x3^2*f5^4*f3^2-24*x1^2*x2*x4*f4^2*f6*f7*f2^2+48*x1^2*x2
*x4*f6*f2*f5*f4^3-96*x1*x2*x3^2*f1^2*f6^2*f7*f5-56*x1*x2*x3^2*f7*f2*f5*f4^3+20
*x3^2*x1*x2*f5^3*f7*f2^2+4*x1^2*x2^2*f3^2*f5^3*f2-32*x1^2*x2^2*f0^2*f7^3*f2+40
*x1*x2*x5^2*f2*f7*f1*f4-16*x1*x2*x5^2*f2^2*f4*f6-80*x1^2*x2*x5*f7^2*f3*f1*f0+
64*x1^2*x2*x5*f0*f6^2*f1*f5+8*x1^2*x2*x5*f3*f2^2*f5*f6+48*x1^2*x2*x5*f1*f6*f4^
2*f3-112*x1^2*x2*x5*f0*f4^2*f3*f7+64*x1^2*x2*x5*f0*f6*f7*f1*f4+64*x1^2*x2*x4*
f0*f6^2*f4*f7*f2+12*x1*x2^2*x4*f5^2*f4^4-44*x2^2*x4*x1*f5*f7^2*f2^2*f3+96*x1^2
*x2*x7*f3*f6^2*f1*f4-32*x1^2*x2*x7*f6^2*f0*f4^2+8*x1*x2^2*x8*f7*f1*f4^2*f6-8*
x1*x2^2*x8*f7*f3*f1*f5*f6+8*x1*x2*x3*x8*f7*f3*f5*f6*f2+48*x1*x2*x3*x8*f7^2*f0*
f5*f4-36*x1*x2*x3*x8*f7^2*f1*f4^2-36*x1*x2*x3*x8*f7^3*f1^2-16*x1*x2*x3*x8*f7*
f3*f1*f6^2+40*x1*x2*x3*x8*f7^2*f2*f1*f6+72*x1*x2*x4*x7*f5^3*f7*f1+120*x1*x2*x4
*x7*f7^2*f2^2*f5+16*x1*x2*x4*x7*f1*f7^2*f4^2-96*x1*x2*x4*x7*f4^3*f6*f5-176*x1*
x2*x4*x7*f4*f5^2*f2*f7+80*x1*x2*x4*x7*f2*f7*f4^2*f6-4*x1^2*x2*x6*f7*f3^4-8*x2^
3*x5*f7*f2*f4^2*f3+24*x2^3*x5*f7*f4^3*f1+16*x2^3*x5*f7^2*f1^2*f4-16*x2^3*x5*f5
*f4^2*f1*f6+12*x2^3*x5*f7*f3*f5*f1*f4+48*x2^3*x5*f0*f6*f4*f5^2-48*x2^2*x3*x5*
f0*f6*f5^3+24*x2^2*x3*x5*f7*f2^2*f4*f6+36*x2^2*x3*x5*f1^2*f5*f7^2+192*x2^2*x3*
x5*f0*f6^2*f5*f4+48*x2^2*x3*x5*f0*f4*f3*f7^2-36*x2^2*x3*x5*f7^2*f2*f1*f4+40*x2
^2*x3*x5*f1*f5^2*f4*f6+12*x2^2*x3*x5*f5^2*f4^2*f3-208*x2^2*x3*x5*f0*f4*f5^2*f7
-176*x2^2*x3*x5*f0*f6*f4^2*f7-32*x2^2*x3*x5*f1*f7*f6*f2*f5+72*x2^2*x4*x5*f1*f7
^2*f3*f4+104*x2^2*x4*x5*f7*f4*f5^2*f1-96*x2^2*x4*x5*f2*f5^2*f4*f6-20*x2^2*x4*
x5*f7*f3^2*f5*f4+52*x2^2*x4*x5*f7*f2*f5^2*f3+416*x2^2*x4*x5*f0*f6*f7*f4*f5-4*
x2^2*x4*x5*f7*f2*f5*f4^2+32*x2^2*x4*x5*f1^2*f7^2*f6-16*x2^2*x4*x5*f1*f7*f3*f5*
f6-304*x2^2*x4*x5*f0*f5^3*f7-368*x2^2*x4*x5*f0*f4^2*f7^2-80*x2^2*x4*x5*f0*f7^3
*f1+72*x2^2*x4*x5*f5^3*f6*f1+64*x2^2*x4*x5*f0*f7^2*f5*f3+80*x2^2*x3*x5*f1*f7*
f5*f4^2-96*x2^2*x3*x5*f0^2*f7^3+16*x2^2*x3*x5*f0*f6*f1*f7^2-48*x2^2*x3*x5*f2*
f5*f4^2*f6-80*x2^2*x3*x5*f0*f6*f5*f3*f7+12*x2^3*x5*f4*f5^3*f1-80*x2^3*x5*f0*f5
*f4^2*f7-8*x2^3*x5*f4^2*f5^2*f2+16*x2^2*x1*x5*f0*f5*f4*f3*f7+16*x2^2*x1*x5*f1*
f4*f5*f3*f6-4*x2^2*x1*x5*f2*f5*f4^3+112*x2^2*x1*x5*f7^2*f0*f1*f4+40*x2^2*x6^2*
f0*f7*f5^2-72*x2^2*x6^2*f1*f4*f7*f5+24*x2^2*x6^2*f3*f4^2*f6-64*x2^2*x1*x6*f0*
f5*f4^2*f7+16*x1^3*x2*f0*f5^2*f6*f3^2+64*x1^3*x2*f0*f4^3*f3*f7-40*x1^4*f0*f5*
f4^2*f7*f1+80*x1^3*x2*f0*f6*f5*f3*f7*f1+32*x1^3*x2*f1*f6^2*f0*f5*f4+64*x1^2*x3
*x7*f0*f6*f5^3+320*x1^2*x3*x7*f0^2*f7^3-128*x1^2*x3*x7*f0*f7*f5^2*f4+104*x1^2*
x3*x7*f1*f4*f7^2*f2-96*x1^2*x3*x7*f3*f7*f1*f4*f6-128*x1^2*x3*x7*f0*f6^2*f5*f4+
40*x1^2*x3*x7*f7*f4*f6*f2^2+64*x1^2*x3*x7*f2*f4^2*f6*f5+128*x1^2*x3*x7*f3*f5*
f6^2*f1-128*x1^2*x3*x7*f7*f2*f5*f1*f6-8*x1^2*x3*x7*f4*f5^2*f1*f6+400*x1^2*x3*
x7*f0*f5*f6*f3*f7-304*x1^2*x3*x7*f0*f4*f3*f7^2-96*x1^2*x3*x7*f7*f2*f3^2*f6-160
*x1^2*x3*x7*f1*f6*f0*f7^2-32*x1^2*x5*x7*f0*f5^3+16*x1^2*x5*x7*f7*f3*f4*f1-96*
x1^2*x5*x7*f1^2*f7*f6-16*x1^2*x5*x7*f5*f1*f6*f3+16*x1^2*x5*x7*f3*f6*f2*f4+64*
x1^2*x5*x7*f0*f5*f4*f6+288*x3^2*x2*x4*f4*f5^2*f3*f6^2-288*x3^2*x2*x4*f1*f5*f7*
f6^2*f4-48*x3^2*x2*x4*f2*f6^2*f7^2*f1-144*x3^2*x2*x4*f6*f4^2*f7*f5*f3-248*x3^2
*x2*x4*f7^2*f3*f4*f2*f6-176*x3^2*x2*x4*f0*f4^2*f7^3-16*x3^2*x2*x4*f7^2*f3^3*f6
+160*x3^2*x2*x4*f1*f4^2*f7^2*f6+192*x3^2*x2*x4*f6^2*f2*f7*f4^2+96*x3^2*x2*x4*
f5^3*f4^2*f6-144*x3^2*x2*x4*f3*f6^2*f7*f2*f5+136*x3^2*x2*x4*f7^3*f2^2*f4+192*
x3^2*x2*x4*f6^2*f5^3*f2+24*x3^2*x2*x4*f6*f7^3*f1^2-640*x3^2*x2*x4*f0*f6^3*f7*
f4+16*x3^2*x2*x4*f4*f5^2*f2*f6*f7-112*x3^2*x2*x4*f4*f5^3*f3*f7-80*x3^2*x2*x4*
f7^2*f2*f3*f5^2+196*x3^2*x2*x4*f7^2*f3^2*f4*f5-204*x3^2*x2*x4*f4*f5^2*f1*f7^2-\
136*x3^2*x2*x4*f7*f2*f5^4-24*x3^2*x2*x4*f7^2*f6*f5*f3*f1+112*x3^2*x2*x4*f7^2*
f2^2*f6*f5+100*x3^2*x2*x4*f7^3*f4*f3*f1-288*x3^2*x2*x4*f5^2*f6^3*f1+640*x3^2*
x2*x4*f0*f3*f6^2*f7^2+32*x3^3*x4*f6^3*f2*f7*f3+144*x3^3*x4*f4*f5^4*f6-96*x3^3*
x4*f5^2*f4^2*f6^2-256*x3^3*x4*f1*f6^3*f7*f4+72*x3^3*x4*f7^3*f3*f4*f2-84*x3^3*
x4*f1^2*f7^4-168*x3^3*x4*f7^2*f3^2*f6*f4+96*x3^3*x4*f0*f7^4*f2+88*x3^3*x4*f4^2
*f5^3*f7+128*x3^3*x4*f4^2*f7*f6^2*f3-128*x3^3*x4*f0*f6*f7^3*f3-112*x3^3*x4*f1*
f5^2*f7*f6^2+288*x3^3*x4*f6^3*f4*f3*f5+192*x3^3*x4*f5^2*f6^3*f2+8*x3^3*x4*f1*
f7^3*f4^2-160*x3^3*x4*f7*f3*f5^2*f6*f4+32*x3^3*x4*f7^3*f2^2*f5-80*x3^3*x4*f1*
f5^3*f7^2+80*x3^3*x4*f6^2*f2*f7*f4*f5+256*x3^3*x4*f0*f5*f7^3*f4-24*x3^3*x4*f1*
f6*f7^3*f2-20*x3^3*x4*f7^2*f4^4-192*x3^3*x4*f6^4*f1*f5-96*x3^3*x4*f3^2*f6^2*f5
*f7-52*x3^3*x4*f4*f5^2*f2*f7^2+448*x3^3*x4*f0*f6^2*f7^2*f4-16*x3^3*x4*f7*f2*f5
^3*f6-32*x3^3*x4*f6^2*f2^2*f7^2-8*x3^3*x4*f7*f3*f5^4+104*x3^3*x4*f1*f7^3*f3*f5
-24*x3^3*x4*f7^2*f3*f5*f2*f6+8*x3^3*x4*f2*f7^2*f4^2*f6-120*x3^3*x4*f7^2*f3^2*
f5^2+72*x3^3*x4*f5*f4^3*f7*f6-196*x3^3*x4*f7^2*f3*f4^2*f5+80*x3^3*x4*f1*f6^2*
f7^2*f3+192*x3^3*x4*f0*f6^3*f5*f7+16*x3^3*x4*f1*f7^2*f6*f4*f5+1200*x3^3*x4*f0*
f6*f5^2*f7^2-16*x3^2*x2*x4*f3^2*f6^2*f4*f7-144*x3^2*x2*x4*f7*f3^2*f6*f5^2-336*
x3^2*x2*x4*f7^2*f2*f5*f4^2+20*x3^2*x2*x4*f7^2*f3*f4^3-56*x3^2*x2*x4*f4^4*f6*f7
+84*x3^2*x2*x4*f4*f5^5-96*x3^2*x1*x4*f4^2*f6^2*f7*f1-80*x3^2*x1*x4*f7*f3*f5^2*
f6*f2-256*x3^2*x1*x4*f0*f4*f7^3*f3+16*x3^2*x5^2*f2*f4*f5*f6-16*x3^2*x5^2*f6*f5
^2*f1+12*x3^2*x2*x5*f7^2*f2*f1*f5+80*x3^2*x2*x5*f5*f6^2*f4*f1-104*x3^2*x2*x5*
f0*f5^3*f7-64*x3^2*x2*x5*f4*f5^2*f2*f6-8*x3^2*x2*x5*f2*f5^4+32*x3^2*x2*x5*f1*
f5^3*f6-528*x2*x5*x3^2*f0*f6*f5*f7*f4+40*x3^2*x2*x5*f6*f7^2*f1^2-40*x3^2*x2*x5
*f0*f7^3*f1-20*x3^2*x2*x5*f7^2*f4*f3*f1+72*x3^2*x2*x5*f0*f4^2*f7^2+16*x3^2*x2*
x5*f4^4*f6+8*x3^2*x2*x5*f7*f3^2*f4*f5-32*x3^2*x2*x5*f0*f5*f7^2*f3-64*x3^2*x2*
x5*f7*f0*f3*f6^2+92*x3^2*x2*x5*f4*f5^2*f1*f7+192*x3^2*x2*x5*f0*f6^3*f4+16*x3^3
*x5*f1*f7^2*f4^2-48*x3^3*x5*f4^2*f6^2*f3-64*x3^3*x5*f6^2*f2*f4*f5+8*x3^3*x5*f2
^2*f7^2*f5-224*x3^3*x5*f0*f6*f5^2*f7-48*x3^3*x5*f7*f1*f3*f6^2+24*x3^3*x5*f5*f4
^3*f6+8*x3^3*x5*f5^2*f7*f3^2-24*x3^3*x5*f7^2*f3*f4*f2+32*x3^3*x5*f7*f3^2*f6*f4
+16*x3^3*x5*f2*f7*f4^2*f6+64*x3^3*x5*f0*f6^3*f5+16*x3^3*x5*f1*f5^2*f6^2-128*x3
^3*x5*f0*f6^2*f7*f4+20*x3^3*x5*f4*f5^2*f2*f7-40*x3^3*x5*f0*f5*f7^2*f4-32*x3^3*
x5*f0*f7^3*f2-24*x3^3*x5*f1*f7*f6*f4*f5+96*x3^3*x5*f4*f6^3*f1+24*x3^3*x5*f1^2*
f7^3-12*x3^2*x4*x5*f4*f5^4-32*x3^2*x4*x5*f2*f6^2*f7*f3+256*x3^2*x4*x5*f6^2*f4*
f1*f7+36*x3^2*x4*x5*f2*f7^3*f1-608*x3^2*x4*x5*f0*f6^2*f5*f7-192*x3^2*x4*x5*f5^
2*f6^2*f2+288*x3^2*x4*x5*f6^3*f1*f5-28*x3^2*x4*x5*f2*f7^2*f4^2+32*x3^2*x4*x5*
f2^2*f7^2*f6-4*x3^2*x4*x5*f7^2*f2*f3*f5-288*x3^2*x4*x5*f3*f5*f4*f6^2+112*x3^2*
x4*x5*f7*f3^2*f5*f6-384*x3^2*x4*x5*f0*f6*f4*f7^2+152*x3^2*x4*x5*f6*f5^2*f1*f7-\
48*x3^2*x4*x5*f3*f7*f4^2*f6-608*x3^2*x4*x5*f0*f5^2*f7^2+128*x3^2*x4*x5*f0*f3*
f7^3+72*x3^2*x4*x5*f7^2*f3^2*f4+144*x3^2*x4*x5*f6*f4^2*f5^2-16*x3^3*x5*f2*f5^3
*f6+96*x3^3*x5*f0*f6*f7^2*f3+24*x3^3*x5*f7*f3*f5*f2*f6+36*x3^3*x5*f1*f5^3*f7-\
48*x3^2*x2*x5*f7*f2*f1*f6^2+56*x3^2*x2*x5*f2*f7*f3*f6*f4+64*x3^2*x2*x5*f0*f6*
f7^2*f2-24*x3^2*x2*x5*f7^2*f2^2*f4-64*x3^2*x2*x5*f6^2*f2*f4^2+32*x3^2*x2*x5*f7
*f2^2*f6*f5-8*x3^2*x2*x5*f7*f6*f5*f3*f1-44*x3^2*x1*x5*f4*f2*f7^2*f1+40*x3^2*x1
*x5*f2*f5*f7*f3*f4-64*x3^2*x1*x5*f7^3*f0^2-32*x3^2*x1*x5*f4*f2^2*f7*f6-96*x3^2
*x1*x5*f2*f6^3*f1+48*x3^2*x1*x5*f1*f6^2*f4^2+216*x3^2*x6^2*f0*f5*f7^2+12*x3^2*
x6^2*f4^2*f6*f5+16*x3^2*x6^2*f2*f5*f6^2-4*x3^2*x6^2*f7*f5*f3*f4+68*x3^2*x6^2*
f7*f5^2*f2+192*x3^2*x6^2*f0*f6^2*f7-56*x3^2*x6^2*f2*f7*f4*f6-224*x3^2*x6^2*f7*
f5*f1*f6-48*x3^2*x1*x6*f3^2*f6^2*f4-92*x3^2*x1*x6*f3*f5^2*f7*f2+12*x3^2*x1*x6*
f7^2*f2^2*f4+224*x3^2*x1*x6*f0*f5^3*f7+168*x3^2*x1*x6*f7*f3*f4*f2*f6-24*x3^2*
x1*x6*f7*f3*f4^3-80*x3^2*x1*x6*f5^3*f6*f1+56*x3^2*x1*x6*f0*f7^3*f1+24*x3^2*x1*
x6*f7*f2^2*f6*f5-32*x3^2*x1*x6*f6^2*f4*f1*f5-160*x3^2*x1*x6*f7*f0*f3*f6^2+8*x3
^2*x1*x6*f7^2*f2*f1*f5-672*x3^2*x1*x6*f0*f6*f5*f4*f7+144*x3^2*x1*x6*f4*f5^2*f1
*f7+16*x3^2*x1*x6*f4^4*f6-92*x3^2*x1*x6*f7^2*f4*f3*f1-160*x3^2*x1*x6*f6^2*f2*
f3*f5-2160*x3^2*x4*x6*f0*f6*f5*f7^2+128*x3^2*x4*x6*f7^2*f2*f4*f5+56*x3^2*x4*x6
*f7*f2*f5^2*f6+48*x3^2*x4*x6*f7^2*f5*f3^2+248*x3^2*x4*x6*f7^2*f5^2*f1-16*x3^2*
x5*x6*f4^3*f6+64*x3^2*x5*x6*f2*f6^2*f4-36*x3^2*x5*x6*f7*f2*f4*f5-192*x3^2*x5*
x6*f0*f6^3-24*x3^2*x5*x6*f2*f7*f3*f6+48*x3^2*x5*x6*f0*f4*f7^2-100*x3^2*x5*x6*
f5^2*f7*f1+16*x3^2*x5*x6*f5*f6^2*f1+432*x3^2*x5*x6*f0*f6*f5*f7-120*x3^2*x4*x6*
f1*f7^2*f4*f6+4*x3^2*x4*x6*f4^2*f7^2*f3-112*x3^2*x4*x6*f0*f4*f7^3-192*x3^2*x4*
x6*f5*f6^3*f2-240*x3^2*x4*x6*f6*f5^3*f4-132*x3^2*x4*x6*f7^3*f3*f1+128*x3^2*x4*
x6*f5*f6^2*f1*f7+160*x3^2*x4*x6*f2*f7^2*f3*f6+48*x3^2*x4*x6*f7*f4^3*f6+512*x3^
2*x4*x6*f0*f6^3*f7-128*x3^2*x4*x6*f7*f2*f6^2*f4+120*x3^3*x6*f7*f2*f4*f5*f6+44*
x3^3*x6*f7^2*f3^2*f4+16*x3^3*x6*f6^2*f2*f3*f7-24*x3^3*x6*f3*f7*f4^2*f6+16*x3^3
*x6*f7^2*f3*f1*f6-48*x3^3*x6*f0*f6*f4*f7^2-24*x3^3*x6*f4*f5*f7^2*f1+248*x3^3*
x6*f6*f5^2*f1*f7+328*x3^2*x2*x6*f1*f7*f6*f4*f5-32*x3^2*x2*x6*f0*f7^3*f2-80*x3^
2*x1*x6*f6^2*f2*f4^2-44*x3^2*x1*x6*f7^2*f2*f3^2+32*x3^2*x1*x6*f4*f5^2*f2*f6+16
*x3^2*x7^2*f7^2*f2*f5+24*x7^2*x3^2*f4*f7*f5^2-20*x3^2*x7^2*f7^2*f1*f6-68*x3^2*
x7^2*f7^2*f3*f4+76*x3^2*x7^2*f7*f4^2*f6-32*x3^2*x7^2*f7*f3*f5*f6+72*x3^2*x1*x7
*f7^2*f3*f4*f2-80*x3^2*x1*x7*f4*f5^2*f2*f7+40*x3^2*x1*x7*f4^2*f5^3+48*x3^2*x1*
x7*f7*f3^2*f5^2-32*x3^2*x1*x7*f6^3*f2*f3+48*x3^2*x1*x7*f3^2*f6^2*f5+128*x3^2*
x1*x7*f1*f7*f6*f4*f5-104*x3^2*x1*x7*f0*f5*f7^2*f4+84*x3^2*x1*x7*f1^2*f7^3+16*
x1^2*x6^2*f0*f5^3+16*x1^2*x3^2*f0*f5^5+4*x2^4*f0*f5^5+6*x2^2*x3^2*f7*f4^5+24*
x2^2*x5^2*f0*f5^3+30*x2^2*x3^2*f4^3*f5^3+8*x2^2*x7^2*f7*f4^3+4*x3^2*x5^2*f5^3*
f2-16*x1^2*x2^2*f7*f2*f4*f1*f6*f3-16*x1^2*x2^2*f0*f5*f6*f1*f7*f4-48*x1^3*x3*f0
*f6*f5*f4^3-64*x1^3*x3*f6^2*f0^2*f7*f4-32*x1^3*x3*f0*f7^3*f1^2+4*x1^4*f0*f5^3*
f3^2-4*x1^2*x3^2*f1*f5^3*f7*f2+52*x1^2*x3^2*f5*f4^3*f1*f7-8*x1^2*x2^2*f5^2*f4^
2*f2*f3+16*x1^2*x2^2*f0*f6*f4*f7*f3^2+32*x1^4*f6*f5*f3*f7*f0^2+56*x1^3*x2*f3^2
*f1*f7*f2*f6-32*x1^3*x2*f6^2*f4^2*f1^2+8*x1^4*f7^2*f1^3*f4-20*x1^4*f1*f4*f7*f3
^3-32*x1^4*f0*f4*f2*f7^2*f1+32*x1^4*f0*f6^2*f5*f3*f1+24*x1^4*f5*f1*f4*f7*f2^2+
12*x1^3*x2*f3^2*f5^3*f1+592*x1^2*x3*x4*f7^2*f2*f1*f3*f6-456*x1^2*x3*x4*f7*f3*
f4*f1*f5*f6-448*x1^2*x3*x4*f0*f6*f3^2*f7^2-32*x1^2*x3*x4*f3*f7^2*f1*f4^2-96*x1
^2*x3*x4*f7^2*f3^2*f5*f1-120*x1^2*x3*x4*f7^2*f2^2*f5*f3-200*x1^2*x3*x4*f7*f3*
f4*f5^2*f2+368*x1^2*x3*x4*f0*f5*f4*f3*f7^2-336*x1^2*x3*x4*f0*f5^3*f4*f7+80*x1^
2*x3*x4*f7*f2^2*f5*f4*f6-560*x1^2*x3*x4*f0*f5*f6*f1*f7^2+272*x1^2*x3*x4*f0*f4*
f1*f7^3+16*x2^2*x1*x7*f7*f3^3*f5+4*x2^3*x8*f7*f3*f5*f4^2+4*x2^3*x8*f7*f5^2*f2*
f4+8*x2^2*x3*x8*f7*f2*f5^3-4*x2^2*x6*x8*f7*f3*f5*f4-8*x2^2*x6*x8*f7*f5^2*f2-8*
x2^2*x1*x7*f7*f2^2*f5^2+4*x2^3*x7*f4^3*f5^2-4*x2^2*x3*x7*f1^2*f7^3+20*x2^2*x3*
x7*f5^3*f4^2-8*x2^2*x4*x6*f7*f4^4-8*x2^2*x4*x6*f7*f3*f5*f4^2-8*x2^2*x4*x6*f7^2
*f3^3+12*x2^2*x1*x5*f1*f7*f3^2*f5-16*x2^2*x1*x5*f3*f4*f5^2*f2+28*x2^2*x1*x5*f7
^2*f2^2*f1+12*x2^2*x1*x5*f1*f5^3*f3-4*x2^2*x1*x5*f7*f2*f3^2*f4-4*x2^3*x5*f1*f7
*f5^2*f2+4*x2^3*x5*f5*f4^3*f3-4*x2^3*x5*f1*f7^2*f2*f3+4*x2^3*x5*f7^2*f2^3+16*
x1^3*x3*f1^2*f5*f7*f6*f3-304*x1^3*x3*f0*f6*f5*f7*f2*f3-80*x1^3*x3*f0*f6*f4*f7*
f3^2+8*x1^3*x3*f7*f3^3*f2*f5+48*x1^3*x3*f3^2*f5^2*f6*f1+40*x1^3*x3*f7*f2*f5^2*
f3*f1-248*x1^2*x4^2*f7^2*f3^2*f6*f1-248*x1^2*x4^2*f7^2*f2*f3^2*f5+892*x1^2*x4^
2*f7^2*f1^2*f6*f5+8*x2^3*x3*f7*f2*f4^2*f3*f6+44*x2^3*x3*f7^2*f2*f5*f1*f4+80*x2
^3*x3*f0*f4*f1*f7^3+32*x2^3*x3*f1*f5*f6^2*f4^2+24*x2^3*x3*f1*f6*f7^2*f2*f3-96*
x2^3*x3*f0*f6^2*f5^2*f4-80*x2^3*x3*f0*f5*f4*f3*f7^2-32*x2^3*x3*f0*f6*f4*f2*f7^
2-16*x2^3*x3*f7*f2^2*f4*f6*f5+32*x2^3*x3*f0*f6^2*f4*f7*f3-16*x2^2*x1*x3*f0*f5^
5-16*x2^3*x3*f1*f6*f5^3*f4+24*x2^2*x1*x3*f1*f5^3*f7*f2-16*x2^2*x1*x3*f5^3*f6*
f2^2+36*x2^2*x1*x3*f7^2*f2*f4^2*f1+32*x2^2*x1*x3*f0*f6^2*f4*f7*f2+204*x2^2*x1*
x3*f1^2*f5*f7^2*f4-48*x2^2*x1*x3*f3*f5^2*f1*f4*f7+8*x2^2*x1*x3*f4*f5^4*f1+40*
x2^2*x4^2*f7*f3^2*f5^2*f6+12*x2^2*x4^2*f7^2*f3^3*f6+576*x2^2*x4^2*f7^2*f0*f5^3
+48*x2^2*x4^2*f5^2*f4^3*f7-48*x2^2*x4^2*f1^2*f7^3*f6+32*x2^2*x4^2*f6^2*f2*f1*
f7^2-4*x2^2*x4^2*f7*f2*f5^4-28*x2^2*x4^2*f7^3*f2*f3^2+12*x2^2*x4^2*f7^2*f3*f4^
3-48*x2^2*x4^2*f0*f6*f2*f7^3-20*x2^2*x4^2*f7^2*f2^2*f6*f5+296*x2^2*x4^2*f7*f2*
f5^2*f4*f6+696*x2^2*x4^2*f7^3*f0*f4^2-248*x2^2*x4^2*f7^3*f1*f3*f4+140*x2^2*x4^
2*f7^3*f1*f2*f5+100*x2^2*x4^2*f7^2*f2*f5^2*f3-156*x2^2*x4^2*f7^2*f2*f5*f4^2-\
176*x2^2*x4^2*f7^3*f0*f5*f3+76*x2^2*x4^2*f7^2*f4^2*f6*f1+192*x2^2*x1*x4*f1*f6^
2*f5*f4^2+16*x2^2*x1*x4*f7*f4^4*f3+1216*x2^2*x1*x4*f5*f0^2*f7^3+112*x2^2*x1*x4
*f1*f5^2*f7*f6*f2+24*x2^2*x1*x4*f3*f5^3*f4^2-32*x2^2*x1*x4*f0*f6^2*f4*f3*f7+
128*x2^2*x1*x4*f0*f3*f2*f7^3-16*x1^2*x3*x4*f6^2*f2^2*f7*f3-320*x1^2*x3*x4*f0*
f6^3*f1*f7-456*x1^2*x3*x4*f5^2*f6*f7*f2*f1+96*x1^2*x3*x4*f7*f2*f4*f6^2*f1+192*
x1^2*x3*x4*f0*f6*f5^4+464*x1^2*x3*x4*f0*f6*f5*f4^2*f7+96*x1^2*x2*x4*f7^2*f2*f1
*f4^2+1536*x1^2*x2*x4*f6*f5*f0^2*f7^2-80*x1^2*x2*x4*f0*f6*f5^2*f2*f7-184*x1^2*
x2*x4*f3*f5*f6*f7*f2^2+592*x1^2*x2*x4*f7^2*f2*f5*f3*f1+56*x1^2*x2*x4*f7*f2*f5^
2*f3^2-32*x1^2*x2*x4*f1^2*f7^2*f4*f5-144*x1^2*x2*x4*f7*f3^2*f5*f1*f6-208*x1^2*
x2*x4*f0*f5*f2*f7^2*f4-68*x1^2*x2*x4*f2*f5*f7*f4^2*f3+48*x1^2*x2*x4*f5^3*f6*f3
*f1-40*x1^2*x2*x4*f2^2*f3*f7^2*f4+152*x1^2*x2*x4*f7*f3^2*f2*f4*f6+96*x1^2*x2*
x4*f0*f5^5+288*x1^3*x4*f0*f5^2*f3*f7*f4+64*x1^3*x4*f7^3*f3*f0^2+96*x1^3*x4*f5^
3*f7*f1^2+48*x1^3*x4*f3^2*f6^2*f1*f5-96*x1^3*x4*f0*f5^3*f2*f7-120*x1^3*x4*f7*
f2*f5^2*f1*f4-144*x1^3*x4*f0*f6*f5*f2*f7*f4+144*x1^3*x4*f1*f6*f5^2*f0*f7-36*x1
^2*x6*x7*f7*f2^2*f5+4*x1^3*x7*f2^2*f5^3+4*x1^3*x7*f3^3*f5^2+4*x1^2*x2*x8*f5^2*
f7*f2^2+96*x1^3*x5*f0*f5*f3*f7*f2-16*x1^3*x5*f0*f4^2*f7*f2-32*x1^3*x5*f3*f6^2*
f1^2-48*x1^3*x5*f1*f7*f2*f3*f4+12*x1^3*x5*f7*f2^3*f4-8*x1^3*x5*f0*f5*f4^3-8*x1
^3*x5*f0*f4*f3^2*f7+68*x1^2*x4^2*f7^2*f2^2*f3*f6+32*x2^2*x1*x3*f4^3*f5^2*f3-12
*x2^2*x1*x3*f4^2*f5^3*f2-96*x2^2*x1*x3*f0*f6^2*f5*f1*f7+16*x2^3*x3*f7^2*f2^2*
f4^2-24*x2^3*x3*f5^2*f7^2*f1^2+16*x2^3*x3*f0*f5^2*f2*f7^2-12*x2^3*x3*f5^3*f4^2
*f3+64*x2^3*x3*f0*f6*f5^2*f3*f7-28*x2^3*x3*f7*f2*f5*f4^3+8*x2^3*x3*f1*f5^2*f7*
f6*f2+64*x2^3*x3*f5*f0^2*f7^3-12*x2^3*x3*f7^2*f2^2*f5*f3-56*x2^3*x3*f4^2*f5^2*
f1*f7-32*x2^3*x3*f1*f6*f7*f4^3+16*x2^3*x3*f0*f6*f5^4+48*x2^3*x3*f0*f3*f2*f7^3+
8*x2^3*x3*f5*f4^3*f3*f6-32*x2^3*x3*f0*f4^3*f7^2-20*x2^3*x3*f7^3*f2^2*f1-8*x2^3
*x3*f3*f5^3*f7*f1-16*x2^3*x3*f0*f6*f3^2*f7^2+12*x2^3*x3*f5^2*f4^4+32*x2^3*x3*
f6*f2*f5^2*f4^2-16*x2^3*x3*f7^2*f3*f4^2*f1+8*x2^3*x3*f3^2*f7^2*f2*f4+8*x2^3*x3
*f4*f5^4*f2-48*x2^3*x3*f3*f5*f6*f1*f4*f7+192*x2^3*x3*f0*f6*f5*f4^2*f7-12*x2^3*
x3*f7^3*f3*f1^2+80*x2^3*x3*f0*f5^3*f7*f4+32*x1^4*f0*f3*f2^2*f7^2-16*x1^3*x2*f6
^2*f2^3*f4-112*x1^3*x2*f0*f5^2*f3*f7*f2+4*x1^4*f0*f4^4*f5-32*x1^4*f2*f1^2*f7^2
*f3-112*x1^3*x2*f0*f6*f4*f3*f7*f2+20*x1^3*x2*f1^2*f5^2*f7*f3+16*x1^3*x2*f1*f6^
2*f5*f2^2+2*x2^4*f5*f4^5-152*x3^3*x1*f3*f5*f6*f7*f2*f4+100*x3^3*x1*f4*f5*f7^2*
f3*f1+72*x3^3*x1*f4^2*f6*f5*f7*f1+40*x3^3*x1*f7*f2*f5^3*f3-40*x3^3*x1*f7^2*f4^
3*f1+96*x3^3*x1*f5*f6^2*f2*f4^2+28*x3^3*x1*f4*f5^4*f3-200*x3^3*x1*f3*f5^2*f6*
f7*f1+48*x3^3*x1*f7^2*f3^2*f2*f5-64*x3^3*x1*f6^3*f2^2*f5-24*x3^3*x1*f3^2*f5^3*
f6+60*x3^3*x1*f1*f7^3*f2*f3+60*x3^3*x1*f4*f7^3*f1^2+32*x3^3*x1*f7^2*f2*f4*f1*
f6+8*x3^3*x2*f5^2*f4^3*f6-144*x3^3*x2*f6*f4*f5^2*f7*f1+8*x3^3*x2*f7^2*f4^2*f3^
2-8*x3^3*x2*f5^3*f6*f3*f4+12*x3^3*x2*f7*f4^4*f5+128*x2*x3^3*f0*f5^2*f4*f7^2+16
*x3^3*x2*f1*f7^2*f3*f6*f4+64*x3^3*x2*f4^2*f6^3*f2+8*x3^3*x2*f1*f7^2*f5*f4^2+
512*x2*x3^3*f0*f6^2*f5*f4*f7+20*x3^3*x2*f1^2*f7^3*f5-128*x3^3*x2*f0*f6^4*f4-8*
x3^3*x2*f7^3*f2^2*f3+48*x3^3*x2*f7^2*f2^2*f6*f4-64*x3^3*x2*f0^2*f7^4-32*x3^3*
x2*f6^2*f2^2*f7*f5+8*x3^3*x2*f7^2*f5^2*f2^2-28*x3^3*x2*f1*f5^4*f7-12*x3^3*x2*
f7*f2*f4*f5^3+192*x3^3*x2*f0*f6*f5^3*f7+80*x3^3*x2*f0*f6*f5*f7^2*f3+16*x3^3*x2
*f7*f3*f5^2*f6*f2-20*x3^3*x2*f3*f4^2*f5^2*f7+16*x3^3*x2*f4^2*f6^2*f7*f1+80*x3^
3*x2*f0*f6*f7^3*f1+48*x3^3*x2*f0*f5*f7^3*f2+32*x3^3*x2*f4^2*f5^4-16*x3^3*x2*f4
^4*f6^2-64*x3^3*x2*f7*f2*f6^2*f3*f4+16*x3^3*x2*f1*f7^3*f2*f4-48*x3^3*x2*f6^2*
f7^2*f1^2-32*x3^3*x2*f3^2*f5*f6*f7*f4-72*x3^3*x2*f7^2*f3*f5^2*f1-24*x3^3*x2*f7
*f3^2*f5^3+32*x3^3*x2*f1*f6^3*f7*f2+64*x3^3*x2*f0*f3*f7*f6^3+16*x3^3*x2*f5^4*
f6*f2-64*x3^3*x2*f1*f6^3*f5*f4-96*x3^3*x2*f0*f6*f4^2*f7^2-96*x3^3*x2*f5*f4^2*
f2*f6*f7+48*x3^3*x2*f3*f6^2*f5*f4^2-8*x3^3*x2*f7^2*f3^2*f2*f6-64*x3^3*x2*f0*f6
^2*f7^2*f2-64*x3^3*x2*f0*f6^3*f5^2-16*x3^3*x2*f1*f6^2*f5^3+96*x3^3*x2*f6^2*f4*
f5^2*f2-8*x3^3*x2*f7^2*f4^3*f2-12*x3^3*x1*f7^2*f2^2*f5*f4+28*x3^3*x1*f4^2*f7^2
*f2*f3-64*x3^3*x1*f1*f6^3*f4^2+224*x3^3*x1*f0*f6*f5*f2*f7^2+16*x3^3*x1*f3*f6^2
*f4^3-484*x3^2*x4^2*f7^2*f3^2*f5*f6+332*x3^2*x4^2*f7*f4*f5^4-112*x3^2*x4^2*f7^
2*f5^3*f2+704*x3^2*x4^2*f7*f3*f5*f4*f6^2+16*x3^2*x4^2*f7^2*f6^2*f2*f3+544*x3^2
*x4^2*f7^3*f0*f6*f4+288*x3^2*x4^2*f7^3*f4*f5*f1-912*x3^2*x4^2*f7^2*f5^2*f3*f4+
1688*x3^2*x4^2*f7^3*f0*f5^2-120*x3^2*x4^2*f7^4*f2*f1+2384*x3^2*x4^2*f7^2*f0*f6
^2*f5-48*x3^2*x4^2*f7^4*f0*f3-64*x3^2*x4^2*f7^3*f2^2*f6+144*x3^2*x4^2*f7^3*f2*
f4^2-80*x3^2*x4^2*f7^2*f2*f4*f5*f6-960*x3^2*x4^2*f6^3*f7*f1*f5-16*x3^2*x1*x4*
f0*f5*f7^3*f2-512*x3^2*x1*x4*f6^2*f7^2*f1^2+56*x3^2*x1*x4*f1*f7^3*f3^2+120*x3^
2*x1*x4*f4^2*f5^4+544*x3^2*x1*x4*f1*f7^2*f6*f2*f5-168*x3^2*x1*x4*f4*f5^3*f3*f6
+72*x3^2*x1*x4*f5*f4*f7^2*f2*f3+464*x3^2*x1*x4*f0*f5^2*f7^2*f4-384*x3^2*x1*x4*
f0*f6^3*f5^2+40*x3^2*x1*x4*f7^2*f2^2*f6*f4+144*x3^2*x1*x4*f3^2*f6^2*f5^2-12*x3
^2*x1*x4*f7^2*f4^2*f3^2-16*x3^2*x1*x4*f7^2*f4^3*f2+448*x3^2*x1*x4*f0^2*f7^4+44
*x3^2*x1*x4*f1^2*f7^3*f5-120*x3^2*x1*x4*f5*f4^2*f2*f6*f7+20*x3^2*x1*x4*f7^2*f3
^3*f5+112*x3^2*x1*x4*f1*f7^3*f2*f4+96*x3^2*x1*x4*f1*f6^2*f5^3-208*x3^2*x1*x4*
f0*f6*f7^3*f1+32*x3^2*x1*x4*f7*f4^4*f5+60*x3^2*x1*x4*f3*f5^5+256*x3^2*x1*x4*f1
*f6^3*f7*f2-72*x3^2*x1*x4*f6*f2*f5^4+112*x3^2*x1*x4*f3*f4^2*f5^2*f7-128*x3^2*
x1*x4*f3*f6^2*f7*f2*f4+48*x3^2*x1*x4*f0*f6*f5*f7^2*f3+320*x3^2*x1*x4*f6*f4*f5^
2*f7*f1-232*x3^2*x1*x4*f7*f2*f4*f5^3-64*x1*x4*x3^2*f0*f6*f5^3*f7-96*x3^2*x1*x4
*f3*f5*f6^3*f2-216*x3^2*x1*x4*f5^2*f4^3*f6-512*x3^2*x1*x4*f3*f6^2*f7*f1*f5+112
*x3^2*x1*x4*f3^2*f5*f6*f7*f4+128*x3^2*x1*x4*f7*f3^2*f5^3-80*x3^2*x1*x4*f7^2*f3
*f5^2*f1-92*x3^2*x1*x4*f1*f5^4*f7-196*x3^2*x1*x4*f1*f7^2*f5*f4^2+336*x3^2*x1*
x4*f6^2*f4*f5^2*f2+232*x3^2*x1*x4*f1*f7^2*f3*f6*f4+144*x2*x4*f0*f5^3*f7^2*x3^2
-384*x3^2*x2*x4*f0*f6*f7^3*f2-48*x3^2*x2*x4*f2*f7^3*f3^2+1664*x3^2*x2*x4*f0*f6
*f5*f7^2*f4+112*x3^2*x2*x4*f0*f7^4*f1+80*x3^2*x2*x4*f5^2*f4^3*f7+72*x3^2*x2*x4
*f5^3*f6*f1*f7+192*x3^2*x2*x4*f4*f6^3*f2*f5-448*x3^2*x2*x4*f0*f5*f7^3*f3-24*x3
^3*x4*f7^3*f3^3+208*x1^2*x2*x3*f0*f6*f3*f1*f7^2-16*x1^2*x2*x3*f6^2*f2^2*f5*f3+
16*x1*x2*x4^2*f5*f4^4*f7-1392*x4^2*x1*x2*f0*f5*f7^3*f2+640*x4^2*x1*x2*f0*f4*f7
^3*f3+16*x1*x2*x4^2*f3*f5*f6^2*f7*f1-280*x4^2*x1*x2*f3*f6*f4*f1*f7^2-4*x4^2*x1
*x2*f7^2*f3^3*f5-36*x4^2*x1*x2*f7^3*f3^2*f1+72*x1*x2*x4^2*f4^2*f5^4+496*x1*x2*
x4^2*f7*f3*f5^2*f6*f2+8*x1*x2*x3^2*f7^2*f3^2*f2*f4+64*x1*x2*x3^2*f3*f5^3*f6*f2
+16*x1*x2*x3^2*f0*f4*f1*f7^3+24*x1*x2*x3^2*f4*f5^3*f1*f6-128*x1*x2*x3^2*f4^2*
f0*f6^3-16*x1*x2*x3^2*f4^5*f6+16*x1*x2*x3^2*f5^2*f4^4+72*x3^2*x1*x2*f1^2*f5^2*
f7^2-20*x3*x6*x1*x2*f2^2*f5^2*f7+24*x3*x6*x1*x2*f3^3*f5*f7-64*x1*x2*x3*x6*f4^2
*f6^2*f1+64*x1*x2*x3*x6*f3*f4^3*f6+32*x1*x2*x3*x6*f3*f5*f6^2*f1-40*x3*x6*x1*x2
*f3*f7^2*f2^2+72*x3*x6*x1*x2*f6*f7*f4*f2^2+244*x3*x6*x1*x2*f4^2*f7*f1*f5+88*x3
*x6*x1*x2*f3*f5^2*f7*f1-144*x3*x6*x1*x2*f0*f4*f3*f7^2+280*x3*x6*x1*x2*f1*f6*f7
*f4*f3-56*x3*x6*x1*x2*f3*f5*f7*f2*f4+24*x1*x2*x3*x6*f5^3*f3^2-36*x1^2*x2*x3*f3
^2*f5^2*f1*f7-112*x3^2*x1*x2*f0*f6*f5*f7^2*f1+128*x3^2*x1*x2*f0*f5*f4*f7^2*f3-\
24*x3^2*x1*x2*f6*f2^2*f5*f7*f4-20*x1*x2*x3^2*f7^2*f3*f4^2*f1-12*x1^2*x2^2*f3^3
*f5^2*f4-12*x1^2*x2^2*f3^3*f6*f4^2+16*x1*x2^2*x3*f2*f6^2*f7*f1*f3+8*x1*x2^2*x3
*f7*f2^2*f5^2*f4-32*x1*x2^2*x3*f3*f6*f4^4-8*x1*x2^2*x3*f1*f5*f7*f2*f4*f6-16*x1
*x2^2*x3*f0*f5*f3^2*f7^2-40*x1^2*x2*x3*f3^2*f6*f4^3+20*x1^2*x2*x3*f3*f5^4*f1+
16*x1^2*x2*x3*f7^2*f3^2*f2^2+8*x1^2*x2*x3*f6*f2*f5^3*f1-208*x1^2*x2*x3*f0*f2*
f1*f7^3-112*x1*x2^2*x3*f0*f5^2*f1*f7^2-32*x1*x2^2*x3*f3*f5^3*f6*f1-64*x1*x2^2*
x3*f1^2*f5^2*f7*f6-16*x1*x2^2*x3*f0*f3*f1*f7^3+176*x1*x2^2*x3*f0*f5^2*f4^2*f7+
16*x1*x2^2*x3*f3*f5*f6*f7*f2^2-32*x1*x2^2*x3*f4^2*f6*f7*f2^2+24*x1*x2*x6^2*f5*
f4^2*f3-64*x1*x2*x6^2*f2*f7*f1*f6+52*x1*x2*x6^2*f7*f2*f3*f4-44*x1*x2*x6^2*f7*
f5*f1*f3+84*x1*x2*x6^2*f1^2*f7^2-12*x1*x2*x6^2*f5^2*f3^2+12*x1^2*x2*x6*f3^3*f5
^2+24*x1^2*x2*x6*f3^3*f6*f4+56*x1*x2^3*f4^2*f7^2*f1^2-8*x1*x2^3*f0*f5^4*f4+48*
x1^2*x2^2*f1*f5*f7*f2*f4^2-32*x1^2*x2^2*f1*f0*f5^2*f6^2+16*x1^2*x2^2*f3*f5^3*
f4*f1-124*x3^2*x1*x2*f5^2*f4^2*f7*f1-64*x1*x2*x3^2*f6^2*f2^2*f5^2+32*x1*x2*x3^
2*f7*f4^4*f3+44*x1*x2*x3^2*f1^2*f7^3*f3-80*x1*x2*x3^2*f0*f6*f5^4-64*x1*x2*x3^2
*f0*f4^3*f7^2-16*x1*x2*x5*x6*f3*f5*f1*f6+64*x1*x2*x5*x6*f3*f4*f2*f6-104*x1*x2*
x5*x6*f7*f3*f4*f1-32*x1*x2*x5*x6*f2^2*f6*f5-40*x1*x2*x5*x6*f7*f2^2*f4+216*x1*
x2*x5*x6*f0*f4^2*f7-168*x1*x2*x4*x6*f1^2*f6*f7^2-224*x1*x2*x4*x6*f7*f3*f4*f2*
f6-144*x1*x2*x4*x6*f7*f3*f5*f1*f6-88*x1*x2*x4*x6*f7*f3^2*f4*f5+288*x1*x2*x4*x6
*f0*f6^2*f5^2-40*x1*x2*x4*x6*f7^2*f3^2*f2+500*x1*x2*x4*x6*f7^2*f3*f4*f1-72*x1*
x2*x4*x6*f3^2*f5^2*f6+24*x1*x2*x4*x6*f6*f5^3*f1+40*x1^2*x2*x6*f1*f7*f2*f3*f6+
12*x1^2*x2*x6*f5^2*f4^2*f1-32*x1^2*x2*x6*f1*f7^2*f2^2+48*x1^2*x2*x6*f1*f6*f5*
f0*f7-32*x1^2*x2*x6*f3*f6*f2*f4^2+128*x1^2*x2*x6*f0*f3*f2*f7^2-288*x1^2*x2*x6*
f5*f0^2*f7^2-100*x1^2*x2*x6*f1^2*f7^2*f3-24*x1^2*x2*x6*f2^2*f5*f4*f6-112*x1^2*
x2*x6*f0*f6*f4*f2*f7+128*x1^2*x2*x6*f2*f4*f6^2*f1-4*x1^2*x2*x6*f7*f2^2*f5*f3+
128*x1^2*x2*x6*f3*f7*f1*f4^2+96*x1^2*x2*x6*f0*f6*f5*f4^2+28*x1^2*x2*x6*f4*f5^2
*f2*f3-32*x1^2*x2*x6*f0*f6*f3^2*f7-12*x2^2*x5*x6*f1*f5*f7*f3-12*x2^2*x5*x6*f3*
f5*f4^2-24*x2^2*x1*x4*f7^2*f2^2*f4^2+8*x2^2*x1*x4*f7^2*f3^4-12*x2^2*x5^2*f4*f5
^2*f1+4*x2^2*x5^2*f2*f5*f4^2-6*x2^2*x5^2*f7*f2^2*f4+8*x2^2*x3*x5*f1*f7*f3*f5^2
+12*x2^2*x3*x5*f7^2*f2^2*f3+12*x2^2*x3*x5*f7*f2^2*f5^2+12*x2^2*x3*x5*f7*f2*f4^
3+12*x2^2*x3*x5*f1*f5^4+8*x2^2*x4*x5*f2*f7^2*f3^2-76*x2^2*x4*x5*f1*f7^2*f2*f5+
16*x2^2*x4*x5*f2^2*f7^2*f4+16*x2^2*x3*x7*f7*f3^2*f5^2+20*x2^2*x5*x7*f7*f2*f5*
f3-36*x2^2*x5*x7*f2*f7^2*f1+4*x2^3*x6*f7^2*f3^2*f1+4*x2^3*x6*f7*f2^2*f5^2-4*x2
^3*x6*f7^2*f2^2*f3-4*x2^3*x6*f7*f2*f4^3+4*x2^3*x6*f1*f5^4+24*x2^2*x3*x6*f4*f5^
3*f3-8*x2^2*x3*x6*f2*f7^2*f3^2+8*x2^2*x5^2*f7*f2*f1*f5-8*x2^2*x1*x6*f2*f3*f5^3
+4*x2^2*x1*x6*f7*f3^3*f4+4*x2^2*x1*x6*f7*f2^2*f4*f5+24*x2^2*x1*x6*f3^2*f5^2*f4
-12*x2^2*x6^2*f3*f5^2*f4+4*x2^2*x7^2*f7*f5^2*f2-16*x2^2*x6*x7*f4^2*f5^2-16*x2^
2*x6*x7*f7*f3*f4^2-16*x2^2*x6*x7*f3^2*f7*f5-32*x2^2*x5*x7*f2*f5*f4*f6-40*x2^2*
x5*x7*f0*f7*f5^2+76*x2^2*x6*x7*f7*f4*f2*f5+32*x2^2*x6*x7*f0*f7*f5*f6-80*x2^2*
x6*x7*f1*f7*f4*f6-16*x2^2*x6*x7*f2*f6*f5^2+176*x2^2*x6*x7*f0*f7^2*f4+24*x2^2*
x5*x7*f5^2*f6*f1+32*x2^2*x5*x7*f0*f6*f7*f4+56*x2^2*x4*x7*f3^2*f5*f6*f7+40*x2^2
*x4*x7*f7*f5*f4^3-176*x2^2*x4*x7*f7*f3*f5^2*f4+144*x2^2*x4*x7*f7^2*f0*f5^2+64*
x2^2*x3*x7*f2*f5*f4*f6^2-72*x2^2*x3*x7*f3*f5*f6*f2*f7-32*x2^2*x3*x7*f7*f3*f5*
f4^2-16*x2^3*x7*f7*f2*f4*f3*f6+12*x2^3*x7*f7*f4*f5^2*f1+64*x2^2*x1*x7*f4^2*f6^
2*f1-56*x2^2*x1*x7*f1*f7*f5*f4^2+24*x2^2*x1*x7*f3^2*f5*f4*f6-16*x2^3*x8*f7^2*
f2*f1*f6-32*x2^3*x8*f7^2*f0*f4*f5-4*x2^2*x3*x8*f7^2*f1*f4*f5+16*x2^2*x3*x8*f7*
f5^2*f3*f4+24*x2^2*x3*x8*f7^2*f2*f5*f3-24*x2^2*x3*x8*f7^2*f1*f3*f6+56*x2^2*x4*
x8*f7^2*f2*f4*f5-32*x2^2*x4*x8*f7^3*f3*f1+16*x2^2*x4*x8*f7*f3*f5^3+32*x2^2*x6*
x8*f7^2*f0*f5-28*x2^2*x6*x8*f7^2*f1*f4+4*x2^2*x7*x8*f7*f5^2*f3-20*x2^2*x7*x8*
f7^2*f1*f5-60*x2^2*x4*x8*f7^2*f1*f5^2+24*x2^2*x3*x8*f7^3*f2*f1+8*x2^3*x8*f7^2*
f2^2*f5+16*x2^3*x8*f7^2*f1*f4^2+24*x2^3*x8*f7^3*f1^2+8*x2^2*x1*x7*f2*f5*f4^2*
f6+24*x2^2*x1*x7*f1*f5*f7*f2*f6+16*x2^3*x7*f0*f7^3*f1+56*x2^3*x7*f1*f7^2*f3*f4
-8*x1^3*x2*f5^2*f4^2*f2^2-8*x1^4*f0*f5^2*f4^2*f3+40*x1^2*x3^2*f7^2*f3^2*f1*f4+
128*x1^2*x3^2*f0*f6*f3*f2*f7^2-8*x1^3*x2*f3^2*f6*f4*f1*f5-128*x1^3*x2*f6^3*f0^
2*f4+64*x1^3*x2*f6^2*f7*f1^3+16*x1^3*x6*f3^2*f5^2*f2+16*x1^3*x6*f0*f6*f4^3-24*
x1^3*x6*f3^2*f6*f1*f5+12*x1^3*x6*f7*f2^3*f5-8*x1^3*x6*f1*f5^3*f2+32*x1^3*x6*f1
^2*f6^2*f4+44*x1^3*x6*f1^2*f2*f7^2-64*x1^3*x6*f1^2*f7*f6*f3-16*x1^3*x6*f0*f5^3
*f3-80*x1^3*x6*f0*f3*f1*f7^2-20*x1^3*x6*f2*f7*f3^3-64*x1^3*x6*f0*f6^2*f3^2-8*
x1^3*x6*f0*f5^2*f4^2+16*x1^3*x6*f6^2*f2^3+4*x2^4*f5^3*f4^2*f2+32*x2^3*x1*f6*f4
*f0^2*f7^2-96*x2^2*x3^2*f1*f5*f7*f4^2*f6-68*x2^2*x3^2*f4*f5^3*f7*f1+8*x2^2*x3^
2*f0*f5*f4^2*f7^2+46*x2^2*x3^2*f7^2*f2^2*f4*f5-16*x2^2*x3^2*f6*f4*f5*f7*f2*f3+
8*x2^4*f1*f6*f5^2*f4^2+32*x2^2*x3^2*f0*f3^2*f7^3+48*x2^2*x3^2*f4*f5^3*f6*f2-16
*x2^2*x3^2*f1*f7^2*f4^3+176*x2^2*x3^2*f0*f6^2*f4^2*f7+16*x2^2*x3^2*f1*f6*f7^2*
f3^2-12*x2^3*x1*f5^3*f7*f1^2+24*x2^4*f0*f3*f1*f7^3-24*x2^4*f0*f4^2*f3*f7^2+4*
x2^4*f5*f4^2*f7*f2*f3+20*x2^2*x1*x3*f1*f5*f7^2*f2*f3-112*x2^2*x1*x3*f5*f4^3*f1
*f7+36*x2^2*x1*x3*f7*f3^2*f4^3+48*x2^2*x3^2*f0*f5*f1*f7^3+16*x2^2*x1*x3*f6*f2*
f5*f4^3-192*x2^2*x3^2*f0*f6^3*f5*f4+80*x1^3*x6*f0*f6*f5*f4*f3+8*x1^3*x6*f7*f3*
f4*f2^2-104*x1^2*x4*x6*f7*f2^2*f5^2+112*x1^2*x4*x6*f7^2*f1*f6*f0+48*x1^2*x4*x6
*f7^2*f2^2*f3-208*x1^2*x4*x6*f7^2*f1^2*f5+168*x1^2*x4*x6*f7^2*f1*f3^2-16*x1^2*
x4*x6*f7*f0*f6*f4^2+34*x2^2*x3^2*f1^2*f7^3*f4-16*x2^3*x1*f0*f6*f5^2*f1*f7+12*
x2^3*x1*f1*f4*f7^2*f2*f3+8*x2^3*x1*f6*f1*f5^3*f2+12*x2^2*x3^2*f3*f5^2*f6*f4^2+
80*x2^2*x3^2*f7^2*f2*f4*f1*f6-128*x2^2*x3^2*f0*f6*f4*f3*f7^2+16*x2^4*f0*f6*f5*
f4*f3*f7-16*x2^2*x3^2*f0*f6^2*f7^2*f1-32*x2^2*x3^2*f3*f5^2*f6*f7*f1+48*x2^4*f4
*f0^2*f7^3-40*x2^3*x1*f2*f6*f7*f1*f4^2+20*x2^3*x1*f1*f5^2*f7*f2*f4-8*x2^3*x1*
f1*f6*f5^2*f3*f4-24*x2^2*x3^2*f7*f2^2*f5^2*f6+12*x2^4*f0*f5^2*f1*f7^2-4*x2^4*
f7^2*f3^2*f4*f1+16*x2^3*x1*f0*f6*f5*f4*f2*f7+8*x2^2*x3^2*f7*f3^2*f4^2*f6-32*x2
^3*x1*f7^2*f0*f2*f4^2+32*x2^3*x1*f0*f2*f1*f7^3+32*x3^3*x1*f7*f2^2*f6^2*f4-16*
x3^4*f4^2*f6^2*f7*f2-50*x3^4*f7^2*f3^2*f4*f5+24*x3^4*f7*f2*f5^4+448*x3^3*x1*f0
*f6*f5^2*f4*f7-16*x3^3*x1*f1*f6^2*f4*f5^2+128*x3^4*f0*f5*f7^3*f3-8*x3^3*x1*f2*
f5^5-40*x3^4*f7*f3^2*f6^2*f4-64*x3^4*f0*f6^4*f5+10*x3^4*f5^2*f4^3*f7+224*x3^4*
f0*f6^2*f5^2*f7+8*x3^4*f7^2*f2*f3*f5^2+28*x3^4*f7^3*f2*f1*f5+48*x3^4*f6^3*f4^2
*f3-48*x3^3*x1*f3*f6*f2^2*f7^2-16*x3^4*f6^2*f2*f3*f5*f7-4*x3^4*f7^3*f2*f3^2+24
*x3^4*f0*f6*f5*f7^2*f4-28*x3^4*f1*f4^2*f7^2*f6-64*x3^4*f1*f6^4*f4-16*x3^4*f7^2
*f2^2*f6*f5-12*x3^4*f0*f7^4*f1-4*x3^4*f7^2*f3^3*f6-80*x3^3*x1*f0*f5*f4^2*f7^2-\
8*x3^3*x1*f7*f3^3*f5*f6+32*x3^3*x1*f1*f6*f5^4-32*x3^3*x1*f5*f4^4*f6+40*x3^3*x1
*f7*f3^2*f4*f5^2-32*x3^3*x1*f0*f6^2*f7^2*f1-20*x3^4*f4*f5^3*f3*f7+20*x3^4*f5^3
*f4^2*f6-24*x3^4*f4^3*f5*f6^2+64*x3^4*f6^3*f2*f4*f5+96*x3^3*x1*f6^2*f2*f7*f1*
f5-96*x3^3*x1*f0*f5^3*f6^2+24*x3^3*x1*f7*f3*f4^3*f5-96*x3^3*x1*f0*f5^4*f7+96*
x3^4*f0*f6^3*f7*f4+32*x1*x3^2*x5*f6^2*f2*f3*f4-8*x1*x3^2*x5*f7*f3^2*f6*f2+128*
x1*x3^2*x2*f6^2*f2*f1*f4*f7-8*x1^2*x3*x5*f1*f6*f4^3+28*x1^2*x3*x5*f7^2*f2^2*f1
+144*x1^2*x3*x5*f3^2*f6*f0*f7-176*x1*x3*x6^2*f0*f7*f5^2-32*x1*x3*x6^2*f3*f4^2*
f6+160*x1*x3*x6^2*f0*f6*f7*f4+12*x1*x3*x6^2*f2*f7^2*f1-24*x1*x3*x6^2*f5^3*f2-\
24*x1*x3*x6^2*f7*f2^2*f6-24*x1*x3*x6^2*f3^2*f6*f5+44*x1*x3*x6^2*f3*f5^2*f4+64*
x1*x3*x6^2*f5^2*f6*f1-192*x1*x3*x6^2*f7*f6*f3*f1+36*x1*x3*x6^2*f7*f3^2*f4+72*
x1*x3*x6^2*f7*f2*f5*f3+16*x2*x3*x6^2*f3*f7*f4^2-20*x2*x3*x6^2*f7*f3^2*f5-12*x2
*x3*x6^2*f3*f5^3+24*x2*x3*x4*x6*f7*f3*f4*f5^2-24*x2*x3*x5*x6*f7*f2*f4^2+12*x2*
x3*x5*x6*f7*f2*f3*f5+84*x1^2*x3*x4*f3*f5^3*f4^2+16*x1*x3*x7^2*f6^2*f3*f4+8*x1*
x3*x7^2*f7*f6*f3^2-32*x1*x3*x7^2*f7*f5^2*f2-48*x1*x3*x7^2*f5*f4^2*f6-32*x1*x3*
x7^2*f6^3*f1-16*x1*x3*x7^2*f0*f7^2*f5+16*x1*x3*x7^2*f6^2*f2*f5+48*x1*x3*x7^2*
f7*f6*f1*f5-64*x1*x3*x7^2*f7^2*f1*f4+40*x1*x3*x7^2*f7^2*f2*f3-56*x1*x3*x7^2*f7
*f2*f4*f6-120*x1^2*x3*x7*f1*f7*f3*f5^2-112*x1^2*x3*x7*f3^2*f5*f4*f6+48*x1^2*x3
^2*f6^2*f4*f3^3+96*x1^2*x3^2*f3^2*f5*f6^2*f2-144*x1^2*x3^2*f0*f6^2*f5^2*f3+8*
x1*x3*x5*x6*f5^2*f2*f4-24*x1*x3*x5*x6*f3^2*f5^2+4*x1^2*x3*x4*f7*f4^4*f3+8*x1*
x3*x5^2*f2*f5^2*f3+4*x1*x3^2*x5*f5*f4^4-128*x1*x3^2*x2*f0*f6^3*f7*f1-32*x1*x3^
2*x2*f1*f6^3*f3*f4+48*x1^2*x3*x7*f6^2*f3^3-192*x1^2*x3*x7*f0*f6^3*f3+16*x1^2*
x3*x7*f3^2*f5^3-256*x1^2*x3*x7*f0*f6^2*f7*f2+192*x1*x3^2*x4*f0*f6^3*f3*f7-8*x1
*x3*x5^2*f3*f6*f2*f4-640*x1*x3*x2*x5*f6*f0^2*f7^2+128*x1*x3*x2*x5*f7*f6^2*f0*
f1-4*x1^2*x3*x7*f5*f4^4+40*x1^2*x3*x7*f7*f2^2*f5^2+128*x1^2*x3^2*f0*f6^3*f5*f2
+512*x1^2*x3^2*f6^3*f0^2*f7-64*x1^2*x3^2*f6^3*f3^2*f1-12*x1^2*x3*x4*f5^2*f4^4-\
32*x1*x3*x5*x7*f7*f6*f2^2+144*x1*x3*x6*x7*f3*f7*f2*f6+8*x1*x3*x6*x7*f7^2*f2^2-\
32*x1*x3*x6*x7*f4^2*f5^2+32*x1*x3*x6*x7*f4^3*f6-44*x1*x3*x6*x7*f7*f3*f4^2+96*
x1*x3*x6*x7*f5^2*f7*f1-88*x1*x3*x6*x7*f3^2*f7*f5+4*x1^2*x3*x5*f3^4*f7-4*x1^2*
x3*x6*f4^3*f3*f5+8*x1*x3*x5*x7*f5*f4^3+16*x1*x3*x5*x7*f7*f2*f4^2+128*x1*x3^2*
x2*f0*f6^2*f5*f2*f7-288*x1*x3^2*x4*f1*f6^3*f5*f4+72*x1*x3*x4*x5*f5^3*f6*f1+32*
x4*x5*x1*x3*f0*f4^2*f7^2+432*x4*x5*x1*x3*f3*f5*f1*f6*f7-8*x4*x5*x1*x3*f4*f5*f7
*f3^2+32*x4*x5*x1*x3*f0*f7^3*f1+40*x4*x5*x1*x3*f4^2*f7*f2*f5+12*x1*x3*x4*x5*f4
*f5^3*f3-528*x4*x5*x1*x3*f0*f6*f5*f4*f7-144*x1*x3*x4*x5*f2*f5^2*f4*f6-8*x1*x3^
2*x5*f1*f5^4+28*x1*x3^2*x2*f7^3*f2^2*f1+48*x1*x3^2*x2*f0*f6*f3^2*f7^2+512*x1*
x3^2*x2*f6^2*f0^2*f7^2+4*x1^2*x3*x5*f2^2*f5^3-4*x1^2*x3^2*f4^4*f6*f3+52*x1^2*
x3^2*f3^3*f7*f5*f4-36*x1^2*x3^2*f3^3*f5^2*f6-48*x1^2*x3*x4*f2^3*f6*f7^2-24*x1^
2*x3*x4*f6*f4^3*f5*f3-36*x1^2*x3*x6*f3^2*f5^2*f4-64*x1^2*x3*x6*f0*f6^3*f2+40*
x1^2*x3*x6*f3^2*f4^2*f6-16*x1^2*x3*x6*f4^3*f6*f2+24*x1*x3*x7^2*f4*f5^3-108*x1*
x3*x4*x6*f7*f3*f5*f4^2+352*x1*x3*x4*x6*f1*f5*f7^2*f3+72*x1*x3*x4*x6*f7^2*f2^2*
f5+120*x1*x3*x4*x6*f7^2*f2*f3*f4+248*x1*x3*x4*x6*f5^3*f7*f1-96*x1*x3*x4*x6*f5^
3*f4^2+80*x1*x3*x4*x6*f4*f7*f6*f1*f5-288*x1*x3*x4*x6*f2*f5*f4*f6^2+272*x1*x3*
x4*x6*f0*f6*f7*f5^2-16*x1*x3*x4*x6*f7*f3^2*f6*f4-528*x1*x3*x4*x6*f0*f7^2*f4*f5
-24*x1*x3^2*x5*f6*f3^2*f5*f4+32*x1*x3*x2*x5*f3*f6^2*f1*f4+144*x1*x3*x2*x5*f0*
f5*f1*f7^2-72*x1^2*x3*x4*f7*f2*f5*f4^3-8*x1^2*x3*x4*f7^2*f3^4-48*x1^2*x3*x4*f1
*f6^2*f5*f4^2-4*x1^2*x3^2*f2^2*f6*f7^2*f1+48*x1^2*x3^2*f0*f3*f1*f7^3-256*x4*x5
*x1*x3*f2*f6^2*f7*f1-256*x4*x5*x1*x3*f0*f6^2*f3*f7+48*x4*x5*x1*x3*f3*f6*f7*f2*
f4-256*x4*x5*x1*x3*f0*f6*f2*f7^2-132*x4*x5*x1*x3*f4*f5^2*f1*f7+12*x4*x5*x1*x3*
f4^3*f7*f3+16*x4*x5*x1*x3*f7*f1*f6*f4^2-160*x1*x3*x4*x5*f0*f5^3*f7-136*x4*x5*
x1*x3*f1*f4*f3*f7^2+8*x4*x5*x1*x3*f2*f5^2*f7*f3-296*x4*x5*x1*x3*f1*f5*f2*f7^2-\
16*x4*x5*x1*x3*f6*f7*f5*f2^2-20*x4*x5*x1*x3*f7^2*f4*f2^2+528*x4*x5*x1*x3*f6*f7
^2*f1^2+24*x1*x3*x4*x5*f5^2*f4^3-176*x2*x3*x4*x6*f6*f5^2*f1*f7+88*x2*x3*x4*x6*
f3*f7*f4^2*f6-176*x2*x3*x4*x6*f6^2*f4*f1*f7+32*x2*x3*x4*x6*f7*f3^2*f5*f6-144*
x2*x3*x4*x6*f4*f5^4-192*x2*x3*x5*x6*f0*f6^2*f5-24*x2*x3*x5*x6*f3*f4*f5^2-32*x2
*x3*x5*x6*f2^2*f7*f6+64*x2*x3*x5*x6*f1*f6^2*f4+8*x2*x3*x5*x6*f3^2*f4*f7+200*x2
*x3*x5*x6*f0*f5^2*f7+64*x2*x3*x5*x6*f2*f4*f5*f6-24*x2*x3*x5*x6*f7*f3*f1*f6-180
*x2*x3*x5*x6*f4*f5*f7*f1+336*x2*x3*x5*x6*f0*f6*f7*f4+896*x2*x3*x4*x6*f0*f6^2*
f5*f7-400*x2*x3*x4*x6*f0*f5^2*f7^2+32*x2*x3*x4*x6*f2^2*f7^2*f6-136*x2*x3*x4*x6
*f7*f2*f4*f5*f6-48*x2*x3*x4*x6*f5*f4^3*f7-1600*x2*x3*x4*x6*f0*f6*f7^2*f4+72*x2
*x3*x4*x6*f7^2*f2*f3*f5+512*x2*x3*x4*x6*f4*f5*f7^2*f1-96*x2*x3*x4*x6*f5^2*f4^2
*f6+168*x2*x3*x4*x6*f2*f7^2*f4^2-192*x2*x3*x4*x6*f6^2*f2*f5^2+224*x2*x3*x4*x6*
f7*f2*f5^3+32*x2*x3^2*x6*f3*f6^2*f1*f7-24*x2^2*x3*x6*f3*f4^2*f6*f5+20*x2*x3*x7
^2*f7*f5*f4^2+48*x2*x3*x7^2*f3*f6^2*f5-48*x2*x3*x7^2*f7*f3*f4*f6-8*x2*x3*x7^2*
f7*f5*f2*f6-64*x2*x3*x7^2*f0*f6*f7^2+24*x2*x3*x7^2*f5^2*f6*f4-28*x2*x3*x7^2*f7
*f5^2*f3-16*x2*x3*x7^2*f6^2*f7*f1+24*x2*x3*x1*x7*f3^2*f5^2*f6-32*x2*x3*x1*x7*
f0*f6^2*f5^2-24*x1*x3*x2*x6*f7*f3^2*f6*f2+24*x1*x3*x2*x6*f6*f3^2*f5*f4-84*x1^2
*x3^2*f3^2*f5*f6*f4^2+20*x1^2*x3^2*f7*f3^2*f4^3+12*x1^2*x3^2*f7^2*f3^3*f2-40*
x1^2*x3^2*f0*f5^2*f4^2*f7-32*x1*x3^2*x8*f7*f0*f6^2*f5-12*x1*x3^2*x8*f7^2*f2*f5
*f3+32*x1*x3^2*x8*f7^2*f2^2*f6+32*x1*x3^2*x8*f7*f2*f5*f4*f6+24*x1*x3*x4*x8*f7^
3*f2^2+56*x1*x3*x4*x8*f7*f5^2*f6*f2-96*x1*x3*x4*x8*f7^2*f1*f5^2-128*x1*x3*x4*
x8*f7^2*f2*f4*f5-80*x1*x3*x4*x8*f7^2*f1*f4*f6+176*x1*x3*x4*x8*f7^2*f0*f5*f6+32
*x1*x3*x5*x8*f7*f1*f4*f6-24*x1*x3*x6*x8*f7*f2*f4*f6+16*x1*x3*x6*x8*f7^2*f2*f3+
36*x1*x3*x6*x8*f7^2*f1*f4+64*x1*x3*x6*x8*f7*f0*f6^2-24*x1*x3*x6*x8*f7*f6*f1*f5
-32*x1*x3*x7*x8*f7*f6^2*f1+16*x1*x3*x7*x8*f7*f6*f2*f5-52*x1*x3*x7*x8*f7^2*f2*
f4+64*x1*x3*x7*x8*f7^2*f0*f6-36*x1*x3*x7*x8*f7^2*f1*f5-16*x1*x3*x5*x8*f7^2*f2^
2+12*x1*x3*x5*x8*f7^2*f3*f1-8*x1^2*x3^2*f2^3*f5*f7^2-336*x1^2*x3*x4*f3^2*f6*f5
^2*f4-24*x1^2*x3*x4*f5^5*f1+72*x2*x3*x1*x4*f3^2*f6*f5^3-96*x2*x3*x1*x4*f0*f6^2
*f5^3-96*x2*x3*x1*x4*f6^2*f2*f3*f5^2+16*x2*x3*x5^2*f2*f4^2*f6+8*x2*x3*x5^2*f2*
f5^2*f4+136*x2*x3*x5^2*f0*f5*f7*f4+24*x2*x3*x5^2*f7*f2*f1*f6-12*x2*x3*x5^2*f7*
f2*f3*f4-32*x2*x3*x5^2*f4*f6*f1*f5-96*x2*x3*x5^2*f0*f6^2*f4+16*x2*x3*x1*x5*f0*
f6*f4*f3*f7-344*x4^2*x2*x3*f7^2*f3*f5*f2*f6+224*x4^2*x2*x3*f1^2*f7^4+128*x2*x3
*x4^2*f3*f6^2*f1*f7^2+208*x4^2*x2*x3*f1*f7^3*f4^2-608*x2*x3*x4^2*f0*f7^4*f2+72
*x4^2*x2*x3*f1*f7^2*f4*f5*f6+288*x2*x3*x4^2*f7^3*f2^2*f5+432*x2*x3*x4^2*f3*f5^
3*f6^2-176*x2*x3*x4^2*f3^2*f6^2*f5*f7+216*x2*x3*x4^2*f4*f5^4*f6+688*x2*x3*x4^2
*f2*f5*f4*f6^2*f7+200*x2*x3*x4^2*f4^2*f5^3*f7-256*x2*x3*x4^2*f7*f3*f5^4-864*x2
*x3*x4^2*f1*f5^2*f7*f6^2-8*x1^2*x3^2*f3^4*f6*f7+26*x1^2*x3^2*f3^2*f5^3*f4+32*
x2*x3^2*x4*f1*f6^3*f7*f3-48*x2*x3^2*x4*f5*f4^3*f6^2+224*x1*x3*x4*x6*f7*f2*f5^2
*f4-352*x1*x3*x4*x6*f0*f7^3*f2+312*x1*x3*x4*x6*f3*f5^2*f6*f4-336*x1*x3*x4*x6*
f5^2*f6^2*f1+576*x1*x3*x4*x6*f0*f6^3*f5-144*x1*x3*x4*x6*f3^2*f6^2*f5+176*x1*x3
*x4*x6*f2^2*f7*f6^2-16*x1*x3*x5^2*f0*f5^3-32*x1*x3*x5^2*f3*f6*f1*f5+32*x1*x3*
x5^2*f7*f2*f1*f5+48*x1*x3*x5^2*f2*f1*f6^2-72*x1*x3*x5^2*f1^2*f7*f6+80*x1*x3*x5
^2*f0*f6*f4*f5-16*x1*x3*x5^2*f2^2*f6*f5+4*x1*x3*x5^2*f1*f7*f3*f4-8*x1^2*x3*x5*
f2*f5^2*f6*f1+144*x1^2*x3*x5*f0*f5^2*f6*f3-96*x1^2*x3*x5*f0*f6^2*f4*f3-20*x1^2
*x3*x5*f1*f5^3*f3+8*x1^2*x3*x5*f3^2*f5*f4^2-96*x1^2*x3*x5*f7^2*f0*f2*f3+128*x1
^2*x3*x5*f0*f6^3*f1-96*x1^2*x3*x5*f0*f6^2*f2*f5+48*x1^2*x3*x4*f3^2*f5^4-72*x1^
2*x3*x4*f4*f5^4*f2+104*x1^2*x3*x4*f3^3*f5^2*f7+56*x1^2*x3*x4*f3^3*f6*f7*f4-264
*x1*x3*x2*x4*f3*f5^2*f6*f4^2+36*x1^2*x3*x7*f7*f3^2*f4^2+16*x1*x3*x2*x8*f7*f4^2
*f6*f2-12*x1*x3*x2*x8*f7^2*f2*f3*f4-32*x1*x3*x2*x8*f7*f0*f6^2*f4-16*x1*x3^2*x8
*f7^2*f1*f3*f6-24*x1*x3^2*x8*f7^2*f2*f4^2-48*x1*x3^2*x8*f7*f1*f6^2*f4-32*x1*x3
^2*x8*f7^3*f2*f1+8*x1*x3^2*x8*f7*f5^2*f6*f1-36*x1*x3^2*x8*f7^2*f1*f4*f5+96*x1*
x3*x4*x7*f5^2*f6^2*f2+96*x1*x3*x4*x7*f5*f6^2*f3*f4+192*x1*x3*x4*x7*f3^2*f5*f6*
f7-36*x1*x3*x4*x7*f7^2*f3^2*f4+112*x1*x3*x4*x7*f7^2*f0*f5^2+192*x1*x3*x4*x5*f6
^2*f4*f1*f5+64*x4*x5*x1*x3*f0*f5*f3*f7^2-32*x1*x3*x2*x5*f0*f3^2*f7^2-96*x1*x3*
x2*x5*f0*f6*f5*f2*f7+112*x1*x3*x2*x5*f0*f4*f7^2*f2+64*x1*x3*x2*x5*f0*f5^2*f3*
f7+12*x1*x3*x2*x5*f5*f4^3*f3+480*x4^2*x1*x3*f6^2*f2*f1*f7^2-104*x4^2*x1*x3*f4*
f6*f7^2*f2*f3-712*x4^2*x1*x3*f7^2*f6*f5*f3*f1-288*x1*x3*x4^2*f6^3*f1*f5^2+56*
x4^2*x1*x3*f3^2*f7^3*f2-16*x4^2*x1*x3*f1*f7^4*f0+24*x1*x3*x4^2*f7*f3*f5*f4^2*
f6+144*x1^2*x3*x4*f3^3*f5*f6^2+4*x1*x3^2*x2*f7^2*f3^4-88*x1*x3*x2*x7*f3*f5*f4^
2*f6-24*x2*x7*x1*x3*f3^2*f7^2*f2-40*x1*x3*x4^2*f7*f2*f5^2*f4*f6-352*x1*x3*x4^2
*f7*f6^2*f4*f1*f5+664*x4^2*x1*x3*f2*f1*f7^3*f5+216*x1*x3*x4^2*f4*f5^5+1088*x4^
2*x1*x3*f0*f6*f4*f7^2*f5+144*x4^2*x1*x3*f6*f7^2*f2^2*f5+32*x4^2*x1*x3*f4^2*f6*
f1*f7^2-88*x4^2*x1*x3*f4*f5^2*f1*f7^2-192*x4^2*x1*x3*f0*f4^2*f7^3-12*x4^2*x1*
x3*f7^3*f2^2*f4-432*x1*x3*x4^2*f5^3*f4^2*f6+320*x4^2*x1*x3*f0*f5^3*f7^2+352*x3
^2*x2*x4*f0*f6^2*f5^2*f7+72*x2^2*x3*x4*f4*f5^3*f3*f6+112*x2^2*x3*x4*f1*f7*f4^2
*f6^2+48*x2*x3*x5^2*f0*f6*f5^2+48*x1*x3*x4*x6*f7*f2*f3*f5*f6-48*x1*x3*x4*x6*f7
*f2*f4^2*f6-576*x1*x3*x4*x6*f0*f7^2*f6*f3-56*x3^3*x1*f4^2*f5^2*f3*f6+92*x3^4*
f0*f5^3*f7^2-64*x3^4*f4*f5^2*f2*f6*f7-56*x3^3*x1*f7*f2*f5^2*f4^2+12*x3^4*f7*f4
^4*f6-8*x3^3*x1*f1^2*f5*f7^2*f6-16*x3^3*x1*f0*f3^2*f7^3+10*x3^4*f4*f5^5-72*x3^
2*x4*x6*f5^5+28*x3^2*x7^2*f6*f5^3+48*x3^2*x7^2*f7^3*f0+48*x3^2*x7^2*f6^3*f3-24
*x3^2*x6*x7*f5^4+8*x3^3*x7*f5^5+36*x3^2*x6^2*f5^3*f4+24*x3^3*x4*f5^6+180*x4^2*
x6^2*f6*f5^3+640*x4^2*x6^2*f0*f7^3+108*x4^2*x1*x7*f5^5+92*x4^2*x7^2*f2*f7^3+46
*x4^4*f7^3*f4^3+108*x4^3*x1*f5^6+72*x3*x4*x6^2*f5^4+36*x1*x4*x7^2*f5^4+4*x5^2*
x6^2*f2*f5+4*x5^4*f0*f5+12*x5^2*x7^2*f3*f6+40*x5^2*x6^2*f7*f0+36*x4^2*x5*x6*f5
^4+2*x6^4*f4*f5-24*x6^3*x4*f5^3+24*x6^2*x3*x7*f5^3+20*x6^2*x7^2*f5*f6+6*x6^2*
x7^2*f7*f4+4*x6^4*f7*f2+4*x6^4*f3*f6-8*x6^3*x7*f5^2-16*x3^4*f7^2*f3*f4^3-128*
x3^2*x1*x7*f0*f6^3*f5-128*x3^2*x1*x7*f0*f6*f7^2*f3-56*x3^2*x1*x7*f4*f5^2*f3*f6
-92*x3^2*x1*x7*f1*f7^2*f4^2-64*x3^2*x1*x7*f0*f6^2*f7*f4+48*x3^2*x5*x7*f4^2*f6*
f5-192*x3^2*x5*x7*f0*f6^2*f7-64*x3^2*x5*x7*f6^2*f2*f5+96*x3^2*x5*x7*f6^3*f1-8*
x5*x7*x3^2*f0*f7^2*f5-64*x3^2*x6*x7*f1*f7^2*f5-64*x3^2*x6*x7*f6^3*f2-80*x3^2*
x6*x7*f4*f5^2*f6-8*x3^2*x6*x7*f7*f4*f6*f3-4*x3^2*x6*x7*f7*f3*f5^2+88*x3^2*x6*
x7*f7*f2*f5*f6+28*x3^2*x5*x7*f4*f7^2*f1-96*x3^2*x5*x7*f6^2*f3*f4+40*x3^2*x5*x7
*f3^2*f7*f6+32*x3^2*x5*x7*f7*f6*f2*f4+256*x3^2*x4*x7*f7*f6^2*f3*f4-32*x3^2*x4*
x7*f7^2*f5^2*f2-176*x3^2*x4*x7*f7*f5^2*f3*f6+184*x3^2*x4*x7*f7*f5^3*f4+640*x3^
2*x4*x7*f7^2*f0*f6^2-184*x3^2*x4*x7*f7^2*f3^2*f6+64*x3^3*x7*f5*f6^3*f2+28*x3^3
*x7*f7^2*f5^2*f1+16*x3^3*x7*f5*f6^2*f1*f7-60*x3^3*x7*f4^2*f7^2*f3-24*x3^3*x7*
f7*f3*f5*f4*f6-192*x3^2*x2*x7*f0*f6*f4*f7^2-128*x3^2*x2*x7*f0*f3*f7^3+24*x3^2*
x2*x7*f5*f4^3*f7-96*x3^2*x2*x7*f6^3*f1*f5-68*x3^2*x2*x7*f7*f2*f5^3+48*x3^2*x2*
x7*f7^2*f3^2*f4+64*x3^2*x2*x7*f2^2*f7^2*f6-4*x3^2*x1*x7*f7^2*f3^3-72*x3^2*x1*
x7*f5*f4^3*f6+112*x3^2*x1*x7*f6^2*f2*f4*f5+32*x3^2*x1*x7*f1*f5^2*f6^2+16*x3^2*
x1*x7*f7*f3^2*f6*f4-72*x3^2*x1*x7*f2*f7*f4^2*f6+20*x3^2*x2*x8*f7*f4^2*f5^2+16*
x3^2*x2*x8*f7*f4*f6^2*f2-32*x3^2*x2*x8*f7*f6^2*f1*f5+24*x3^2*x2*x8*f7^2*f4^2*
f3-80*x3^2*x2*x8*f7^2*f4*f6*f1+48*x3^2*x2*x8*f7^2*f0*f6*f5-48*x3^2*x2*x8*f7^3*
f0*f4+8*x3^2*x2*x8*f7^3*f3*f1-16*x3^3*x8*f7*f5*f4^2*f6+16*x3^3*x8*f7^3*f4*f1-\
16*x3^3*x8*f7^2*f5*f1*f6+48*x3^3*x8*f7^2*f5*f3*f4-32*x3^3*x8*f7*f6^3*f1+8*x3^3
*x8*f7^3*f2*f3+32*x3^3*x8*f7*f2*f5*f6^2-144*x3^3*x8*f7^3*f0*f5+128*x3^3*x8*f7^
2*f0*f6^2+52*x3^2*x4*x8*f7*f5^4-72*x3^2*x4*x8*f7^3*f2*f4+448*x3^2*x4*x8*f7^3*
f0*f6+48*x3^2*x4*x8*f7^3*f3^2+200*x3^2*x4*x8*f7^2*f5*f4^2+56*x4*x8*f7*x3^2*f4*
f6*f5^2-112*x3^2*x4*x8*f7^2*f1*f6^2-128*x3^2*x5*x8*f7^2*f0*f6-32*x3^2*x5*x8*f7
*f6*f2*f5+24*x3^2*x6*x8*f7^2*f1*f6+112*x3^2*x6*x8*f7^3*f0-44*x3^2*x6*x8*f7^2*
f3*f4-32*x3^2*x6*x8*f7*f6^2*f2-48*x3^2*x6*x8*f7*f4*f5^2+8*x7*x8*f7*x3^2*f4*f5*
f6+76*x3^2*x7*x8*f7^2*f4^2-48*x3^2*x7*x8*f7^2*f2*f6+20*x3^2*x7*x8*f7*f5^3+48*
x3^2*x7*x8*f7*f3*f6^2+44*x7*x8*f7^2*x3^2*f3*f5+48*x3^2*x5*x8*f7*f6^2*f1+24*x3^
2*x5*x8*f7^2*f2*f4+136*x3^2*x4*x8*f7^2*f3*f6*f4+172*x3^2*x4*x8*f7^2*f3*f5^2-\
144*x3^2*x4*x8*f7^3*f1*f5+128*x3^2*x4*x8*f7*f3*f6^2*f5+8*x3^3*x8*f7*f3*f6*f5^2
+24*x3^3*x8*f7^2*f4^3-48*x3^3*x8*f7^2*f6*f2*f4+32*x3^3*x8*f7*f6^2*f4*f3+8*x3^3
*x8*f7^2*f3^2*f6+24*x3^3*x8*f7*f5^3*f4+16*x3^3*x8*f7^2*f5^2*f2+20*x3^2*x2*x8*
f7^2*f5*f3^2+32*x3^2*x2*x8*f7*f2*f6*f5^2+20*x3^2*x1*x7*f3*f5^4+24*x3^2*x1*x7*
f1*f6*f7^2*f2-24*x3^2*x1*x7*f5^3*f6*f2-32*x3^2*x2*x7*f2*f7^2*f4^2+28*x3^2*x2*
x7*f4*f5^4-40*x3^2*x2*x7*f3*f7*f4^2*f6+48*x3^2*x2*x7*f4*f5*f7^2*f1-152*x3^2*x2
*x7*f0*f5^2*f7^2-72*x3^2*x2*x7*f4*f7*f6*f2*f5+64*x3^2*x2*x7*f5^2*f6^2*f2+64*x3
^2*x2*x7*f4*f6^3*f2+96*x3^2*x2*x7*f3*f5*f4*f6^2+32*x3^2*x2*x7*f7^2*f3*f1*f6-48
*x3^2*x2*x7*f7*f3^2*f5*f6+88*x3^2*x2*x7*f6*f5^2*f1*f7-28*x3^2*x2*x7*f7*f5^2*f3
*f4-4*x3^2*x2*x7*f7^2*f2*f3*f5-16*x3^2*x2*x7*f6^2*f4*f1*f7-64*x3^2*x2*x7*f6^2*
f2*f7*f3+32*x3^2*x2*x7*f4^2*f5^2*f6-48*x3^3*x7*f1*f7^2*f4*f6+48*x3^3*x7*f4^3*
f7*f6-32*x3^3*x7*f5*f4^2*f6^2-8*x3^3*x7*f5^3*f7*f3-64*x3^3*x7*f6^4*f1+128*x3^3
*x7*f0*f6^3*f7+36*x3^3*x7*f7^2*f2*f4*f5-48*x3^3*x7*f7^2*f5*f3^2+96*x3^3*x7*f6^
3*f4*f3-32*x3^3*x7*f0*f6*f5*f7^2+80*x3^3*x7*f0*f4*f7^3-32*x3^3*x7*f6^2*f2*f4*
f7-48*x3^3*x7*f7*f2*f5^2*f6-12*x3^3*x7*f7^3*f3*f1-48*x3^3*x7*f3^2*f6^2*f7+48*
x3^3*x7*f6*f5^3*f4+48*x3^3*x7*f2*f7^2*f3*f6+24*x3^3*x7*f7*f5^2*f4^2-288*x3^2*
x4*x7*f6^3*f1*f7-80*x3^2*x4*x7*f7^2*f4^3+88*x3^2*x4*x7*f7^3*f2*f3-24*x3^2*x4*
x7*f7^2*f6*f2*f4+8*x3^2*x4*x7*f7^2*f5*f1*f6-464*x3^2*x4*x7*f7^2*f5*f3*f4+296*
x3^2*x4*x7*f7*f4^2*f6*f5+304*x3^2*x4*x7*f7^3*f0*f5+128*x3^2*x4*x7*f6^2*f2*f7*
f5+288*x3^2*x4*x7*f6^3*f3*f5+168*x3^2*x4*x7*f6*f5^4-24*x3^2*x2*x6*f1*f7^2*f4^2
-68*x3^2*x2*x6*f4^2*f5^3-320*x3^2*x2*x6*f0*f6^2*f7*f4+192*x3^2*x2*x6*f0*f6^3*
f5-48*x2*x6*f3*f6*f2*f7*x3^2*f5-8*x3^2*x2*x6*f4^4*f7+64*x3^2*x2*x6*f7*f2*f4^2*
f6-4*x3^2*x2*x6*f7*f3*f4^2*f5-8*x3^2*x2*x6*f7*f3^2*f6*f4-16*x3^2*x2*x6*f1*f5^2
*f6^2+120*x3^2*x2*x6*f1*f7^2*f3*f5+84*x3^2*x2*x6*f1*f5^3*f7-8*x3^2*x2*x6*f1*f6
*f7^2*f2-384*x3^2*x2*x6*f0*f6*f5^2*f7+4*x3^2*x2*x6*f4*f5^2*f2*f7-240*x3^2*x2*
x6*f0*f5*f7^2*f4+40*x3^2*x2*x6*f7*f3^2*f5^2-24*x3^2*x2*x6*f7^2*f2^2*f5+32*x3^2
*x2*x6*f2^2*f6^2*f7-8*x3^2*x2*x6*f5*f4^3*f6-128*x3^2*x2*x6*f0*f6*f7^2*f3+12*x3
^2*x2*x6*f7^2*f3*f4*f2-96*x3^2*x2*x6*f6^2*f2*f4*f5-448*x3^3*x6*f0*f6^2*f5*f7+
16*x3^3*x6*f6^2*f4^3-32*x3^3*x6*f6*f4^2*f5^2-96*x3^3*x6*f0*f7^3*f3+16*x3^3*x6*
f2^2*f7^2*f6-68*x3^3*x6*f7*f2*f5^3-28*x3^3*x6*f2*f7^3*f1-16*x3^3*x6*f5*f4^3*f7
-32*x3^3*x6*f6^3*f1*f5-32*x3^3*x6*f6^2*f2*f5^2+8*x3^3*x6*f3*f5^3*f6-20*x3^3*x6
*f2*f7^2*f4^2-232*x3^3*x6*f0*f5^2*f7^2+128*x3^3*x6*f0*f6^4-24*x3^3*x6*f3^2*f5*
f6*f7-12*x3^3*x6*f7^2*f2*f3*f5+28*x3^3*x6*f7*f5^2*f3*f4-32*x3^3*x6*f4*f5^4-64*
x3^3*x6*f6^3*f2*f4-32*x3^2*x4*x6*f2^2*f7^3-124*x3^2*x4*x6*f7*f5^2*f4^2-80*x3^2
*x4*x6*f3^2*f6^2*f7+104*x3^2*x4*x6*f7*f3*f5*f4*f6-40*x3^2*x4*x6*f7*f5^3*f3-48*
x3^2*x5^2*f6^2*f4*f1+56*x3^2*x5^2*f0*f5^2*f7+12*x3^2*x5^2*f3*f4^2*f6+24*x3^2*
x5^2*f1*f7*f3*f6+56*x3^2*x5^2*f0*f6*f4*f7+64*x3^2*x1*x5*f2^2*f6^2*f5+8*x3^2*x1
*x5*f5^2*f3*f4^2-16*x3^2*x1*x5*f7^2*f0*f1*f6-16*x3^2*x1*x5*f1*f6*f7*f3*f4+40*
x3^2*x1*x5*f1^2*f7^2*f5-48*x3^2*x1*x5*f2*f5*f4^2*f6+68*x3^2*x1*x5*f7*f3*f5^2*
f1+56*x3^2*x1*x5*f1*f6*f4*f5^2-96*x3^2*x1*x5*f7^2*f0*f2*f5-216*x3^2*x1*x5*f7*
f0*f4*f5^2+80*x3^2*x1*x5*f0*f6*f5^3-128*x3^2*x1*x5*f4*f0*f6^2*f5-32*x3^2*x1*x5
*f7*f0*f3*f5*f6+48*x3^2*x1*x5*f7^2*f0*f3*f4-112*x3^2*x1*x5*f2*f5*f7*f1*f6-64*
x3^2*x1*x5*f2*f5^2*f3*f6-36*x3^2*x1*x5*f4^2*f5*f7*f1+12*x3^2*x1*x5*f3^2*f5^3-4
*x3^2*x1*x5*f2*f5^3*f4+80*x3^2*x1*x5*f1*f6^2*f3*f5-8*x3^2*x1*x5*f4^3*f3*f6+144
*x3^2*x1*x5*f1^2*f6^2*f7+12*x3^2*x1*x5*f2*f4^3*f7+432*x3^2*x4^2*f5^2*f6^3*f3-\
200*x3^2*x4^2*f7*f3*f5^3*f6+208*x3^2*x4^2*f7*f6*f4^2*f5^2-168*x3^2*x4^2*f7^3*
f3^2*f4+244*x3^2*x4^2*f7^3*f2*f5*f3-240*x3^2*x4^2*f7^2*f6^2*f4*f1+576*x3^2*x4^
2*f7*f2*f5^2*f6^2-228*x3^2*x4^2*f7^2*f5*f4^3-112*x3^2*x4^2*f7^2*f6*f5^2*f1+16*
x3^2*x4^2*f7^2*f3*f4^2*f6+96*x3^2*x4^2*f7^3*f3*f1*f6-16*x3^4*f7^3*f4*f3*f1-32*
x3^4*f6*f7^3*f1^2+16*x3^4*f6^2*f2*f5^3+48*x3^4*f7^2*f3*f4*f2*f6-80*x3^4*f0*f6^
2*f7^2*f3+32*x3^4*f1*f6^3*f7*f3+20*x3^4*f7^2*f2*f5*f4^2+8*x3^4*f6*f4^2*f7*f5*
f3+36*x3^4*f0*f4^2*f7^3+4*x3^4*f4*f5^2*f1*f7^2+32*x3^4*f1*f5*f7*f6^2*f4-88*x3^
4*f1*f5^3*f7*f6-4*x3^4*f5^4*f6*f3+48*x3^4*f0*f6*f7^3*f2-24*x3^4*f7^2*f6*f5*f3*
f1+24*x1*x4*x3*x7*f7*f4^3*f5-8*x1*x4*x2*x6*f7*f3^3*f6-48*x1^2*x4*x6*f3^2*f5^3+
24*x1^2*x4*x6*f7*f2^2*f6*f4+48*x1^2*x4*x6*f6^2*f2^2*f5+264*x1^2*x4*x6*f1*f7*f3
*f5^2-12*x1^2*x4*x6*f7*f3^2*f4^2-56*x1*x4*x7^2*f1*f7^2*f5+4*x4^3*x3*f4^2*f7^3*
f3+292*x4^2*x2*x6*f2*f7^2*f4*f5-8*x4^2*x3*x6*f7^2*f4^3-312*x1*x4^3*f7*f2*f5^3*
f6+320*x4^3*x1*f5*f7^3*f3*f1-32*x4^3*x1*f3*f6^2*f1*f7^2+24*x4^3*x1*f2*f5^2*f7^
2*f4-24*x1*x4^3*f5*f4^3*f7*f6-528*x1*x4^3*f1*f5^2*f7*f6^2-72*x1*x4*x6^2*f2*f6*
f5^2+20*x1*x4*x6^2*f7*f2*f4*f5+112*x1*x4*x6^2*f2*f7*f3*f6-144*x1*x4*x6^2*f7*f5
^2*f1-416*x1*x4*x6^2*f0*f6*f5*f7+16*x1^2*x4*x6*f0*f5*f2*f7^2+24*x1^2*x4*x6*f1*
f5^4+144*x1*x4^2*x6*f5^2*f4^2*f6+896*x1*x4^2*x6*f0*f6^2*f5*f7-16*x1*x4^2*x6*f6
^2*f2*f3*f7-8*x1*x4^2*x6*f6*f5^2*f1*f7-288*x1*x4^2*x6*f0*f6*f7^2*f4+112*x1*x4^
2*x6*f0*f5^2*f7^2+104*x1*x4^2*x6*f2^2*f7^2*f6+72*x1*x4^2*x6*f3*f5^3*f6+340*x1*
x4^2*x6*f7^2*f2*f3*f5-52*x1*x4^2*x6*f4*f5*f7^2*f1+24*x3^2*x1*x5*f7^2*f2^2*f3-8
*x3^2*x5^2*f7*f2*f3*f5-80*x3^2*x1*x6*f7*f3^2*f4*f5+20*x3^2*x5*x7*f7*f5^2*f2-4*
x3^2*x5*x7*f5^3*f4-24*x3^2*x5*x7*f7^2*f2*f3+16*x3^2*x5*x7*f7*f5*f3*f4-36*x3^2*
x6*x7*f7^2*f2*f4-40*x3^2*x6*x7*f7*f4^2*f5+52*x3^2*x1*x7*f7*f3*f4^2*f5+20*x3^2*
x2*x8*f7^2*f2*f4*f5+12*x2*x8*f7*x3^2*f3*f5^3-8*x5*x8*f7*x3^2*f3*f5^2+4*x3^2*x5
*x8*f7*f5*f4^2-28*x6*x8*f7^2*f2*x3^2*f5+8*x3^2*x1*x7*f4^4*f7+8*x1*x5*f3^3*f7*
x3^2*f5-12*x3^2*x2*x5*f7*f3*f4^3+12*x3^2*x2*x5*f7^2*f2*f3^2+12*x3^2*x2*x5*f4*
f5^3*f3+44*x3^2*x2*x5*f7*f2*f5*f4^2+16*x1^2*x3^2*f4^3*f5^2*f3-128*x1^2*x3^2*f0
*f6^2*f3^2*f7-16*x1^2*x3^2*f6^3*f2^2*f3-16*x1^2*x3^2*f6^2*f2^3*f7+528*x1*x3*x4
^2*f7*f3^2*f5^2*f6-328*x1*x3*x4^2*f7*f2*f5^4-1312*x1*x3*x4^2*f7*f0*f6^2*f5^2-\
64*x1*x3^3*f3*f6^3*f1*f5+64*x1*x3^3*f6^4*f2*f1-16*x3^3*x1*f1*f5^2*f7^2*f2-64*
x3^3*x1*f0*f5*f7^3*f1+8*x1*x3^3*f7*f3^2*f4^2*f6+16*x1*x3^3*f6^2*f2*f7*f3^2+128
*x1*x3^3*f6*f0^2*f7^3-24*x1*x3^3*f1*f6*f7^2*f3^2+48*x1*x3^3*f3^2*f6^2*f5*f4-96
*x1*x3^3*f1^2*f6^3*f7+20*x1*x3^3*f4^3*f5^3+96*x1*x3^3*f0*f6^2*f5*f3*f7-44*x3^3
*x1*f4*f5^3*f7*f1+96*x1*x3^3*f6^2*f2*f3*f5^2+32*x1*x3^3*f3*f6^2*f1*f4*f7-16*x1
*x3^3*f4*f5^3*f6*f2+24*x1*x3^2*x6*f5^4*f2+56*x1*x3^2*x6*f7*f2*f5*f4^2+96*x1*x3
^2*x6*f3*f5*f4^2*f6+128*x1*x3^2*x6*f0*f6^2*f5^2+136*x1*x3^2*x6*f0*f4^2*f7^2+
400*x1*x3^2*x6*f1*f7*f3*f5*f6+64*x1*x3^2*x6*f6^3*f2^2+24*x1*x3^2*x6*f1^2*f7^2*
f6+48*x1*x3^2*x6*f3^2*f5^2*f6-160*x1*x3^2*x6*f0*f6*f2*f7^2-64*x1*x3^2*x6*f4*f5
^3*f3-20*x1*x3^2*x6*f4^3*f5^2-128*x1*x3^2*x6*f0*f7^2*f5*f3-128*x1*x3^2*x6*f6^2
*f2*f1*f7+128*x1*x3^2*x6*f0*f6^3*f4-144*x1*x3^3*f0*f4*f2*f7^3-32*x1*x3^3*f6^3*
f2*f3*f4-48*x1*x3^3*f0*f6*f4*f3*f7^2+48*x1^2*x3^2*f6^3*f1^2*f5+16*x1*x3^2*x2*
f6*f2*f5^2*f4^2+8*x1*x3^2*x2*f1*f5^5-16*x1*x3^2*x2*f1*f5*f6^2*f4^2+64*x1*x3*x6
^2*f3*f6^2*f2-120*x1*x3*x6^2*f1*f4*f7*f5+28*x1^2*x3*x6*f7*f2*f4^2*f3-256*x1^2*
x3^2*f0*f6^2*f4*f7*f2-32*x1*x3^3*f7*f2*f4^3*f6-32*x1*x3^3*f0*f6^2*f4^2*f7-32*
x1*x3*x5*x6*f3*f6^2*f1-96*x1*x3*x5*x6*f0*f6*f5^2-124*x1*x3*x5*x6*f1*f5*f7*f3+
360*x1*x3*x5*x6*f0*f7*f4*f5+16*x1*x3*x5*x6*f5^3*f1+96*x1*x3*x5*x6*f2*f3*f5*f6+
24*x1*x3*x5*x6*f3^2*f6*f4-496*x1*x3*x4*x6*f7^2*f2*f6*f1-96*x1*x3*x4*x6*f0*f6^2
*f7*f4-216*x1*x3*x4*x6*f7*f3^2*f5^2+252*x3^2*x4^2*f6*f5^5-8*x2^2*x3*x5*f7*f3^2
*f4^2-16*x2^2*x7*x3*f4^2*f2*f6*f7+24*x2^2*x3*x7*f3*f5^2*f6*f4+8*x2^2*x7*x3*f1*
f5^3*f7+96*x2*x3^2*x7*f0*f6^2*f5*f7-16*x2*x3^2*x7*f4^3*f6^2-8*x2*x3^2*x7*f2*f7
^3*f1-384*x2*x3*x4*x7*f7^2*f2*f4*f5+16*x2*x3*x4*x7*f7*f2*f5^2*f6+128*x2*x3*x4*
x7*f7*f5^2*f4^2+16*x2*x3*x4*x7*f4^2*f7^2*f3-304*x2*x3*x4*x7*f1*f7*f6^2*f5-120*
x2*x3*x4*x7*f4^3*f7*f6+224*x2*x3*x4*x7*f6^2*f2*f4*f7-64*x2^2*x3*x6*f1*f0*f7^3+
16*x2^2*x3*x6*f0*f6*f2*f7^2-32*x2^2*x3*x6*f0*f6^2*f3*f7+32*x2^2*x3*x6*f7*f2*f5
*f4^2-32*x2*x3^2*x6*f2*f5^3*f6-64*x2*x3^2*x6*f4*f6^3*f1-112*x2*x3*x4*x6*f3^2*
f4*f7^2-96*x2*x3*x4*x6*f2*f7^3*f1+32*x1*x3^2*x7*f6^2*f4^2*f3-288*x1*x3*x4*x7*
f6*f4^2*f5^2-192*x1*x3*x4*x7*f7*f2*f5*f4*f6+144*x1*x3*x4*x7*f4*f5^4+216*x1*x3*
x4*x7*f7*f3*f5^2*f4+120*x1*x3*x4*x7*f7^3*f2*f1+80*x1*x3*x4*x7*f7^2*f2^2*f6-192
*x1*x3*x4*x7*f5*f6^3*f1+64*x1*x3*x4*x7*f7^2*f1*f3*f6-128*x1*x3*x4*x7*f7*f1*f6^
2*f4-208*x1*x3*x4*x7*f7*f2*f5^3+96*x1^2*x3*x5*f0*f7*f5^2*f2+24*x1^2*x3*x5*f7*
f2*f3^2*f4+36*x1^2*x3*x5*f1*f7*f3^2*f5+12*x1^2*x3*x5*f3^3*f5^2-352*x1^2*x3*x5*
f0*f5*f4*f3*f7+64*x1^2*x3*x5*f3^2*f6^2*f1-24*x1^2*x3*x5*f3^3*f4*f6+16*x1^2*x3*
x5*f3*f6^2*f2^2-56*x1^2*x3*x5*f3^2*f5*f6*f2+48*x1^2*x3*x5*f7*f0*f6*f1*f5-2*x1^
2*x3^2*f4^5*f5-32*x1*x3*x4*x6*f7^2*f3^3+32*x1*x3^2*x6*f3*f6^3*f1+24*x2^2*x3*x5
*f1*f7*f3*f6*f4-24*x2*x3^2*x5*f3*f4^2*f6*f5+224*x2*x3*x4*x5*f0*f7^3*f2-144*x2*
x3*x4*x5*f3*f5^2*f6*f4+24*x4*x5*x2*x3*f5^2*f7*f3^2-96*x2*x3*x4*x5*f6*f5^3*f2+
16*x4*x5*x2*x3*f4*f6*f7*f3^2+48*x4*x5*x2*x3*f1*f6*f7^2*f2-512*x4*x5*x2*x3*f0*
f5*f4*f7^2-104*x4*x5*x2*x3*f4^2*f2*f6*f7+272*x4*x5*x2*x3*f4*f6*f7*f1*f5-512*x4
*x5*x2*x3*f0*f6*f3*f7^2+92*x4*x5*x2*x3*f3*f4*f7^2*f2+16*x4*x5*x2*x3*f3*f5*f1*
f7^2-48*x4*x5*x2*x3*f3*f4^2*f5*f7-864*x4*x5*x2*x3*f0*f6*f5^2*f7-84*x4*x5*x2*x3
*f1*f4^2*f7^2+96*x2*x3*x4*x5*f5*f4^3*f6+640*x3*x2*x4*x5*f0*f6^2*f4*f7+96*x4*x5
*x2*x3*f1*f5^3*f7-48*x4*x5*x2*x3*f7^3*f1^2-32*x2*x3*x4*x5*f3*f6^2*f1*f7+288*x2
*x3*x4*x5*f6^2*f5^2*f1-192*x2*x3*x4*x5*f6^2*f4*f2*f5-8*x2*x3^2*x5*f7*f4^2*f1*
f6-16*x2^2*x3*x5*f4*f5^3*f2-32*x2^2*x3*x5*f4^2*f6^2*f1+112*x2*x3*x6^2*f0*f4*f7
^2+44*x2*x3*x6^2*f5^2*f4^2+32*x2*x3*x6^2*f2*f7*f3*f6+160*x2*x3*x6^2*f0*f6*f5*
f7+16*x2*x3*x6^2*f2*f6*f5^2+20*x2*x3*x6^2*f7*f2*f4*f5-80*x2*x3*x6^2*f7*f5^2*f1
+24*x2*x3*x6^2*f3*f5*f4*f6-152*x2*x3*x6^2*f7*f4*f6*f1+32*x1*x3^2*x7*f2^2*f7*f6
^2-96*x1*x3^2*x7*f1*f6^3*f4-48*x1*x3*x6*x7*f0*f7*f5*f6-108*x1*x3*x6*x7*f3*f7^2
*f1+80*x1*x3*x6*x7*f7*f4*f2*f5-112*x1*x3*x6*x7*f1*f6^2*f5+224*x1*x3*x6*x7*f0*
f7^2*f4+192*x1*x3*x6*x7*f0*f6^3-96*x1*x3*x6*x7*f4*f6^2*f2-48*x1*x3*x6*x7*f3^2*
f6^2+104*x1*x3*x6*x7*f4*f5*f3*f6-52*x1*x3*x5*x7*f1*f4*f7*f5-48*x1*x3*x5*x7*f2*
f5*f4*f6+4*x1*x3*x5*x7*f3*f5^2*f4+16*x1*x3*x5*x7*f7*f6*f3*f1+64*x1*x3*x5*x7*f1
*f6^2*f4-40*x1*x3*x5*x7*f2*f7^2*f1+24*x1*x3*x5*x7*f5^2*f6*f1-8*x1^2*x3^2*f0*f6
*f5^3*f4+40*x1*x3*x4*x8*f7^2*f2*f3*f6-96*x1*x3*x4*x8*f7^3*f3*f1-96*x1*x3*x4*x8
*f7*f5*f6^2*f1+96*x1*x3^2*x8*f7^2*f0*f6*f4+192*x1^2*x3*x7*f0*f5*f2*f7^2+48*x1^
2*x3*x7*f7*f3^3*f5-24*x1^2*x3*x7*f5^3*f2*f4-16*x1^2*x3*x7*f4^2*f6^2*f1-8*x1^2*
x3*x7*f3*f4^3*f6+28*x1^2*x3*x7*f3*f4^2*f5^2-8*x1^2*x3*x7*f5^4*f1+320*x1*x3^2*
x4*f0*f6^2*f7^2*f2+16*x1*x3^2*x4*f3^3*f6^2*f7+96*x1*x3^2*x4*f6^2*f3*f5*f4^2-4*
x2*x3*x7^2*f1*f7^2*f5+4*x2^2*x3*x8*f7*f4^3*f5+4*x2*x3^2*x8*f7^2*f5^2*f1-16*x2*
x3*x5*x8*f7*f5^2*f2-12*x2*x3*x5*x8*f7*f3*f5*f4-16*x2*x3*x6*x8*f7^2*f1*f5-28*x2
*x3*x6*x8*f7*f5*f4^2+4*x2^2*x3*x5*f7*f3*f4*f2*f5-4*x2^2*x3*x5*f7^2*f3^2*f1+4*
x2^2*x3*x5*f5*f4^4-128*x1^2*x3^2*f0*f6^4*f1-1200*x4^2*x1*x3*f1^2*f6*f7^3+1040*
x4^2*x2*x3*f0*f6*f5^2*f7^2-408*x4^2*x2*x3*f5*f7^3*f3*f1-24*x2*x3*x4^2*f7^3*f3^
3+1152*x4^2*x2*x3*f0*f6*f7^3*f3+56*x4^2*x2*x3*f7^2*f2*f6*f4^2-256*x4^2*x2*x3*
f1*f7^3*f2*f6+212*x4^2*x2*x3*f7^2*f3^2*f5^2+16*x4^2*x2*x3*f1*f7^2*f5^3+944*x4^
2*x2*x3*f0*f5*f4*f7^3+28*x4^2*x2*x3*f5*f4^2*f7^2*f3-80*x4^2*x2*x3*f7^3*f2*f4*
f3-780*x4^2*x2*x3*f2*f5^2*f7^2*f4-832*x3*x2*x4^2*f0*f6^2*f4*f7^2+32*x3*x2*x4^2
*f7^2*f6*f4*f3^2+160*x2*x3*x4^2*f7*f2*f5^3*f6-16*x2*x3*x4^2*f7*f3*f5^2*f6*f4-\
360*x2*x3*x4^2*f5*f4^3*f7*f6-16*x1^2*x3*x4*f5^2*f7^2*f1^2-576*x1^2*x3*x4*f0*f6
^3*f5*f3+96*x1^2*x3*x4*f7*f3^2*f5*f4^2-280*x1^2*x3*x4*f3*f5^3*f7*f1-40*x1*x3*
x6*x7*f5^3*f3+352*x1^2*x3*x5*f7^2*f0^2*f5-24*x1^2*x3*x5*f1^2*f7*f5^2-16*x1^2*
x3*x5*f1^2*f6^2*f5-512*x1^2*x3*x5*f7*f6^2*f0^2+128*x1^2*x3*x5*f7*f2*f0*f4*f6+
16*x1^2*x3*x5*f7*f6*f2^3-16*x1^2*x3*x5*f7^2*f0*f1*f4+256*x1*x3*x4^2*f7*f4*f5^3
*f3+332*x4^2*x1*x3*f7^3*f3*f4*f1+48*x4^2*x1*x3*f3*f5^2*f7^2*f2+1088*x4^2*x1*x3
*f2*f6*f7^3*f0+360*x1*x3*x4^2*f7*f5^3*f6*f1-80*x4^2*x1*x3*f2*f5*f7^2*f4^2-24*
x4^2*x1*x3*f7^2*f3*f4^3+144*x1*x3*x4^2*f6^2*f2*f5^3-160*x4^2*x1*x3*f0*f5*f7^3*
f3+144*x1*x3*x4^2*f3*f6^2*f4*f5^2+768*x4^2*x1*x3*f0*f6^2*f7^2*f3-24*x4^2*x1*x3
*f7^2*f3^2*f4*f5+4*x2^2*x3^2*f7^2*f3^3*f4-12*x2^2*x3^2*f4*f5^4*f3-4*x2^2*x3^2*
f2^3*f7^3-4*x2^2*x3^2*f3*f6*f2^2*f7^2-32*x2^2*x3^2*f3*f6^2*f4*f1*f7-4*x2^2*x3^
2*f5*f4^4*f6+32*x2^2*x3^2*f1*f6^3*f4^2-32*x2^2*x3^2*f6^2*f1*f5^2*f4+16*x1*x3*
x4*x7*f7^2*f0*f6*f4-228*x1*x3*x4*x7*f7^2*f1*f4*f5+24*x1*x3*x4*x7*f7*f3*f4^2*f6
+280*x1*x3*x4*x7*f7*f5^2*f6*f1-608*x1*x3*x4*x7*f7*f0*f6^2*f5+88*x1*x3*x4*x7*f7
^2*f2*f5*f3-16*x1*x3*x2*x6*f1*f5^4-8*x2*x3*x5*x6*f4^3*f5-12*x2*x3*x5^2*f5^3*f1
+8*x2*x3*x4*x5*f7^2*f3^3+4*x4*x5*x2*x3*f7*f4^4-40*x2*x3*x4*x5*f7^2*f2^2*f5-32*
x2*x3*x5*x7*f2^2*f7^2-4*x2*x3^2*x6*f7^2*f3^3-4*x2*x3*x1*x5*f3^3*f4*f7-8*x2*x3*
x5^2*f7*f2^2*f5+4*x2*x3*x5^2*f1*f7*f3*f5+16*x2*x3*x6^2*f2^2*f7^2-32*x2*x3*x1*
x7*f6^2*f2*f3*f5-64*x2*x3*x5*x7*f2*f6^2*f4-160*x2*x3*x5*x7*f0*f6*f7*f5+16*x2*
x3*x5*x7*f1*f7*f4*f6+176*x2*x3*x5*x7*f0*f4*f7^2-48*x2*x3*x6*x7*f5^3*f4-32*x2*
x3*x6*x7*f4^2*f6*f5+112*x2*x3*x6*x7*f7*f5^2*f2+208*x2*x3*x6*x7*f0*f5*f7^2+128*
x2*x3*x6*x7*f0*f6^2*f7-16*x2*x3*x6*x7*f4^3*f7-112*x2*x3*x6*x7*f7*f5*f1*f6-8*x2
*x3*x6*x7*f7*f5*f3*f4+16*x2*x3*x6*x7*f7*f2*f4*f6+24*x2*x3*x6*x7*f3^2*f7*f6-56*
x2*x3*x6*x7*f4*f7^2*f1-64*x2*x3*x6*x7*f6^2*f2*f5-32*x2*x3*x5*x7*f5^2*f6*f2-20*
x2*x3*x5*x7*f3*f7*f4^2-48*x2*x3*x5*x7*f3*f5*f4*f6+48*x2*x3*x5*x7*f2*f7*f3*f6+
60*x2*x3*x5*x7*f7*f2*f4*f5+96*x2*x3*x5*x7*f5*f6^2*f1+32*x2*x3*x5*x7*f4^3*f6+
144*x2*x3*x4*x7*f6*f5^3*f4-176*x2*x3*x4*x7*f7*f5^3*f3+120*x2*x3*x4*x7*f7^3*f2^
2-80*x2*x3*x4*x7*f3^2*f6^2*f7+288*x2*x3*x4*x7*f3*f5^2*f6^2+128*x2*x3*x4*x7*f1*
f7^2*f4*f6-64*x2*x3*x4*x7*f7^3*f3*f1-288*x2*x3*x4*x7*f0*f4*f7^3+216*x2*x3*x4*
x7*f7^2*f5*f3^2+48*x2*x3*x4*x7*f7^2*f5^2*f1-144*x2*x3*x4*x7*f7*f3*f5*f4*f6-160
*x2*x3*x4*x7*f0*f6*f5*f7^2-120*x2*x3*x4*x7*f2*f7^2*f3*f6+96*x2^2*x7*x3*f4*f6*
f7*f1*f5+16*x2^2*x3*x8*f7^2*f2*f4^2-64*x2^2*x3*x8*f7^2*f0*f6*f4+16*x2^2*x3*x8*
f7*f2*f4*f5*f6+8*x2*x3^2*x8*f7^3*f2^2+48*x2*x3*x4*x8*f7^2*f3^2*f6+24*x2*x3*x4*
x8*f7*f5^3*f4+144*x2*x3*x4*x8*f7*f3*f6*f5^2+496*x2*x3*x4*x8*f7^3*f0*f5+112*x2*
x3*x6*x8*f7^2*f0*f6+8*x2*x3*x6*x8*f7*f3*f6*f4-40*x2*x3*x6*x8*f7^2*f2*f4-32*x2*
x3*x6*x8*f7*f6*f2*f5-12*x2*x3*x6*x8*f7*f3*f5^2+8*x2*x3*x7*x8*f7*f4*f5^2-16*x2*
x3*x7*x8*f7^2*f2*f5+48*x2*x3*x7*x8*f7*f3*f5*f6-56*x2*x3*x7*x8*f7^2*f1*f6-64*x2
*x3*x5*x8*f7^2*f0*f5+32*x2*x3*x5*x8*f7*f6*f1*f5+52*x2*x3*x5*x8*f7^2*f1*f4-240*
x2*x3*x4*x8*f7^2*f6*f1*f5+112*x2*x3*x4*x8*f7^2*f2*f4*f6-260*x2*x3*x4*x8*f7^3*
f1*f4+40*x2*x3*x4*x8*f7^3*f2*f3+40*x2*x3*x4*x8*f7^2*f5^2*f2+32*x2*x3^2*x8*f7*
f3*f4*f5*f6+8*x2*x3^2*x8*f7^2*f2*f3*f6-8*x2^2*x3*x8*f7*f6*f5^2*f1+8*x2^2*x3*x8
*f7*f3*f4^2*f6+48*x1^2*x3*x6*f3^3*f5*f6-80*x1^2*x3*x6*f6^2*f2*f3^2-64*x1^2*x3*
x6*f1^2*f6^3-24*x1^2*x3*x6*f5*f4^2*f1*f6-44*x1^2*x3*x6*f7*f3^3*f4+96*x1*x3*x4*
x6*f5*f4^3*f6+212*x1*x3*x4*x6*f1^2*f7^3-120*x1*x3*x4*x6*f3*f5^4+256*x1*x3*x4*
x6*f3*f6^2*f1*f7+136*x1*x3*x5*x6*f7*f2*f1*f6-56*x1*x3*x5*x6*f1*f5*f4*f6-16*x1*
x3*x5*x6*f7*f2^2*f5-64*x1*x3*x5*x6*f2^2*f6^2+32*x1*x3*x5*x6*f4^2*f6*f2-48*x1*
x3*x5*x6*f7*f2*f3*f4-12*x1*x3*x5*x6*f3*f5*f4^2-96*x1*x5*x3*x7*f0*f5^2*f7-32*x1
*x5*x2*x6*f0*f5*f7*f3-32*x1*x5*x2*x6*f4^2*f1*f6-152*x1*x5*x2*x6*f1*f0*f7^2-64*
x1^2*x5*x6*f0^2*f7^2+32*x1*x5*x7^2*f7*f0*f6-20*x1*x5*x7^2*f7*f1*f5-4*x5^3*x6*
f1*f5+4*x5^3*x3*f1*f5^2-4*x5^3*x3*f7*f3*f1+12*x5^2*x2*x6*f1*f5^2+8*x5^2*x2*x6*
f7*f2^2+8*x5^2*x3*x6*f7*f2*f3+4*x5^3*x1*f3*f1*f5-8*x5^2*x1*x6*f2*f3*f5+4*x5^2*
x2*x8*f7*f2*f4-8*x5^2*x2*x8*f7*f1*f5+4*x5^2*x3*x8*f7*f3*f4+8*x5^2*x3*x8*f7*f2*
f5+4*x5^3*x8*f7*f1-8*x5^2*x6*x8*f7*f2+8*x5^2*x7*x8*f7*f3-8*x5^2*x2*x7*f7*f2*f3
-8*x5^2*x3*x7*f7*f3^2-4*x5^3*x2*f7*f2*f1+4*x5^3*x2*f1*f4*f5+96*x1*x5*x3*x6*f0*
f6*f7*f3+64*x1*x5*x3*x6*f0*f7^2*f2-32*x1*x5*x6^2*f2*f3*f6+52*x1*x5*x6^2*f7*f3*
f1-4*x1*x5*x6^2*f2*f4*f5-8*x1^2*x5*x6*f0*f5^2*f4+128*x1^2*x5*x6*f0*f7*f3*f4+12
*x1^2*x5*x6*f3*f5*f2*f4-80*x1^2*x5*x6*f0*f6*f7*f1+16*x1*x5^2*x6*f0*f5^2+16*x1*
x5^2*x6*f2^2*f6-24*x1*x5*x4*x6*f5^2*f1*f6+224*x1*x5*x4*x6*f0*f7^2*f3+144*x4^4*
f6^2*f7*f4*f5^2-232*x4^4*f5*f7^3*f3*f4-128*x4^4*f0*f6^2*f7^3+80*x4^4*f2*f6*f4*
f7^3+1440*x4^4*f6*f7*f5^4+644*x4^4*f2*f5^2*f7^3+1836*x4^4*f0*f5*f7^4-16*x4^4*
f4*f7^2*f6^2*f3-1104*x4^4*f5^3*f7^2*f4+32*x4^4*f7^2*f6^3*f1-216*x4^3*x1*f4*f6*
f5^4+64*x4^3*x1*f0*f6^2*f4*f7^2+312*x4^3*x1*f7*f3*f5^2*f4*f6-24*x4^3*x1*f5^3*
f7*f4^2+240*x4^3*x1*f7*f3*f5^4+128*x4^3*x1*f7^3*f2*f4*f3+216*x4^3*x1*f1*f7^2*
f5^3+228*x4^3*x1*f7^2*f3^2*f5^2+1088*x4^3*x1*f0*f7^4*f2-872*x4^3*x1*f7^2*f3*f5
*f2*f6+544*x4^3*x1*f0*f6*f7^3*f3+296*x4^3*x1*f1*f7^3*f2*f6-816*x4^3*x1*f0*f6*
f5^2*f7^2+160*x4^3*x1*f0*f5*f4*f7^3+16*x4^3*x1*f7^2*f2*f6*f4^2+216*x4^3*x1*f2^
2*f5*f7^3-120*x2*x4^3*f7^4*f2*f1+288*x4^3*x2*f5^3*f6*f3*f7-48*x4^3*x2*f4^3*f7^
2*f5-44*x4^3*x2*f4^2*f7^3*f2+520*x4^3*x2*f2*f6*f4*f7^2*f5-64*x4^3*x2*f4^2*f6*
f7^2*f3-296*x4^3*x2*f3*f5*f7^3*f2+168*x4^3*x2*f4*f7*f5^4+480*x2*x4^3*f0*f3*f7^
4-336*x4^3*x2*f0*f6*f7^3*f4+152*x4^3*x2*f3*f5^2*f4*f7^2+88*x4^3*x2*f3*f6*f7^3*
f1-240*x4^3*x2*f0*f5^2*f7^3+436*x4^3*x2*f1*f4*f7^3*f5-472*x4^3*x2*f2*f5^3*f7^2
+112*x4^3*x2*f4*f7^3*f3^2+408*x4^3*x3*f5^5*f7-1232*x4^3*x3*f1*f6^2*f7^2*f5+556
*x4^3*x3*f2*f7^3*f4*f5-360*x4^3*x3*f3^2*f5*f7^3-96*x4^3*x3*f2^2*f7^4+912*x4^3*
x3*f5^3*f7*f6*f4+1392*x4^3*x3*f3*f6^2*f5^2*f7+656*x4^3*x3*f1*f5^2*f7^3+64*x4^3
*x3*f0*f7^4*f4-56*x4^3*x3*f1*f4*f7^3*f6-96*x4^3*x3*f3*f7^4*f1-192*x4^3*x3*f3*
f6*f7^2*f4*f5+432*x4^3*x3*f5^4*f6^2-944*x4^3*x3*f5^2*f7^2*f4^2+192*x4^3*x3*f3^
2*f6^2*f7^2+288*x4^3*x3*f2*f6*f5^2*f7^2+4240*x4^3*x3*f0*f6*f7^3*f5-976*x4^3*x3
*f3*f5^3*f7^2+16*x4^3*x3*f6^2*f7^2*f2*f4-440*x4^3*x2*f1*f6*f7^2*f5^2-256*x4^3*
x2*f3^2*f6*f5*f7^2+432*x4^3*x2*f5^3*f6^2*f4-480*x4^3*x2*f4^2*f7*f6*f5^2-32*x4^
3*x2*f2^2*f6*f7^3+32*x4^3*x2*f1*f6^2*f7^2*f4-48*x4^3*x2*f3*f6^2*f4*f7*f5+32*x4
^3*x2*f3*f6^2*f7^2*f2+280*x4^3*x1*f1*f7^2*f4*f5*f6-168*x4^3*x1*f5*f4^2*f7^2*f3
-908*x4^3*x1*f1^2*f7^4+12*x4^3*x1*f7^2*f4^4-64*x4^3*x1*f1*f7^3*f4^2+776*x4^2*
x5^2*f0*f5*f7^2-216*x4^2*x2*x5*f3*f6*f5^3+152*x4^2*x2*x5*f3*f5*f7^2*f2+8*x4^2*
x2*x5*f1*f4*f7^2*f5-464*x4^2*x2*x5*f0*f7^3*f3+4*x4^2*x2*x5*f4^2*f7^2*f2+448*x4
^2*x2*x5*f0*f6*f7^2*f4+16*x4^2*x2*x5*f2^2*f6*f7^2+80*x4^2*x2*x5*f2*f7^3*f1-16*
x4^2*x2*x5*f4*f7^2*f3^2+56*x3*x5*f2^2*f7^3*x4^2-2688*x4^2*x3*x5*f0*f6*f7^2*f5+
64*x4^2*x3*x5*f3*f5^3*f7-256*x4^2*x3*x5*f2*f6*f5^2*f7-432*x4^2*x3*x5*f3*f6^2*
f5^2+172*x4^2*x3*x5*f5^2*f7*f4^2+960*x4^2*x3*x5*f1*f6^2*f7*f5+104*x4^3*x5*f7^3
*f2*f3-104*x4^3*x5*f7^2*f6*f3^2+240*x4^3*x5*f7*f5^3*f4-24*x4^3*x5*f7^2*f2*f6*
f4+648*x4^3*x5*f7^2*f1*f6*f5-28*x4^3*x5*f7^2*f4^3-2192*x4^3*x5*f7^3*f0*f5-112*
x4^3*x5*f7^2*f2*f5^2+32*x4^3*x5*f7^2*f0*f6^2-648*x4^3*x5*f7*f6*f3*f5^2+48*x4^3
*x5*f7*f6*f4^2*f5+76*x4^3*x5*f7^3*f1*f4+216*x4^3*x5*f7^2*f5*f3*f4+32*x4^2*x3*
x5*f3*f7^3*f1+120*x4^2*x3*x5*f1*f4*f7^2*f6+216*x4^2*x3*x5*f5^3*f6*f4+244*x4^2*
x3*x5*f3^2*f5*f7^2+12*x4^2*x3*x5*f4^2*f7^2*f3+8*x4^2*x3*x5*f3*f6*f7^2*f2-200*
x4^2*x3*x5*f0*f7^3*f4+144*x4^2*x2*x5*f4^2*f6*f5^2+88*x4^2*x2*x5*f3^2*f6*f5*f7-\
568*x4^2*x2*x5*f0*f5^2*f7^2-64*x4^2*x2*x5*f3*f6*f1*f7^2-344*x4^2*x2*x5*f2*f6*
f4*f7*f5-132*x4^2*x2*x5*f3*f5^2*f4*f7+164*x4^2*x2*x5*f2*f7*f5^3+432*x4^2*x2*x5
*f1*f6*f7*f5^2-132*x4^2*x1*x5*f3^2*f5^2*f7+20*x4^2*x1*x5*f7^2*f3^3-36*x4^2*x1*
x5*f3*f5^4+160*x4^2*x1*x5*f0*f6*f7*f5^2+68*x4^2*x1*x5*f4^2*f7*f3*f5-140*x4^2*
x1*x5*f7*f1*f5^3-64*x4^2*x1*x5*f7^2*f3*f4*f2-376*x4^2*x1*x5*f7^2*f0*f4*f5-24*
x4^2*x1*x5*f7*f2*f5^2*f4-432*x4^2*x1*x5*f0*f6*f3*f7^2-496*x4^2*x1*x5*f7^3*f0*
f2-16*x4^2*x6^2*f7^2*f3*f4+44*x6^2*x4^2*f6*f7^2*f1-144*x4^2*x6^2*f2*f5*f7^2+34
*x4^2*x6^2*f4*f5^2*f7-48*x4^2*x6^2*f6*f7*f3*f5-140*x4^2*x1*x6*f3*f5^2*f4*f7-\
108*x4^2*x1*x6*f4*f5^4+320*x4^2*x1*x6*f3*f6*f1*f7^2-232*x4^2*x1*x6*f2*f6*f4*f7
*f5+68*x4^2*x5*x6*f7*f3*f5^2-144*x4^2*x5*x6*f6*f5^2*f4+272*x4^2*x5*x6*f2*f6*f5
*f7-272*x4^2*x5*x6*f0*f6*f7^2-4*x5*x6*x4^2*f1*f5*f7^2-144*x4^3*x6*f3^2*f7^3-64
*x4^3*x6*f1*f7^2*f6^2-544*x4^2*x3*x6*f2*f6^2*f5*f7-184*x4^2*x3*x6*f6*f7^2*f3^2
+448*x4^2*x3*x6*f0*f6^2*f7^2+56*x4^2*x3*x6*f6*f7*f3*f5^2+336*x4^2*x3*x6*f6*f7*
f4^2*f5-208*x4^2*x3*x6*f1*f7^3*f4+248*x4^2*x2*x6*f3*f7^3*f1+4*x4^2*x2*x6*f4^2*
f7^2*f3+64*x4^2*x2*x6*f3*f6*f7*f4*f5-112*x4^2*x2*x6*f1*f4*f7^2*f6-216*x4^2*x2*
x6*f5^3*f6*f4+232*x4^2*x2*x6*f3*f5^3*f7-72*x4^2*x2*x6*f5^2*f7*f4^2+4*x4^2*x2*
x6*f1*f5^2*f7^2-1424*x4^2*x2*x6*f0*f7^3*f4+16*x4^2*x1*x6*f4^2*f7^2*f2-260*x4^2
*x1*x6*f2*f7^3*f1-168*x4^2*x1*x6*f3^2*f6*f5*f7-592*x4^2*x1*x6*f0*f7^3*f3+364*
x4^2*x1*x6*f2*f5^3*f7-12*x4^2*x1*x6*f4^3*f7*f5-346*x4^2*x7^2*f7^2*f5*f4+928*x4
^2*x7^2*f7*f6*f5^2+52*x4^2*x7^2*f7^2*f6*f3+36*x4^2*x1*x7*f2*f7^2*f4*f5+72*x4^2
*x1*x7*f1*f4*f7^2*f6+292*x4^2*x1*x7*f3*f7^3*f1-36*x4^2*x1*x7*f4^2*f7^2*f3-544*
x4^2*x1*x7*f0*f6*f7^2*f5-280*x4^2*x1*x7*f3*f6*f7^2*f2-368*x4^2*x1*x7*f2*f6*f5^
2*f7+200*x4^2*x1*x7*f3*f6*f7*f4*f5-20*x4^2*x1*x7*f5^2*f7*f4^2+48*x4^2*x1*x7*f2
^2*f7^3+28*x4^2*x1*x7*f1*f5^2*f7^2-104*x4^2*x1*x7*f0*f7^3*f4-408*x4^2*x5*x7*f7
^3*f0+168*x4^2*x5*x7*f7^2*f1*f6+200*x4^2*x5*x7*f7*f4*f5^2+312*x4^2*x6*x7*f7*f5
*f4*f6+132*x4^2*x6*x7*f3*f7^2*f5-436*x4^2*x6*x7*f5^3*f7-432*x4^2*x6*x7*f5^2*f6
^2-104*x4^2*x6*x7*f2*f7^2*f6-224*x4^2*x6*x7*f1*f7^3+8*x4^2*x6*x7*f7^2*f4^2-408
*x4^2*x5*x7*f7*f3*f5*f6+32*x4^2*x5*x7*f7^2*f3*f4+456*x4^3*x7*f7^3*f2*f5-8*x4^3
*x7*f1*f7^3*f6+192*x4^3*x7*f0*f7^4-120*x4^2*x3*x7*f3^2*f7^3+8*x4^2*x3*x7*f3*f7
^2*f4*f6+960*x4^2*x3*x7*f0*f6*f7^3+412*x4^2*x3*x7*f5*f7^3*f1-336*x4^2*x3*x7*f1
*f7^2*f6^2+1096*x4^2*x3*x7*f6*f5^2*f4*f7+896*x4^2*x3*x7*f7*f3*f5*f6^2+432*x4^2
*x2*x7*f6^2*f4*f5^2-112*x4^2*x2*x7*f6*f7^2*f3^2+60*x4^2*x2*x7*f5*f7^2*f3*f4-56
*x4^2*x2*x7*f2*f3*f7^3-12*x4^2*x1*x7*f3^2*f5*f7^2-216*x4^2*x1*x7*f5^3*f6*f4+
272*x4^2*x1*x7*f3*f5^3*f7+240*x4^2*x2*x8*f7*f6*f5^2*f4-148*x4^2*x2*x8*f7^3*f5*
f1+32*x4^2*x2*x8*f7^3*f2*f4-16*x4^2*x2*x8*f7^2*f4^2*f5+144*x4^2*x3*x8*f7^3*f3*
f4+664*x4^2*x3*x8*f7^2*f4*f5^2+568*x4^2*x3*x8*f7^2*f6*f3*f5+108*x4^3*x8*f7^4*
f1-64*x4^3*x8*f7^3*f2*f6-36*x4^3*x8*f7^3*f4^2+28*x4^2*x5*x8*f7^2*f4^2+28*x4^2*
x6*x8*f7^2*f4*f5-76*x4^2*x6*x8*f7^3*f2-192*x4^2*x6*x8*f7*f6*f5^2+56*x6*x8*f7^2
*f3*f6*x4^2-8*x7*x8*f7^2*f4*f6*x4^2+108*x4^2*x7*x8*f7^3*f3+692*x4^2*x7*x8*f7^2
*f5^2-4*x4^2*x5*x8*f7^3*f1+16*x4^2*x5*x8*f7^2*f2*f6-260*x5*x8*f7^2*x4^2*f3*f5+
468*x4^3*x8*f7^3*f3*f5+716*x4^3*x8*f7^2*f5^3-40*x4^3*x8*f7^2*f5*f4*f6+216*x4^2
*x3*x8*f7*f6*f5^3-152*x4^2*x3*x8*f7^3*f2*f5-72*x4^2*x3*x8*f7^2*f6*f4^2+36*x4^2
*x2*x8*f7^3*f3^2+8*x4^2*x2*x8*f7^2*f2*f6*f5+52*x4^2*x2*x8*f7^2*f3*f5^2-40*x2*
x8*f7^2*f3*f6*f4*x4^2-904*x4^2*x2*x7*f0*f5*f7^3+152*x4^2*x2*x7*f5^3*f7*f4-364*
x4^2*x2*x7*f2*f5^2*f7^2-128*x4^2*x2*x7*f1*f6*f5*f7^2+96*x4^2*x2*x7*f6*f7*f3*f5
^2-328*x4^2*x2*x7*f6*f7*f4^2*f5+168*x4^2*x2*x7*f2*f6*f4*f7^2+232*x4^2*x2*x7*f1
*f7^3*f4-16*x4^2*x2*x7*f7^2*f4^3-904*x4^2*x3*x7*f7^2*f3*f5^2+244*x4^2*x3*x7*f7
^3*f2*f4-600*x4^2*x3*x7*f7^2*f4^2*f5+432*x4^2*x3*x7*f5^3*f6^2+352*x4^2*x3*x7*
f5^4*f7-32*x4^2*x3*x7*f2*f6*f5*f7^2-1080*x4^3*x7*f4*f5^2*f7^2+96*x4^3*x7*f5*f6
^2*f4*f7+376*x4^3*x7*f7^2*f3*f5*f6-64*x4^3*x7*f7^2*f6*f4^2+1896*x4^3*x7*f6*f5^
3*f7-56*x4^2*x2*x6*f3*f6*f7^2*f2+12*x4^2*x2*x6*f3^2*f5*f7^2-8*x2*x6*x4^2*f2^2*
f7^3-368*x4^2*x2*x6*f2*f6*f5^2*f7+768*x4^2*x2*x6*f0*f6*f5*f7^2-432*x4^2*x3*x6*
f5^3*f7*f4+40*x4^2*x3*x6*f1*f6*f5*f7^2-432*x4^2*x3*x6*f6*f5^4+32*x4^2*x3*x6*f2
*f6*f4*f7^2+236*x4^2*x3*x6*f2*f5^2*f7^2-2296*x4^2*x3*x6*f0*f5*f7^3+204*x4^2*x3
*x6*f5*f7^2*f3*f4+8*x4^2*x3*x6*f2*f3*f7^3+48*x4^3*x6*f7*f3*f5*f6^2-432*x4^3*x6
*f5^3*f6^2-480*x4^3*x6*f5^4*f7+432*x4^3*x6*f6*f5^2*f4*f7+44*x4^3*x6*f7^3*f2*f4
+48*x4^3*x6*f7^2*f4^2*f5-304*x4^3*x6*f2*f6*f5*f7^2+72*x4^3*x6*f3*f7^2*f4*f6-\
472*x4^3*x6*f5*f7^3*f1+160*x4^3*x6*f0*f6*f7^3+96*x4^3*x6*f7^2*f3*f5^2+108*x4^2
*x5^2*f6*f3*f5^2-240*x4^2*x5^2*f1*f6*f5*f7+124*x4^2*x1*x5*f7^2*f1*f3*f5+4*x4^2
*x1*x5*f4^2*f1*f7^2-240*x4^2*x1*x5*f7^2*f1*f2*f6-152*x4^2*x1*x5*f7^2*f2^2*f5+
624*x4^2*x1*x5*f7^3*f1^2+32*x4^2*x1*x5*f7*f1*f4*f5*f6+296*x4^2*x1*x5*f3*f5*f7*
f2*f6-72*x4^2*x1*x5*f3*f5^2*f4*f6+144*x4^2*x1*x5*f1*f5^2*f6^2-288*x4^4*f1*f6*
f5*f7^3+672*x4^4*f6*f7^2*f3*f5^2-180*x4^4*f6*f7^2*f4^2*f5-16*x4^4*f2*f6^2*f5*
f7^2-132*x4^4*f7^4*f2*f3-184*x4^4*f1*f7^4*f4+184*x4^4*f6*f7^3*f3^2+96*x1*x4*x3
*x5*f0*f6^2*f5^2-72*x1*x4*x3*x5*f3^2*f6*f5^2+192*x1*x4*x6^2*f5*f6^2*f1-32*x1*
x4*x6^2*f2^2*f7^2-96*x1*x4*x6^2*f3*f5*f4*f6+76*x1*x4*x6^2*f7*f3^2*f5+60*x1*x4*
x6^2*f3*f5^3-232*x1*x4*x6^2*f3*f7^2*f1-48*x1*x4*x6^2*f7*f4*f6*f1+360*x1*x4*x6^
2*f0*f4*f7^2-4*x4^2*x5*x1*f7*f4^4+132*x1^2*x4^2*f7*f3^2*f4*f5^2-36*x1^2*x4^2*
f3*f5^2*f6*f4^2-24*x1*x4*x5^2*f3*f5*f6*f2-72*x1*x4*x7^2*f5^2*f6*f4-96*x1*x4*x7
^2*f0*f6*f7^2-48*x1*x4*x7^2*f6^2*f7*f1+100*x1*x4*x7^2*f7*f5^2*f3+32*x1*x4*x7^2
*f7*f3*f4*f6-136*x1*x4*x7^2*f7*f5*f2*f6-24*x1*x4*x7^2*f7^2*f3^2-64*x1^2*x4*x7*
f1*f0*f7^3+72*x1^2*x4*x7*f7*f3^3*f6-168*x1^2*x4*x7*f3^2*f5^2*f6-48*x1^2*x4*x7*
f5^4*f2-288*x1^2*x4*x7*f0*f6^2*f3*f7+2*x1^2*x4^2*f7*f4^5+288*x1^2*x4*x7*f6^2*
f2*f3*f5-88*x1^2*x4*x7*f7^2*f2*f3^2-12*x1^2*x4*x7*f5^2*f4^3+96*x1^2*x4*x7*f0*
f6^2*f5^2+40*x1^2*x4*x7*f7*f4^2*f1*f6-384*x1^2*x4*x7*f0*f6*f2*f7^2+96*x1^2*x4*
x7*f2*f5^2*f4*f6-24*x1^2*x4*x7*f3*f5*f4^2*f6-16*x1*x4^2*x3*f7^2*f3^3*f6+16*x1*
x4^2*x3*f3^2*f6^2*f7*f4-576*x4^2*x1*x3*f6^2*f2*f3*f5*f7+96*x1*x4*x5^2*f0*f5*f7
*f4+64*x1*x4*x5^2*f7*f2*f1*f6-136*x1*x4*x5^2*f1^2*f7^2+48*x1*x4*x2*x5*f3*f5^2*
f6*f2+36*x1*x4*x2*x5*f5^2*f4^2*f3-8*x3*x6*x1*x4*f7*f4^4-96*x1^2*x4*x7*f1*f5*f6
^2*f4+96*x1*x4*x2*x7*f6^2*f2*f4*f5-16*x1*x4^2*x2*f7*f3*f4^3*f6-216*x4^2*x1*x2*
f1*f5^2*f7*f4*f6+96*x1^2*x4*x7*f7*f3^2*f5*f4+72*x1^2*x4*x7*f4*f5^3*f3-32*x1*x4
*x5*x7*f0*f4*f7^2+24*x1*x4*x5*x7*f4^2*f5^2-64*x1*x4*x5*x7*f3*f7^2*f1-112*x1*x4
*x5*x7*f7*f5^2*f1+16*x1*x4*x5*x7*f1*f7*f4*f6+144*x1*x4*x5*x7*f0*f6*f7*f5-72*x1
*x4*x6*x7*f5^3*f4-116*x1*x4*x6*x7*f7*f5*f3*f4-96*x1*x4*x6*x7*f6^2*f2*f5+96*x1*
x4*x6*x7*f4^2*f6*f5+48*x1*x4*x6*x7*f5^2*f3*f6-80*x1*x4*x6*x7*f7*f2*f4*f6+40*x1
*x4^2*x3*f5^2*f4^3*f7-8*x1*x4^2*x5*f7*f6*f4*f3^2+12*x1*x4*x2*x5*f7*f3^2*f4^2-8
*x1^2*x4^2*f3*f5*f7*f4^3+96*x1^2*x4*x6*f0*f6^2*f5*f4-288*x1^2*x4*x6*f3*f5*f6^2
*f1+144*x1*x4*x3*x6*f2*f5^3*f6-20*x1^2*x4^2*f4*f7^2*f3^3-252*x1^2*x4^2*f3^2*f6
*f5^3+16*x1^2*x4^2*f6^2*f2^2*f7*f4+144*x1^2*x4^2*f5*f4^2*f1*f6*f7-72*x1^2*x4^2
*f5^5*f2-144*x1^2*x4^2*f6^2*f1*f5^2*f4+144*x1*x4^2*x2*f6^2*f2*f5^2*f4+32*x1*x4
^2*x2*f1*f7*f4^2*f6^2+32*x4^2*x5*x1*f1*f6^2*f7*f3+16*x2*x4*x5*x6*f7*f5*f3^2-32
*x2*x4*x5*x6*f2^2*f7^2-448*x5*x6*x2*x4*f0*f5*f7*f6+96*x2*x4*x5*x6*f2*f5^2*f6-\
24*x2*x4*x5*x6*f5^2*f4^2-72*x2*x4*x5*x6*f7^2*f3*f1+88*x2*x4*x5*x6*f4*f6*f7*f1+
744*x2*x4*x5*x6*f0*f4*f7^2-112*x4*x2*x5*x6*f5^2*f7*f1-4*x4*x2*x5*x6*f7*f2*f4*
f5-36*x2*x4^2*x6*f5^5-56*x2*x4*x7^2*f7*f4^2*f6-24*x2*x4*x7^2*f7*f3*f5*f6-88*x7
^2*x2*x4*f2*f7^2*f5+44*x4*x2*x7^2*f7*f4*f5^2-8*x2*x4*x7^2*f7^2*f1*f6+144*x2*x4
*x7^2*f5*f6^2*f4+48*x1*x4*x2*x6*f4*f5^2*f6*f2-16*x1*x4*x3*x8*f7*f6^2*f2*f4-80*
x1*x4^2*x8*f7^2*f6*f1*f5+48*x1*x4^2*x8*f7^3*f0*f5+8*x1*x4*x5*x8*f7*f2*f4*f6-24
*x1*x4*x6*x8*f7*f6*f2*f5+96*x1*x4*x6*x8*f7^2*f1*f5+112*x1*x4*x6*x8*f7^2*f0*f6-\
48*x1*x4*x7*x8*f7^3*f0-16*x1*x4*x7*x8*f7^2*f1*f6-152*x1*x4*x7*x8*f7^2*f2*f5-\
144*x1*x4*x5*x8*f7^2*f0*f5-16*x1*x4*x5*x8*f7*f5^2*f2-32*x1*x4^2*x8*f7^2*f2*f4*
f6+216*x1^2*x4^2*f3^3*f6*f7*f5-8*x1^2*x4^2*f7*f2*f4^3*f6-18*x1^2*x4^2*f5^3*f4^
3+144*x1^2*x4^2*f6*f4*f5^3*f2+18*x2^2*x4^2*f4*f5^5+8*x2*x4^2*x6*f7*f4^3*f6-20*
x2*x4*x5^2*f7*f2*f3*f5+48*x2*x4*x5^2*f2*f4*f5*f6-72*x2*x4*x5^2*f6*f5^2*f1-160*
x2*x4*x5^2*f0*f6*f4*f7-64*x2*x4*x5^2*f4*f5*f7*f1+344*x5^2*x2*x4*f0*f5^2*f7-24*
x2*x4*x1*x5*f2*f5^3*f4+36*x2^2*x4^2*f5^3*f4^2*f6+144*x2*x4^2*x3*f5^2*f4^2*f6^2
-80*x1*x4*x5^2*f1*f7*f3*f5-72*x1^2*x4*x5*f5*f6*f3^3+288*x1^2*x4*x5*f5*f6^2*f0*
f3+24*x1^2*x4*x5*f3^2*f5^2*f4-24*x1*x4^2*x2*f7^3*f3*f2^2-48*x1*x4*x2*x8*f7^2*
f0*f6*f4+144*x1*x4*x3*x8*f7^3*f0*f4-8*x1*x4^2*x7*f4^3*f7*f6-320*x1*x4^2*x7*f1*
f7*f6^2*f5+96*x1*x4*x3*x5*f6^2*f2*f3*f5+36*x1*x4^2*x5*f4^2*f5^3-32*x4^2*x1*x5*
f0*f6^2*f4*f7-144*x2*x7*x1*x4*f4*f6*f7*f1*f5+36*x2*x4^2*x3*f5^6-48*x4^2*x2*x3*
f4^2*f7*f6^2*f3-4*x2^2*x4^2*f4^4*f6*f7-16*x2^2*x4*x5*f0*f6*f7^2*f2-56*x2^2*x4*
x5*f1*f4^2*f7*f6-80*x2^2*x7*x4*f0*f6*f4*f7^2+96*x2^2*x7*x4*f3*f5*f2*f7^2+12*x2
^2*x4*x7*f4*f5^4+96*x2*x4*x3*x7*f5*f4^2*f6^2-16*x2*x4^2*x7*f7*f6^2*f3*f4+160*
x4*x2*x3*x6*f7^2*f3*f1*f6+16*x1*x4^2*x6*f3*f7*f4^2*f6-32*x1*x4^2*x6*f6^2*f4*f1
*f7-144*x1*x4^2*x6*f6^2*f2*f5^2+32*x1*x4*x2*x6*f0*f6^2*f3*f7+12*x2^2*x4*x5*f5^
2*f4^3+112*x3*x5*x2*x4*f3*f5*f2*f6*f7+24*x4^2*x5*x2*f4^3*f5*f7+16*x4^2*x5*x2*
f3*f6*f7*f4^2+24*x2*x4*x3*x5*f4^2*f5^3+100*x3*x5*x2*x4*f5^2*f7*f2*f4-292*x2*x4
*x6^2*f4*f7^2*f1+60*x2*x4*x6^2*f5^3*f4+160*x4*x2*x6^2*f7*f5*f1*f6+128*x4*x2*x6
^2*f0*f5*f7^2+56*x4*x2*x6^2*f7*f5*f3*f4-88*x4*x2*x6^2*f7*f5^2*f2+40*x2*x4*x6^2
*f7^2*f2*f3-128*x1*x4*x3*x7*f0*f7^3*f3+152*x1*x4*x6*x7*f3*f7^2*f2-56*x1*x4*x6*
x7*f3^2*f7*f6+232*x1*x4*x6*x7*f7*f5^2*f2+288*x1*x4*x6*x7*f0*f6^2*f7-40*x1*x4*
x5*x7*f7*f5*f3^2+96*x1*x4*x5*x7*f2*f7*f3*f6+8*x1*x4*x5*x7*f7*f2*f4*f5-40*x1*x4
*x5*x7*f2^2*f7^2-24*x1*x4*x5*x7*f5^3*f3+64*x3^2*x4^2*f7*f3^2*f6^3+72*x3^2*x4^2
*f4*f5^3*f6^2-48*x3*x4*x5^2*f7*f5^2*f1+48*x3*x4*x5^2*f2*f5^2*f6+464*x5^2*x3*x4
*f0*f6*f5*f7+72*x3*x4*x5^2*f3*f5*f4*f6-80*x3^2*x5*x4*f3*f6*f1*f7^2-64*x3*x4^2*
x5*f3^2*f6^2*f7-36*x3*x4^2*x5*f5^5-232*x4^2*x5*x3*f4*f6*f7*f3*f5+84*x4^2*x5*x3
*f5^2*f7^2*f1-72*x4^2*x5*x3*f4*f5*f7^2*f2+24*x3^2*x4*x5*f5*f4^3*f7+80*x3^2*x4*
x5*f7*f5^2*f3*f4-48*x3*x4*x1*x5*f4^2*f3*f5*f6+64*x6^2*f7*f1*f6^2*x3*x4+16*x3*
x4*x6^2*f7*f5*f4^2-40*x3*x4*x6^2*f7*f2*f5*f6+96*x3*x4*x6^2*f4*f5^2*f6+832*x3*
x4*x6^2*f0*f6*f7^2+80*x3*x4*x6^2*f7*f3*f5^2-260*x3*x4*x6^2*f7^2*f5*f1-84*x3*x4
*x6^2*f2*f7^2*f4+76*x3*x4*x5*x6*f4*f7^2*f1+1016*x3*x4*x5*x6*f0*f5*f7^2-64*x3*
x4*x5*x6*f7^2*f2*f3-12*x3*x4*x5*x6*f7*f2*f5^2-96*x3*x4*x5*x6*f4^2*f6*f5-8*x3*
x4*x5*x6*f7*f3*f5*f4+192*x3*x4*x5*x6*f2*f5*f6^2-176*x3*x4*x5*x6*f7*f6*f5*f1+64
*x3*x4*x5*x6*f7*f2*f4*f6-512*x3*x4*x5*x6*f0*f6^2*f7-96*x3*x4*x7^2*f4^2*f7^2+96
*x3*x4*x7^2*f7*f5^3-32*x7^2*f2*f7^2*x3*x4*f6+432*x3*x4*x7^2*f7*f5*f4*f6+144*x3
*x4*x7^2*f5^2*f6^2-256*x3*x4*x7^2*f7^2*f3*f5+144*x3*x4*x7^2*f3*f6^2*f7+48*x3*
x4*x7^2*f7^3*f1-208*x1*x4^2*x8*f7^2*f5^2*f2+16*x1*x4*x2*x8*f7*f2*f4*f5*f6+112*
x1^2*x4*x7*f0*f5*f3*f7^2-32*x2*x4*x5*x8*f7^2*f2*f4+4*x2^2*x4*x5*f7*f3*f4^3-64*
x4^2*x1*x3*f1*f6^3*f7*f3+64*x4^2*x1*x3*f0*f6^3*f4*f7+16*x1*x4^2*x2*f6^2*f2*f7*
f3*f4-76*x1^2*x4^2*f7^3*f2^3-864*x1^2*x4^2*f0*f6^2*f5*f3*f7+108*x1^2*x4^2*f3*
f5^4*f4+144*x1^2*x4^2*f0*f6^2*f5^3+432*x1^2*x4^2*f6^2*f2*f3*f5^2-24*x1^2*x4*x5
*f1*f5*f4^2*f6-8*x1^2*x4*x5*f2*f7*f3*f4^2+8*x1^2*x4*x5*f3^3*f4*f7-96*x1^2*x4*
x6*f1^2*f6^2*f7-64*x1^2*x4*x6*f5*f7*f3^3-84*x1*x4*x2*x6*f4*f5^3*f3-64*x1*x4*x2
*x6*f0*f6*f2*f7^2-144*x2*x4*x5*x7*f5^2*f3*f6+40*x2*x4*x5*x7*f7^2*f2*f3-112*x2*
x4*x5*x7*f7*f6*f2*f4+168*x4*x2*x6*x7*f7*f3*f5^2+176*x2*x4*x6*x7*f0*f6*f7^2+16*
x2*x4*x6*x7*f7*f4*f6*f3-168*x4*x2*x6*x7*f7*f2*f5*f6-36*x4*x2*x6*x7*f1*f7^2*f5-\
24*x2*x4*x6*x7*f5^4-60*x4*x2*x6*x7*f7*f4^2*f5+120*x2*x4*x6*x7*f7^2*f2*f4-144*
x2*x4*x6*x7*f4*f5^2*f6+108*x4*x2*x5*x7*f7*f5^2*f2+296*x4*x2*x5*x7*f0*f5*f7^2+
96*x2*x4*x5*x7*f4^2*f6*f5-72*x4*x2*x5*x7*f7*f5*f3*f4+152*x2*x4*x5*x7*f7*f5*f1*
f6+24*x2*x4*x3*x7*f5^5+24*x2^2*x4*x7*f4^2*f5^2*f6+32*x2^2*x8*f7*x4*f3*f6*f5*f4
+16*x2^2*x4*x8*f7^3*f2^2+8*x2^2*x4*x8*f7*f4^3*f6-12*x2^2*x4*x8*f7^2*f4^2*f3+16
*x2^2*x4*x8*f7^2*f0*f6*f5-48*x2^2*x4*x8*f7^3*f0*f4-12*x2*x4*x3*x8*f7^2*f4^3+88
*x3*x8*f7^2*x2*x4*f4*f5*f3-32*x2*x4*x3*x8*f7*f6^2*f4*f3+104*x3*x8*f7*x2*x4*f5*
f4^2*f6-24*x4^2*x8*f7*x2*f5^4+128*x2*x4^2*x8*f7^3*f0*f6-44*x5*x8*f7*x2*x4*f3*
f5^2-112*x6*x8*f7^2*x2*x4*f2*f5-32*x6*x8*f7*x2*x4*f3*f5*f6+28*x2*x4*x6*x8*f7^2
*f3*f4+32*x2*x4*x6*x8*f7^2*f1*f6+112*x2*x4*x6*x8*f7^3*f0-16*x2*x4*x6*x8*f7*f4^
2*f6-68*x2*x4*x7*x8*f7^3*f1-8*x2*x4*x7*x8*f7^2*f4^2-20*x7*x8*f7*x2*x4*f5^3+176
*x7*x8*f7*x2*x4*f4*f5*f6-12*x7*x8*f7^2*x2*x4*f3*f5+16*x2*x4*x5*x8*f7*f3*f6*f4+
100*x5*x8*f7^2*x2*x4*f1*f5-48*x2*x4*x5*x8*f7^2*f0*f6-32*x2*x4^2*x8*f7^2*f1*f6^
2-16*x2^2*x4*x8*f7^2*f4*f6*f1+16*x2^2*x4*x8*f7^2*f2*f3*f6+24*x1^2*x4*x6*f4*f5^
3*f2-48*x1^2*x4*x6*f5*f4^2*f2*f6-12*x1^2*x4*x6*f5^2*f4^2*f3-96*x1^2*x4*x6*f0*
f6^2*f2*f7+120*x1^2*x4*x6*f6*f3^2*f5*f4-48*x1^2*x4*x6*f4*f5^2*f1*f6-288*x1*x4*
x5*x6*f0*f6^2*f5-88*x1*x4*x5*x6*f2^2*f7*f6+72*x1*x4*x5*x6*f3^2*f5*f6+188*x1*x4
*x5*x6*f2*f7^2*f1+288*x1*x4*x5*x6*f0*f5^2*f7+96*x1*x4*x5*x6*f2*f4*f5*f6-120*x1
*x4*x5*x6*f7*f3*f1*f6-48*x1*x4*x5*x6*f7*f2*f3*f5-36*x1*x4*x5*x6*f3*f4*f5^2-32*
x1*x4*x5*x6*f4*f5*f7*f1+144*x1*x4*x5*x6*f0*f6*f7*f4-24*x3*x4*x5*x7*f7*f2*f5*f6
-24*x3*x4*x5*x7*f5^4+32*x3*x4*x6*x7*f7^2*f3*f4+88*x3*x4*x6*x7*f7^2*f2*f5-288*
x3*x4*x6*x7*f5^3*f6+80*x3*x4*x6*x7*f7*f3*f5*f6-72*x3*x4*x6*x7*f1*f7^2*f6-264*
x3*x4*x6*x7*f7*f4*f5^2+112*x3*x4*x6*x7*f7*f6*f4^2-176*x3*x4*x6*x7*f6^2*f2*f7-\
176*x3*x4*x6*x7*f0*f7^3-96*x3*x4*x6*x7*f5*f6^2*f4+64*x3*x4*x5*x7*f7*f3*f5^2+72
*x3*x4*x5*x7*f7^2*f3^2-624*x3*x4*x5*x7*f0*f6*f7^2+144*x3*x4*x5*x7*f4*f5^2*f6-\
288*x3*x4*x5*x7*f3*f5*f6^2+12*x3*x4*x5*x7*f7^2*f5*f1+80*x3*x4*x5*x7*f7*f4^2*f5
+288*x3*x4*x5*x7*f7*f6^2*f1-36*x3*x4*x5*x7*f2*f7^2*f4-192*x1*x7*x3*x4*f3*f6^2*
f2*f7+32*x3^2*x8*f7^2*x4*f2*f6*f5-32*x3^2*x8*f7*x4*f4^2*f6^2+576*x3*x4^2*x8*f7
^4*f0-136*x4^2*x8*f7^3*x3*f6*f1-48*x4^2*x8*f7*f4*f5*f6^2*x3-120*x5*x8*f7*x3*x4
*f3*f5*f6+24*x3*x4*x6*x8*f7^2*f4^2+172*x3*x4*x6*x8*f7^3*f1-148*x3*x4*x6*x8*f7^
2*f3*f5-152*x6*x8*f7^2*x3*x4*f2*f6-56*x6*x8*f7*x3*x4*f4*f5*f6+32*x6*x8*f7*f3*
f6^2*x3*x4-92*x3*x4*x6*x8*f7*f5^3-16*x7*x8*f7*f4*f6^2*x3*x4+436*x3*x4*x7*x8*f7
^2*f4*f5-88*x3*x4*x7*x8*f7^3*f2+144*x7*x8*f7*x3*x4*f6*f5^2+176*x7*x8*f7^2*x3*
x4*f3*f6-304*x3*x4*x5*x8*f7^3*f0-52*x3*x4*x5*x8*f7^2*f3*f4+112*x5*x8*f7^2*x3*
x4*f1*f6+24*x5*x8*f7*x3*x4*f4^2*f6-16*x3*x4*x5*x8*f7*f4*f5^2+48*x3^2*x4*x7*f5^
2*f6^2*f4+56*x3^2*x4*x7*f4*f7^3*f1+48*x3^2*x4*x6*f5*f4^2*f6^2+48*x4^2*x6*x3*f6
^2*f7*f3*f4-144*x3*x4^2*x6*f5^2*f6^2*f4-144*x3*x4*x5^2*f5*f6^2*f1-32*x3*x4*x5^
2*f7*f5*f3^2+12*x3*x4*x5^2*f7^2*f3*f1-64*x3*x4*x5^2*f1*f7*f4*f6+16*x3*x4*x1*x5
*f7^2*f3^2*f2-104*x5^3*x4*f7*f0*f5+24*x5^3*x4*f6*f1*f5+8*x5^3*x3*f1*f4*f6-16*
x5^3*x3*f0*f5*f6-8*x5^3*x3*f7*f0*f4-16*x5^3*x2*f0*f5^2+16*x5^3*x2*f0*f6*f4-36*
x5^2*x1*x6*f7*f2*f1-16*x5^3*x6*f0*f6-48*x5^2*x4*x6*f6*f2*f5+128*x5^2*x4*x6*f7*
f0*f6+56*x5^2*x4*x6*f7*f1*f5+96*x5^2*x3*x6*f0*f6^2-8*x5^2*x1*x7*f2*f3*f6+8*x5^
2*x1*x7*f7*f0*f4-4*x5^2*x1*x7*f7*f3*f1-16*x5^3*x7*f7*f0+8*x5^3*x7*f1*f6-16*x5^
2*x6*x7*f2*f6-48*x5^2*x3*x7*f6^2*f1+16*x5^2*x2*x7*f2*f4*f6-24*x5^2*x3*x8*f7*f1
*f6+28*x5^2*x4*x8*f7*f3*f5-24*x5^2*x4*x8*f1*f7^2+32*x5^2*x3*x8*f0*f7^2-24*x5^2
*x2*x7*f6*f1*f5+56*x5^2*x2*x7*f7*f0*f5+24*x5^2*x3*x7*f3*f6*f4+16*x5^2*x3*x7*f6
*f2*f5+96*x5^2*x3*x7*f7*f0*f6+72*x5^2*x4*x7*f3*f5*f6+152*x5^2*x4*x7*f7^2*f0-72
*x5^2*x4*x7*f7*f1*f6+48*x5^2*x2*x6*f0*f5*f6-8*x5^2*x2*x6*f2*f4*f5-88*x5^2*x2*
x6*f7*f0*f4+8*x5^2*x3*x6*f6*f1*f5-8*x5^2*x3*x6*f5^2*f2-16*x5^2*x3*x6*f2*f4*f6-\
104*x5^2*x3*x6*f7*f0*f5+12*x5^3*x1*f7*f1^2-8*x5^3*x1*f0*f4*f5-8*x5^3*x1*f2*f1*
f6+16*x1*x5^2*x2*f0*f5*f7*f2-8*x1*x5^2*x3*f4^2*f1*f6-8*x1*x5^2*x3*f5^2*f1*f4-\
16*x1*x5^2*x3*f0*f5*f7*f3-104*x1*x5*x6^2*f7*f0*f4+12*x1*x5*x6^2*f3^2*f5+16*x1*
x5*x6^2*f1*f4*f6+4*x4*x5^2*x1*f7*f4^2*f1+16*x1*x5*x4*x7*f4^2*f7*f3+8*x1*x5*x2*
x6*f3^2*f7*f2-4*x1*x5*x3*x6*f3^3*f7-12*x2*x5*x6^2*f7*f2*f3+4*x2*x5^2*x6*f7*f3*
f1-8*x1*x5*x7^2*f3*f6*f4+16*x1*x5*x7^2*f6^2*f1+96*x1^2*x5*x7*f0*f6^2*f3-4*x1*
x5*x4*x6*f4^2*f2*f7+4*x1*x5^2*x6*f1*f4*f5-4*x1*x5^2*x2*f4^2*f1*f5-4*x1*x5^2*x2
*f3^2*f7*f1+4*x1*x5^2*x3*f4^2*f2*f5-4*x1*x5^2*x4*f3^3*f7+8*x1^2*x5*x7*f3^2*f5*
f4-24*x1^2*x5*x7*f3^3*f6+8*x1*x5*x6*x8*f7*f2*f4+12*x1*x5*x2*x7*f4^2*f3*f5-12*
x2*x7*x1*x5*f3^3*f7+224*x2*x7*x1*x5*f0*f7^2*f2-8*x1*x5*x2*x7*f4*f5^2*f2+32*x1^
2*x5*x7*f1*f0*f7^2+24*x1^2*x5*x7*f3^2*f7*f2-8*x1^2*x5*x7*f4^2*f1*f6+128*x1*x5*
x6*x7*f7*f0*f5-2*x1^2*x5^2*f2^2*f4*f5-4*x1^2*x5*x6*f5^2*f2^2-4*x1^2*x5*x6*f4^2
*f1*f5-4*x1*x5*x7^2*f3*f5^2+4*x1*x5*x7^2*f7*f2*f4+4*x1*x5^2*x7*f2*f4*f5-4*x1*
x5^2*x7*f1*f5^2+12*x1*x5^2*x4*f4*f5^2*f2-8*x1^2*x5*x6*f5*f6*f1*f2-48*x1^2*x5*
x6*f3*f1*f4*f6-48*x1^2*x5*x6*f0*f6*f5*f3+16*x1^2*x5*x6*f0*f6*f4^2-16*x1^2*x5*
x6*f4*f2^2*f6+32*x1^2*x5*x6*f6^2*f1^2+20*x1^2*x5*x6*f5^2*f1*f3+36*x1^2*x5*x6*
f1*f4*f7*f2-24*x1^2*x5*x6*f3*f7*f2^2-64*x1^2*x5*x6*f0*f5*f7*f2+8*x1^2*x5*x6*f5
*f7*f1^2-44*x1*x5*x3*x6*f7^2*f1^2-12*x1*x5*x4*x6*f3^2*f7*f4-8*x1^2*x5^2*f0*f7*
f1*f5-4*x1^2*x5^2*f3*f4*f1*f5+48*x1*x5^2*x4*f0*f6*f5^2+8*x4*x5^2*x1*f7*f4*f3*
f2+32*x4*x5^2*x1*f7*f2^2*f5+80*x4*x5^2*x1*f0*f6*f7*f3-12*x1*x5^2*x4*f5^3*f1-24
*x1*x5^2*x4*f4*f6*f1*f5-16*x2*x5^2*x6*f1*f4*f6-8*x2*x5*x3*x6*f1*f7^2*f2+16*x2^
2*x5*x6*f0*f6*f7*f3-24*x2*x5*x7^2*f3*f5*f6+16*x2*x5*x7^2*f4^2*f6+8*x2*x5*x7^2*
f7*f1*f6+88*x2*x5*x7^2*f0*f7^2-8*x2*x5*x7^2*f7*f3*f4+16*x2*x5*x1*x7*f3*f6*f2*
f5+32*x1*x5*x2*x6*f0*f6*f7*f2+48*x1*x5*x4*x8*f7*f6*f1*f5-32*x1*x5*x6*x8*f7*f0*
f6+16*x1*x5*x7*x8*f7*f1*f6-24*x1*x5*x7*x8*f7^2*f0-4*x1*x5*x7*x8*f7*f2*f5+8*x1*
x5^2*x8*f7*f0*f5-4*x1^2*x5^2*f1^2*f6*f5-18*x1^2*x5^2*f1^2*f7*f4+128*x1^2*x5^2*
f6*f0^2*f7-4*x1^2*x5^2*f2^3*f7+48*x1^2*x5^2*f3*f0*f6*f4+8*x1^2*x5^2*f2*f1*f6*
f4+16*x1^2*x5^2*f5*f6*f0*f2-16*x6^3*x1*f6*f1*f5-208*x1^2*x5*x7*f0*f5*f7*f3+16*
x1*x5*x2*x8*f7*f0*f6*f4-8*x1*x5*x2*x8*f5^2*f7*f0+96*x1*x5*x4*x7*f5*f6^2*f1+16*
x1*x5^2*x3*f1*f0*f7^2+8*x1*x5^2*x3*f7*f4*f2^2+48*x4*x5^2*x1*f0*f7^2*f2+192*x1*
x5^2*x2*f0^2*f7^2-8*x1*x5^2*x2*f3*f4*f6*f1-32*x1*x5^2*x2*f1*f6*f0*f7+8*x1*x5^2
*x2*f0*f5^2*f4+16*x1*x5^2*x2*f4^2*f0*f6+16*x1*x5*x6^2*f7*f2^2+128*x2*x7*x1*x5*
f0*f6*f7*f3+8*x2^2*x5^2*f1*f6*f4^2+112*x2^2*x7*x5*f0*f3*f7^2-8*x2*x5*x3*x7*f1*
f7^2*f3-60*x2*x5*x4*x7*f7^2*f1*f4+16*x2^2*x5*x6*f2*f5^2*f4-12*x2^2*x5*x6*f7^2*
f1^2+16*x2*x5*x3*x6*f5^3*f2+64*x2*x5*x3*x6*f0*f7^2*f3-16*x2*x5*x3*x6*f5^2*f1*
f6-2*x3^2*x5^2*f4^3*f5-4*x4*x5^2*x3*f4^2*f7*f3+4*x3^2*x5*x7*f4^3*f7-4*x3*x5^2*
x7*f5*f4^2+64*x1*x5*x3*x7*f0*f7^2*f3-16*x1^2*x5^2*f3^2*f6*f1-40*x1^2*x5^2*f7*
f3^2*f0+4*x1^2*x5^2*f2*f1*f5^2+36*x1^2*x5^2*f1*f7*f2*f3+8*x1^2*x5^2*f0*f5*f4^2
+8*x2^2*x5^2*f7*f3*f0*f5+16*x2*x5^2*x3*f0*f6*f7*f3+96*x4*x5^2*x2*f0*f3*f7^2+8*
x2*x5^2*x4*f1*f6*f7*f3-16*x2*x5^2*x3*f2*f0*f7^2+12*x2^2*x5^2*f0*f7^2*f1-4*x2^2
*x5^2*f3*f7*f1*f4-8*x2*x5*x6^2*f5^2*f2-80*x2*x5*x6^2*f7*f0*f5+76*x2*x5*x6^2*f7
*f1*f4-16*x1*x5*x3*x7*f4^2*f3*f6+32*x1*x5*x3*x7*f3*f7*f2*f5+32*x1*x5*x6*x7*f2*
f4*f6-8*x1*x5*x6*x7*f6*f1*f5-40*x1*x5*x6*x7*f7*f2*f3+24*x1*x5*x6*x7*f6*f3^2-96
*x1*x5*x6*x7*f0*f6^2+8*x1*x5^2*x7*f7*f2^2-8*x1*x5^2*x7*f1*f4*f6+16*x1*x5^2*x7*
f0*f5*f6-48*x1*x5*x4*x7*f3*f5*f4*f6-32*x3^2*x5^2*f0*f3*f7^2+4*x3^2*x5^2*f4*f5*
f1*f7-8*x5^2*x3*x4*f2^2*f7^2+8*x4*x5^2*x3*f3*f6*f2*f7-20*x4*x5^2*x3*f4*f5*f7*
f2-12*x3*x5^2*x4*f5^2*f4^2+80*x4*x5^2*x3*f0*f4*f7^2-4*x3^2*x5^2*f4^2*f7*f2-176
*x3*x5*x6^2*f7*f0*f6+16*x3*x5*x6^2*f7*f2*f4+88*x3*x5*x6^2*f7*f1*f5-16*x3*x5*x6
^2*f6*f2*f5-32*x3*x5*x1*x6*f0*f6^2*f4+12*x3*x5*x7^2*f7*f3*f5+24*x3*x5*x7^2*f4*
f5*f6-48*x3*x5*x7^2*f3*f6^2+32*x3*x5*x1*x7*f6^2*f2*f3+24*x1*x5*x4*x8*f7^2*f1*
f4-8*x1*x5*x4*x8*f7^2*f2*f3-48*x1*x5*x3*x8*f7^2*f0*f4-12*x1*x5*x3*x8*f7*f2*f4*
f5+128*x1^2*x5*x7*f0*f6*f7*f2-4*x2^2*x5*x8*f7^2*f2^2+4*x2^2*x5*x8*f7*f1*f5^2+4
*x2^2*x5*x8*f7^2*f3*f1+4*x2*x5*x3*x8*f7*f4^3-8*x2*x5*x3*x8*f7^2*f2*f3-12*x2*x5
*x4*x8*f7^2*f3^2+4*x2*x5*x7*x8*f7*f4^2+4*x2^2*x5*x7*f4^3*f5-12*x2*x5*x4*x6*f7*
f4^2*f3-12*x1*x5*x6*x7*f3*f5*f4-4*x1*x5*x6*x7*f7*f1*f4+4*x1*x5*x2*x8*f5*f7*f1*
f4-4*x1*x5*x2*x8*f7*f4^2*f2-4*x1*x5^2*x8*f7*f1*f4-32*x1^2*x5^2*f0*f6^2*f1-4*x1
^2*x5^2*f2^2*f3*f6-24*x1^2*x5^2*f3*f0*f5^2+4*x1^2*x5^2*f3^2*f2*f5+32*x1*x5*x2*
x6*f6*f7*f1^2-4*x2*x5^2*x3*f7^2*f1^2-4*x2*x5^2*x4*f7*f3^2*f4+4*x4*x5^2*x2*f4^2
*f7*f2+8*x2*x5*x3*x7*f5^2*f4^2+12*x2*x5*x6^2*f3*f5*f4+16*x2*x5*x7^2*f7*f2*f5-4
*x2*x5^2*x7*f7*f1*f4-8*x2*x5*x6*x7*f5*f4^2+8*x2*x5*x6*x7*f7*f3^2-64*x2*x5*x6*
x7*f7*f0*f6+32*x2*x5*x6*x7*f6*f2*f5-24*x2*x5*x6*x7*f7*f2*f4+40*x2*x5*x4*x7*f3^
2*f6*f7-12*x2^2*x7*x5*f3^2*f7*f4+12*x2^2*x7*x5*f4^2*f7*f2+24*x2^2*x5*x8*f7^2*
f0*f4-8*x2^2*x5*x8*f7*f2*f4*f5-32*x2*x5*x6*x8*f7^2*f0+16*x2*x5*x6*x8*f7*f2*f5+
28*x2*x5*x7*x8*f1*f7^2-12*x2*x5*x7*x8*f7*f3*f5+8*x2*x5*x4*x8*f7*f5*f4^2+32*x1^
2*x5*x6*f2*f0*f6^2+40*x1^2*x5*x6*f2*f6*f3^2-12*x1^2*x5*x6*f3^3*f5-32*x1^2*x5*
x6*f1*f7*f3^2-16*x1*x5^2*x6*f0*f6*f4+8*x1*x5^2*x6*f3*f1*f6+32*x3*x5*x1*x7*f0*
f6^2*f5+24*x3*x5*x6*x7*f0*f7^2+64*x3*x5*x6*x7*f6^2*f2-36*x3*x5*x6*x7*f7*f2*f5+
8*x3*x5*x6*x7*f7*f3*f4-32*x3*x5*x6*x7*f4^2*f6-8*x3*x5^2*x7*f7*f2*f4-24*x3*x5*
x1*x7*f3^2*f5*f6-24*x3^2*x5*x8*f7*f3*f6*f4+12*x3^2*x5*x8*f7^2*f1*f5+32*x3*x5*
x6*x8*f7*f2*f6-16*x3*x5*x6*x8*f7^2*f1+24*x3*x5*x7*x8*f2*f7^2-40*x3*x5*x7*x8*f7
*f3*f6-16*x3*x5*x2*x8*f7*f2*f4*f6-8*x3^2*x5*x7*f5*f6*f1*f7+32*x3^2*x5*x6*f5^2*
f6*f2-8*x5*x3^2*x6*f2^2*f7^2+40*x3*x5*x4*x6*f3^2*f7*f6-4*x6*x7*x4*x5*f7*f4^2-4
*x5^2*x8*f7*x4*f4^2+12*x3*x5*x6^2*f3*f5^2+8*x3*x5*x7^2*f7*f4^2-4*x3^2*x5*x8*f7
^2*f3^2+4*x3*x5*x6*x8*f7*f3*f5+4*x5*x3^2*x6*f3*f7^2*f1+4*x4^2*x5^2*f4^3*f7-20*
x4^2*x5^2*f3*f7^2*f2-40*x4^2*x5^2*f4*f7*f3*f5+16*x4^2*x5^2*f3^2*f7*f6-18*x4^2*
x5^2*f5^3*f4-16*x4^2*x5^2*f5^2*f7*f2-4*x4^2*x5^2*f7^2*f4*f1-32*x6^2*f7*f1*f6*
x4*x5-344*x6^2*x4*x5*f0*f7^2+8*x6^2*x4*x5*f7*f3*f4+12*x6^2*x4*x5*f7*f2*f5-20*
x4^2*x6*x5*f4^2*f5*f7-20*x4^2*x6*x5*f7^2*f4*f2-64*x4*x5*x7^2*f3*f6*f7+52*x5*x4
*x7^2*f7*f4*f5-8*x7^2*x4*x5*f2*f7^2-12*x4*x5^2*x7*f4*f5^2+24*x4*x5*x6*x7*f5^3+
16*x6*x7*x4*x5*f7*f3*f5+88*x6*x7*x4*x5*f7*f2*f6+48*x6*x7*x4*x5*f1*f7^2-96*x4*
x5*x6*x7*f4*f5*f6-8*x5^2*x7*x4*f7*f3*f4-20*x5^2*x7*x4*f7*f2*f5-44*x4^2*x7*x5*
f7^2*f2*f5+16*x5*x4^2*x7*f7*f4^2*f6-96*x3*x7*x4*x5*f4*f6*f3*f7+8*x5*x4*x2*x7*
f4^3*f7-48*x4^2*x8*f7*x5*f5^3+24*x4^2*x8*f7*f4*f5*f6*x5-12*x6*x8*f7*x4*x5*f4*
f5+60*x6*x8*f7^2*x4*x5*f2-16*x6*x8*f7*f3*f6*x4*x5+8*x7*x8*f7*f4*f6*x4*x5-68*x7
*x8*f7^2*x4*x5*f3-28*x7*x8*f7*x4*x5*f5^2-16*x4^2*x6*f4*f6*f3*f7*x5+40*x4^2*x6*
x5*f3^2*f7^2+48*x1^2*x6^2*f0*f3*f6^2-24*x1*x6*x7^2*f7*f3*f4-4*x6^3*x5*f3*f5+24
*x6^2*x3*x7*f7*f3*f5+32*x6^2*x3*x7*f1*f7^2+4*x6^3*x2*f7*f3^2+4*x6^3*x2*f3*f5^2
+16*x6^2*x5*x7*f7*f2+8*x6^2*x2*x8*f7*f4^2+12*x6^2*x3*x8*f2*f7^2-4*x6^3*x8*f7*
f4-4*x6^3*x3*f7*f3*f4+32*x1*x6^2*x3*f1*f6^2*f4-32*x1*x6^2*x3*f0*f6^2*f5+8*x1*
x6^2*x4*f7*f4^2*f3+12*x1*x7^3*f7*f3*f5+4*x7^3*x5*f7*f4+4*x7^3*x2*f7*f4*f5-12*
x1*x7^3*f1*f7^2+16*x1*x6*x2*x7*f2*f6*f4*f5+24*x2*x7*x1*x6*f7*f2^2*f6+32*x2*x7*
x1*x6*f0*f7^2*f3+24*x6^3*x1*f7*f1*f4+48*x6^3*x1*f7*f0*f5+8*x6^3*x1*f5^2*f2-20*
x6^3*x1*f7*f2*f3-8*x6^3*x1*f3*f5*f4-24*x6^3*x5*f7*f1+20*x6^2*x1*x7*f3*f5^2+36*
x6^2*x1*x7*f7*f3^2+64*x6^2*x1*x7*f6^2*f1-32*x6^2*x1*x7*f3*f6*f4-24*x6^2*x1*x7*
f6*f2*f5-112*x6^2*x1*x7*f7*f0*f6-12*x6^3*x7*f7*f3+28*x6^2*x4*x7*f7*f4*f5-64*x6
^2*x4*x7*f2*f7^2+120*x6^2*x4*x7*f6*f5^2+32*x6^2*x3*x7*f4*f5*f6+28*x6^2*x2*x7*
f7*f3*f4+48*x6^2*x2*x7*f7*f1*f6+28*x6^2*x3*x8*f7*f4*f5+40*x6^2*x4*x8*f7*f5^2-\
16*x6^2*x4*x8*f7^2*f3+16*x6^2*x7*x8*f7*f5+4*x6^2*x1*x7*f7*f2*f4-56*x6^2*x1*x7*
f7*f1*f5-44*x6^2*x2*x7*f7*f2*f5-88*x6^2*x2*x7*f0*f7^2+20*x6^2*x2*x7*f4*f5^2+8*
x6^2*x3*x7*f7*f4^2-40*x6^2*x3*x7*f7*f2*f6-16*x6^2*x4*x7*f3*f6*f7-16*x6^3*x2*f3
*f6*f4-12*x6^3*x2*f7*f2*f4+24*x6^3*x2*f7*f1*f5-8*x6^3*x2*f5*f4^2-8*x6^3*x3*f3*
f5*f6-16*x6^3*x3*f4*f5^2+64*x6^3*x3*f7*f1*f6-28*x6^3*x3*f7*f2*f5-72*x6^3*x3*f0
*f7^2+84*x6^3*x4*f1*f7^2-32*x6^3*x4*f7*f3*f5-4*x1*x6*x4*x7*f7*f4^3-4*x1*x6^2*
x2*f3^3*f7+16*x1*x6*x7^2*f4^2*f6+96*x1*x6*x7^2*f0*f7^2-36*x1^2*x6*x7*f3^3*f7+
116*x1^2*x6*x7*f7*f3*f1*f5+16*x1^2*x6*x7*f6^2*f2^2+8*x1^2*x6*x7*f4*f5^2*f2-16*
x1^2*x6*x7*f3^2*f5^2-24*x1^2*x6*x7*f7*f4*f0*f5-16*x1^2*x6*x7*f4^2*f6*f2+40*x1^
2*x6*x7*f3^2*f6*f4-96*x1^2*x6*x7*f6^2*f1*f3+32*x1^2*x6*x7*f0*f6^2*f4+8*x1^2*x6
*x7*f5^3*f1-4*x1*x6^2*x8*f7*f2*f5-28*x1*x6*x2*x7*f5^2*f3*f4-64*x1^2*x6*x7*f7^2
*f0*f2-16*x1^2*x6*x7*f1*f6*f5*f4+4*x1*x6^2*x3*f4^3*f5+36*x1*x6*x7^2*f7*f2*f5-\
12*x1*x6*x7^2*f4*f5^2+32*x1^2*x6^2*f7*f3^2*f2-88*x1^2*x6^2*f7*f3*f0*f5+36*x1^2
*x6^2*f7^2*f0*f1-12*x1^2*x6^2*f3^3*f6+8*x1^2*x6^2*f1*f6*f4^2+112*x1*x6^2*x3*f0
*f7^2*f3-16*x1*x6^2*x3*f2*f6*f4*f5+12*x1*x6^2*x4*f5^2*f4^2-16*x2*x6^2*x5*f6*f1
*f5-8*x2*x6^2*x4*f4*f6*f2*f7+8*x2*x6^2*x4*f3^2*f7*f6+8*x2^2*x6^2*f5^2*f1*f6-24
*x2^2*x6^2*f0*f3*f7^2-8*x2^2*x6^2*f3*f6*f1*f7+28*x2*x6*x7^2*f7*f3*f5-12*x2*x6*
x7^2*f7*f4^2-24*x2*x6*x7^2*f4*f5*f6-16*x1*x6^2*x2*f0*f6*f5^2+32*x1*x6^2*x2*f0*
f6*f7*f3+16*x1*x6^2*x8*f1*f6*f7-24*x1*x6^2*x8*f7^2*f0+36*x1*x6*x7*x8*f1*f7^2+8
*x1*x6*x2*x8*f7^2*f2^2+304*x1*x6*x4*x7*f0*f5*f7^2-32*x1*x6*x4*x7*f7^2*f1*f4+16
*x1^2*x6*x7*f7*f3*f4*f2+64*x1^2*x6*x7*f0*f6*f7*f3+16*x2^2*x7*x6*f3*f6*f2*f7+8*
x2^2*x6^2*f0*f6*f4*f7-48*x2*x6^2*x3*f3*f7^2*f1+32*x2*x6^2*x3*f5*f6^2*f1-4*x3*
x6^2*x5*f7*f3^2+4*x3*x6^2*x5*f5*f4^2-8*x1*x6*x4*x7*f7*f6*f1*f5-8*x1*x6*x3*x7*
f1*f6*f7*f4+48*x1*x6*x3*x7*f5^2*f6*f2-32*x3*x6^2*x5*f6^2*f1+56*x4*x6^2*x3*f3^2
*f7^2+24*x3^2*x6^2*f3^2*f7*f6+16*x3^2*x6^2*f7^2*f4*f1-16*x7^2*x3*x6*f2*f7^2-48
*x3*x6*x7^2*f6*f5^2+16*x3*x6*x7^2*f3*f6*f7-40*x6*x3*x7^2*f7*f4*f5-16*x1*x6*x4*
x8*f4*f7^2*f2+24*x1*x6*x3*x8*f7^2*f0*f5+24*x1*x6*x2*x8*f7^2*f0*f4+4*x7^3*x1*f5
^3-16*x7^3*x6*f6^2+16*x7^4*f6*f7+24*x7^3*x8*f7^2+4*x5*x8^3*f7^2+4*x2*x6*x7^2*
f1*f7^2-4*x2^2*x6*x8*f7*f4^3+4*x2^2*x7*x6*f2^2*f7^2-4*x2^2*x7*x6*f5^2*f7*f1+4*
x2*x6^2*x4*f4^3*f7+4*x1*x6^2*x7*f5*f4^2-4*x1^2*x6*x7*f7*f1*f4^2-4*x1^2*x6*x7*
f4^2*f3*f5+4*x1*x6*x3*x8*f7*f5^2*f2+32*x1*x6^2*x2*f4*f6*f1*f5-16*x1*x6^2*x2*f0
*f7^2*f2+8*x1*x6^2*x2*f5^3*f1-20*x1*x6^2*x2*f2*f5^2*f4-8*x2*x6*x5*x7*f7*f1*f5+
16*x2*x6*x3*x7*f3*f7^2*f2-48*x2^2*x7*x6*f3*f7^2*f1+12*x2*x6^2*x8*f7^2*f1-12*x2
*x6*x7*x8*f7*f4*f5-32*x2*x6*x4*x8*f7*f4*f5^2+10*x1^2*x6^2*f4*f5*f3^2+16*x1*x6^
2*x5*f0*f5*f6-8*x1*x6^2*x5*f1*f5^2-16*x3*x6*x5*x7*f7*f1*f6+44*x3^2*x7*x6*f3^2*
f7^2+8*x6*x3^2*x8*f7*f3*f5*f6+16*x3^2*x8*f7*x6*f4^2*f6-16*x6^2*x8*f7*x3*f3*f6-\
8*x7*x8*f7*f4*f6*x3*x6-44*x7*x8*f7^2*x3*x6*f3-36*x7*x8*f7*x3*x6*f5^2+16*x3^2*
x6*x7*f4^2*f6^2+16*x3^2*x6*x7*f6^2*f1*f7+32*x3^2*x6^2*f6^3*f1-56*x4*x6^2*x3*f4
*f6*f3*f7-4*x2*x8*f7^2*f3^2*x3*x6-8*x5*x8*f7*x3*x6*f4^2+4*x5^2*x6*x7*f7*f1+4*
x5*x6^2*x7*f4*f5-4*x5*x6*x2*x8*f7*f3*f4+4*x5*x6^2*x8*f3*f7-8*x5*x6*x7*x8*f4*f7
+12*x4*x6^2*x5*f4*f5^2-4*x4^2*x6^2*f4^2*f7*f6+24*x4*x6*x7^2*f3*f7^2-128*x4*x6*
x7^2*f7*f5^2+56*x4*x6*x7^2*f7*f4*f6-144*x4*x6*x7^2*f5*f6^2+16*x4^2*x6*x7*f6^2*
f3*f7+8*x4*x6^2*x8*f7*f4*f6+20*x4*x6*x7*x8*f7^2*f4-136*x4*x6*x7*x8*f7*f5*f6+8*
x5^2*x6^2*f1*f6-16*x5*x6*x7^2*f4*f6-8*x1*x7*x6*x8*f7*f2*f6-24*x1*x7^2*x8*f2*f7
^2-8*x1*x7*x2*x8*f7^2*f2*f3+8*x1*x7*x2*x8*f7*f2*f4*f6+16*x2*x7^2*x1*f2^2*f7^2+
16*x1^2*x7^2*f0*f6^2*f5-28*x1^2*x7^2*f3^2*f5*f6-32*x7^2*x2*x3*f7^2*f4*f2+40*x7
^2*x2*x3*f3^2*f7^2-176*x4*x7^2*x2*f0*f7^3-4*x3*x7^2*x5*f5^3+12*x1*x7^2*x4*f7^2
*f4*f2-8*x1^2*x7^2*f7*f4^2*f2+24*x1^2*x7^2*f7*f1*f4*f5-64*x1^2*x7^2*f7*f0*f5^2
-4*x2^2*x8*f7^2*f3^2*x7-12*x6*x8*f7^2*x2*x7*f2-4*x7^2*x8*f7*x2*f5^2+2*x2^2*x7^
2*f4*f5^3+4*x2*x7^2*x3*f5^4-2*x1^2*x7^2*f4^3*f5-4*x2*x7^2*x6*f5^3-16*x7^2*x2*
x6*f7*f2*f6+16*x2*x7^2*x3*f4^2*f6^2+16*x2^2*x7^2*f3^2*f7*f6-28*x2^2*x7^2*f7^2*
f4*f1+80*x3*x8*f7^3*x2*x7*f0+20*x3*x8*f7^2*x2*x7*f3*f4-16*x6*x8*f7*x2*x7*f3*f6
+32*x3*x8*f7*x2*x7*f4^2*f6+16*x2^2*x8*f7*x7*f3*f6*f4+4*x2^2*x7^2*f4^2*f6*f5+20
*x2^2*x7^2*f3*f7^2*f2+12*x3*x7^2*x5*f1*f7^2-16*x3*x7^2*x6*f6^2*f4+16*x3*x7^2*
x5*f7*f2*f6+12*x3^2*x7*x8*f7^3*f1-16*x3^2*x7^2*f6^2*f2*f7+8*x3^2*x7^2*f6^2*f4*
f5-2*x5^2*x7^2*f4*f5+4*x5*x7^2*x6*f5^2-4*x5*x7^2*x8*f7*f5+16*x4^2*x7^2*f7*f6^2
*f4-2*f7*x2^2*x8^2*f4*f5^2-4*f7*x2*x8^2*x3*f5^3-4*f7^3*x2*x8^2*x3*f1-4*f7^2*x2
*x8^2*x5*f2-16*x7^3*x1*f7*f2*f6-12*x7^3*x6*f5*f7-36*x7^3*x4*f7^2*f4-8*x7^3*x2*
f7*f3*f6-8*x7^3*x1*f4*f5*f6-4*x7^2*x2*x8*f7^2*f3+32*x7^2*x2*x8*f7*f4*f6+24*x7^
2*x3*x8*f7*f5*f6+76*x7^2*x3*x8*f7^2*f4-24*x7^2*x6*x8*f7*f6+224*x7^2*x4*x8*f5*
f7^2-8*x7^3*x2*f7^2*f2+16*x7^3*x2*f6^2*f4+8*x7^3*x3*f7*f5^2-24*x7^3*x3*f7^2*f3
+56*x7^3*x3*f7*f4*f6+16*x7^3*x3*f5*f6^2+200*x7^3*x4*f7*f5*f6-4*x1*x7^2*x4*f4^2
*f5*f7+16*x1^2*x7^2*f2*f6*f4*f5-8*x1^2*x7^2*f5^3*f2-16*x1^2*x7^2*f6^2*f1*f4+72
*x1^2*x7^2*f0*f6*f4*f7+12*x1^2*x7^2*f5^2*f3*f4-32*x1^2*x7^2*f1*f6*f7*f3+24*x1^
2*x7^2*f2*f7^2*f1-96*x1^2*x7^2*f0*f3*f7^2+48*x1^2*x7^2*f6^2*f2*f3-4*x1^2*x7^2*
f4^2*f3*f6+4*x1*x7^2*x3*f4^3*f7-24*x2*x7^2*x1*f4*f6*f1*f7+88*x2*x7^2*x1*f3*f6*
f2*f7+16*x1*x7^2*x2*f6^2*f2*f4+18*x1^2*x7^2*f3^2*f4*f7-36*x1^2*x7^2*f7*f2*f3*
f5+8*x1*x7^2*x6*f3*f5*f6-16*x1*x7^2*x6*f6^2*f2+4*x1*x7^2*x5*f5*f4^2-4*x5^2*x7^
2*f7*f2+4*f7*x2*x8^2*x6*f5^2+4*f7^2*x2*x8^2*x6*f3-32*f7^3*x2^2*x8^2*f0+8*f7^2*
x2^2*x8^2*f1*f6-12*f7^2*x2*x8^2*x3*f3*f5-8*f7^2*x2*x8^2*x4*f4*f5-24*f7^2*x2*x8
^2*x4*f3*f6+8*f7^3*x2*x8^2*x4*f2-4*f7^2*x2^2*x8^2*f3*f4-4*f7^2*x2^2*x8^2*f2*f5
-8*f7*x3^2*x8^2*f6*f5^2+8*f7*x3^2*x8^2*f6^2*f4-4*f7^2*x3^2*x8^2*f3*f6-24*f7^3*
x3*x8^2*x4*f3+8*f7*x3*x8^2*x6*f5*f6-8*f7*x3*x8^2*x5*f4*f6+24*f7^2*x3*x8^2*x4*
f4*f6-24*f7^2*x3*x8^2*x4*f5^2-4*f7^3*x3^2*x8^2*f2-2*f7^2*x3^2*x8^2*f4*f5-4*f7^
2*x3*x8^2*x5*f3+4*f7*x3*x8^2*x5*f5^2+4*f7^2*x3*x8^2*x6*f4+2*f7*x5^2*x8^2*f4-4*
f7*x5*x8^2*x6*f5+32*f7^2*x4*x8^2*x6*f5-16*f7^2*x4*x8^2*x5*f4+12*f7^3*x4^2*x8^2
*f4-4*f7^2*x4^2*x8^2*f5*f6+4*f7^2*x8^2*x6*x7, -24*x1^3*x7*f7*f1*f4^2*f2+256*x4
^3*x2*f7^2*f3*f5*f2*f6+48*x4^3*x2*f5*f4^3*f7*f6-272*x4^3*x2*f1*f7^3*f3*f5+32*
x4^3*x2*f0*f6*f7^3*f3+64*x2^2*x3*x7*f0*f4^2*f7^2-96*x3*x1^2*x4*f0*f4^3*f6*f7-\
160*x3*x1^2*x4*f0*f5^2*f4^2*f7-24*x3*x1*x4*x6*f7*f3^2*f4*f5+36*x3*x1*x4*x6*f4*
f5^2*f1*f7-128*x3*x1*x4*x6*f0*f6^2*f3*f7-8*x3*x1*x6^2*f1^2*f7^2+176*x4^3*x5*f0
*f6*f5*f7^2+72*x4^3*x5*f2^2*f7^3+228*x4^3*x5*f5^2*f1*f7^2+180*x4^3*x5*f7*f5^2*
f4^2-48*x4^3*x5*f5^2*f7*f2*f6+44*x4^3*x5*f3*f7^3*f1-48*x1*x4*x2*x7*f0*f7^2*f5*
f3-72*x4^2*x3*x6*f5^5+128*x3*x4^2*x2*f0*f6^3*f7*f4-8*x2^3*x5*f0*f4*f1*f7^2+144
*x3*x2*x4^2*f7*f6^2*f2*f3*f5+256*x3*x2*x4^2*f1^2*f7^3*f6+24*x3*x1*x4*x5*f5*f4^
4-384*x3*x1^2*x4*f4*f0^2*f7^3-88*x3*x1^2*x4*f4*f5^2*f1*f3*f7+112*x3^2*x4*x2*f6
^2*f7^2*f1^2+144*x3*x2*x4*x7*f3*f5^3*f6-32*x3*x2*x5*x7*f2*f5*f4*f6+48*x3*x2*x5
*x7*f0*f7*f5^2+48*x3*x1^2*x7*f0*f6*f5^2*f4+24*x3*x1^2*x7*f3*f5^3*f2+152*x1^2*
x2*x4*f5*f7^2*f3*f1^2-80*x3*x2*x6^2*f1*f4*f7*f5+32*x3*x1*x4*x7*f7^2*f2*f3*f4-\
28*x3*x1*x4*x7*f5*f4^2*f7*f3-32*x3*x2^2*x6*f2*f5*f4^2*f6-8*x3*x2*x5*x8*f7^2*f2
^2+48*x3^3*x4*f4*f5^5+40*x4*x5*x3^2*f5^2*f7*f3^2-4*x4*x5*x3^2*f1*f4^2*f7^2-704
*x4*x5*x3^2*f0*f6^2*f7*f4+8*x2^4*f4^2*f6*f2*f7*f1-12*x2^2*x5*x6*f3*f4^3+40*x1^
2*x2*x7*f7*f3^2*f4*f2-16*x1^2*x2*x7*f7*f3^2*f1*f5-16*x1^2*x2*x7*f7*f3*f5*f2^2-\
4*x6^3*x1*f7*f2^2-20*x6^2*x1*x7*f7*f1*f4+4*x6^3*x7*f7*f2-12*x6^2*x5*x7*f7*f1-4
*x1^2*x5*x7*f3*f7*f2^2-24*x1^2*x5^2*f0*f3*f7*f2+16*x1*x5*x3*x8*f7*f0*f5^2-16*
x2*x5*x6*x8*f7*f0*f6+4*x5^3*x1*f1*f3*f4-4*x5^3*x1*f1*f2*f5+48*x2^2*x3*x6*f0*f6
*f5^3-48*x2^2*x4*x6*f5^2*f4^3-224*x3*x1*x4^2*f0*f6^2*f4*f5*f7+28*x3*x1*x6^2*f5
*f4^2*f3-64*x3*x1*x6^2*f0*f6*f5^2+96*x3*x1*x6^2*f0*f6^2*f4-48*x3*x1*x4^2*f5^2*
f4^2*f7*f3+88*x3*x1*x4^2*f7*f3^2*f5*f6*f4+124*x4*x5*x1^2*f1*f5*f7*f3^2+80*x4^2
*x2*x7*f2*f7^2*f3*f6+104*x4^2*x3*x7*f7^2*f2*f4*f6-40*x4^2*x5*x7*f7*f2*f5*f6+
120*x4^2*x5*x7*f7*f4^2*f5-68*x4^2*x5*x7*f7*f3*f5^2+8*x2*x1*x3*x7*f4*f5^2*f1*f6
-16*x2*x1*x3*x7*f0*f6*f5^3+32*x2*x1^2*x4*f0*f6*f7^2*f2^2-16*x2*x1^2*x6*f0*f5*
f3^2*f7+16*x2*x1*x3*x5*f2^2*f5^3+12*x2^2*x5*x7*f7*f2^2*f5-16*x2^2*x5*x7*f5^2*
f2*f4-18*x2^2*x4^2*f4^2*f5^4+24*x2*x1*x6^2*f3*f4^3+16*x2^3*x3*f6*f2*f5*f4^3-8*
x2^3*x3*f1^2*f5^2*f7*f6+128*x1^3*x3*f6*f5*f0^2*f7*f4-48*x3*x1^2*x4*f0*f5^5-4*
x1^2*x7^2*f4*f5^2*f2-16*x1^2*x7^2*f0*f6*f5^2-4*x2^2*x8*f7*f4^3*x7-8*x1*x7^2*x4
*f7*f4^3-12*x2^3*x4*f5^5*f1-8*x1^3*x5*f0*f4^4+4*x2*x1*x5*x7*f7*f2*f5*f1+32*x2^
2*x1*x3*f0*f6^2*f1*f7*f4-96*x2*x1*x4*x6*f7*f1*f5^2*f3+64*x2*x1^2*x6*f6*f5*f0^2
*f7+24*x2^2*x1*x6*f4^2*f3^2*f5+288*x3*x1*x4*x6*f0*f6^2*f5^2-6*x3^2*x1^2*f3^3*
f5^3+8*x3^2*x2*x5*f1*f7*f3*f6*f4-16*x3^2*x1*x5*f0*f3^2*f7^2-4*x2^4*f0*f5^4*f4+
24*x3^2*x1*x7*f7*f3*f4*f6*f2-16*x3^2*x6^2*f3*f7*f4^2+16*x3^2*x6^2*f2*f6^2*f4-\
16*x2^2*x3*x7*f0*f5^3*f7-64*x1^2*x2^2*f0*f6*f4*f7*f3*f2-8*x2^2*x3*x6*f6*f5^2*
f1*f4-8*x2*x1*x5*x6*f1*f5^2*f3+32*x2*x1*x4*x7*f7^2*f3^2*f2+72*x2*x1*x4*x7*f7*
f1*f6*f4^2-8*x2*x1*x3*x8*f6*f7^2*f1^2-24*x2*x1*x3*x5*f7*f3^2*f5*f1+40*x3^2*x7^
2*f4^2*f6^2+192*x4*x2*x6*x7*f7*f5*f3*f4+16*x4*x2*x6*x7*f4^3*f7-104*x2*x1*x4^2*
f7*f4*f5^3*f1+48*x2*x1*x6*x7*f0*f5^2*f6-88*x2*x1*x6*x7*f4*f6*f1*f5+8*x2^2*x1*
x3*f1*f4*f6*f7*f3^2+8*x2*x1*x3*x6*f5^2*f4^2*f2-32*x2^2*x1*x3*f6^2*f1*f7*f2^2-\
44*x1*x2*x3^2*f4*f5^2*f1*f3*f7+20*x7^2*x4*x5*f7*f4^2-4*x1^2*x5*x6*f2^3*f7-8*x3
^2*x5*x6*f3*f7*f2*f5+4*x1*x5^2*x6*f1*f4^2+16*x2^2*x1*x5*f2^2*f5^2*f4+72*x3^2*
x4^2*f4^2*f5^3*f7+20*x4^4*f7^4*f3*f1-152*x4^4*f1*f7^3*f4*f6+48*x4^4*f7^2*f2*f5
^2*f6-16*x4^4*f6^2*f2*f4*f7^2-16*x4*x2*x6^2*f3*f7*f4^2-24*x4*x2*x6*x8*f7*f3*f5
^2+4*x4*x2*x7*x8*f7^2*f3*f4-96*x4*x2*x3*x6*f0*f6*f7^2*f3+48*x4*x1*x3*x5*f3*f5^
2*f6*f2+16*x4^2*x7*x3*f3^2*f7^2*f6+8*f7*x2*x8^2*x3*f3*f5*f6+28*x1^2*x2^2*f3*f5
^2*f4^2*f1-40*x1^2*x2*x4*f7^2*f3^2*f2^2+16*x2^2*x4*x6*f7*f3*f4*f2*f6-8*x1^3*x5
*f2*f3^2*f4^2-16*x1^2*x2^2*f1^2*f4^2*f7*f5+8*x1^3*x2*f1*f6*f5^2*f2^2+8*x3^4*f7
^2*f2*f4^3+64*x3^4*f0*f6^4*f4+64*x1^3*x5*f6^2*f0^2*f4+8*x1^2*x2^2*f7*f2*f3^3*
f4+98*x1^2*x4^2*f7*f5^2*f4^2*f1+36*x4^2*x1^2*f5^5*f1-32*x3*x4*x2*x6*f2^2*f6^2*
f7+32*x4^2*x5*x3*f4*f6^2*f1*f7+104*x4^2*x5*x3*f4^3*f7*f5+64*x4^2*x5*x3*f2*f7^3
*f1+128*x4^2*x5*x3*f3*f6*f1*f7^2-32*x4^2*x5*x3*f3^2*f5*f6*f7-4*x1^3*x2*f3^2*f5
*f4^2*f2+12*x2*x1^2*x5*f3^3*f4^2+16*x1^3*x7*f3^2*f5^2*f2-16*x3^2*x6^2*f2*f7*f3
*f6+88*x4^2*x3^2*f1*f5^3*f7^2+72*x4^4*f5^5*f7+32*x1^3*x3*f6^2*f5*f3*f1^2+32*x1
^2*x3*x7*f1^2*f6*f7*f5+72*x1^3*x6*f0*f5*f7*f3*f2-36*x1^3*x6*f1^2*f7*f3*f5-32*
x1^3*x6*f1*f6^2*f0*f4-8*x2^2*x1*x3*f5^4*f2^2-320*x4*x5*x1^2*f7*f0*f4*f3*f5-64*
x1^3*x4*f7^3*f0^2*f2+16*x1^3*x6*f0*f6*f4^2*f3-8*f7^2*x3*x8^2*x7*f4+8*f7*x3*x8^
2*x6*f4*f6-2*f7^2*x3^2*x8^2*f3*f5-64*x2*x5*f3*f6*f0*f7^2*x4^2-152*x2*x5*x4^2*
f0*f5*f7^2*f4-48*x4^2*x2*x5*f7*f3*f4^2*f5+16*x2*x5*f3^3*f7^2*x4^2-8*x2^2*x1^2*
f0*f5^2*f4^3-24*x2*x1*x5*x7*f1^2*f7*f6-36*x2*x1^2*x4*f4^2*f5^2*f3^2+8*x2*x1*x3
*x5*f7*f2*f1*f4*f5+8*x1^2*x3*x4*f7*f4^4*f2+4*x2^2*x1*x7*f4^5-32*x1*x6*x3*x7*f1
*f7^2*f2-8*x6*x3^2*x7*f4^3*f7-4*x5*x6*x7^2*f4*f5+4*x3^2*x2^2*f1*f5^5+72*x3*x2*
x4*x5*f5^2*f4^3+88*x4*x5*x2*x3*f1*f5*f7^2*f2-32*x3*x1^2*x7*f2*f6*f7*f1*f4-96*
x3*x1^2*x7*f0*f6^2*f5*f3+80*x3^2*x1^2*f1*f6^2*f4^2*f3-8*x4*x5*x1*x3*f3^2*f1*f7
^2-16*x3*x1^2*x5*f0*f5*f3^2*f7-32*x3*x2*x6*x7*f0*f7^2*f4-48*x1^2*x3*x6*f0*f7^2
*f3*f2+24*x2^3*x6*f7*f4^3*f1+8*x2^3*x6*f1^2*f7*f5*f6-32*x2^2*x4*x5*f0*f4*f3*f7
^2+16*x1*x6*x4*x7*f3*f6*f2*f7+8*x6*x2^2*x7*f7*f6*f2^2-24*x1^2*x6^2*f3*f1*f4*f6
-8*x3^2*x4*x7*f4^3*f7*f6+240*x3^2*x4*x7*f5*f4^2*f6^2+40*x3^2*x4*x7*f7^3*f3*f1-\
36*x4*x3*x5*x8*f7*f3*f5^2-64*x4*x3*x5*x8*f7*f5*f4^2-32*x3*x4*x5*x8*f7*f6^2*f1-\
16*x3*x4*x6*x8*f7*f4^2*f6+96*x4^2*x1*x8*f7^3*f3*f1+144*x4*x1^2*x7*f1*f7*f3*f6*
f4-208*x1*x4*x2*x7*f0*f5^3*f7+480*x4^2*x1^2*f3*f5*f6*f1*f4*f7-4*x3^3*x8*f7^2*
f2*f5*f4+4*x3^3*x8*f7^2*f3^2*f5-48*x4*x5*x3^2*f0*f7^3*f2-16*x4*x5*x3^2*f0*f6*
f7^2*f3+32*x3^2*x2*x7*f6*f5^3*f2+48*x3^2*x2*x7*f5*f4^3*f6+24*x2^2*x1*x3*f6*f2*
f5^3*f1-8*x1^3*x5*f1*f5*f2^2*f6+36*x3*x2*x6*x7*f3*f7^2*f1+64*x3^2*x2*x4*f0*f6^
3*f3*f7+32*x3*x1^2*x7*f1*f5*f0*f7^2-32*x3*x1*x6^2*f0*f5*f7*f4-32*x3*x1*x2*x8*
f7*f0*f6*f5*f4+8*x3*x1^2*x5*f2^2*f5^2*f4+4*x1^3*x3*f3^2*f5^2*f2*f4-24*x5^2*x3*
x7*f6*f1*f5+12*x5^2*x3*x7*f3*f5*f4-16*x5^2*x3*x7*f7*f0*f5+40*x3^2*x1^2*f3^2*f5
^2*f2*f6-16*x3*x2^2*x7*f7*f2*f4*f3*f6+56*x3*x2^2*x7*f4^2*f6*f1*f7+24*x3*x2^2*
x7*f1*f7^2*f2*f5+8*x3*x2^2*x7*f1*f7*f3*f5*f6+4*x3*x2*x5*x6*f7*f2*f3*f4+32*x3*
x1^2*x5*f0*f4^3*f6+16*x3^3*x1*f3*f5*f2^2*f7^2+16*x3^3*x1*f4^2*f6*f5^2*f2-16*x3
^3*x1*f6^2*f1*f5^2*f3-16*x3^3*x1*f1*f6^2*f4^2*f5+32*x3^3*x1*f0*f6*f3^2*f7^2-32
*x3^3*x1*f0*f6^2*f4*f3*f7+8*x3^3*x1*f4^2*f5^3*f3-32*x1*x3^3*f7*f2*f5*f4^3+8*x3
^3*x1*f2^2*f7^3*f1-4*x6^2*x1*x3*f3^3*f7+32*x1^2*x6^2*f0^2*f7^2+40*x6*x3^2*x7*
f4*f7*f3*f5-24*x3^2*x1*x5*f2*f4^2*f5^2-8*x3^2*x1*x5*f2*f4^3*f6-16*x3^2*x1*x5*
f2*f3*f4*f5*f6+4*x2*x1*x6*x7*f5*f4^2*f3-48*x2*x1*x6^2*f1*f6*f4^2-88*x1*x2*x4^2
*f7^2*f2*f5^2*f1+4*x2*x1^2*x5*f3*f5^2*f2^2-8*x1*x2*x4^2*f7^3*f2*f1*f3+4*x2^2*
x1^2*f5^4*f1^2-20*x1^2*x2*x3*f7*f2*f3*f1*f5^2-36*x1^2*x2^2*f7*f2*f3*f1*f4*f5+
304*x3*x2*x4*x6*f0*f6*f7*f5^2+72*x3*x2*x4*x6*f7*f3^2*f5^2-28*x3^2*x1^2*f3^2*f6
*f4^3+8*x2*x7^2*x8*f2*f7^2+8*x1*x7^2*x4*f7*f5^2*f2-64*x1*x7^2*x4*f0*f5*f7^2+4*
x5*x7^2*x6*f7*f2-4*x1*x7^2*x3*f4^2*f7*f3+32*x7^2*x2*x5*f7*f0*f6-144*x4*x3*x5^2
*f0*f5^2*f7+368*x3*x4*x5^2*f0*f6*f4*f7-24*x4*x3*x5^2*f1*f7*f3*f6-72*x4*x3*x5^2
*f6*f5^2*f1+16*x4*x2^2*x6*f0*f6*f2*f7^2+36*x4^2*x3^2*f5^6-12*x1^2*x3^2*f7*f2*
f5^2*f1*f4-56*x3^2*x4*x6*f7^2*f3*f1*f6-44*x1^2*x3*x6*f7*f4^2*f2^2-8*x2^3*x5*f0
*f4^3*f7-8*x2^3*x5*f7*f3*f4^2*f1+32*x2^3*x5*f5*f0^2*f7^2+24*x2^2*x3*x5*f0*f5^4
-32*x3^3*x2*f1*f6^3*f4^2+16*x3*x1^2*x6*f0*f4^3*f7-416*x4^2*x2*x3*f0*f5^3*f7^2+
96*x3^2*x2*x4*f6^2*f4*f5^2*f2-8*x2*x5*x6^2*f2*f4*f5+2*x3^2*x5^2*f3^3*f7-32*x2*
x5*x6^2*f7*f0*f4+4*x2^2*x5*x7*f4^4+16*x1^2*x3*x4*f7*f2^2*f5^2*f4+96*x1^2*x3*x4
*f5*f4^3*f6*f2+256*x3^2*x1*x4*f6*f0^2*f7^3+48*x3^2*x2*x4*f4^2*f5^4+80*x3^2*x4*
x1*f7^2*f2*f4*f1*f6-64*x3*x1*x4*x7*f4*f5^2*f2*f7-8*x3*x1*x2*x8*f7^2*f2^2*f4+16
*x3^2*x1*x6*f3*f5*f6^2*f1-32*x3^2*x1*x6*f4^2*f6^2*f1-48*x3*x1*x4*x6*f5^2*f4^3+
16*x1^2*x6*x7*f0*f5^3-8*x2*x6^2*x5*f1*f5^2+12*x1*x6^2*x8*f1*f5*f7+4*x1*x6^2*x7
*f4^3+16*x6^2*x3*x7*f7*f1*f6-32*x3^3*x1*f6^2*f2^2*f5^2-320*x3*x1*x4*x6*f0*f6*
f5*f4*f7+396*x3*x2*x4^2*f7^2*f4*f5^2*f1-68*x3*x2*x4^2*f7^2*f3^2*f5*f4+504*x3*
x2*x4^2*f5^3*f4^2*f6-160*x4*x5*x1*x3*f0*f6*f5*f7*f3+24*x3*x1^2*x6*f3^3*f6*f4-\
176*x3^2*x1*x4*f0*f6*f4*f3*f7^2-12*x3^2*x1*x4*f7^2*f3*f4^2*f2+40*x3^2*x1*x4*f7
^2*f4^3*f1+8*x1*x4^2*x5*f7*f3*f4^3+36*x4^2*x1*x6*f3*f5^4+16*x4*x1*x6*x7*f3*f7^
2*f1+64*x4^2*x1^2*f0*f6^3*f7*f1+64*x4*x1^2*x5*f0*f7*f5^2*f2+8*x2^2*x1*x5*f7*f1
^2*f6*f3-160*x2*x1*x4*x6*f7^3*f0^2+68*x1*x2*x3*x6*f7*f2*f5^2*f1+92*x1*x2*x3*x6
*f7*f3*f4*f1*f5+72*x2^2*x1^2*f0*f6*f5*f4^2*f3+64*x3*x1*x4*x6*f1^2*f6*f7^2-8*x3
^2*x2*x7*f7*f3^2*f6*f4-64*x3^2*x1*x7*f0*f6^2*f5^2+4*x1^3*x3*f7*f3^2*f2^2*f5+16
*x3^2*x2*x8*f7^2*f4*f5*f1+320*x3*x1*x4^2*f0^2*f7^4+32*x2^2*x1*x3*f1^2*f7^2*f6*
f2-24*x2*x1*x4*x6*f5*f4^4-128*x2*x1^2*x3*f0*f6*f5*f7*f2*f3-448*x3*x4*x1^2*f6*
f5*f7^2*f0^2+16*x1^3*x7*f1^2*f5^2*f6-8*x1^3*x7*f2*f5^3*f1+8*x2^3*x3*f3*f5*f6*
f7*f2^2-32*x2^3*x3*f0*f4^2*f3*f7^2+48*x2^3*x3*f0*f6*f4*f1*f7^2+128*x3*x1*x4^2*
f3*f5*f6^2*f7*f1-16*x3^2*x2*x8*f7*f3*f6^2*f2-8*x3*x2*x7^2*f4*f5^3-80*x3*x1^2*
x7*f0*f5*f4^2*f7+24*x3*x1^2*x7*f3^3*f6*f5+4*x3*x2^2*x5*f4^5-32*x4*x1*x6^2*f2*
f7^2*f1+12*x4*x1*x6^2*f3*f5^2*f4+20*x4*x1*x6^2*f7*f2*f4^2-64*x4*x1^2*x5*f0*f4^
3*f7+12*x1^2*x2*x3*f2*f7*f5*f1*f4^2+2*x1^4*f4^2*f3*f5*f2^2-20*x1*x6^2*x2*f4^2*
f2*f5+16*x3^2*x6^2*f5*f6^2*f1+4*x5^2*x6^2*f1*f5-12*x2^2*x4*x7*f5^3*f4^2+4*x1^3
*x3*f5^2*f7*f3*f1^2-16*x2^2*x5*x7*f0*f7^2*f2+16*x1^2*x5*x6*f0*f6*f5*f2+64*x1*
x5*x4*x6*f7*f6*f0*f3-16*x1*x5*x7^2*f7*f1*f4-4*x1^2*x5*x6*f4^3*f1-8*x1*x5*x3*x8
*f7*f2*f4^2+24*x1*x5*x3*x6*f4^2*f2*f5+8*x5^2*x4*x8*f7*f1*f6+8*x5^2*x8*f7*x4*f2
*f5+8*x4*x5*x6*x8*f7*f2*f6+6*x2^2*x3^2*f4^2*f5^3*f3-20*x1^2*x2*x3*f7*f2*f3^3*
f5-44*x1^2*x2*x3*f1*f4^3*f7*f3-20*x2^2*x3^2*f7^2*f3*f4^2*f1-32*x2^2*x3^2*f4^2*
f6^2*f1*f5-32*x1^3*x3*f0*f6*f3^3*f7+64*x2^2*x4^2*f0*f6^2*f4*f5*f7-24*x2^2*x1*
x4*f7^2*f3*f4*f2^2+20*x2^2*x1*x4*f7*f2*f4^4+192*x4^3*x2*f0*f7^4*f2-240*x4^3*x2
*f4^2*f5^3*f7-96*x4^3*x2*f6*f5^3*f7*f2-176*x4^3*x2*f0*f6*f5^2*f7^2+16*x3^3*x1*
f3*f6^2*f4*f2*f5+128*x1*x3^3*f5*f0^2*f7^3-16*x2^2*x1^2*f0*f6*f5*f2^2*f7+8*x2*
x1*x5^2*f4^2*f2*f3-8*x2*x1*x5^2*f2^2*f5*f4+12*x2*x1*x5^2*f2*f5^2*f1+32*x2^2*x1
^2*f5^3*f0^2*f7+64*x1^3*x2*f0*f3*f2^2*f7^2+48*x1^3*x4*f6*f5^3*f1^2-12*x6^2*x3*
x4*f4^3*f7+16*x3^3*x8*f7*f5^2*f6*f2+16*x3^3*x8*f7*f4^3*f6-64*x3^3*x8*f7^2*f0*
f5*f6+8*x1^2*x3*x6*f5^2*f4^2*f1+8*x2^3*x6*f0*f3^2*f7^2-4*x2^2*x6*x7*f3^2*f7*f4
-4*x2^2*x6*x7*f7*f2*f3*f5-12*x2^2*x6*x7*f2*f7^2*f1-48*x4*x1*x3*x6*f5^4*f2-32*
x4^2*x1^2*f7*f3^2*f6*f2*f5-8*x4*x1*x2*x6*f7*f3^2*f6*f2+32*x4^2*x7*x2*f1*f6^2*
f7*f5+144*x4*x1^2*x7*f3*f5^2*f6*f2-2*x1^2*x2^2*f1*f5^2*f7*f2^2+16*x1^3*x2*f0*
f5*f1^2*f7^2+16*x3^4*f6^2*f1*f5^3+16*x1^3*x7*f1^2*f7*f6*f3+48*x3*x2*x4*x8*f7*
f3*f5^3-56*x3*x1*x4*x7*f3*f5*f6*f2*f7+16*x3*x1*x4^2*f0*f5*f2*f7^3-600*x3*x1*x4
^2*f1*f7^2*f3*f6*f4+16*x1^3*x7*f1^2*f7^2*f2-64*x1^3*x7*f0^2*f7^2*f4-32*x1^3*x7
*f1^2*f4*f6^2-12*x1^3*x7*f7*f2*f3*f1*f5-40*x1*x3^3*f5^3*f7*f3*f1+32*x3^3*x1*f3
*f5^3*f6*f2+24*x3^3*x1*f3*f1^2*f7^3+16*x3^3*x1*f1*f5^5+36*x1^2*x2*x3*f7*f2*f3^
2*f4^2+20*x2^2*x4*x6*f7*f4^3*f3-8*x2^2*x4*x6*f7*f3*f5*f1*f6-188*x2^2*x4*x6*f4*
f5^2*f1*f7-24*x2^2*x4*x6*f5^4*f2+4*x2^2*x1*x4*f1^2*f5*f7^2*f4+160*x1*x2*x4^2*
f7^2*f0*f5*f4^2+192*x1*x2*x4^2*f7^2*f0*f6*f4*f3-8*x2^2*x1*x7*f5*f4^3*f3+12*x2*
x1*x3*x6*f3^2*f5^2*f4+112*x1*x2*x4^2*f7^3*f1^2*f4+10*x2^2*x1^2*f4^4*f3^2+2*x1^
2*x2^2*f5^2*f7*f3*f1^2+352*x3^2*x1*x4*f0*f6^2*f4^2*f7-16*x3^2*x1*x4*f3^3*f6*f7
*f5-264*x1*x4*x3^2*f1^2*f6*f7^2*f5+64*x1^3*x4*f7^2*f0^2*f3*f6+72*x1^3*x4*f7^2*
f2*f3^2*f1-32*x3^2*x2*x6*f2*f4^2*f6^2+48*x3^2*x2*x6*f3*f4^2*f6*f5-64*x3^2*x2*
x6*f4*f5^2*f6*f2-32*x3^2*x2*x6*f5^3*f6*f1-32*x1^3*x5*f1^2*f0*f7^2+116*x3^2*x4*
x5*f7*f3*f4^2*f5-80*x2*x6*x4*x7*f0*f5*f7^2-36*x1^3*x7*f1*f4*f7*f3^2+12*x1^2*x6
^2*f1^2*f7*f5-12*x5^2*x2*x7*f1*f5^2+8*x5^2*x3*x7*f5^2*f2-12*x1*x5*x3*x6*f5*f3^
2*f4+16*x2^2*x5*x6*f0*f5*f7*f3+12*x2*x5*x6*x7*f7*f2*f3+4*x1^4*f0*f4^5+16*x1^4*
f5^4*f0^2-2*x1^4*f4^4*f2^2-32*x5^2*x4*x7*f7*f1*f5+8*x5^2*x6*x7*f7*f0-32*x5^2*
x3*x8*f7*f0*f6-80*x5^2*x4*x8*f7^2*f0+8*x1^3*x7*f2^2*f5^2*f4+16*x1^3*x7*f1*f6*
f0*f7*f4-40*x1^2*x2*x7*f6*f1^2*f4*f7-80*x1^2*x2*x7*f0*f7^2*f3*f2-16*x1^3*x7*f4
^2*f6*f2^2+20*x1^3*x7*f1^2*f4*f7*f5+96*x3*x2*x4*x7*f7*f1*f6^2*f4+32*x3*x2^2*x5
*f6*f0^2*f7^2+2*f7*x5^2*x8^2*f3-4*f7*x5*x8^2*x7*f5-20*x3*x1*x4*x8*f7^2*f2*f3*
f5+16*x3*x1*x4*x8*f7*f4*f5*f6*f2-52*x3*x1*x4*x8*f7^2*f1*f4*f5+192*x3*x2*x4^2*
f7*f0*f6^2*f5^2+72*x3*x1*x4*x6*f3*f5*f4^2*f6+48*x3*x1*x4^2*f7^2*f2*f1*f5*f6-12
*x2^3*x4*f7^2*f3^2*f5*f1+16*x1^3*x6*f0*f5^3*f2-32*x2^2*x3*x5*f2*f0*f7^2*f4+8*
x1^3*x3*f3*f5^2*f4^2*f1+40*x1^2*x2*x6*f7*f2*f3*f1*f5+100*x2*x6*x3^2*f1*f5^2*f7
*f4-256*x2*x6*x3^2*f0*f6*f5*f7*f4+84*x4^2*x1*x6*f7*f3*f5*f4^2-36*x4^2*x1*x6*f5
^3*f4^2-12*x4*x1*x5*x7*f3^2*f4*f7+48*x4*x1*x5*x7*f0*f6*f7*f4+128*x4*x1*x5*x7*
f0*f7*f5^2-76*x4*x1*x5*x7*f1*f4*f7*f5-32*x4^2*x1^2*f0*f6^2*f4*f3*f7+96*x1^2*x5
*x7*f0^2*f7^2-12*x1^2*x5*x7*f3^3*f5-32*x3*x1^2*x5*f1*f6*f4^2*f3+8*x3*x1*x7^2*
f7*f2*f3*f6+24*x3*x1*x7^2*f4*f7*f1*f6-16*x3^3*x1*f1^2*f6^2*f7*f5+12*x3*x5*x6*
x7*f7*f2*f4+4*x3*x5^2*x7*f7*f1*f4-4*x3^2*x5^2*f7^2*f1^2-8*x3^2*x5^2*f0*f6*f7*
f3-16*x3*x5*x7*x8*f7*f3*f5+44*x1^2*x6*x7*f3*f7*f1*f4+4*x2*x6^2*x8*f7*f2*f5-12*
x2*x6*x7*x8*f7*f3*f5-16*x3*x6^2*x5*f6*f1*f5+4*x3*x6^2*x5*f4^3-32*x1^3*x2*f0*f4
^3*f2*f7-48*x1^3*x3*f0*f5^2*f7*f3*f2+48*x1^3*x3*f0*f4^3*f3*f7+48*x3*x1*x4*x5*
f0*f6*f5^3-32*x3*x1*x5*x6*f2^2*f6*f5-4*x3*x1^2*x6*f4^4*f3+64*x2^2*x3*x4*f7^2*
f3^2*f2*f5+32*x4*x3*x7*x8*f7^2*f2*f6-704*x4^2*x1^2*f0*f6*f5*f4^2*f7-24*x4*x3^2
*x5*f5*f4^3*f6-12*x4*x1*x5^2*f2*f5^2*f3-44*x4*x3*x6*x8*f7^2*f2*f5+80*x4*x3*x6*
x8*f7^3*f0-40*x3*x4*x6*x8*f7^2*f1*f6-52*x4*x3*x6*x8*f7^2*f3*f4-32*x2^3*x6*f6*
f0^2*f7^2-88*x1^2*x4^2*f7*f2^2*f5*f4*f6-20*x2*x1^2*x6*f4^3*f3^2-288*x3*x2*x1*
x4*f0*f6^2*f5^2*f4+32*x3*x1*x6*x7*f2*f5*f4*f6-92*x4^3*x5*f3^2*f5*f7^2+24*x4^2*
x1*x5*f2^2*f6*f7*f5+16*x3^3*x8*f7^2*f2*f3*f6+72*x3^2*x4*x8*f7^2*f2*f4*f6-108*
x4^3*x2*f5^6+384*x4*x5*x3^2*f0*f6*f5^2*f7-42*x4^2*x7^2*f4^2*f7^2+2*f7*x2^2*x8^
2*f3*f5^2-4*x1^4*f5^2*f2^3*f4-8*x1^2*x2*x6*f7*f2^2*f3*f4-40*x3*x2*x4^2*f7^2*f3
*f4^3+48*x3*x1*x6*x8*f7*f0*f5*f6-24*x3*x2*x7^2*f7*f2*f4*f6+128*x1^2*x3*x6*f0^2
*f7^2*f5+48*x1^2*x3*x6*f1*f7^2*f2^2+136*x1*x4*x3^2*f6*f4*f5*f7*f2*f3+80*x1*x4*
x3^2*f1*f7^2*f5^2*f2-32*x1*x4*x3^2*f5*f4^3*f7*f3-112*x1*x4*x3^2*f7*f2^2*f5^2*
f6-16*x7*x2*x3*x8*f7*f6^2*f1-60*x2*x4*x3^2*f4*f5^3*f7*f2-64*x3*x4*x6*x7*f6^2*
f7*f1+32*x4*x3*x6*x7*f7^2*f3^2+88*x4*x3*x6*x7*f7*f3*f5^2-240*x4*x3*x6*x7*f4*f5
^2*f6-4*f7^2*x2^2*x8^2*f2*f4-4*f7*x2^2*x8^2*f5*f4^2-48*x7^2*x1*x2*f0*f5^2*f7+
14*x1^2*x7^2*f7*f1*f4^2-8*x1^2*x7^2*f7*f2^2*f5-8*x2^2*x7^2*f4*f6*f1*f7-8*x2^2*
x7^2*f2^2*f7^2+4*x1^2*x7^2*f5^3*f1+6*x1^2*x7^2*f3^3*f7+4*x7^2*x6^2*f5^2-6*x2^4
*f7*f4^4*f1-8*x2^3*x4*f4^2*f6*f7*f2*f3-32*x4^2*x3^2*f7^3*f2^2*f5+80*x2*x4*x3^2
*f7^2*f2^2*f5^2+480*x3*x4^3*f7*f3*f5^3*f6+2032*x3*x4^3*f7^3*f0*f6*f4-144*x3*x4
^3*f7^2*f3*f4^2*f6-120*x3*x4^3*f7^3*f3*f1*f6-56*x3*x4^3*f7^2*f6*f5^2*f1+128*x3
*x4^3*f7^2*f3^2*f5*f6-8*f7^2*x4^2*x8^2*f5^2-12*f7^2*x4^2*x8^2*f4*f6-8*f7*x2*x8
^2*x7*f4*f6+52*x1^2*x2*x3*f5^3*f1*f4*f3-8*x1*x7*x6*x8*f7*f2*f5-8*x1*x7*x2*x8*
f7^2*f3*f1+48*x1^2*x7^2*f0*f6^2*f4+10*x1^2*x7^2*f4^2*f3*f5+168*x2^2*x1*x4*f5^2
*f4^2*f1*f6+44*x2^2*x1*x4*f7^2*f2^3*f5+160*x2^2*x1*x4*f4*f0^2*f7^3-72*x2^2*x1*
x4*f4*f5^4*f1-4*x3*x2^2*x8*f7^2*f2*f3*f4+144*x3*x1*x4*x6*f0*f5^3*f7+32*x3*x2^2
*x6*f0*f4*f3*f7^2+160*x2*x4*x3^2*f0*f5*f2*f7^3-36*x2*x4*x3^2*f7^2*f3*f4*f2*f5+
64*x2*x4*x3^2*f3*f5*f6^2*f1*f7-180*x2*x4*x3^2*f5^2*f4^2*f7*f3+48*x2*x4*x3^2*f0
*f5^2*f4*f7^2-8*x1*x7^2*x3*f4^3*f6-24*x7^2*x1*x2*f3^2*f7*f4-32*x4*x7^2*x2*f5^2
*f7*f3-32*x2*x1*x6^2*f0*f5^3-4*f7*x3^2*x8^2*f5^3-12*f7^3*x2*x8^2*x4*f1-8*x1^3*
x2*f3^2*f6*f1*f4^2+12*x2^2*x7^2*f4^3*f6+4*x2^3*x1*f7*f3^4*f4+32*x2^2*x4*x8*f7^
3*f2*f1-24*x2^2*x1*x4*f2*f7^3*f1^2+24*x4*x3*x5^2*f5^3*f2+36*x4^2*x1*x2*f4*f5^4
*f3-68*x4*x1*x6^2*f1*f4*f7*f5+128*x4*x1*x6^2*f0*f6*f7*f4-16*x4*x3^2*x7*f2^2*f7
^3-128*x1^3*x4*f0*f4^2*f1*f7^2-24*x3^2*x6^2*f4*f6*f3*f5-16*x1^3*x3*f0*f6*f4^2*
f1*f7+8*f7^2*x4*x8^2*x6*f4+24*f7*x4*x8^2*x6*f5*f6-16*f7^2*x4*x8^2*x7*f5-8*f7*
x3*x8^2*x5*f3*f6+8*x1^4*f7^2*f0*f2^3+128*x3^2*x1^2*f6^3*f0*f4*f2-28*x4*x5*x2^2
*f5*f7^2*f1^2-24*x4^2*x6^2*f4^2*f5*f7-8*x4^2*x6^2*f7*f6^2*f1-16*x1^2*x6^2*f0*
f5^2*f4-6*x6^2*x7^2*f7*f3+48*x4^2*x5*x3*f3*f6*f7*f4^2-120*x4*x1*x6^2*f2*f5*f4*
f6+72*x4*x1*x6^2*f7*f2*f5*f3-128*x4*x1^2*x7*f0*f4*f5^2*f7+72*x4*x1^2*x7*f7*f3^
3*f5+224*x4*x1^2*x7*f0*f5*f2*f7^2+8*x2^4*f0*f2*f1*f7^3-4*x2^4*f5*f4^2*f1*f3*f7
-4*x2^4*f7*f2*f4^3*f3-372*x1^2*x4^2*f7^2*f3^2*f1*f5+96*x1^2*x2*x4*f1*f7^2*f5*
f2^2+256*x1^2*x2*x4*f5^2*f0^2*f7^2+20*x3^2*x2*x5*f1^2*f5*f7^2+184*x3*x1*x4^2*
f7^2*f2^2*f4*f6+704*x3*x1*x4^2*f0*f6*f4^2*f7^2-92*x3*x1*x2*x4*f7*f3^2*f4^2*f5+
64*x3^2*x4*x7*f1*f7^2*f4*f6+8*x3^2*x5*x7*f2*f7*f3*f6+16*x5*x7*x3^2*f0*f5*f7*f6
+48*x3^2*x5*x7*f5*f6^2*f1-32*x1^3*x5*f6*f5^2*f0^2+32*x1^3*x5*f1*f6*f3*f4*f2-8*
x7^2*x2*x5*f7*f3^2-32*x3^2*x2*x4*f1*f7^3*f2*f4-8*x3^2*x2*x4*f1*f7^2*f3*f6*f4+
144*x3^3*x4*f1*f5^3*f7*f6+24*x3^3*x4*f7^2*f2*f5*f4^2+44*x1^3*x3*f1^2*f4^2*f7*
f5+64*x1*x4*x3^2*f0*f5*f4^2*f7^2+40*x1*x4*x3^2*f5^2*f7*f3^2*f4+136*x1*x4*x3^2*
f1*f5*f7*f4^2*f6+44*x1*x4*x3^2*f7^2*f3*f5*f1*f4+24*x3*x1^2*x6*f4^2*f6*f2*f3+32
*x3*x2^2*x7*f6^2*f2*f1*f7-16*x1^3*x5*f1*f6*f5*f0*f4-32*x1^3*x5*f0*f3^2*f6*f4+
24*x1^3*x5*f7*f5*f1^2*f2-8*x2^3*x1*f1*f4^3*f7*f3+24*x2^3*x1*f3*f5^2*f4^2*f2+
224*x4^2*x7^2*f7*f5*f4*f6+108*x4^2*x6^2*f4*f5^2*f6+80*x4^2*x6^2*f7^2*f5*f1+48*
x4^2*x6^2*f2*f7^2*f4+64*x4^2*x3^2*f6^2*f2*f7*f4*f5-48*x4^2*x3^2*f4^2*f7*f6^2*
f3-36*x4^2*x1^2*f4*f5^4*f2-36*x4^2*x1*x3*f3*f5^5+152*x4^2*x1*x6*f7*f2*f5^2*f4-\
264*x4^2*x1*x6*f4*f7*f6*f1*f5-24*x4*x1*x3*x7*f3*f5^4-8*x1*x7^2*x6*f6*f2*f5-4*
x5*x7*x2*x8*f7*f2*f5+8*x1^2*x7^2*f4^2*f6*f2+32*x3^3*x1*f1*f6^3*f5*f2-40*x3^3*
x1*f4*f6*f1^2*f7^2+16*x1^3*x4*f1^2*f4^2*f7*f6-32*x3^2*x1*x2*f6^2*f7*f1^2*f4-\
416*x3*x1*x4^2*f0*f6*f5^3*f7+96*x3*x1^2*x7*f3*f6^2*f1*f4-8*x3^2*x1*x2*f7*f3^4*
f6+36*x2*x1^2*x4*f3^3*f5^3-192*x2*x4^3*f0*f5*f7^3*f4+24*x2^2*x3*x6*f3*f4^3*f6-\
16*x2^2*x3*x6*f2*f5^3*f4+4*x2^2*x3*x6*f7*f3^3*f5+12*x1^3*x4*f5*f4^4*f2-4*f7^2*
x2*x8^2*x6*f2+2*f7^3*x3^2*x8^2*f1-4*f7^2*x2*x8^2*x3*f2*f5-4*f7^2*x2*x8^2*x3*f3
*f4+4*f7^2*x2*x8^2*x5*f1+20*x3^4*f1^2*f7^3*f5-96*x3^2*x4*x5*f6*f5^3*f2-224*x2^
2*x1*x4*f0*f5^2*f1*f7^2+48*x2^2*x1*x4*f6^2*f7*f1^2*f4+36*x1^2*x4^2*f7^2*f3^2*
f4*f2+32*x1^3*x6*f1^2*f4*f6*f5+32*x2*x1^2*x5*f0*f4^2*f7*f2-16*x2*x1^2*x5*f0*f5
*f4^3-8*x2*x1*x3*x8*f6*f7*f2^2*f5+48*x2*x1*x3*x7*f7*f1*f5^2*f3+32*x1^3*x7*f7*
f2^2*f3*f4+32*x3^2*x1*x2*f0*f6^2*f3^2*f7+16*x3*x2*x6^2*f2*f7^2*f1-288*x3*x1^2*
x4*f0*f6^2*f5^2*f3-12*x4*x1^2*x5*f2^2*f5^3+192*x4*x1^2*x5*f0*f6*f5*f4^2+24*x4*
x1^2*x5*f3^2*f5*f4^2+24*x4*x1*x3*x8*f7*f2*f5^3-96*x4*x1*x3*x6*f5^3*f6*f1-64*x1
^2*x2*x3*f7*f2*f3*f1*f4*f6-16*x1^2*x3^2*f5*f4^2*f2*f3*f6+8*x1^2*x3^2*f7^2*f2*
f3*f1*f4-24*x1^2*x2*x6*f4^2*f6*f2^2-28*x1^2*x2*x6*f7*f1*f4^2*f2-16*x3*x2*x6*x7
*f3*f7*f2*f6+48*x3*x2*x6*x7*f0*f7*f5*f6-80*x3*x2*x6*x7*f1*f7*f4*f6+104*x3*x2*
x6*x7*f7*f4*f2*f5+64*x3*x1^2*x5*f0*f6*f3*f2*f7+8*x1^3*x2*f7*f1*f2^2*f3*f6+144*
x3^2*x4*x5*f6^2*f5^2*f1-64*x1^3*x2*f5*f2*f0^2*f7^2-48*x1^3*x4*f0*f5^4*f3+16*x1
^3*x5*f0*f5^3*f1+12*x6^2*x4*x7*f1*f7^2-4*x3^2*x8*f7^2*f3^2*x6+16*x2^4*f0*f5^2*
f4*f3*f7-8*x2^4*f4*f6*f1^2*f7*f5+28*x3^2*x2*x6*f7*f3*f4^3-48*x3^2*x2*x6*f1*f0*
f7^3+320*x1^2*x4^2*f7^2*f0*f6*f4*f2+64*x1^2*x4^2*f7^2*f0*f6*f1*f5+38*x1^2*x4^2
*f7^3*f1*f2^2+24*x3*x1^2*x7*f4^3*f3*f5-96*x3*x1*x2*x5*f5*f0^2*f7^2+16*x3*x2^2*
x4*f0*f3^2*f7^3+12*x3*x1^2*x6*f3^3*f5^2-8*x3*x1^2*x6*f5^3*f2^2-16*x3^2*x2*x5*
f1^2*f7*f6^2+32*x3^2*x7*f4*f6^2*f2*f7*x4-80*x4*x1^2*x6*f0*f5*f1*f7^2-24*x4*x1^
2*x6*f0*f3^2*f7^2+48*x4*x2*x5*x6*f5^3*f2-296*x1^2*x4^2*f7^2*f2*f5*f1*f4+4*x3^2
*x5^2*f5*f1*f7*f3+48*x2*x5*x3*x8*f7*f0*f5*f6-4*x4*x5^2*x2*f2^2*f7*f5-4*x2*x5^2
*x4*f3^3*f7-24*x1*x5*x6*x8*f7*f0*f5+32*x3*x5*x6*x7*f6*f2*f5+48*x2*x7*x3^2*f0*
f7^3*f2+24*x2*x7*f2^2*f7^2*x3^2*f5-44*x2*x7*x3^2*f5^2*f7*f3^2+36*x2*x7*x3^2*f1
*f7*f5^3+72*x2*x7*x3^2*f4*f6*f1*f5*f7-16*x2*x7*x3^2*f0*f6*f5^2*f7-12*x2^2*x1*
x4*f3*f5^4*f2-112*x2^2*x1*x4*f0*f5^3*f3*f7+16*x3^3*x2*f3*f6^2*f4*f1*f7+24*x2*
x1^2*x6*f3^3*f4*f5+32*x2^2*x1^2*f6^2*f0^2*f7*f3+20*x2^2*x1^2*f5*f7^2*f1^3-8*x2
*x1*x3^2*f7*f4^4*f2-12*x2*x1*x6*x7*f3^2*f5^2+12*x4^2*x3^2*f7^3*f3^3+128*x4^2*
x6^2*f0*f6*f7^2-100*x1^2*x3*x4*f1*f4*f7^2*f3^2+40*x2^2*x3^2*f4^3*f6*f7*f1+216*
x3^2*x4^2*f3*f5^3*f6^2-60*x1^2*x3*x4*f1^2*f4*f7^2*f5-8*x2^3*x3*f7^2*f2*f5*f1*
f3-8*x2^3*x3*f7*f2^2*f5^2*f4-8*x2^3*x3*f0*f5*f3^2*f7^2+4*x1^3*x2*f3*f4^4*f2-4*
x1^3*x2*f4^5*f1+4*x2^3*x1*f1*f5^4*f2-40*x2^2*x1*x7*f2*f6*f4^3+12*x2^2*x3*x8*f7
*f5^2*f2*f4-4*x2^2*x6*x8*f7*f3^2*f5-48*x1^3*x4*f6*f2^2*f5*f4^2+108*x2^2*x4^2*
f5^2*f4^3*f6+8*x1^2*x2*x6*f1^2*f4*f7*f5-4*x2^4*f1*f5*f7^2*f2^2+4*x2^2*x1*x4*f7
*f3^2*f5^2*f2+8*x1^2*x2*x6*f1*f4*f7*f3^2-24*x4*x1*x6^2*f7*f3^2*f4-12*x4*x1^2*
x7*f7*f3^2*f4^2+112*x4^2*x1^2*f0*f6*f3^2*f7^2-144*x4^2*x1^2*f1*f6*f5^3*f4+8*x2
^3*x5*f1*f7^2*f2^2-160*x4^2*x3*x6*f5*f6^2*f1*f7-184*x4^2*x3*x6*f7^2*f2*f4*f5-\
304*x4^2*x3*x6*f0*f4*f7^3-104*x4^2*x3*x6*f7^3*f3*f1+84*x4^2*x3*x6*f7^2*f5*f3^2
+4*x1^3*x2*f4^3*f3^3+4*x1^3*x2*f5^2*f2*f3^3+32*x2*x6*x7^2*f7*f3*f4-20*x3*x6^2*
x1*f1*f4^2*f7+4*x2^3*x1*f3*f2^3*f7^2+2*x2^4*f3*f5^2*f7*f2^2+64*x1^2*x2*x7*f0*
f6*f7*f4*f2-8*x1^2*x2*x7*f1*f6*f7*f3*f2+64*x1^2*x2*x7*f0*f5*f3*f7*f4+12*x6^2*
x3^2*f2*f7*f5*f4-16*x2^3*x3*f1*f6*f7^2*f2^2-36*x1^3*x4*f3*f5^2*f2*f4^2+24*x1^3
*x4*f5^3*f2^2*f4-8*x2*x7*x6*x8*f7*f2*f6+8*x1*x7*x3*x8*f7*f5^2*f2-8*x1^3*x5*f1^
2*f4*f7*f3+16*x1^3*x5*f0*f5*f4^2*f3+128*x4^2*x3*x6*f7*f5^3*f3+8*x4^2*x3*x6*f7*
f5^2*f4^2-360*x4^2*x3*x6*f6*f5^3*f4-212*x4^2*x3*x6*f7^2*f5^2*f1+48*x2^2*x3^2*
f0*f6*f5^2*f3*f7+12*x2^2*x4*x5*f7*f3^2*f4^2+272*x4^2*x3*x7*f7*f5^3*f4+432*x4^2
*x3*x7*f5^2*f6^2*f4+176*x4^2*x3*x7*f7*f4^2*f6*f5+16*x3^2*x6^2*f3*f7^2*f1-20*x3
^2*x5*x8*f7*f3*f5*f4-8*x3^2*x5*x8*f7^2*f1*f4+8*x6*x8*f7*x3^2*f3*f5^2-16*x6*x8*
f7*x3^2*f5*f4^2-2*x2^2*x7^2*f5^2*f4^2+32*x3^2*x4*x8*f7^3*f1*f4+72*x4*x8*f7^2*
x3^2*f4*f5*f3-96*x4*x8*f7^3*x3^2*f0*f5-24*x3^2*x4*x5*f2*f7*f4^2*f6+16*x4*x5*x3
^2*f4*f6*f7*f3^2+24*x3*x5*x4*x6*f1*f7^2*f3-4*x3*x6*x1*x5*f7*f2*f5*f1-48*x3^2*
x1*x4*f6^2*f2*f3*f5^2-128*x1*x4*x3^2*f0*f6*f4*f5^2*f7-12*x3^2*x5*x6*f4^3*f5-4*
x2^2*x5*x7*f7*f2*f3*f4+8*x2^2*x5*x7*f7*f5*f1*f3+40*x1^2*x2*x4*f4^3*f7*f2*f3-\
184*x3*x4^3*f7^2*f5*f4^3+320*x3*x4^3*f7^2*f2*f4*f5*f6-64*x3*x4^3*f7^4*f2*f1+2*
x2^4*f7*f3^3*f4^2-4*x5^3*x6*f1*f4-8*x5^2*x4*x6*f7*f2*f3-8*x5^2*x1*x6*f2*f3*f4+
48*x1^3*x3*f0*f3^2*f7^2*f2+24*x1^2*x3^2*f2^3*f7^2*f4+12*x1^3*x3*f1*f5^2*f7*f2^
2+8*x1^4*f5^2*f3^2*f2^2-44*x2^2*x3*x7*f7*f4^3*f3-48*x3^2*x1*x4*f6^2*f2*f5*f4^2
+16*x3^2*x1*x4*f0*f3^2*f7^3+24*x2*x1*x4^2*f7*f2^2*f5^2*f6+144*x2*x1*x4^2*f7*f2
*f5^3*f3-32*x2*x1*x3*x6*f2*f5^3*f3+16*x3^2*x2*x6*f7*f3*f4*f2*f6+16*x3^2*x2*x6*
f6^2*f4*f5*f1-8*x2^2*x6^2*f0*f6*f7*f3+8*x2^2*x6^2*f1*f6*f7*f2-16*x1*x6^2*x3*f4
*f5^2*f2+8*x2*x5*x6*x8*f7*f2*f4+8*x2*x5*x6*x8*f1*f5*f7-16*x1*x5*x3*x6*f4*f1*f5
^2+8*x1^2*x5*x7*f4^2*f3^2+4*x1*x5^2*x8*f7*f3*f1-4*x2^2*x5*x8*f7*f3^2*f4+16*x3^
2*x7*x8*f7^3*f0+12*x2^2*x3*x7*f7^2*f3^2*f2-16*x2^2*x3*x7*f7*f2*f5^2*f3+12*x2*
x1*x3*x7*f3^2*f5^3-32*x2*x1*x4*x8*f7*f1*f5^3-64*x2*x1^2*x4*f6^2*f0^2*f7*f5-128
*x3*x4*x1*x2*f0*f6*f5^2*f7*f3-148*x4*x5*x3^2*f5^2*f7*f2*f4-16*x4*x5*x3^2*f3*f5
*f2*f6*f7+40*x4*x5*x3^2*f3*f7^2*f2*f4-144*x4*x5*x3^2*f0*f5*f7^2*f4+32*x3^2*x1*
x5*f0*f5^4-48*x1^2*x2*x3*f0*f4*f7^2*f3*f2+84*x2^2*x1*x4*f5^3*f4^2*f2+64*x1^2*
x2*x3*f0*f6*f7^2*f1*f2+12*x1^2*x2*x3*f3*f7*f4*f2^2*f5-16*x1^3*x7*f0*f5^3*f3+32
*x1^3*x7*f1*f6*f4^2*f3+112*x3*x4*x1^2*f0*f6*f4*f7^2*f1+4*x5^2*x7*x8*f7*f2-4*x5
*x8*f7*x2*x4*f5^2*f2-16*x3*x5*x2*x6*f4*f6*f1*f5+32*x3*x5*x2*x6*f2*f4^2*f6-8*x3
^2*x5*x8*f7*f4^3+32*x1*x5*x6*x7*f7*f0*f4+24*x1*x5*x6*x7*f1*f4*f6+4*x1^2*x2^2*
f7*f3^3*f1*f5-8*x3*x2*x5^2*f7*f2*f1*f5-16*x3^2*x1*x6*f7*f2^2*f4*f6-8*x3*x1^2*
x6*f1^2*f7^2*f3+60*x3*x1*x6*x7*f7*f2*f4^2+8*x3*x1*x7^2*f7^2*f2^2-20*x1^2*x2^2*
f7*f3^2*f2^2*f5-28*x1^2*x2*x5*f7*f3*f1^2*f5-24*x2^2*x3^2*f5*f4^3*f3*f6-14*x1^2
*x2^2*f7*f3^2*f1*f4^2-12*x1^2*x2*x5*f7*f5*f1*f2^2-24*x1^2*x3^2*f5^3*f7*f1^2-32
*x1^3*x2*f0*f6*f3^2*f2*f7-22*x2^2*x3^2*f5^2*f4^2*f1*f7-28*x2^2*x3^2*f1^2*f6*f7
^2*f4-56*x4^2*x6*x7*f0*f7^3-216*x4^2*x5*x7*f4*f5^2*f6-40*x4^2*x1*x7*f7^3*f2*f1
-36*x4*x2*x7^2*f5^4+192*x4^2*x1^2*f0*f5^2*f2*f7^2+44*x4*x2*x5^2*f1^2*f7^2-4*x2
^2*x4*x8*f7*f5^3*f2-16*x4^2*x1*x2*f7*f2*f4^3*f6+4*x4*x1^2*x5*f3^4*f7+20*x1^3*
x2*f7*f2*f3^2*f1*f5-4*x1^3*x2*f5^3*f2^3+96*x4*x3*x5*x6*f0*f4*f7^2-40*x4*x2*x5*
x8*f7^2*f1*f4+176*x5*x8*f7^2*x2*x4*f0*f5+16*x4*x2*x5*x8*f7^2*f2*f3-8*x4*x2*x6*
x8*f7*f5*f4^2-24*x5*x8*f7*x2*x4*f3*f5*f4+100*x4*x2*x6^2*f7*f5^2*f1-92*x4*x2*x6
^2*f7*f2*f4*f5+28*x4*x2*x6^2*f3*f7^2*f1-240*x4*x1^2*x7*f0*f6*f4^2*f7+24*x4*x3^
2*x7*f5^5+16*x3^3*x8*f7^2*f1*f4*f6-16*x3^3*x8*f7*f3^2*f6^2+12*x3^2*x1*x7*f5^2*
f4^3-16*x6^2*x1*x3*f0*f7^2*f2-16*x2^3*x6*f0*f5^2*f3*f7-160*x1^2*x3^2*f5^2*f0^2
*f7^2+12*x2*x1*x6*x7*f7*f2^2*f5+32*x2*x1^2*x6*f0*f5^2*f4^2+48*x2*x1^2*x5*f0*f5
^2*f3*f4-64*x2^2*x1*x6*f6^2*f0^2*f7+40*x3^2*x6^2*f5^2*f4^2-40*x1^2*x2*x3*f5^2*
f2*f1*f4*f6+16*x3^2*x1*x5*f1*f5^3*f4+64*x3^2*x2*x5*f0^2*f7^3-16*x1^3*x5*f1*f4*
f7*f2^2+52*x1*x2*x3*x6*f4^3*f7*f1-32*x1*x2*x3*x6*f7*f2^2*f5*f4+16*x2*x1*x3*x8*
f6^2*f7*f2*f1+8*x1^3*x2*f7*f4^2*f2^3-32*x1^3*x7*f0*f4^3*f6+16*x2^4*f4*f6*f0^2*
f7^2-4*x2^4*f0*f4*f3^2*f7^2+176*x2^2*x3*x4*f0*f5*f4^2*f7^2+112*x2^2*x3*x4*f0*
f5*f7^3*f1+4*x3^4*f7^2*f2^2*f5^2-32*x1^2*x3*x6*f0*f6*f1*f7*f5+140*x1^2*x2*x4*
f5^3*f7*f1^2-16*x1^3*x3*f0*f5^2*f1*f7*f4-4*x1^2*x3^2*f5^2*f4^3*f2-32*x1^2*x2*
x3*f0*f5^2*f2*f7*f4+24*x1^3*x2*f1^2*f4^3*f7+12*x1^2*x3^2*f3*f5^3*f2*f4+4*x6^2*
f7*f3^2*x3^2*f5+64*x4*x5*x1^2*f0*f4*f7^2*f1+4*x2^2*x3*x7*f7^2*f3*f4*f1-64*x2^2
*x3*x7*f7*f4^2*f5*f2+64*x3*x4^2*x1*f0*f6^2*f7^2*f2-16*x4^2*x2*x7*f6^2*f2*f4*f7
-16*x3*x4^2*x1*f7*f4^3*f3*f6+16*x4*x2*x3*x6*f7^2*f3^3+32*x4*x2^2*x8*f7*f2*f4*
f5*f6-48*x3^2*x5*x7*f6*f3*f4*f5+48*x2^2*x5*x7*f0*f5*f7*f4-12*x1^2*x5*x6*f4*f3^
3+4*x2*x5*x7^2*f7*f2*f4-4*x2*x5*x7^2*f7*f1*f5+4*x1*x5^2*x3*f4^3*f2-8*x2*x5*x3*
x6*f3^3*f7-16*x2*x5*x3*x6*f0*f7^2*f2-96*x3*x1^2*x4*f0*f6^2*f5*f4^2-24*x3*x1*x7
*x8*f7*f6*f1*f5+80*x3*x1*x2*x6*f0*f5*f7^2*f1+4*x3*x2^2*x5*f7^2*f2^3+192*x3*x4^
3*f6^3*f7*f1*f5-24*x2^2*x1*x4*f5^2*f4^3*f3+8*x2*x1^2*x3*f4^3*f3^2*f5-8*x2*x1*
x3*x4*f3*f7^2*f1*f4^2-24*x2*x1^2*x4*f7*f4^2*f3^3+8*x2*x1*x5*x8*f7*f2^2*f5-4*x2
^2*x1^2*f7^2*f2^4-68*x2^2*x4*x7*f7^2*f2^2*f5+176*x2^2*x4*x7*f0*f5*f4*f7^2+64*
x3*x2*x4*x7*f7*f0*f6^2*f5-16*x3*x1*x2*x5*f0*f4^3*f7-8*x3^2*x2*x8*f7^3*f2*f1+16
*x3^2*x2*x8*f7^2*f2^2*f6-96*x3*x1*x2*x6*f6*f0^2*f7^2-20*x2^3*x3*f7*f2*f4^4+6*
x1^2*x6^2*f1*f7*f3^2-72*x4*x6*x7^2*f6*f5^2+12*x4*x6*x7^2*f2*f7^2+320*x3*x1^2*
x4*f0*f4^2*f3*f7^2-48*x3*x2*x1*x4*f3*f5^3*f6*f2+16*x3*x1*x4*x7*f0*f5*f4*f7^2-\
20*x3*x1^2*x5*f3^2*f2*f5^2-16*x3*x2*x1*x6*f0*f6*f5*f2*f7-32*x3^2*x1^2*f0*f5^4*
f4-16*x2^2*x4*x6*f7^2*f2^2*f4+4*x2^2*x4*x6*f7*f2*f5^2*f3-24*x2*x1*x5*x7*f2*f5*
f4^2+96*x2*x1^2*x3*f0*f6^2*f4^2*f3-48*x2^3*x1*f0*f6*f2*f4^2*f7-32*x2^3*x1*f0*
f5^3*f4^2+48*x2^3*x1*f0*f5^2*f4*f7*f2+8*x2^3*x1*f5^2*f7*f2^3-24*x3^3*x4*f7^2*
f3*f4*f2*f6+16*x3^3*x4*f6^2*f2*f3*f5*f7+24*x3^3*x4*f7^2*f3^3*f6+368*x3^3*x4*f0
*f6*f5*f7^2*f4-8*x3^3*x4*f1*f4^2*f7^2*f6-32*x3^2*x5*x7*f0*f4*f7^2-20*x5*x7*x3^
2*f2*f7*f5*f4+16*x2^2*x4*x5*f0*f6*f5*f3*f7-32*x4^2*x5*x1*f1*f6^2*f7*f2-40*x4*
x1*x5*x6*f1*f5*f7*f3-8*x4*x2^2*x5*f7^2*f3*f2^2+112*x4*x1*x2*x6*f0*f6*f1*f7^2+6
*x5^2*x7^2*f3*f5-16*x1^3*x7*f0*f7^2*f2^2-10*x2^2*x1^2*f5^2*f4^2*f2^2-96*x2*x1*
x3*x4*f4^2*f5^2*f2*f6+24*x2*x1*x3*x4*f6*f5^3*f1*f4+24*x4*x5*x1*x2*f0*f3^2*f7^2
-64*x1*x2*x4*x5*f0*f6*f4*f3*f7-40*x2^2*x1^2*f0*f4^3*f3*f7-4*x1^2*x3^2*f4^2*f5^
3*f1-4*x2^2*x6*x8*f7*f1*f5^2-8*x1*x5*x7^2*f7*f2*f3-8*x2*x5*x6^2*f7*f3*f1+8*x1*
x5*x6*x7*f7*f3*f1-16*x3^2*x5*x6*f7*f3^2*f4-4*x1*x5^2*x8*f7*f2^2-8*x1*x5*x3*x8*
f7^2*f2*f1-32*x1*x5*x4*x7*f3*f7*f1*f6-8*x2^3*x3*f3*f6*f4^4+4*x3^3*x6*f3^3*f7^2
-208*x1*x2*x4^2*f7^3*f1*f5*f0-8*x2^2*x1^2*f3^2*f5^3*f1-16*x2*x1^2*x6*f1^2*f5^2
*f6+8*x2*x1^2*x6*f7*f2^3*f5-4*x1^4*f1*f5^2*f3^3+36*x1^2*x3^2*f5^4*f3*f1-120*x3
^2*x4*x6*f5^2*f4^2*f6-256*x3^2*x4*x6*f0*f6*f7^2*f4+32*x2^2*x4^2*f1^2*f7^3*f5+
32*x2^3*x1*f7*f0*f3*f5*f4^2+8*x2^3*x1*f7*f2^3*f4*f6-8*x6^3*x2*f4^3-32*x3*x2*x4
*x8*f7^2*f2*f3*f6-72*x4^3*x1*f5^2*f4^3*f7+168*x4^3*x1*f7^2*f3^2*f4*f5-4*x3^3*
x6*f7*f4^4+160*x4^3*x3*f7^3*f2*f5*f3-648*x4^3*x3*f7^2*f5^2*f3*f4+260*x4^3*x1*
f7^3*f2^2*f4+24*x3*x4*x1^2*f6*f5*f7*f2^2*f3+16*x1^3*x3*f5^4*f1^2-8*x4*x2^2*x5*
f1*f7*f3*f6*f4-32*x4*x1^2*x7*f7*f2^2*f5^2-12*x1*x6*x3*x7*f7*f3^2*f4+10*x1^2*x6
^2*f3*f7*f2^2-8*x2*x6^2*x4*f2*f6*f7*f3-16*x1*x6*x7^2*f7*f1*f5+24*x1*x6*x7^2*f7
*f2*f4+128*x3*x1^2*x5*f4*f0^2*f7^2+32*x3^2*x1*x2*f4*f5^4*f1-24*x3^2*x1*x2*f3*
f6*f4^4-24*x3*x2*x5*x7*f3*f5^2*f4-12*x2^2*x3*x8*f7^3*f1^2-24*x1^2*x3^2*f5*f7^2
*f3*f1^2+32*x1^2*x3^2*f7*f2^2*f5*f4^2-8*x1^3*x2*f0*f5^3*f3^2+32*x2^3*x1*f0*f6*
f1*f7^2*f2-8*x2^3*x1*f6*f7^2*f1^3-36*x1^2*x3^2*f4^3*f7*f2*f3+128*x4*x5*x1*x2*
f0*f5*f7^2*f1-112*x2*x1*x4*x7*f1*f0*f7^3-80*x2*x1^2*x5*f0*f6*f5*f4*f2+144*x4^2
*x1*x3*f6*f2*f5^4-96*x4*x3*x5*x7*f4^2*f6*f5-128*x4*x3*x5*x7*f0*f5*f7^2-64*x4^2
*x5*x2*f0*f6^2*f7*f4-64*x3^4*f0*f6^3*f5^2-108*x4*x5*x1^2*f7*f5^2*f1^2-32*x2*x1
*x3^2*f7^2*f3^2*f1*f4-48*x2*x1^2*x3*f0*f5^4*f3-56*x2*x1*x4*x7*f7^2*f2^2*f4+16*
x2*x1^2*x5*f7*f1^2*f2*f6-64*x3*x1*x5*x6*f0*f5^3-16*x3*x1*x5*x6*f3*f5*f1*f6-12*
x3*x1*x5*x6*f3*f4^3-144*x4*x5*x2*x3*f6*f7^2*f1^2+16*x3*x2*x4*x5*f7*f3^3*f6+16*
x3^2*x1^2*f3^2*f6^2*f4*f2+48*x3*x1^2*x5*f3*f0*f5^3+16*x3*x2*x5*x6*f1*f5*f7*f3-\
24*x3*x1*x2*x7*f7*f3^2*f4^2+24*x3^2*x1^2*f6*f7^2*f2*f1^2-64*x3^2*x1^2*f0*f6^2*
f3*f2*f7+8*x1^3*x3*f7*f2*f3*f1*f4*f5+16*x2^3*x3*f0*f6*f3*f2*f7^2-64*x1^3*x3*f0
*f5*f4^2*f7*f2+52*x1^3*x4*f1^2*f4*f7*f5^2+4*x1^3*x3*f3^3*f5*f4^2-12*x3^2*x1*x6
*f5*f4^4-20*x4*x5*x1^2*f5*f2^2*f7*f3+16*x3*x4*x1*x2*f6^2*f2^2*f7*f3-16*x3*x4*
x1*x2*f0*f6*f3^2*f7^2-32*x3*x4*x1*x2*f7*f3^3*f6*f4+32*x2*x1*x3*x6*f2^2*f5^2*f6
-32*x2*x1*x3^2*f0*f6*f3*f2*f7^2+8*x2*x1^2*x5*f1^2*f5*f4*f6+44*x1*x2*x3*x6*f7*
f2*f3^2*f5-304*x1^2*x4^2*f7*f3*f5^2*f2*f4+40*x4*x5*x1^2*f7*f3*f1*f4^2-328*x1^2
*x4^2*f7^3*f0*f3*f2-8*x4*x6^2*x7*f7*f4^2+60*x2^2*x4*x8*f7^2*f1*f4*f5-64*x2^2*
x4*x8*f7^2*f0*f5^2-48*x4^2*x6^2*f7*f2*f5*f6-108*x4^2*x1*x6*f7*f3^2*f5^2+56*x4^
2*x1*x6*f1*f7^2*f4^2-32*x4^2*x1*x6*f5^3*f7*f1+16*x4^2*x1*x6*f1*f6*f7^2*f2+32*
x1*x5*x2*x6*f0*f5*f2*f7-8*x3*x5*x6*x7*f7*f3^2-16*x3*x5*x6*x7*f5*f4^2-12*x1*x5*
x6*x7*f4^2*f3-8*x1*x5^2*x7*f1*f4*f5+12*x1*x5*x6*x7*f3^2*f5+2*x3^2*x5^2*f7*f4^2
*f1-20*x1^2*x4*x5*f7*f3^2*f4*f2+20*x1^2*x3*x5*f4*f3*f5^2*f1-4*x1^2*x3*x5*f4^2*
f3*f5*f2+4*x1^3*x3*f5^2*f2^2*f4^2+12*x1^2*x3^2*f7^2*f3^3*f1-32*x3^2*x1^2*f6^2*
f3^2*f1*f5-16*x3*x1*x7^2*f6^2*f1*f5-48*x1^2*x3*x4*f1*f7^2*f2^2*f6+104*x1^2*x3*
x4*f1^2*f7^3*f2+32*x1*x4*x3^2*f0*f6*f5*f2*f7^2+4*x3^2*x1*x4*f4*f7^2*f3^3-2*x2^
4*f3*f4^4*f5-16*x2^3*x4*f7*f4^3*f1*f6+16*x2^3*x4*f0*f6*f4*f2*f7^2+12*x2^3*x1*
f5^2*f4^3*f1+16*x2^3*x1*f6*f4^2*f7*f1^2+304*x4*x5*x2*x3*f0*f5^3*f7-96*x3*x2*x4
*x5*f2*f5^2*f4*f6+16*x4*x5*x2*x3*f4*f5*f7*f3^2-4*x3*x1^2*x7*f4^5-24*x2^3*x4*f3
*f5^2*f7*f2*f4+64*x2^3*x4*f0*f6*f5*f4^2*f7+36*x2^3*x4*f7^2*f3*f4^2*f1-44*x2^2*
x4*x8*f7^2*f2*f3*f5-8*x2*x1*x3*x6*f4^5-80*x1^2*x4*x7*f7^2*f1*f2*f4+432*x3*x1*
x4^2*f0*f6*f5*f3*f7^2+4*x7^4*f7*f5+4*x1^3*x5*f3^2*f4*f1*f5-16*x2^3*x1*f0*f4^4*
f7-32*x2^2*x1*x4*f0*f6^2*f4*f7*f2+128*x2^2*x1*x4*f4*f5^2*f1*f3*f7+4*x2^2*x1*x3
*f4^6-56*x4^3*x1*f7^2*f2*f5*f4^2+64*x3*x1*x4*x7*f3*f6^2*f1*f7+24*x3*x1*x5^2*f2
*f1*f5*f6-8*x3*x2^2*x6*f1*f5^4-8*x3*x1*x5^2*f2^2*f5^2+32*x2^3*x3*f0*f6^2*f5*f1
*f7+16*x2^3*x3*f5^3*f4^2*f2+48*x4^2*x6*x7*f7^2*f3*f4-76*x4^2*x6*x7*f7*f4*f5^2-\
12*x4^2*x6*x7*f7^2*f2*f5-104*x4^2*x6*x7*f1*f7^2*f6-216*x4^2*x6*x7*f5^3*f6-80*
x1^2*x2*x3*f0*f5*f7^2*f3*f1+180*x4^4*f7^3*f5^2*f1+168*x4^4*f7^3*f5*f3^2-240*x4
^3*x1*f1^2*f7^3*f6+120*x1^2*x4*x6*f7*f1*f4*f3*f5+4*x2^2*x1*x7*f7*f4*f3^3-288*
x3^3*x4*f1*f5*f7*f6^2*f4+128*x3^3*x4*f0*f5*f7^3*f3-52*x3^3*x4*f4*f5^2*f1*f7^2-\
8*x2^3*x3*f0*f5^5-16*x4*x2*x3*x8*f7*f5*f6^2*f1+96*x4*x3*x7^2*f7^3*f0+64*x3*x4*
x7^2*f7^2*f1*f6+16*x4*x2*x6^2*f2^2*f7^2+128*x2*x5*x4^2*f7^2*f2*f1*f6+24*x2*x5*
x4^2*f5*f7^2*f2^2+24*x4^2*x2*x5*f7*f3^2*f5^2+224*x4^2*x2*x5*f0*f6*f5^2*f7-72*
x4^2*x2*x5*f7*f3*f5*f2*f6-96*x4^2*x2*x5*f4*f5^2*f2*f7-8*x1^2*x2*x4*f7^2*f2*f3*
f1*f4+20*x2^2*x7^2*f1*f7^2*f3-16*x1^2*x6*x7*f0*f6*f5*f4+8*x5*x6*x7*x8*f7*f3-4*
x5*x6^2*x8*f7*f2-32*x1^2*x3*x7*f4^2*f6*f1*f5+36*x2*x3^3*f7^2*f2^2*f4*f5+32*x3^
3*x2*f0*f5^4*f7-32*x2*x3^3*f1*f6^2*f7*f2*f5+64*x3*x2*x5*x7*f0*f6*f7*f4-96*x3^2
*x4*x2*f1*f6^3*f7*f2+96*x3*x1*x4*x6*f2*f5^2*f4*f6+48*x3^2*x1*x5*f3*f6^2*f4*f1-\
96*x3^2*x1*x5*f0*f6^2*f4^2-64*x3^2*x1*x5*f6*f0^2*f7^2+28*x3^2*x1*x5*f4*f1^2*f7
^2+64*x2^2*x3^2*f0*f4*f1*f7^3+64*x2^2*x3^2*f5^2*f4^2*f6*f2+68*x2^2*x1*x7*f7*f3
*f4*f1*f5-80*x2^2*x1*x7*f1*f5*f0*f7^2+32*x1^3*x3*f0*f6*f2^2*f7*f5-32*x1^3*x3*
f6*f2*f5^2*f3*f1-32*x1^3*x3*f7^2*f3*f0*f4*f1+8*x1^3*x3*f1*f4*f7*f2^2*f6-16*x1^
2*x2*x5*f7*f2^3*f4+8*x3^4*f1*f7^2*f3*f6*f4+24*x3^4*f0*f6*f4^2*f7^2-32*x3^4*f0*
f6^3*f3*f7+4*x3^4*f7^2*f3*f4*f2*f5-24*x3^4*f5*f4^2*f1*f7^2+16*x3^4*f3*f5*f6^2*
f1*f7-320*x2*x4*x3^2*f0*f6*f5^3*f7+80*x3*x2*x5*x6*f0*f7*f4*f5-96*x3*x2*x5*x6*
f0*f6*f5^2+20*x3*x2*x5*x6*f7*f1*f4^2+36*x3*x2*x4*x7*f7^2*f2*f5*f3+268*x3*x2*x4
*x7*f7^2*f1*f4*f5+16*x3*x2*x4*x7*f7*f3*f4^2*f6+64*x3*x2*x4*x7*f7^2*f0*f5^2-56*
x3*x2*x4*x7*f7^2*f1*f3*f6+296*x4^2*x3^2*f1*f7^3*f3*f5-32*x1^3*x3*f0*f6^2*f5*f3
*f2-48*x1^3*x3*f0*f6*f5*f4^2*f3+24*x2^3*x4*f4*f5^4*f2-16*x3^2*x4^2*f5*f4^3*f7*
f6+4*x2^2*x3*x7*f7*f3^2*f4*f5+64*x2^2*x3*x7*f4*f5^2*f1*f7+32*x2^2*x3*x7*f2*f5^
2*f4*f6+64*x4*x2*x5*x6*f4*f5*f7*f1+16*x4^2*x2*x6*f6^2*f4*f1*f7+64*x4*x2*x5*x6*
f0*f6*f7*f4+28*x4*x2*x5*x6*f7*f2*f3*f5-24*x4*x1*x6*x8*f7*f5^2*f2+24*x4*x2*x7^2
*f1*f7^2*f5+4*f7^2*x3*x8^2*x5*f2-4*f7*x3*x8^2*x5*f4*f5+28*x2^2*x1*x7*f5^2*f4^2
*f2-16*x2^2*x1*x7*f0*f6*f4*f3*f7+8*x2^2*x6*x8*f7^2*f3*f1-48*x2*x1*x6*x7*f3*f7*
f5*f1-4*x2^2*x1*x6*f3^4*f7-8*x2^2*x1^2*f6^2*f7*f1^3-100*x1*x2*x4^2*f7^2*f2^2*
f5*f4-48*x2*x1*x4*x7*f5^3*f1*f6+40*x2^2*x3*x4*f1*f7^2*f3*f5*f4-16*x2^2*x1*x3*
f5*f4^2*f7*f2^2-28*x1^2*x3*x7*f1*f4*f7*f3*f5-16*x5^2*x3^2*f0*f5*f7*f4-48*x3^2*
x5^2*f4*f6*f1*f5-16*x2^3*x1*f3*f5*f7*f2^2*f4-12*x2^3*x1*f5*f4^3*f3^2-64*x2^3*
x1*f5*f0^2*f7^2*f4+128*x3*x4*x1*x2*f0*f4*f6^2*f3*f7-12*x2*x1^2*x7*f4^2*f3^2*f5
+24*x2*x1*x3*x4*f4^4*f5^2+8*x2^2*x1^2*f0*f6*f4^4+32*x3^3*x7*f4^3*f6^2+128*x1^3
*x2*f0*f4*f2*f1*f7^2-32*x1^3*x7*f0*f5*f2*f7*f4+4*x1^3*x6*f7*f3^3*f1-16*x2*x7*
x3^2*f0*f6*f7^2*f3+48*x3^2*x2*x7*f3*f5^2*f6*f4+64*x2^2*x7^2*f0*f7^2*f4-64*x1^3
*x2*f0*f6*f4*f3*f1*f7+96*x4*x5*x2*x3*f1*f6^2*f7*f2+8*x4*x5*x2*x3*f4^3*f7*f3-40
*x3^2*x1^2*f4^2*f6*f2*f7*f1+48*x2*x1^2*x4*f0*f5^4*f4+12*x2*x1^2*x4*f4^4*f3*f5-\
8*x2^2*x1*x8*f7^2*f1*f4*f2+12*x1^2*x6^2*f4*f6*f2^2+4*x1^4*f1*f5^3*f2^2-8*x1^3*
x2*f7*f3^2*f2^2*f4-16*x1^3*x2*f0*f5^4*f1+12*x3^4*f3^2*f5^3*f7+36*x2^2*x4*x7*f5
^4*f3+80*x3*x4*x2^2*f0*f6*f4*f3*f7^2+24*x2^3*x4*f1*f5^2*f7*f6*f2+16*x1^3*x2*f6
*f4*f7*f1^2*f2-32*x2*x7*x3^2*f0*f5*f7^2*f4+8*x2*x7*x3^2*f3*f7^2*f2*f4-52*x2*x7
*x3^2*f5^2*f7*f2*f4+16*x2*x7*x3^2*f3*f6^2*f1*f7-32*x2*x7*x3^2*f0*f6^2*f7*f4+12
*x2^3*x1*f4*f7^2*f3*f1^2+32*x2^3*x1*f0*f4*f3*f7^2*f2-16*x2^3*x1*f6*f7*f2^2*f1*
f5-8*x2^3*x1*f5^3*f2^2*f4-8*x2^3*x1*f3*f5^3*f4*f1-16*x2^3*x5*f0*f6*f5*f1*f7-12
*x7^2*x5*x8*f7*f4-4*x7^2*x3*x8*f3*f7^2+12*x7^2*x2*x8*f7*f4*f5-64*x1^3*x3*f1*f6
^2*f4*f3*f2+24*x1^2*x3^2*f4^4*f6*f2-48*x1^2*x2*x6*f0*f7^2*f3*f1+64*x1^3*x2*f6*
f4^2*f0^2*f7+8*x1^3*x2*f7*f2*f3^4-32*x2^2*x4^2*f5*f4^4*f7-8*x1^3*x5*f4*f6*f2^3
-48*x4*x5*x2*x3*f0*f7^3*f1+48*x4*x5*x2*x3*f1*f4*f7^2*f3-96*x3*x1*x4*x7*f6^2*f2
*f5*f4+40*x3*x1*x4*x7*f7^2*f2^2*f5-96*x3*x1*x4*x7*f5^2*f6^2*f1-256*x4*x5*x2*x3
*f0*f6*f5*f7*f4+12*x4*x2^2*x5*f5*f4^4-48*x4*x1*x3*x7*f5*f4^3*f6-72*x4*x1^2*x7*
f3^2*f5*f4*f6-24*x4*x1*x5*x7*f2*f5^3-36*x1^2*x4*x7*f7^2*f1^2*f5-8*x2^3*x3*f7*
f3^2*f2*f4*f6+12*x1^2*x2*x6*f5*f4^2*f2*f3-68*x1^2*x2*x6*f1*f4*f3*f5^2-20*x1^2*
x2*x4*f7*f4^4*f1+12*x1^3*x2*f3*f5^2*f4*f2^2+16*x1^3*x2*f4*f5^3*f1^2-48*x2^3*x4
*f0*f5*f4*f3*f7^2+24*x2^2*x3*x4*f5^5*f2-32*x2^3*x3*f6*f5*f0^2*f7^2+64*x3^2*x2*
x4*f6^2*f2^2*f7*f5+16*x4*x5*x2*x3*f3*f5*f1*f6*f7-8*x4*x8*f7^2*x3^2*f1*f5*f6-\
128*x1^2*x2*x4*f5*f6*f7*f4*f1^2-6*x2^2*x7^2*f7*f5^2*f1-64*x4*x1^2*x6*f7*f6^2*
f0*f1+80*x4*x1*x3*x5*f0*f4*f3*f7^2-32*x4*x3*x6*x7*f1*f7^2*f5+16*x1*x4^2*x5*f7*
f2*f4*f3*f6-32*x1^3*x3*f6*f5*f7*f1^2*f2-240*x1^2*x2*x4*f0*f5^2*f6*f1*f7-16*x2*
x5*x3^2*f0*f6*f5*f7*f3+20*x2*x1*x3*x7*f1^2*f7^2*f5-16*x2*x1*x3*x7*f7*f4^2*f5*
f1-20*x2*x1*x3*x4*f7^2*f3^2*f5*f1+28*x2*x1*x5*x7*f7*f2^2*f4+48*x4*x3*x6^2*f4^2
*f6*f5-32*x3*x4*x6^2*f7*f3^2*f6+40*x3*x4*x6^2*f2*f7*f4*f6+40*x3*x4*x6^2*f7*f5*
f1*f6-44*x4*x3*x6^2*f7*f5*f3*f4-64*x2^2*x5*x4*f0*f5*f7^2*f2-32*x3^2*x2*x6*f0*
f4^2*f7^2+112*x3*x6*f4^2*f7^2*f3*x4^2+16*x7^2*x1*x2*f0*f7^2*f3-48*x2^2*x1*x3*
f0*f4^2*f2*f7^2-24*x4^2*x3^2*f7*f3*f5^2*f6*f4-8*x3^2*x5*x8*f7^2*f2*f3+12*x2*x8
*f7*x3^2*f4^3*f5-8*f7^2*x2*x8^2*x3*f1*f6+112*x4^2*x5*x1*f7*f0*f5^3-128*x3*x4^2
*x6*f0*f6^3*f7-48*x4*x1^2*x6*f5*f4^2*f1*f6-24*x4*x2*x6*x7*f5^3*f4-108*x4^2*x1^
2*f3^2*f6*f5^2*f4+8*x4^2*x1^2*f3^3*f6*f7*f4+48*x4^2*x3*x5*f2^2*f7^2*f6+12*x5*
x4*x6*x8*f7*f3*f5-16*x2*x5*x3*x8*f7*f2*f4*f5+8*x1*x5*x6^2*f7*f2*f1+32*x2*x6*x1
*x7*f7^2*f0*f2-4*x1*x6^2*x8*f7*f2*f4+16*x2^2*x1*x4*f0*f2^2*f7^3+36*x2*x1*x7^2*
f7*f3*f5*f2+8*x2^2*x1*x8*f5*f7*f2*f1*f6+64*x1*x2*x3^2*f0*f5^2*f4^2*f7-16*x2*x1
*x3^2*f5^3*f6*f3*f1+4*x3^2*x6^2*f4^3*f6+32*x2*x1^2*x4*f7^3*f1^3-16*x3*x2*x1*x5
*f0*f7*f5^2*f2-112*x4*x5*x2*x3*f4^2*f7*f2*f5-96*x3*x1*x2*x5*f0*f6*f4*f2*f7+44*
x3*x2*x6^2*f4^3*f5+16*x3*x1^2*x6*f0*f5^2*f2*f7+32*x3*x1^2*x4*f0*f5*f3^2*f7^2-8
*x3*x2^2*x4*f7^3*f2^3+48*x2^2*x1*x6*f4^3*f1*f6-48*x4*x5*x2^2*f0*f6*f7^2*f1-64*
x2^2*x1*x3*f0*f6*f4^2*f3*f7-24*x2^2*x1*x3*f7^3*f1^3-112*x1^2*x3*x4*f0*f7^3*f3*
f1-4*x3^3*x2*f7*f4^5-4*x1^3*x6*f3*f4^3*f2-360*x4^2*x3^2*f1*f7^2*f6*f4*f5-100*
x4^2*x3^2*f7^3*f3*f4*f2-144*x4^2*x3^2*f1*f6^2*f7^2*f3-16*x3^2*x1*x5*f2*f3*f5^3
-4*x3^2*x1*x5*f2*f7*f3*f4^2+18*x2^2*x3^2*f3*f5*f7^2*f2^2+16*x2^2*x3^2*f7^2*f3^
2*f2*f4-64*x4^2*x2^2*f0*f6*f5^3*f7+16*x4*x1*x3*x7*f0*f7^3*f2+8*x4*x3*x2*x6*f1^
2*f7^3+12*x4*x2*x5^2*f7*f2*f3*f4+8*x3*x1^2*x6*f3*f4*f1*f5*f6-16*x3*x1^2*x6*f4^
2*f3^2*f5+64*x3*x1*x2*x5*f0*f5*f4*f3*f7-8*x3^2*x1^2*f6^2*f2^2*f5*f3-12*x4*x5^2
*x7*f5*f4^2-8*x3^2*x5*x6*f1*f7^2*f2+16*x3^2*x5*x6*f0*f7^2*f3-32*x1^3*x7*f1*f6^
2*f0*f5+32*x1^3*x7*f1*f5^2*f0*f7-12*x3^2*x5*x6*f3*f4*f5^2-96*x3^2*x5*x6*f0*f6^
2*f5+32*x3^2*x5*x6*f6*f5^2*f1+64*x3^2*x5*x6*f2*f4*f5*f6+48*x2^3*x4*f0*f6*f5*f1
*f7^2-48*x4*x2^2*x8*f7^2*f0*f6*f4-12*x2^2*x5*x8*f7^2*f2*f1+8*x2^2*x5*x8*f7*f2*
f3*f5+4*x1^3*x3*f4^5*f2-4*x1*x7^2*x5*f5^2*f2+8*x2^2*x7*x8*f7*f2*f4*f6+40*x1^2*
x7^2*f7^2*f0*f2+4*x1*x7^2*x6*f3*f5^2-4*x1*x7^2*x6*f5*f4^2+40*x2*x1*x3*x4*f5*f4
^3*f7*f2+4*x2^3*x7*f2^2*f7^2*f3+20*x2^2*x1*x7*f7*f2*f1*f5^2-32*x2^2*x1*x7*f0*
f4*f7^2*f2+56*x2^2*x1*x7*f5*f4^2*f1*f6-48*x2^2*x1*x7*f0*f5^2*f3*f7-24*x2^2*x1*
x7*f1*f5^3*f4-48*x2^2*x1*x7*f0*f6*f5^2*f4-96*x1^3*x4*f0*f5^2*f2*f7*f4+64*x3^3*
x7*f0*f6*f7^2*f4+12*x2^3*x6*f7*f3*f4^2*f2+48*x2^3*x4*f0*f5^2*f2*f7^2-96*x2^3*
x4*f0*f5^3*f4*f7+8*x2^3*x4*f7*f3^2*f4^2*f5-32*x2^3*x4*f0*f6*f5^2*f3*f7+92*x2^3
*x4*f5^2*f4^2*f1*f7-4*x2^3*x1*f3^2*f4^2*f7*f2-16*x3^4*f0^2*f7^4-8*x3*x2*x1*x5*
f7*f6*f2^3-120*x3*x1^2*x4*f3^2*f6*f4^2*f5-16*x3*x1*x4^2*f7^2*f3^2*f2*f6+80*x2*
x1*x4*x6*f7*f0*f5^2*f4-16*x2*x1*x3^2*f5*f4^3*f6*f2-8*x2^2*x6*x8*f7*f2*f4*f5-2*
x1^2*x7^2*f4^4+16*x2^2*x1*x4*f0*f6*f5^2*f7*f2-8*x1^3*x3*f7*f2^3*f3*f6+48*x1^2*
x2*x6*f1^2*f7^2*f2+64*x1^2*x3*x6*f2*f6*f5^2*f1-144*x4*x1^2*x6*f3*f5^2*f6*f1-32
*x4*x2*x6*x8*f7*f6*f2*f5-56*x4*x2*x6*x8*f7^2*f1*f5+144*x4*x1^2*x6*f6*f4*f5*f2*
f3+32*x4*x2*x3*x7*f0*f7^3*f3-4*x4*x2*x6^2*f7*f3^2*f5+72*x4*x1^2*x5*f1^2*f6*f7*
f4+48*x4*x1^2*x6*f0*f5^4+32*x4*x1*x2*x6*f0*f6^2*f7*f2+4*x1^3*x6*f2^2*f5*f4^2-\
104*x2^2*x1*x4*f5*f4^3*f7*f1+12*x2^2*x3*x7*f5^2*f4^3+8*x2^2*x3*x7*f5^4*f2+24*
x3^2*x1*x6*f3^2*f5*f6*f4+16*x3^2*x2*x8*f7*f5^2*f3*f4+48*x3*x2*x4*x8*f7*f4*f5*
f6*f3-16*x3*x1*x6*x7*f5*f4^3+12*x1*x6^2*x4*f4^3*f5-8*x3^2*x6^2*f4*f6*f1*f7+16*
x6^2*x2*x3*f7*f6*f2^2+4*x3^3*x5*f7^2*f2*f3^2-8*x2^3*x6*f5^2*f4^2*f2+16*x2^3*x6
*f0*f6*f4*f3*f7-16*x2^3*x6*f7*f2*f4*f1*f6-48*x2^3*x6*f0*f5*f4^2*f7-8*x3*x2*x6*
x8*f7*f3*f5*f4+72*x1^2*x2*x6*f6*f2*f5*f1*f4+8*x3*x2*x5*x7*f7*f6*f3*f1-64*x3*x2
*x6*x7*f5^2*f7*f1+4*x3*x1*x2*x5*f3^4*f7+144*x3*x1^2*x4*f0*f5^2*f1*f7^2-8*x3^2*
x2^2*f7*f3^3*f6*f4+16*x1*x3^3*f6*f4*f5*f7*f2^2+72*x1*x3^3*f1*f7^2*f2*f4*f5+8*
x1*x3^3*f7*f3^2*f4^2*f5+28*x3^3*x2*f5^3*f4^3+32*x2^2*x1^2*f3^2*f0*f7*f4*f5-4*
x2*x1*x3*x7*f7*f2*f3*f5*f4+20*x2*x1*x3*x7*f2^2*f3*f7^2+96*x3^3*x4*f5*f4^3*f6^2
-32*x3^3*x4*f1*f6^3*f7*f3-100*x3^3*x4*f7^2*f3^2*f4*f5+168*x3^3*x4*f7^2*f6*f5*
f3*f1-32*x1^2*x2*x6*f0*f7^2*f2^2+4*x1^2*x2*x6*f5*f4^3*f1-104*x2^2*x4^2*f7^2*f2
^2*f5^2+4*x2^3*x8*f7^2*f2*f1*f5+4*x2^3*x8*f7*f4^2*f5*f2+4*x2^3*x8*f7*f3^2*f5*
f4+64*x1*x2*x4^2*f7^2*f0*f6^2*f1-4*x2^2*x1*x8*f5^2*f7*f2^2+32*x2*x1*x3*x4*f0*
f3*f2*f7^3-48*x2*x1*x3*x4*f5^5*f1-48*x2^2*x1^2*f0*f5^3*f3*f4+24*x1^2*x4*x5*f5^
2*f4^2*f1+12*x3*x5*x4^2*f7^2*f2*f4^2+32*x2^2*x1*x3*f0*f6^2*f2*f7*f3-32*x2*x1*
x3*x7*f1*f7^2*f3^2+8*x4*x5*x1*x2*f4*f7^2*f1^2-24*x1*x2*x3*x6*f0*f5*f4^2*f7+160
*x1^3*x4*f0*f7^3*f1^2-82*x4^2*x7^2*f7^2*f5*f3+16*x4^2*x7^2*f7^2*f6*f2-8*x3^2*
x2*x8*f7*f3^2*f6*f5-4*x2^2*x1*x3*f1^2*f5^3*f7+12*x2^2*x1*x3*f7^2*f3^2*f2^2-12*
x2^2*x1*x3*f5^2*f4^2*f3^2+72*x4^2*x1^2*f6*f2*f5^2*f4^2-36*x4^2*x1*x5*f2*f5^4-\
16*x4^2*x1*x7*f7^2*f2^2*f6+48*x4^2*x8*f7^2*x3*f3*f6*f4-24*x1^2*x4*x5*f5*f4^3*
f2-48*x3*x1*x4*x5*f7*f2^2*f4*f6+28*x3*x2*x7^2*f7^2*f1*f4+36*x3*x2^2*x6*f7*f2*
f4^3-224*x3*x1*x4*x7*f0*f6*f5^2*f7-56*x3*x1*x4*x7*f1^2*f7^3-8*x3*x2*x5*x7*f2*
f7^2*f1+80*x2^2*x3^2*f0*f5^3*f4*f7-8*x2^2*x3^2*f7*f3^2*f4^2*f5-16*x5*x4^2*x6*
f4*f6*f2*f7+4*x1*x5^2*x6*f3*f1*f5-4*x2^2*x5*x8*f7*f4^2*f2+32*x3^2*x5*x6*f0*f6*
f7*f4+8*x3^2*x5*x6*f2*f7*f4^2-4*x1^3*x4*f4^3*f7*f2^2-8*x1^4*f2*f5*f3^3*f4-4*x4
*x5*x2^2*f4^2*f1*f5*f7+16*x1^3*x7*f0*f4^2*f5^2+68*x4*x5*x1^2*f7*f2*f5*f4*f1+4*
x2*x1^2*x5*f4^4*f1-48*x3^2*x1*x5*f6^2*f2*f1*f5+32*x3^2*x1*x5*f1*f5*f4^2*f6+16*
x3^2*x1*x5*f1*f5^2*f3*f6-256*x1^3*x4*f6^2*f0^2*f7*f4+448*x3^3*x4*f0*f6^3*f7*f4
-4*x3^2*x2*x5*f4^3*f7*f2+96*x3^2*x2*x5*f0*f6*f5^3-128*x1*x2*x3*x6*f0*f5^2*f3*
f7+64*x2*x1*x3*x6*f0*f5^4+32*x2^2*x1^2*f0^2*f7^3*f1-32*x2*x1*x3^2*f4*f6^2*f2^2
*f5+16*x2*x1*x3*x6*f3*f5^2*f1*f6+32*x2*x1*x3^2*f6^2*f2*f4^2*f3-4*x2^3*x8*f7*f2
*f5^2*f3+4*x2^3*x8*f7*f4*f5^2*f1-4*x2^3*x8*f7^2*f3*f4*f1-8*x1^3*x3*f7*f2^3*f5*
f4-28*x1^2*x3*x4*f7^2*f2*f3^3+4*x2^3*x7*f5*f4^4-12*x1^2*x2*x6*f7*f2*f3^3-40*x1
^2*x3*x6*f1*f6*f7*f3*f2-32*x3^3*x7*f6^3*f1*f5-8*x3^3*x7*f2*f7^3*f1+40*x3^3*x7*
f1*f5^2*f6*f7+16*x3^3*x7*f4*f5^4+432*x4^2*x1^2*f0*f6^2*f5^2*f4+92*x4*x6*x3^2*
f4*f5^2*f7*f3+8*x3^4*f4^4*f6^2+8*x3^3*x8*f7^2*f1*f5^2+40*x3^3*x8*f7*f3*f4*f5*
f6+12*x2^3*x3*f4^2*f2*f7^2*f1-16*x2^3*x3*f6^2*f7*f1^2*f4+8*x2^3*x3*f7^3*f2*f1^
2+12*x2^3*x3*f5*f4^5+288*x4*x1^2*x7*f0*f6^2*f5*f4+64*x4*x1^2*x7*f1*f6*f0*f7^2-\
32*x4^2*x1^2*f6^2*f7*f1^2*f5+24*x4*x1^2*x6*f1*f5^3*f4-12*x4*x1^2*x6*f4^3*f3*f5
+4*x1*x7^2*x3*f5^2*f4^2-4*x1*x7^2*x3*f3*f5^3+16*x3*x2^2*x6*f1^2*f6^2*f7-8*x3^2
*x1*x8*f7^3*f1^2-32*x3*x1^2*x4*f0*f6*f5^2*f7*f2+64*x3^2*x1^2*f6^2*f5*f0^2*f7-\
288*x3*x2*x4*x6*f0*f7^2*f4*f5-256*x3*x2*x4^2*f5^2*f4^3*f7+32*x3^2*x2*x5*f0*f6*
f4^2*f7-16*x3^2*x2*x5*f1*f7*f3*f5^2+4*x3*x2^2*x5*f7*f3^3*f4-48*x3*x2*x5*x6*f7*
f2*f1*f6-4*x1^2*x3*x6*f7*f3*f5*f2^2-52*x2^2*x1*x7*f7*f2^2*f4*f5-8*x6^3*x7*f4*
f5+4*x6^2*x1*x7*f3*f5*f4+12*x6^2*x4*x8*f7*f4*f5-8*x6^2*x2*x8*f0*f7^2-24*x5*x6*
x4*x7*f4*f5^2+20*x1^2*x3*x6*f7*f2*f5*f1*f4+80*x1^2*x3*x6*f0*f6*f7*f4*f2+24*x2^
2*x1*x7*f0*f5*f4^2*f7-20*x2^2*x1*x7*f7*f4^3*f1+12*x2^2*x1*x7*f1^2*f7^2*f4-20*
x1^2*x3*x6*f7*f3^2*f4*f2-8*x2^2*x4*x7*f7*f4^4-32*x3^2*x1*x4*f0*f5^2*f3*f7^2+8*
x4*x5*x1*x3*f7^2*f2*f4*f1+88*x3*x1*x4*x6*f7*f2^2*f6*f5-20*x3*x2*x6*x7*f7^2*f2^
2-16*x3*x2*x5*x7*f2*f5^3-8*x3*x2*x5*x7*f3^2*f4*f7+44*x1^2*x3*x6*f7*f1*f4^2*f3-\
144*x2*x1^2*x4*f0*f6*f4^2*f5^2+88*x2*x1*x4*x7*f7^2*f1^2*f6+20*x2*x1*x3*x5*f7*
f2^2*f4^2+12*x2*x1*x3*x5*f1*f7^2*f2^2-30*x2^2*x4^2*f7^3*f3^2*f1-32*x1^3*x6*f0*
f5*f3^2*f6+16*x1^3*x6*f0*f5^2*f3*f4-48*x1^3*x6*f0*f7^2*f1*f2-4*x5^2*x6*x8*f7*
f1+24*x4*x6^2*x7*f5^3-8*x3*x6^3*f3*f5^2+8*x3*x6^3*f3*f6*f4-48*x1^3*x4*f3*f5^2*
f2^2*f6+32*x1^3*x4*f7*f2^2*f3^2*f6-8*x1^3*x4*f4*f7*f3^4+12*x1^2*x2*x5*f7*f3^2*
f2^2-8*x1^2*x2*x5*f7*f3^3*f1-80*x4^2*x3*x6*f2*f7^2*f3*f6+280*x4^2*x3*x6*f1*f7^
2*f4*f6+192*x4^2*x3*x6*f0*f6*f5*f7^2-40*x3^3*x6*f4^2*f5^3-8*x1^3*x7*f3^2*f6*f4
*f2-24*x1^2*x4*x7*f7*f4*f6*f2^2-8*x1^2*x4*x7*f7*f1*f6*f2*f5+16*x2*x5*x6*x7*f5^
2*f2-12*x2*x5*x7^2*f3*f5^2+8*x1^2*x5^2*f0*f4^3+32*x1^2*x5^2*f5*f0^2*f7+6*x1^2*
x5^2*f7*f2^2*f1-8*x1^2*x5^2*f3^2*f5*f1-12*x1*x5*x3*x6*f4*f7*f3*f1+28*x3*x5*x6*
x7*f7*f1*f5-16*x1*x5*x4*x6*f7*f3^3+4*x1^2*x5^2*f3^2*f2*f4-8*x1^2*x5^2*f1*f4*f0
*f7-12*x1^2*x7^2*f3^2*f6*f4-16*x2*x1*x3*x7*f2^2*f5^2*f7-64*x2*x1^2*x6*f4*f0^2*
f7^2-8*x2*x1*x5*x6*f1*f4^2*f5-48*x2*x1^2*x7*f3*f6*f2*f4^2-4*x3^4*f5^2*f4^3*f6-\
8*x3^2*x1*x8*f7*f3*f5*f6*f2+8*x3^2*x1*x8*f7*f1*f5^3+8*x3^2*x1*x8*f7^2*f5*f1*f3
-96*x3^3*x2*f0*f6^2*f5^3-20*x2*x3^3*f7^2*f3*f5*f1*f4+64*x3^3*x2*f0*f6^2*f1*f7^
2+48*x3^3*x7*f3*f5*f4*f6^2-2*x3^4*f3^3*f7^2*f5-16*x1^3*x5*f0*f5*f7*f2^2-8*x1*
x5^2*x3*f7*f2*f1*f4+16*x2*x5^2*x4*f0*f6*f7*f3+8*x1*x5*x2*x7*f0*f7*f4^2+2*x2^2*
x5^2*f3*f7*f2^2-4*x1*x5*x7*x8*f7*f2*f4+360*x3^2*x4^2*f6^2*f5^2*f4^2-224*x4*x6*
x3^2*f7*f4*f6*f2*f5+64*x4*x6*x3^2*f0*f6^2*f5*f7+36*x4*x6*x3^2*f3*f5*f2*f7^2-\
168*x4*x6*x3^2*f1*f5^2*f6*f7+12*x3*x2*x7^2*f7^2*f2*f3+72*x3*x1^2*x4*f3^3*f5^2*
f6+64*x3*x1^2*x4*f7*f3^3*f5*f4+48*x3*x1^2*x7*f0*f5^2*f3*f7-128*x3*x1^2*x7*f6*
f0^2*f7^2-32*x3*x2^2*x7*f1^2*f7^2*f6-192*x2*x1*x3*x6*f0*f6^2*f4^2+48*x4*x2*x5*
x7*f4^2*f5^2-56*x4*x2*x5*x7*f1*f7*f4*f6-112*x4*x1^2*x6*f0*f6*f4*f3*f7+96*x4*x1
^2*x6*f6*f0^2*f7^2+16*x3*x4^2*x1*f4^2*f6^2*f7*f1+64*x4^2*x3^2*f0*f6^3*f5*f7-44
*x2^2*x3*x4*f1^2*f7^3*f4+32*x1^4*f3*f5^2*f7*f0^2-32*x1^4*f4*f2*f7^2*f0^2-16*x1
^4*f0*f4^3*f5*f3-4*x2^3*x7*f3*f5*f7*f2*f4-64*x3^3*x2*f6^2*f1*f5^2*f4-16*x3^3*
x2*f3*f6*f2^2*f7^2-4*x2^2*x4*x7*f1^2*f7^3+64*x2^2*x1*x3*f3*f6*f4^2*f2*f5+36*x2
^2*x4*x5*f5^4*f1-8*x1^3*x2*f7^2*f1*f2^3-80*x2*x1*x3*x4*f0*f5*f4*f3*f7^2+4*x2*
x1^2*x6*f4*f5^2*f2^2+144*x2*x1*x3*x4*f7*f3*f4*f5^2*f2+4*x2^2*x1*x6*f3*f5^3*f1+
172*x4^2*x2*x6*f2*f7^3*f1-36*x4^2*x2*x6*f4*f5^4-216*x4^2*x2*x6*f6*f4^2*f5^2+48
*x1^2*x4*x7*f7*f3*f5^2*f1+76*x1^2*x4*x7*f7*f4^2*f1*f5-32*x1^2*x6^2*f1*f6*f2*f5
-32*x4^2*x1*x3*f4*f5^3*f2*f7-296*x4*x2*x5*x6*f0*f5^2*f7-24*x4*x2*x5*x6*f4^3*f5
-88*x4*x2*x5*x6*f2*f7^2*f1+24*x4*x1*x3*x7*f5^3*f4^2+24*x4*x1*x5*x7*f5*f4^3+80*
x2^2*x1*x4*f7*f2*f5^3*f1-24*x2^2*x1*x4*f7*f3^2*f4^3-16*x3^3*x6*f1^2*f7^3-176*
x4^2*x1*x6*f0*f6*f7^2*f3+160*x1*x6*x4^2*f0*f7^3*f2-248*x1*x6*x4^2*f0*f5*f7^2*
f4-8*x1^2*x2*x7*f7*f4^2*f2^2-56*x2^2*x3*x4*f7*f3*f5^3*f2+96*x3*x4*x2^2*f0*f6^2
*f7^2*f1+22*x1^2*x3^2*f7*f4^4*f1+144*x1^2*x3*x4*f0*f5*f2*f7^2*f4+26*x2^2*x4^2*
f7^2*f3^3*f5-12*x3^2*x2*x6*f7^2*f2*f3^2+36*x1*x4*x3^2*f7^2*f2^2*f4*f5+20*x1*x4
*x3^2*f4*f5^3*f7*f1+80*x1^2*x3^2*f4^2*f7^2*f0*f2+32*x3^2*x1*x4*f6^2*f4*f7*f2^2
-96*x3*x1*x2*x7*f0*f6*f5*f3*f7-80*x3*x1*x2*x7*f0*f5*f2*f7^2-72*x3*x1*x2*x4*f5*
f4^3*f3*f6+16*x3^2*x1*x4*f2^3*f7^3-24*x3*x1*x6^2*f3^2*f6*f4+72*x3*x1^2*x4*f5^2
*f4^3*f3-16*x4*x5*x1*x3*f0*f5*f7^2*f2+16*x3^2*x2^2*f0*f6*f3^2*f7^2-24*x3*x1^2*
x4*f5^3*f4^2*f2+480*x3^2*x4*x2*f0*f6^2*f5*f4*f7-116*x4^4*f2^2*f7^4-16*x2^2*x1^
2*f0*f6*f1^2*f7^2-8*x2*x1^2*x6*f1*f7*f2^2*f6-20*x2*x1^2*x6*f3^2*f5^2*f2-16*x2*
x1^2*x6*f0*f6*f4^3+64*x2*x1^2*x3*f0*f5^2*f7*f3^2+64*x3*x4*x1*x2*f7*f3^2*f6*f2*
f5-8*x2*x1*x7^2*f1*f5^2*f6+24*x2*x1^2*x3*f3*f5*f6*f1*f4^2-48*x2*x1*x3*x5*f6*f2
*f5^2*f1-112*x2*x1*x3*x5*f0*f6*f5*f4^2+12*x2*x1^2*x5*f4^2*f5*f3*f1+24*x4^2*x1*
x6*f7^2*f2^2*f5-4*x4^2*x5*x7*f2*f7^2*f4-4*x4^3*x7*f7^3*f4*f2-48*x2^2*x4*x5*f2*
f5^3*f4-8*x1^4*f7^2*f1^2*f2^2-48*x3^2*x5^2*f0*f6*f5^2-40*x3^2*x6*x7*f4^2*f6*f5
-48*x6*x7*x3^2*f1*f5*f6*f7+44*x6*x7*x3^2*f2*f7*f5^2+72*x1^2*x2*x3*f7*f1^2*f5*
f6*f3-32*x3^2*x5*x7*f5^2*f6*f2-16*x3^2*x5*x7*f3*f7^2*f1+32*x3^2*x5*x7*f3*f7*f4
^2+4*x3^2*x7^2*f5^4-72*x1^2*x3*x7*f1^2*f7^2*f4-24*x4^2*x8*f7^2*x5*f3*f4+32*x2*
x5*x3*x6*f0*f6*f7*f3-16*x4*x5^2*x1*f7*f1^2*f6+16*x1^2*x5*x6*f6*f5*f1^2-16*x1^2
*x5*x6*f0*f4*f7*f2-56*x2*x5*x6*x7*f7*f0*f5-48*x1^2*x5*x6*f0*f5^2*f3+8*x1^2*x5*
x6*f0*f3^2*f7-168*x2*x1*x4*x6*f7*f2*f3*f5*f4+32*x2*x1*x4*x6*f7^2*f1*f4*f2+12*
x1*x2*x3^2*f7*f4*f5^2*f2^2+4*x2^2*x3^2*f4^5*f6+32*x2*x1^2*x5*f1*f6*f5^2*f0-60*
x1*x2*x3*x6*f7^2*f2*f1*f3-16*x2*x1^2*x5*f0*f4*f3^2*f7-280*x3*x4*x1^2*f1*f6*f5*
f7*f3^2+12*x1^2*x3*x5*f4^3*f1*f5+392*x4^2*x5^2*f0*f4*f7^2-28*x4^2*x5^2*f7^2*f3
*f1+12*x4^2*x5^2*f7*f5*f3^2-118*x4^2*x5^2*f7*f5^2*f1-44*x4^2*x1*x5*f3^2*f5*f7*
f4+8*x4^2*x1*x5*f7^2*f3^2*f2-64*x4*x3*x7^2*f7^2*f3*f4+24*x7^2*x3*x4*f4^2*f7*f6
+32*x3*x4^2*x6*f3^2*f6^2*f7+64*x4^2*x7*x3*f1*f6^3*f7+304*x4^4*f5*f6^2*f1*f7^2+
128*x4^4*f7^3*f2*f4*f5-380*x4^4*f7^2*f5^2*f4^2+720*x4^4*f6*f5^3*f7*f4+8*x4^4*
f2*f7^3*f3*f6-138*x4^4*f4^2*f7^3*f3-384*x4^4*f0*f6*f5*f7^3-68*x4^2*x5*x1*f7*f4
*f5^2*f1+36*x4*x3*x7*x8*f7^2*f3*f5+60*x4*x3*x7*x8*f7^2*f4^2-16*x5*x8*f7*x3*x4*
f6*f2*f5+32*x4*x1*x5*x8*f7*f1*f5^2-72*x4*x1*x2*x5*f5*f4^2*f1*f6+24*x4*x1*x2*x5
*f2*f5^3*f3+12*x3^3*x7*f4^3*f5*f7+8*x3^3*x7*f2*f7^2*f4^2+4*x5^3*x7*f1*f5-4*x5^
2*x1*x7*f2*f3*f5+4*x3^3*x2*f7^2*f3^3*f4+4*x3^3*x2*f7^2*f3*f4^2*f2+32*x2*x4*x3^
2*f7^2*f3^3*f5-20*x2*x6*x3^2*f1*f7^2*f2*f5+80*x1^3*x2*f0*f6*f5*f4^2*f2+12*x2^2
*x3*x8*f7^2*f1*f4^2-88*x1*x2*x4^2*f7^2*f4^3*f1-112*x2^2*x1*x4*f0*f4^2*f3*f7^2-\
8*x2^3*x1*f1^2*f5*f7*f6*f3-4*x3^2*x1*x4*f7*f4^5-64*x1^3*x2*f0*f4^2*f5*f1*f7-48
*x1*x5*x3^2*f0*f3*f5^2*f7+128*x6^2*x3^2*f0*f5*f7*f6+140*x4^2*x7^2*f7*f5^3+48*
x2^2*x3*x7*f1*f0*f7^3+12*x2^2*x3*x7*f3*f5^3*f4-16*x2^2*x3*x7*f0*f5*f3*f7^2-44*
x2^2*x1*x3*f7*f3^2*f2*f4*f5+88*x2^2*x4^2*f7^2*f2*f4^3-64*x3^3*x4*f7*f2*f5^4+
128*x3^3*x4*f0*f5^3*f7^2-8*x3^3*x4*f7^3*f2*f1*f5+64*x2^2*x3^2*f0*f6*f5*f4^2*f7
+24*x3^2*x1*x4*f5^2*f4^2*f3*f6+16*x3*x2*x6^2*f2*f5*f4*f6+96*x3*x2*x6^2*f0*f6*
f7*f4+12*x3*x2*x6^2*f3*f5^2*f4+16*x3*x2*x5*x8*f7*f2*f3*f6-16*x3*x2*x5*x8*f7^2*
f3*f1+32*x3^3*x4*f7*f2*f4^2*f6^2+4*x3^3*x2*f4*f1^2*f7^3+4*x3^3*x2*f3*f2*f7^3*
f1+4*x3^3*x2*f4*f5^4*f3-12*f7^2*x2*x8^2*x4*f4^2-64*x1^2*x4*x6*f7*f2^2*f5*f4-40
*x1^2*x4*x6*f7*f1^2*f6*f5-88*x1^2*x3*x4*f6*f2*f5*f1*f4*f7+8*x6^3*x4*f7*f1*f6-\
24*x6^3*x4*f4*f5^2+8*x6^3*x5*f7*f0+16*x6^3*x1*f1*f4*f6-16*x6^3*x1*f1*f5^2-40*
x6^2*x1*x7*f2*f4*f6+12*x6^2*x1*x7*f7*f2*f3+8*x6^2*x1*x7*f5^2*f2-8*x6^2*x1*x7*
f7*f0*f5+32*x6^2*x1*x7*f6*f1*f5-44*x6^2*x2*x7*f7*f2*f4+20*x6^2*x2*x7*f5*f4^2-2
*x3^4*f7^2*f3^2*f4^2+16*x3^3*x7*f7*f4*f6*f2*f5-24*x3^3*x7*f2*f7*f5^3-40*x3^2*
x6*x7*f5^3*f4-8*x3*x1*x6*x7*f3*f7*f1*f6-24*x3*x2*x6^2*f3*f4^2*f6+48*x3*x2*x6^2
*f0*f7*f5^2-24*x3*x2*x6^2*f7*f2*f5*f3+96*x3*x1^2*x7*f0*f6*f4*f3*f7+120*x3*x1*
x2*x7*f1*f7*f3*f6*f4+56*x1^2*x3^2*f0*f5^2*f3*f7*f4+72*x1^2*x3^2*f0*f5^2*f6*f1*
f7-32*x1^3*x3*f6^2*f4^2*f1^2-28*x4*x5*x1^2*f7^2*f2^2*f1-8*x3^3*x6*f5*f4^3*f6-4
*x1^3*x7*f1*f4*f3*f5^2+48*x1^2*x3^2*f5*f6*f7*f4*f1^2-40*x1^2*x3^2*f5*f4^2*f7*
f3*f1+12*x1^2*x4*x7*f7*f4^3*f2-8*x2^3*x7*f7*f2^2*f4*f6+32*x2^3*x7*f0^2*f7^3-24
*x1^2*x3*x7*f7*f2*f5^2*f1+144*x1^2*x3*x7*f0*f7^2*f4*f2-84*x1^2*x4*x6*f7*f3^2*
f5*f2-12*x4*x5*x3^2*f3^3*f7^2+4*x1^3*x6*f4^4*f1+16*x1^3*x6*f7*f2*f3*f1*f4+32*
x1^3*x6*f7^2*f1^3-48*x1^2*x4*x6*f7*f4^2*f2*f3-12*x1^3*x6*f1*f4^2*f3*f5+12*x2^2
*x7^2*f7*f2*f5*f4-40*x2^2*x3*x6*f5*f4^4-172*x1^2*x4*x7*f7*f3*f5*f2*f4+16*x1^2*
x2*x7*f1*f7^2*f2^2-52*x2^2*x3^2*f4*f5^2*f7*f2*f3+16*x1^3*x5*f0*f6*f3*f5*f2-128
*x2*x1*x3*x4*f5^2*f4^2*f7*f1-128*x2*x1*x3^2*f0*f6*f5^3*f4-8*x2*x1*x5*x8*f7*f2*
f1*f6-40*x1*x2*x3*x6*f1^2*f7*f6*f5-32*x1*x2*x3^2*f1*f5^3*f7*f2-24*x1*x2*x3*x6*
f7*f2^2*f3*f6+12*x1*x2*x3*x6*f7^2*f2^3+36*x2*x1*x3*x4*f3^2*f5^4+240*x2*x1*x4*
x6*f6*f2*f5*f4^2+4*x2^2*x1*x6*f7*f2*f3^2*f4-16*x1^2*x3*x7*f4*f6^2*f2^2+96*x2*
x4*x3^2*f5*f4^2*f7*f2*f6-64*x3^2*x2*x4*f0*f6*f4^2*f7^2+24*x3^2*x1^2*f6^2*f7*f1
^2*f3-48*x3*x1*x6*x7*f4*f6^2*f1+96*x3*x1*x6*x7*f0*f6^2*f5+24*x3*x1*x2*x6*f5*f4
^2*f1*f6+184*x4*x5*x2*x3*f4^2*f1*f6*f7-16*x1^3*x3*f0*f5^4*f2-4*x1^3*x3*f3^4*f5
^2+8*x2^4*f0*f5*f4*f1*f7^2+4*x1^3*x3*f7*f3^5+12*x4*x5*x3^2*f7*f4^4-168*x4^3*x6
*f7^2*f2*f5^2-192*x4^3*x6*f0*f6^2*f7^2-152*x4^3*x6*f7^3*f2*f3+120*x4^3*x6*f4*
f7^3*f1+16*x1^2*x3*x7*f3*f5^2*f6*f1-8*x1^2*x3*x7*f7^2*f2*f3*f1+24*x2^2*x1^2*f7
*f2*f4^3*f1+64*x2*x1*x3*x6*f4^3*f6*f2-44*x2*x1*x3*x6*f5*f4^3*f3+248*x2*x1*x4^2
*f1*f4^2*f7*f5*f6+160*x2*x1*x3^2*f0*f6^2*f5*f4^2-8*x2^2*x1*x6*f0*f4*f1*f7^2+64
*x3*x4*x1*x2*f0*f6*f7^2*f2*f4-8*x1*x2*x3*x6*f3^2*f6*f7*f1-16*x4*x3*x5*x6*f7*f5
*f3^2-72*x4^2*x1*x3*f4^3*f5^2*f6-64*x4*x2^2*x7*f0*f6*f5^2*f7-96*x3*x5*x4^2*f7^
3*f0*f3-104*x4^2*x3*x5*f7*f2*f4*f5*f6+28*x3*x5*x4^2*f7^2*f3^2*f4+48*x1^3*x4*f3
^2*f5^3*f2+32*x2^2*x3*x5*f7*f2*f4*f1*f6-16*x2^2*x3*x5*f0*f5*f4^2*f7-8*x2^2*x3*
x5*f1^2*f7*f5*f6-48*x2*x1^2*x7*f0*f6*f5^2*f3+32*x2^2*x1^2*f0*f6^2*f2*f7*f1+16*
x2*x1^2*x6*f0*f5^2*f1*f7-48*x2*x1^2*x4*f0*f5^3*f2*f7+16*x2*x1^2*x7*f0*f5^3*f4-\
32*x3*x1^2*x4*f0*f5^3*f3*f7-8*x3^2*x1*x2*f7*f3^3*f5*f4-8*x3*x2^2*x5*f0*f3^2*f7
^2-16*x4*x5*x2*x3*f0*f4^2*f7^2-72*x3*x2*x4*x5*f4*f5^3*f3-96*x3*x2*x4*x5*f0*f7^
2*f5*f3+12*x6^2*x7^2*f4*f6+16*x2^2*x1*x3*f1^2*f5*f7^2*f3-28*x2^2*x1*x3*f7*f4^4
*f1-16*x4*x2^2*x5*f0*f6*f4^2*f7+24*x4*x1*x2*x7*f4*f5^3*f3-4*x4*x3*x5^2*f3^2*f4
*f7+4*x4*x3*x5^2*f7*f2*f3*f5+8*x3^2*x5^2*f2*f0*f7^2-4*x3^2*x5^2*f7*f4*f2*f3+4*
x3^2*x5^2*f5^3*f1-16*x1^2*x5^2*f0*f6*f5*f1-48*x1*x5*x4*x6*f7^2*f0*f2-16*x1*x5*
x6*x7*f1*f5^2-72*x4*x5*x7^2*f4*f5*f6+12*x5*x4*x6^2*f7*f3^2-16*x3^3*x6*f7*f4^2*
f2*f6-16*x3^3*x6*f3*f5*f1*f7^2+16*x3^3*x6*f0*f7^3*f2+32*x3^3*x6*f3*f5*f2*f6*f7
-8*x3^3*x6*f7^2*f2^2*f5+32*x1^3*x7*f0*f6^2*f2*f4-12*x3*x1*x4*x5*f5^2*f4^2*f3+
32*x3*x1*x6^2*f3*f5*f6*f2-68*x3*x1*x6^2*f7*f5*f1*f3-280*x3*x1*x4^2*f1^2*f7^3*
f5-144*x3*x1^2*x4*f6^2*f7*f1^2*f4+40*x3*x1*x6^2*f7*f2*f3*f4+24*x3*x2*x4*x8*f7^
3*f2^2+40*x3*x1*x4^2*f7^3*f3^2*f1+20*x1^3*x4*f7*f2*f3^2*f4^2+12*x2^2*x5*x7*f1*
f5^3-8*x1^2*x3*x5*f4^4*f2+32*x1^2*x3^2*f6*f2*f5*f7*f3*f1-12*x1^2*x3^2*f4*f5^2*
f6*f2^2+64*x1*x5*x2*x7*f0*f7*f5*f3-8*x7^3*x2*f7*f3*f5+16*x7^3*x2*f4*f5*f6-44*
x4*x5*x1*x2*f7*f1*f5^2*f2+12*x2^2*x1*x3*f5^2*f4^3*f2+32*x2*x1*x3*x4*f0*f4*f1*
f7^3+4*x2^2*x1*x5*f3*f7*f2^2*f4-12*x2^2*x1*x5*f7*f2^3*f5-12*x2^2*x1*x5*f1*f5^3
*f2+16*x2*x1*x6*x7*f1*f5^3+24*x2^2*x1^2*f0*f3^2*f7^2*f2-4*x2^2*x1*x3*f3*f5^4*
f1+64*x2^2*x1*x6*f5*f0^2*f7^2-8*x2*x1^2*x5*f5^3*f1^2+96*x4^3*x5*f4*f6*f1*f7^2-\
96*x4^3*x5*f5*f6^2*f1*f7-76*x4^3*x5*f4*f5*f7^2*f2-216*x4^3*x5*f6*f5^3*f4-168*
x4^3*x5*f7*f3*f5^3-128*x1^3*x3*f0*f6*f4*f7*f3*f2+4*x1^4*f2^4*f7*f5+40*x2^2*x1*
x6*f0*f4^3*f7-96*x2*x1*x3*x6*f3*f5*f4*f6*f2+32*x2*x1^2*x3*f6*f5^3*f1^2+48*x2*
x1*x3*x6*f3^2*f4^2*f6-12*x2*x1*x4*x7*f7*f5^2*f1*f4+148*x2*x1*x4*x7*f7*f2*f5^2*
f3+8*x5*x4*x6*x8*f7*f4^2-68*x4*x5*x7*x8*f7*f4*f5-36*x4*x5*x7*x8*f2*f7^2+16*x5*
x6*x3^2*f1*f7*f4*f5-48*x3^2*x5*x6*f1*f6^2*f4-64*x3^2*x2*x5*f0*f6*f1*f7^2-4*x2^
2*x3^2*f7^2*f3^2*f1*f5-40*x2^2*x3^2*f7*f2*f5*f4^3-8*x7^2*x2*x3*f4^3*f7+16*x1*
x7^2*x3*f5^2*f6*f2-24*x2*x1*x6*x8*f7*f1*f4*f5+8*x2*x1^2*x5*f2*f4^2*f1*f6+96*x2
*x1*x4*x5*f4*f5^3*f1+28*x4*x5*x1*x2*f7*f3*f5*f4*f1+68*x4*x2*x5*x7*f3*f7^2*f1+
12*x4*x2*x5*x7*f2^2*f7^2+4*x4*x1*x3*x7*f7^2*f3^3+96*x4*x1*x3*x7*f6*f5^3*f2+16*
x4^2*x5*x2*f4^2*f7*f2*f6+112*x4*x5*x2^2*f0*f5^2*f4*f7+92*x4*x5*x2^2*f2*f7^2*f4
*f1+80*x4^3*x5*f4^2*f7^2*f3-1072*x4^3*x5*f0*f4*f7^3+4*x1^3*x5*f3*f4^3*f1-24*x3
*x2*x5*x6*f3*f5*f4^2+16*x3*x2*x5*x6*f5^3*f1+4*x3*x1*x5*x8*f7*f2*f3*f5+12*x3*x1
*x5*x8*f7*f1*f4*f5-96*x3^2*x1*x2*f0*f6*f5*f4*f3*f7-4*x1^3*x5*f2*f5*f3^3-12*x7*
x2^2*x8*f7^2*f2*f3-8*x7*x2^2*x8*f7*f6*f1*f5-8*x2^2*x7^2*f3*f6*f2*f7+72*x5*x6*
x3^2*f0*f5^2*f7+108*x4^3*x5*f5^5+8*x3*x1*x7*x8*f6*f7*f2*f4+6*x3^2*x2^2*f7^3*f3
*f1^2-264*x3*x2*x4^2*f7*f4*f5^3*f3+56*x2^2*x1*x4*f7^2*f3^2*f1*f4+48*x1^3*x5*f0
*f3*f4*f7*f2-12*x3^2*x1*x6*f7*f3^2*f4^2+4*x1*x6*f3^3*f7*x3^2*f5-28*x3^2*x1*x6*
f5^2*f4^2*f3+4*x1*x5^2*x3*f3*f7*f2^2-4*x1*x5*x6^2*f4^2*f2-24*x4*x8*f7^2*x2*x7*
f1*f6+16*x7^2*x2*x3*f5^2*f2*f7+136*x1^2*x3^2*f0*f5*f1*f7^2*f4+72*x1^2*x3^2*f0*
f5*f7^2*f3*f2-8*x7^2*x2*x6*f7*f2*f5+16*x4*x7^2*x2*f3^2*f7^2+24*x4*x1^2*x6*f2^2
*f6*f5^2+16*x4^2*x1*x6*f7*f2*f4^2*f6+12*x4*x1*x5^2*f7*f2*f1*f5+36*x2^2*x1*x4*
f5^3*f3^2*f4-4*x2*x6^2*x5*f7*f2^2-4*x1^2*x6*x7*f4^3*f3+32*x3^3*x4*f0*f4^2*f7^3
-24*x3^3*x4*f7^3*f2*f3^2-128*x3*x1^2*x5*f2*f0*f6^2*f4+16*x3*x1^2*x5*f0*f6*f5^2
*f2+8*x3*x1*x2*x8*f7*f3*f6*f2*f4+8*x3*x1*x2*x8*f7*f1*f4^2*f6-128*x3*x1*x4*x6*
f1*f0*f7^3+96*x3*x1*x4*x6*f6*f2*f0*f7^2-24*x1^2*x3^2*f5*f4^3*f1*f6-48*x3^2*x1^
2*f0*f4*f3^2*f7^2-8*x3*x2^2*x4*f7^2*f2^2*f4*f5-2*x3^2*x1^2*f4^6+24*x2^3*x4*f3*
f5*f7^2*f2^2+16*x2^3*x4*f0*f4^3*f7^2+2*x2^4*f1^2*f5*f7^2*f3+12*x2^2*x6^2*f4^4+
4*x1^3*x5*f2^3*f5^2-16*x4^2*x5^2*f0*f6*f5*f7+60*x4*x2*x6^2*f5^2*f4^2-4*x4*x1*
x6*x8*f7^2*f2*f3-12*x4*x1*x5*x7*f7*f2*f4^2-48*x4*x1*x5*x7*f3*f5^2*f4-16*x4*x1*
x6*x7*f7^2*f2^2+4*x1^3*x5*f3^4*f4-96*x1^3*x4*f6^2*f5*f4*f1^2-16*x1^3*x4*f2*f5*
f7^2*f1^2-52*x1^2*x3*x7*f7*f4^2*f2*f3+32*x1^3*x3*f7*f3*f0*f6*f1*f5-8*x1^3*x3*
f5*f7^2*f1^3+4*x1^3*x5*f4^3*f2^2+48*x1^2*x3*x4*f5^3*f6*f3*f1+12*x1^4*f1*f5*f4^
2*f3^2-64*x1^3*x3*f3*f0^2*f5*f7^2+64*x1^4*f4^2*f5*f7*f0^2-16*x1^2*x2*x4*f0*f6*
f7^2*f3*f1-20*x1^3*x4*f1*f4^3*f7*f3+16*x1^3*x4*f0*f3^2*f5^2*f7+32*x1^3*x4*f0*
f7*f4^4+96*x4*x5*x1^2*f7^2*f0^2*f5+24*x1^2*x4*x5*f2^2*f5*f4*f6+8*x1^2*x3*x7*f2
^2*f7*f5*f4-12*x1^2*x6^2*f3*f5*f2*f4+40*x2^2*x4*x6*f1*f7*f4^2*f6-52*x4^2*x1*x7
*f7^2*f2*f3*f5-272*x4^2*x1*x7*f0*f5^2*f7^2-36*x3*x8*f7^3*f3^2*x4^2-4*x4^2*x3*
x8*f7^3*f5*f1+48*x4*x5*x1^2*f1*f6*f0*f5*f7-16*x2^2*x1*x3*f0*f5*f6*f3^2*f7-8*x4
*x5*x1^2*f7*f4^2*f2^2+224*x2^2*x1*x4*f6*f5*f0^2*f7^2-32*x2^2*x1*x4*f1*f6*f7^2*
f2^2-56*x2^2*x1*x4*f0*f5*f3^2*f7^2+24*x2^2*x1*x4*f0*f5^5+48*x4*x1*x3*x5*f1*f5^
4+12*x4*x1^2*x6*f3^2*f5^2*f4-28*x4^2*x1^2*f7*f2^2*f5^3-16*x2^2*x6*x7*f5*f4^3+
48*x1^3*x4*f0*f5^3*f4^2+32*x2*x1*x3*x7*f0*f7*f5^2*f4-32*x2*x1*x3*x7*f1*f4*f7^2
*f2-96*x2*x1^2*x4*f1^2*f7^2*f6*f2-16*x2*x1^2*x3*f6^2*f5*f1^2*f4-64*x2*x1*x3^2*
f6^2*f2*f1*f3*f7-12*x2^2*x5^2*f2*f7*f1*f4+54*x2^2*x4^2*f3*f5^5+8*x1^2*x5*x7*f3
*f5*f2*f4-144*x2^2*x1*x4*f0*f6*f5^3*f4+64*x2^2*x1*x4*f0*f5*f4*f7^2*f2-2*x3^4*
f7^3*f3^2*f1+160*x2*x3^3*f0*f6*f4*f5^2*f7+48*x2^2*x1*x3*f4^2*f7^2*f1^2+40*x2*
x1*x3*x5*f1*f7*f2*f3*f6+8*x2^2*x1^2*f1*f5^3*f2*f4-24*x2^2*x1^2*f3*f6*f4^3*f1+4
*x2^2*x5*x7*f1^2*f7^2+24*x3^3*x6*f3*f5^2*f6*f4-36*x4^2*x6^2*f7^2*f3^2+8*x4*x2*
x5*x8*f7*f6*f1*f5-12*x4*x2*x6*x8*f7^2*f3^2+48*x4*x2*x6*x8*f7^2*f0*f6-16*x4*x2*
x6*x8*f7^2*f2*f4-4*x4*x2^2*x8*f7*f4^3*f5-8*x4^2*x5*x1*f1*f6*f4^2*f7+28*x4*x1^2
*x7*f7^2*f2^2*f3-144*x1^2*x3^2*f0*f6*f5*f2*f7*f4-32*x1^2*x3^2*f6*f2*f5^3*f1-\
112*x1*x2*x4^2*f7^3*f0*f4*f2+16*x2*x1*x6^2*f2*f5^2*f3-4*x2*x1*x6*x8*f7*f2*f3*
f5+64*x1*x2*x3^2*f3*f5*f6*f7*f2^2-64*x2^2*x1*x3*f0*f5^4*f4-48*x1^3*x6*f0*f6*f5
*f2*f4+56*x1^3*x4*f1*f4*f7^2*f2^2+64*x1^3*x4*f6*f5^2*f0^2*f7+48*x1^3*x4*f0*f5^
3*f1*f7-12*x2^2*x6^2*f7*f2*f3*f4-4*x2^2*x6^2*f7*f5*f1*f3-160*x2^2*x4^2*f0^2*f7
^4+16*x1^2*x3^2*f0*f7^3*f1*f2+12*x3^2*x2*x5*f1*f7^2*f2*f4+4*x2*x5*x3^2*f7*f3^3
*f5+32*x2*x5*x3^2*f2*f6*f7*f1*f5-96*x2^2*x3*x6*f0*f6*f4^2*f7+16*x6*x3*x1*x7*f0
*f3*f7^2-16*x3*x6*x1*x7*f5^3*f2-16*x3*x6*x7*x8*f7*f3*f6+12*x3*x5*x6*x8*f7*f2*
f5+16*x1*x5^2*x2*f0*f5*f4^2+48*x1^2*x5*x6*f0*f6*f4*f3+48*x2*x5*x1*x7*f0*f6*f5*
f4+64*x1*x5*x3*x6*f0*f5*f3*f7+36*x2^2*x1*x3*f3*f5^3*f2*f4-40*x2^2*x1*x3*f3*f6*
f4*f1*f5^2+48*x2^2*x1*x3*f0*f6*f5*f4*f2*f7-4*x2^2*x1*x7*f3*f5^3*f2+64*x3^2*x4*
x7*f7*f2*f5^2*f6+144*x3^2*x4*x7*f3*f5^2*f6^2-48*x1^2*x2*x4*f4*f5^2*f6*f2^2+16*
x3*x1*x2*x4*f0*f4^3*f7^2-8*x3^2*x2^2*f2^3*f6*f7^2+32*x3^2*x2^2*f0*f6^3*f7*f1+
40*x3*x1*x4*x7*f7*f3^2*f5^2-20*x3*x1^2*x7*f5^2*f3^2*f4+20*x3^2*x1^2*f7*f3^3*f4
^2+24*x1^2*x7^2*f3*f6*f2*f5-4*x2^4*f7*f3^2*f2*f4*f5-8*x2^4*f0*f6*f4^2*f3*f7-4*
x2^4*f1*f5^2*f7*f2*f4+16*x2^4*f0*f5*f4^3*f7+48*x2*x1*x6^2*f0*f5*f4*f6-40*x2*x1
*x6^2*f7*f2*f5*f1+20*x4*x5*x1*x2*f2*f1*f7^2*f3+32*x4*x5*x1*x2*f7*f2*f6*f4*f1-\
96*x4*x3*x2*x6*f5*f4^3*f6+16*x4*x3*x5*x8*f7^2*f1*f5+112*x1^2*x3*x4*f7^2*f2^2*
f3*f4-72*x4*x1^2*x6*f2*f3*f5^3-104*x1*x4*x2*x7*f7*f3^2*f5*f4+28*x4*x1^2*x6*f7*
f3^3*f4+8*x5^2*x1*x6*f2^2*f5-8*x5^2*x2*x7*f7*f3*f1+8*x5^2*x2*x7*f2*f4*f5-8*x5^
2*x6*x7*f2*f5-16*x3^4*f1^2*f6^2*f7^2-12*f7*x4*x8^2*x5*f5^2-12*f7^2*x4*x8^2*x5*
f3-8*x1^3*x3*f5*f4^3*f2*f3+12*x5^2*x2*x6*f7*f2*f1+4*x5^2*x2*x6*f1*f4*f5+56*x1^
2*x4*x6*f7*f1*f4*f2*f6+16*x1^2*x2*x7*f3*f5^2*f2*f4-16*x2^2*x6*x7*f0*f6*f7*f4+
72*x2^2*x6*x7*f7*f2*f4^2-72*x2^2*x6*x7*f1*f7*f4*f5+16*x1^3*x7*f0*f7^2*f3*f1+44
*x1^2*x2*x7*f1^2*f7*f5^2-120*x3*x2*x4^2*f7*f2*f5^2*f4*f6+48*x3*x1*x2*x7*f0*f4*
f3*f7^2-32*x3*x1*x2*x7*f0^2*f7^3+8*x3^2*x2*x8*f7*f2*f5^3+8*x3^2*x2*x8*f7*f5^2*
f6*f1+64*x1^4*f6*f7^2*f0^3+8*x2^4*f0*f6*f5^2*f1*f7+192*x3^2*x1*x4*f0*f6^2*f5*
f3*f7+8*x3^2*x2*x4*f7^2*f2*f4^3+96*x3^2*x2*x4*f0*f6*f1*f7^3-56*x1^3*x4*f7^2*f2
^3*f3-12*x2*x7*x3^2*f7*f4^4+48*x2^3*x3*f0*f5^2*f4^2*f7+16*x3*x1^2*x6*f1*f6^2*
f2*f4+72*x3^2*x1*x4*f6*f4*f5^3*f2-12*x3^2*x1*x4*f3*f5^4*f4+16*x1^3*x3*f0*f4^3*
f5^2+8*x1^2*x3*x6*f2^2*f5*f4*f6-200*x3^3*x4*f6*f4^2*f7*f5*f3+184*x3^3*x4*f4*f5
^2*f2*f6*f7+4*x2^3*x3*f7*f3^2*f4^3-48*x1^2*x6*x7*f3*f5*f1*f6+4*x2^2*x6^2*f5^3*
f1+8*x3*x6^2*x8*f7*f2*f6-32*x1*x6*x3*x7*f5^2*f1*f6+4*x3^2*x1*x5*f4^5+32*x3*x1*
x2*x5*f0*f4*f1*f7^2-24*x3*x1*x4*x6*f7^2*f2*f1*f5-112*x4*x5*x1*x3*f7*f1*f6*f5*
f2-108*x4*x5*x1*x3*f7*f3*f5*f2*f4-352*x4*x5*x1*x3*f7*f0*f6*f4^2-40*x3^2*x6*x7*
f0*f5*f7^2+8*x3^2*x6*x7*f3^2*f7*f6-4*x7^3*x2*f5^3-64*x3^2*x1*x6*f0*f6^2*f5*f4-\
24*x1*x6*x3^2*f2*f6*f7*f1*f5-12*x1^2*x5*x6*f4*f5*f2^2-16*x1^2*x5*x6*f1*f5*f0*
f7-12*x1^2*x5*x6*f1*f3*f7*f2+16*x1^3*x3*f1*f6^2*f5*f2^2-20*x3^2*x1*x6*f7^2*f3*
f2^2+144*x1*x4*x3^2*f1*f6^2*f7*f2*f5+72*x3^2*x1*x4*f3^2*f6*f5^3-48*x4*x1^2*x7*
f3^2*f5^3-24*x4*x1^2*x7*f5^3*f2*f4+24*x4*x1^2*x7*f5^4*f1-16*x4^2*x1^2*f7*f2*f4
^2*f3*f6-50*x2^2*x4^2*f7^2*f3^2*f4^2-32*x1^3*x3*f0*f5*f7^2*f1*f2-8*x3^2*x2*x6*
f4^4*f6+48*x3*x4^2*x6*f7*f2*f6^2*f4+216*x4^2*x1^2*f3*f5^3*f6*f2+16*x4^2*x2^2*
f7^3*f3*f2^2-16*x4*x2*x5*x7*f3*f7*f4^2-144*x4*x1^2*x5*f1*f4*f5*f3*f6-24*x4*x1*
x7*x8*f7^2*f1*f5-288*x4*x1^2*x7*f0*f6*f5*f3*f7+48*x2^2*x3^2*f0*f6*f4*f2*f7^2+8
*x2^2*x3^2*f6*f4*f5*f7*f2^2-12*x4*x1^2*x7*f5*f4^4+24*x4*x1*x6*x7*f5^3*f3-96*x4
*x1^2*x7*f1*f5^2*f4*f6+64*x3*x4^2*x1*f1*f6^3*f7*f2+4*x3*x5^2*x8*f7*f2*f4-12*x3
*x5^2*x4*f4^3*f5-16*x4*x5^2*x3*f2*f7^2*f1-48*x3*x5*x6^2*f7*f0*f5-36*x1^3*x3*f7
*f3^2*f1*f4^2+4*x1^2*x5^2*f5^2*f1^2-16*x1*x5^2*x3*f0*f4*f3*f7-20*x3^2*x5*x7*f1
*f5^2*f7+40*x2^2*x4^2*f7^2*f4^2*f5*f1-104*x2^2*x4^2*f0*f6*f5*f3*f7^2+176*x2^2*
x4^2*f0*f5*f2*f7^3+56*x2^2*x4^2*f1*f7^2*f3*f6*f4-432*x4^3*x8*f7^4*f0+312*x4^3*
x8*f7^2*f4*f5^2+120*x4^3*x8*f7^3*f6*f1+152*x4^3*x8*f7^3*f2*f5+72*x4^3*x8*f7^3*
f4*f3+312*x4^2*x5*x8*f7^3*f0-16*x2^3*x1*f0*f7^3*f1^2+64*x4^2*x3*x8*f7^2*f2*f5*
f6+128*x4^2*x3*x8*f7^2*f6^2*f1+192*x4^2*x3*x8*f7^2*f4^2*f5+156*x4^2*x3*x8*f7^3
*f2*f4-480*x4^2*x3*x8*f7^3*f0*f6+192*x4^2*x3*x8*f7*f4*f5^2*f6-128*x1^3*x4*f0*
f5*f6*f7*f3*f2-128*x1^3*x4*f7*f2*f3*f1*f4*f6+44*x3*x6*x2^2*f3*f5*f7*f2*f4-288*
x4^2*x1*x5*f7^3*f1*f0-124*x4^2*x1*x5*f7^2*f2^2*f4+72*x4^2*x1*x5*f1*f5^3*f6+72*
x4^2*x1*x5*f2*f6*f4*f5^2-64*x4^2*x1*x5*f7*f1*f3*f5*f6+176*x4*x5*x1^2*f0*f3*f7^
2*f2-72*x3*x4*x1*x2*f1*f6*f3*f7^2*f2-264*x2*x1*x4*x6*f1*f4*f6*f5^2+80*x2*x1*x4
*x6*f7*f2^2*f5^2+24*x2*x1*x3*x5*f1^2*f7*f4*f6+8*x1^3*x5*f7*f2^3*f3-8*x1^3*x3*
f5*f4^4*f1-32*x2*x1*x3^2*f4^2*f6*f7*f2^2+64*x2*x1*x3*x5*f3*f5*f1*f4*f6-24*x3*
x4*x1*x2*f3*f6*f4*f7*f1*f5-12*x2*x1^2*x4*f7*f3^4*f5+16*x1*x6*x3^2*f0*f5*f7^2*
f2+8*x3^2*x1*x6*f4*f5^3*f2+40*x3^2*x1*x6*f4^3*f7*f2+24*x3^2*x1*x6*f5*f4^2*f2*
f6-4*x1^2*x3*x7*f7*f3^2*f5*f2+4*x2^3*x3*f7^2*f2^3*f5+4*x2^2*x3*x4*f7^2*f3*f4^2
*f2+12*x1^3*x6*f2*f3^2*f5*f4-20*x1^3*x6*f7*f1*f5*f2^2+2*x6^4*f3*f5-4*x2^3*x3*
f5*f4^3*f7*f1-8*x2^3*x6*f4^5+48*x4*x5*x3^2*f3*f6^2*f1*f7+320*x4*x5*x3^2*f4*f6*
f1*f5*f7-100*x4*x5*x3^2*f3*f5*f1*f7^2+64*x4*x5*x3^2*f1*f6*f7^2*f2-128*x1^3*x2*
f4*f3*f0^2*f7^2-16*x2^3*x4*f1^2*f6*f7^2*f4-68*x6^2*x3^2*f1*f5^2*f7-20*x2*x1*x4
*x8*f7^2*f2^2*f5-4*x2^2*x1*x3*f7^2*f3^3*f1-24*x2*x1^2*x3*f3*f6*f4^3*f2+24*x3*
x1^2*x5*f7*f3^2*f1*f4-16*x1^3*x3*f5^3*f2*f1*f4-24*x3*x1*x5^2*f1*f4*f3*f6+176*
x3*x2*x4*x6*f7*f2*f5^2*f4-24*x3^2*x1*x5*f7*f1*f4^3+16*x3^2*x2*x5*f5*f4^4+8*x2^
3*x6*f1*f7*f3*f5*f4-18*x1^4*f5^2*f7*f1^3+48*x3*x4*x2^2*f4^3*f6*f2*f7-32*x3*x4*
x2^2*f7*f3^2*f4^2*f6-24*x1^2*x3*x5*f4*f1*f6*f2*f5-16*x3*x1^2*x5*f1*f5^2*f7*f0-\
144*x3*x1*x4^2*f4*f6^2*f2*f5^2+96*x3*x1*x2*x5*f0*f6*f5*f1*f7+12*x3*x1*x2*x5*f3
*f4^4+56*x3*x1*x5*x6*f0*f4^2*f7-8*x3*x1^2*x4*f7*f3^2*f4^3+32*x3^2*x2*x6*f0*f6*
f2*f7^2+16*x3^2*x2*x6*f3^3*f6*f7+192*x3^2*x1*x2*f6*f5*f0^2*f7^2+168*x3*x2*x4*
x6*f7*f3*f5*f4^2+8*x3*x2*x4*x6*f7*f2*f3*f5*f6+24*x3*x2*x4*x6*f7*f4^4-8*x3*x1^2
*x6*f4^3*f1*f6-32*x3*x1*x6^2*f2*f4^2*f6+6*x2^2*x7^2*f5^3*f3+64*x3*x4*x1^2*f2*
f3*f6^2*f7*f1+448*x3*x4*x1^2*f0*f6*f5*f4*f7*f3-32*x2*x1*x3*x4*f7*f3^3*f5^2+544
*x3*x4*x1*x2*f0*f6*f5*f4^2*f7+96*x3*x4*x1*x2*f3*f6*f4^2*f7*f2-12*x1^3*x4*f5^2*
f4^3*f1+100*x4^2*x3*x8*f7^2*f3*f5^2+112*x4*x1^2*x6*f0*f5^2*f3*f7-52*x4^2*x3*x7
*f7^2*f4^3-48*x4^2*x5*x2*f0*f7^3*f2+180*x4^2*x5*x2*f3*f5*f1*f7^2-1488*x4^2*x5*
x3*f0*f6*f4*f7^2+144*x4^2*x3*x5*f4*f5^4+360*x4^2*x5*x3*f5^2*f1*f6*f7-144*x4^2*
x3*x5*f6*f4^2*f5^2+40*x4*x1^2*x6*f0*f5*f4^2*f7+52*x3*x2*x4*x8*f7*f5^2*f4^2-48*
x3*x2*x4*x8*f7^2*f3^2*f5-224*x3*x1*x4^2*f0*f4*f3*f7^3+228*x3*x1*x4^2*f7^2*f4^2
*f5*f1+48*x2*x1*x4*x7*f7*f5*f1*f6*f3+20*x2*x1*x4*x7*f7*f2*f5*f4^2+72*x2*x1*x4*
x7*f7^2*f3*f4*f1+20*x2*x1^2*x3*f3^2*f5^3*f2+8*x2*x1*x5*x6*f4^3*f2+64*x1^3*x3*
f6^2*f0^2*f3*f7+16*x3*x1*x2*x7*f0*f6*f4^2*f7+32*x3^2*x1^2*f3*f0^2*f7^3-200*x3*
x1*x4^2*f7*f3*f5^2*f6*f2+16*x3*x2^2*x4*f7^2*f2^2*f6*f3+128*x3*x2*x4^2*f7^2*f0*
f6*f4*f5-64*x3*x1*x4^2*f7^2*f2*f4^3+128*x3*x2*x4*x7*f7*f2*f5^3-184*x3*x2*x4*x7
*f7*f5^2*f6*f1+4*x2^2*x1^2*f6*f5^2*f1^2*f4+16*x2*x1^2*x4*f6^2*f1*f7*f2^2-16*x3
*x4*x1*x2*f1*f6^2*f7*f2*f4-24*x2*x1*x3*x5*f3*f7*f1*f4^2+80*x2^2*x3^2*f0*f6*f5*
f1*f7^2+16*x1^3*x2*f3*f6*f4^2*f2^2-16*x1^3*x3*f0*f6*f4^4-48*x1^2*x2^2*f7*f3*f0
*f6*f1*f5-8*x1^3*x3*f7*f2*f3^3*f4-72*x2*x1*x4*x5*f5^2*f4^2*f2-96*x4*x5*x1*x2*
f6*f0^2*f7^2-8*x2^2*x1^2*f6*f1*f4*f7*f2^2+48*x2*x1*x6^2*f5^2*f1*f4+32*x2*x1*x3
*x5*f2^2*f5*f4*f6+16*x1*x2*x4*x5*f7*f3^3*f4+8*x2^2*x1^2*f3^2*f1*f7*f2*f6-48*x2
*x1^2*x3*f0*f6*f5^2*f3*f4-16*x1*x2*x3^2*f7^2*f2^3*f5-8*x2^2*x6*x7*f5^3*f2+12*
x1^3*x3*f3*f5^3*f2^2+40*x3^2*x4*x8*f7^3*f2*f3+128*x3^2*x4*x8*f7*f4^2*f6*f5+72*
x3^2*x4*x8*f7*f3*f6*f5^2-48*x3^2*x4*x8*f7^2*f3^2*f6+8*x1^4*f2*f6*f3^2*f1*f5-4*
x1^4*f7*f1*f3^2*f4*f2-24*x1^4*f3*f7^2*f1^3+44*x4*x2*x5*x7*f7*f5^2*f1-72*x4*x2*
x5*x7*f5^3*f3+64*x4*x2*x5*x7*f0*f4*f7^2+160*x4*x2*x5*x7*f0*f6*f7*f5+24*x4*x1*
x2*x7*f2*f5^4+16*x4*x5^2*x3*f0*f3*f7^2-4*x1*x5^2*x2*f7*f1*f3*f2-48*x1*x5*x6^2*
f0*f6*f4-12*x1*x5^2*x3*f4^2*f1*f5+8*x1*x5*x3*x7*f2^2*f5*f7-16*x1*x5*x6^2*f2*f3
*f5-32*x5*x4*x6^2*f7*f2*f4-48*x5*x4*x6^2*f7*f0*f6+48*x1^2*x4*x5*f3*f5^3*f1-88*
x2*x4*x3^2*f3*f5^2*f6*f7*f2+144*x3^2*x2*x4*f4*f5^3*f3*f6+16*x1^3*x2*f0*f4^2*f3
^2*f7+8*x2^3*x5*f1^2*f6*f7*f4+16*x2^3*x5*f1*f7*f2*f4*f5+8*x2^3*x5*f0*f5^3*f4-\
32*x1^4*f0*f5*f3^2*f7*f2+32*x3^4*f0*f6^2*f2*f7^2+64*x1^3*x2*f0*f6*f5*f4*f3^2+
36*x4^2*x1*x5*f3*f5^2*f7*f2+16*x3^3*x7*f0*f5^2*f7^2-224*x4^2*x3*x5*f7*f2*f5^3-\
216*x4^2*x3*x5*f3*f5^3*f6+168*x3*x5*x4^2*f7^2*f1*f4*f5-32*x1^3*x3*f0*f6*f5^3*
f1-16*x1^3*x3*f5^2*f6*f4*f1^2-16*x3^3*x4*f4*f5^3*f3*f7-16*x3^3*x4*f7*f3^2*f6^2
*f4-8*x3^3*x4*f7*f4^4*f6-108*x3*x2*x4^2*f7^3*f2^2*f4+48*x3*x2*x5^2*f0*f6*f4*f5
+16*x3*x2*x5^2*f1^2*f7*f6+248*x3*x2*x4^2*f7*f2*f5^4-52*x3*x2*x5*x7*f1*f4*f7*f5
+8*x3*x2*x5*x7*f7*f6*f2^2+48*x1^3*x3*f7*f2^2*f3*f4^2-24*x2^2*x1*x6*f1*f7*f2*f3
*f6-144*x3*x4*x1*x2*f0*f6*f5*f7^2*f1-8*x2^2*x1*x3*f7*f2*f6*f3^3-8*x2*x1^2*x3*
f3*f5^2*f6*f2^2+64*x1^3*x3*f0*f6*f7^2*f1^2-336*x4^2*x1*x5*f4^2*f0*f7^2+48*x4^2
*x1*x5*f7^2*f1*f2*f5+292*x4^2*x1*x5*f7^2*f1*f3*f4+128*x4^2*x1*x5*f7^2*f1^2*f6-\
176*x4^2*x1*x5*f3*f5*f0*f7^2-16*x1*x3^3*f4*f5^2*f7*f2*f3+8*x1*x3^3*f7^2*f3^2*
f1*f5+4*x2^2*x6^2*f4*f5^2*f2-32*x2*x3^3*f5^2*f4^2*f2*f7-16*x2^2*x6*x8*f7*f1*f4
*f6+16*x2^2*x6*x8*f7*f0*f5*f6-8*x6*x1*x2*x7*f3*f7*f2*f4-8*x2*x6*x3*x8*f7*f4^3+
16*x6^2*x1*x3*f7*f2*f1*f6-8*x7^2*x3*x6*f7*f4^2-24*x2^2*x3*x7*f6*f5^3*f1+8*x2^2
*x3*x7*f7^2*f2^2*f4-80*x2^2*x3*x7*f0*f6*f5*f4*f7+8*x3^2*x1*x7*f3*f5*f4^2*f6-24
*x3*x2*x5^2*f1*f4^2*f6-48*x3^2*x1^2*f0*f6^2*f4^3+48*x3^2*x4*x2*f7*f2*f6^2*f3*
f4-112*x3*x1^2*x5*f0*f4^2*f3*f7-16*x3*x1^2*x5*f3*f7*f2^2*f4+8*x2^2*x5^2*f1^2*
f7*f5+8*x1^3*x3*f6*f2*f5*f3^3-368*x4^2*x3^2*f7^2*f3*f4^2*f5-112*x4^2*x3^2*f0*
f6*f5^2*f7^2-232*x4^2*x3^2*f1*f5^2*f7*f6^2+208*x3^2*x4^2*f7*f2*f5^3*f6-240*x3^
2*x1*x4*f3*f6^2*f4*f1*f7+16*x3^2*x1*x4*f7^2*f3^2*f1*f6+4*x5^3*x2*f1*f4^2-4*x5^
3*x2*f7*f1^2+4*x5^3*x4*f7*f3*f1-120*x2^2*x1*x4*f6*f2*f5*f4^3+100*x2^2*x1*x4*f7
*f2*f5*f4^2*f3+16*x2^2*x1*x4*f0*f6*f5*f4*f3*f7+132*x2^2*x4*x6*f7*f4^2*f5*f2-4*
x2^2*x4*x6*f7*f3^2*f4*f5-2*x5^2*x7^2*f4^2+24*x1^3*x3*f3*f6*f4^3*f1+12*x2*x1*x4
*x6*f4^2*f5^2*f3-32*x3*x2^2*x7*f0*f6^2*f7*f3+32*x3*x2^2*x7*f0*f6*f7^2*f2+32*x3
^3*x1*f0*f5^3*f4*f7-8*x3*x1*x6*x8*f7*f2*f3*f6+96*x2^2*x3*x4*f6*f2*f5^3*f4+8*x3
^2*x2*x5*f7^2*f3*f2^2+12*x3^2*x2*x5*f7^2*f3^2*f1-36*x2*x5*x3^2*f4^2*f1*f7*f5+8
*x2^2*x1*x3*f3^3*f7*f4^2-96*x2*x1*x4*x6*f2*f5^3*f4+8*x3*x2^2*x7*f3^3*f6*f7+48*
x3^2*x2*x5*f4^2*f6^2*f1+44*x1*x6*x3^2*f5*f7^2*f1^2-4*x3^2*x1*x7*f4*f5^3*f3+24*
x3^2*x5*x7*f4^2*f5^2+144*x4^3*x1*f4*f5^3*f3*f7+432*x4^3*x1*f0*f4^2*f7^3-404*x4
^3*x1*f1*f7^3*f3*f4-88*x4^3*x1*f1*f7^3*f2*f5+4*x2^2*x6^2*f1^2*f7^2-32*x1^3*x2*
f0*f6*f4*f2^2*f7-4*x4^2*x3^2*f1^2*f7^4+32*x2^3*x3*f4*f0^2*f7^3+624*x4^2*x3*x7*
f0*f5*f7^3-32*x4^2*x3*x7*f7^3*f2*f3+192*x4^2*x3*x7*f7^2*f6*f5*f1-176*x4^2*x3*
x7*f7^2*f2*f5^2-444*x4^2*x3*x7*f7^2*f3*f5*f4+72*x4^2*x3*x7*f4*f7^3*f1+4*x2*x1*
x7^2*f1*f4*f7*f5-40*x2*x5*x3^2*f0*f5^2*f7*f4-96*x3^2*x2*x5*f0*f6^2*f5*f4-152*
x4^3*x1*f7^2*f2*f3*f5^2-24*x4^3*x1*f7^2*f3*f4^3+176*x4^3*x1*f7^2*f6*f5*f3*f1-\
56*x4^3*x2*f2*f7^2*f4^2*f6+96*x4^3*x2*f1*f5^2*f7*f6^2+312*x4^3*x3*f7*f6*f4^2*
f5^2-60*x3*x4^3*f7^3*f3^2*f4-80*x3^3*x6*f0*f5*f7^2*f4+16*x2^2*x7*x8*f7*f3*f5*
f4+200*x3*x4^2*x1*f6*f4*f5^2*f7*f1+168*x4^2*x1^2*f3^3*f5^2*f7-152*x4^2*x1*x7*
f7*f5^2*f6*f1+12*x1^3*x2*f1^2*f4*f7*f3*f5+16*x1^2*x3^2*f6^2*f2*f5*f1*f4-4*x1^2
*x2^2*f5*f4^4*f1-32*x1*x2*x3^2*f7*f2*f5^2*f3^2-28*x1*x2*x3^2*f5*f4^3*f1*f7+84*
x2*x1*x4^2*f7*f5^2*f4^2*f2-24*x2*x1*x3^2*f3^2*f6*f4^2*f5+8*x1^2*x3*x6*f1^2*f7*
f5^2-8*x1^4*f6*f4*f7*f1^3+8*x1^4*f0*f5^2*f4^2*f2-8*x1^4*f6*f2^3*f3*f5-24*x1^4*
f0*f5^3*f3*f2-64*x1^3*x3*f4^2*f0^2*f7^2-4*x2^3*x3*f5^2*f4^3*f3-4*x1^2*x3^2*f7^
2*f3^2*f2^2-16*x3^3*x4*f7^3*f2^2*f4-32*x2^2*x6^2*f1*f7*f4^2-16*x1*x5^2*x2*f7*
f0*f5*f1-8*x1*x5^2*x2*f7*f4*f1^2+16*x1*x5^2*x2*f7*f0*f4*f2-224*x3*x4*x5*x6*f0*
f6*f5*f7-160*x3*x4^2*x6*f7*f2*f5^2*f6+24*x4*x1*x6^2*f5^3*f2-24*x1^3*x3*f7*f3^3
*f1*f5-32*x2*x1*x3^2*f5^3*f6*f2^2+184*x3*x4*x1*x2*f1*f5^2*f7*f6*f2+8*x2*x1*x3*
x7*f5*f4^4-16*x2^2*x7*x8*f7^2*f0*f5+12*x2^2*x7*x8*f7^2*f1*f4+16*x2^2*x1*x4*f1^
2*f6*f7^2*f3+128*x3^2*x1*x2*f0*f6^2*f2*f7*f4+24*x3^2*x1*x2*f5^2*f4^3*f3+256*x4
*x5*x1*x3*f7*f1*f6*f4*f3-104*x3*x2*x4*x7*f7*f5*f4^3+336*x3*x2*x4*x7*f6*f4^2*f5
^2+24*x3*x1^2*x7*f7*f4*f3^3+1360*x4^2*x3^2*f0*f6^2*f7^2*f4-128*x4^2*x3^2*f1*f6
*f7^3*f2+64*x4^2*x3^2*f2*f7^2*f4^2*f6-44*x3^2*x4^2*f7^2*f6*f4*f3^2+160*x4^2*x3
^2*f7^2*f3*f5*f2*f6+144*x4^2*x3^2*f0*f6*f7^3*f3+76*x4^2*x3^2*f4*f5^2*f2*f7^2+
568*x4^2*x3^2*f0*f5*f7^3*f4-16*x1^3*x2*f0*f3^3*f5*f7+32*x3*x2*x4^2*f7^3*f2*f3^
2+224*x3*x2*x4^2*f7*f6^2*f4*f1*f5-64*x4^2*x1*x8*f7^3*f2^2+144*x4*x3*x7^2*f5*f6
^2*f4+48*x4*x1*x5*x7*f2*f5*f4*f6+16*x1^2*x3*x5*f4^2*f6*f2^2+36*x4^2*x1*x2*f5^5
*f2-96*x4*x2*x3*x8*f7^3*f0*f4+16*x2^3*x1*f0*f6*f5*f3*f7*f2+72*x4^3*x6*f7^2*f2*
f4*f6-312*x4^3*x6*f7^2*f6*f5*f1+64*x4^3*x6*f7^2*f3*f5*f4+48*x4^3*x6*f3^2*f7^2*
f6+376*x4^3*x6*f0*f5*f7^3-8*x4*x2*x5*x7*f7*f5*f3^2-12*x4*x2*x5*x7*f7*f2*f4*f5+
16*x4^2*x5*x2*f4*f6*f7*f3^2+16*x2^2*x1*x3*f5*f4^4*f3-8*x2^2*x1*x3*f7^2*f2^3*f4
+36*x2^2*x4*x8*f7*f3*f5^2*f4+8*x2^3*x8*f7*f1*f4^2*f6-16*x2^3*x8*f7*f0*f6*f5*f4
+32*x2^2*x6*x7*f0*f5^2*f7-68*x1^2*x2*x4*f7*f2*f5^2*f1*f4-136*x1^2*x2*x4*f5*f4^
2*f7*f3*f1+12*x2^2*x4*x7*f7^2*f3^3+16*x1*x5*x3*x7*f5^3*f1-24*x2*x5*x4*x7*f3*f6
*f2*f7+8*x2^2*x5*x8*f5^2*f7*f0+4*x1*x5^2*x7*f4^2*f2+32*x1^3*x2*f0*f6^2*f4^2*f1
-4*x4*x1*x6*x8*f7^2*f1*f4+64*x4*x1*x6*x8*f7^2*f0*f5-4*x1^4*f1*f3^4*f7-128*x3^2
*x4*x8*f7^2*f0*f6^2+32*x4*x3^2*x8*f7^2*f5^2*f2+28*x4*x1*x6*x7*f7*f3*f4^2-48*x4
*x1*x6*x7*f2*f6*f5^2+40*x4*x1*x7^2*f7^2*f1*f4+8*x4*x1*x7^2*f7^2*f2*f3-16*x1^4*
f3^2*f7^2*f0^2+40*x1^3*x3*f4*f7^2*f1^2*f2-24*x1^4*f0*f4^3*f7*f1-96*x4*x5*x1*x3
*f0*f6*f7^2*f1-32*x3^2*x2*x6*f4^2*f6*f1*f7-16*x2^3*x5*f0*f5*f4*f3*f7+36*x4*x3*
x5^2*f5^2*f3*f4+48*x4*x1*x2*x6*f7*f3^2*f4^2+32*x2^2*x1*x3*f0*f5^3*f2*f7+24*x2^
2*x1^2*f3^2*f5^2*f2*f4+8*x2*x1*x4*x8*f7^3*f1^2+288*x2*x1^2*x4*f4*f5^2*f1*f6*f3
-128*x1*x2*x4^2*f7^2*f0*f5^2*f3+48*x1^2*x2*x6*f0*f6*f7*f3*f2-20*x3^3*x6*f5^2*
f7*f3^2-40*x3^2*x2*x4*f7^3*f3^2*f1-24*x3^2*x2*x4*f7^2*f3^2*f4^2-76*x2*x4*x3^2*
f5*f4^4*f7-16*x2*x1^2*x4*f0*f4*f7^2*f3^2+32*x2^2*x1*x6*f0*f6*f3^2*f7-16*x1*x2*
x4^2*f7^2*f3^2*f6*f1+48*x2*x1*x5*x6*f3*f5*f2*f4-16*x2*x1*x3*x8*f5^3*f7*f0-48*
x2^2*x1*x4*f1*f6*f7*f4^2*f3+16*x2^2*x1*x4*f4^2*f6*f7*f2^2+160*x2^2*x1*x4*f0*f4
^3*f6*f7-168*x2^2*x1*x4*f7*f2^2*f5^2*f4+64*x3^2*x2*x5*f1*f5^2*f4*f6-16*x3^2*x2
*x5*f7*f3^2*f2*f6-64*x3^2*x2*x5*f4^2*f6*f2*f5-64*x3^2*x2*x5*f0*f4*f3*f7^2+12*
x3^3*x5*f5^2*f4^3-32*x4*x1*x2*x6*f2^2*f7*f4*f6-80*x4*x1*x6*x7*f1*f7*f4*f6-84*
x1^2*x2*x4*f7*f3^2*f1*f5^2-44*x1^2*x2*x4*f3*f5^2*f7*f2^2+32*x1^3*x2*f3^2*f7*f6
*f1^2-216*x4^3*x6*f6*f5^4+48*x4^3*x6*f7*f2*f5*f6^2-48*x4^3*x6*f7*f4^2*f6*f5-\
128*x2*x1*x3*x4*f1*f4*f7^2*f2*f5+64*x2*x1^2*x4*f1^2*f6^2*f7*f3+24*x2*x1*x3*x4*
f2*f7^2*f3^2*f4+32*x2*x1*x5*x7*f5^2*f1*f4+8*x2*x1*x4*x7*f7*f3*f6*f2*f4+12*x2*
x1*x3*x5*f3^2*f5*f4^2+20*x2*x1*x6^2*f7*f2^2*f4+24*x2*x1*x6^2*f1^2*f7*f6-64*x2*
x1*x3^2*f3*f6^2*f1*f4*f5+8*x2*x1*x3*x5*f3*f5^3*f1+8*x5^2*x1*x6*f0*f5*f4+8*x5^2
*x1*x7*f0*f5^2+32*x2*x3^3*f0*f6^2*f5*f3*f7+36*x4^2*x6^2*f5^4+24*x1^2*x3^2*f7*
f2^2*f3*f4*f6+24*x1^3*x2*f6*f5*f7*f1^3+8*x2^2*x3*x4*f7*f3^3*f5*f6-48*x3*x2*x4*
x5*f2*f5^4+32*x3^2*x1*x2*f0*f4^3*f6*f7-192*x3^2*x1^2*f4*f6*f0^2*f7^2-8*x1^3*x5
*f7*f2*f3^2*f1+32*x1^3*x5*f1*f4^2*f0*f7-16*x1^2*x3*x4*f0*f7^3*f2^2-8*x3*x2*x1*
x7*f7*f3^3*f5+12*x3*x1*x7^2*f7*f5^2*f1+240*x3*x1*x4^2*f7^2*f2*f3*f5*f4-128*x4^
2*x1*x3*f0*f5^2*f4*f7^2+20*x2^2*x1*x3*f5^3*f4^2*f1-16*x2^2*x1*x3*f0*f5*f3*f2*
f7^2-48*x1^2*x3^2*f0*f6*f7^2*f3*f1-4*x3*x2*x4*x8*f7^2*f1*f5^2+128*x3*x2*x4*x8*
f7^2*f2*f4*f5-160*x3*x2*x4*x8*f7^2*f0*f5*f6+64*x3*x2*x4*x8*f7^3*f3*f1+24*x3*x2
*x4*x8*f7^2*f1*f4*f6+20*x3*x1*x6*x7*f7*f2*f3*f5-16*x3*x1^2*x7*f0*f5^4+84*x4^2*
x2*x8*f7^2*f2*f5^2+4*x2*x8*f7^2*x4^2*f5*f4*f3+48*x3^4*f6^2*f2*f5^2*f4-14*x3^4*
f5^2*f4^2*f7*f3-24*x3^4*f7*f3*f4^3*f6-8*x3^4*f7^2*f3^2*f2*f6-18*x4^2*x5^2*f5^2
*f4^2+12*x1*x5*x7*x8*f7*f1*f5-144*x1*x6*x3^2*f0*f6*f5*f7*f3-48*x3^2*x1*x6*f1*
f5^4+32*x1^4*f0*f6*f5*f4*f3*f2+4*x2^2*x5^2*f4^3*f2+124*x1^3*x4*f3*f7*f4*f2^2*
f5+32*x1^3*x4*f7*f1*f5*f2^2*f6+8*x1^3*x2*f0*f5*f4^4-8*x2*x1*x6*x7*f4^4-144*x1^
3*x4*f0*f4*f7^2*f3*f2+96*x1^3*x4*f7*f1^2*f5*f6*f3+64*x1^2*x2*x4*f0*f5^2*f3*f7*
f4+172*x1^2*x2*x4*f7*f2*f3^2*f5*f4-4*x2^3*x7*f5^4*f1+176*x3*x4*x1^2*f6*f5^2*f7
*f1^2+8*x1^2*x3*x4*f5*f2^3*f7^2+16*x1^3*x4*f2^3*f6*f7*f4-48*x3^3*x6*f0*f6*f7^2
*f3-16*x2*x1*x5^2*f1*f4*f3*f5+64*x2*x1^2*x3*f0*f7^3*f1^2+16*x2*x1*x3^2*f3*f5^4
*f2+48*x2*x1*x4*x6*f1*f5^4+144*x2*x1*x4*x6*f0*f6*f5^3+20*x1^2*x4*x6*f7*f1*f4^3
+16*x1^3*x4*f0*f5*f7^2*f2^2-96*x1^3*x4*f0*f5*f4^3*f6+8*x1^2*x2*x4*f2^3*f7^2*f4
+36*x2^2*x4^2*f3^2*f5^3*f7-32*x3*x4*x5*x7*f7*f6*f2*f4+112*x3*x4*x5*x7*f7*f5*f1
*f6-96*x4*x3*x5*x7*f7*f5^2*f2-144*x4*x3*x5*x7*f5^2*f3*f6-16*x1^3*x7*f3*f6*f2^2
*f5-12*x1^3*x7*f5*f4^2*f2*f3-16*x1^3*x7*f0*f6*f7*f3*f2+16*x1^3*x7*f6*f2*f5*f1*
f4+24*x2*x1*x6*x8*f7*f0*f5^2+64*x2^2*x1*x3*f6^2*f0^2*f7*f5-16*x4^2*x6*x7*f7*f4
^2*f6-8*x6^2*x2*x3*f7*f3^2*f4+4*x1*x7^2*x2*f5^2*f3*f4-16*x2^2*x7^2*f0*f6*f5*f7
+8*x3^2*x2*x5*f7*f3^2*f4^2-8*x5^3*x2*f0*f5*f4+8*x5^3*x3*f0*f5^2+8*x5^3*x3*f1*
f4*f5-32*x5^3*x3*f0*f6*f4+144*x3^2*x2*x4*f5^2*f4^3*f6-40*x3^2*x2*x4*f7^2*f2^2*
f6*f4+12*x3^3*x5*f7*f3*f4^3-16*x3^3*x5*f1*f5^2*f7*f4+72*x3^2*x4*x5*f4^2*f5^3+
16*x1*x6^2*x2*f0*f5*f7*f3-60*x1^2*x2*x3*f1*f4*f7*f3^2*f5-80*x4*x1*x6*x7*f0*f7^
2*f4+16*x4*x1*x6^2*f7*f2^2*f6-120*x4*x1*x6^2*f0*f7*f5^2-640*x4^2*x1^2*f0*f6*f5
^2*f3*f7+16*x2*x1*x3*x8*f5*f7*f4^2*f2-24*x2*x1*x5*x6*f3^2*f4^2-64*x2*x1^2*x4*
f1*f4*f6*f7*f3^2+10*x1^2*x6^2*f4^2*f3^2-40*x3*x6*x7^2*f4*f5*f6+16*x3*x6*x7^2*
f7*f3*f5-4*x2*x6*x7^2*f4*f5^2-16*x4*x5*x2^2*f2^2*f6*f7*f4+64*x3*x1^2*x5*f0*f5*
f4*f7*f2-24*x3*x1^2*x5*f2*f7^2*f1^2+24*x3*x1*x4*x7*f3^2*f7*f6*f4-8*x3*x1*x2*x5
*f1*f4^3*f6+16*x1^3*x2*f6*f3*f5^2*f1^2+24*x1^2*x2*x4*f5^2*f4^3*f2-28*x1^2*x5*
x7*f1^2*f7*f5-24*x3^2*x2*x5*f4*f5^3*f2+96*x3^3*x5*f6^2*f4*f1*f5+28*x3^3*x5*f3^
2*f5*f4*f7-16*x3^3*x5*f5^3*f6*f1+96*x3^3*x5*f0*f6^2*f5^2-16*x1^3*x2*f0*f6*f4^3
*f3+32*x1^2*x2*x5*f7*f6*f0*f3*f1-64*x1^3*x3*f6*f0^2*f7^2*f2-32*x1^3*x5*f0*f6*
f4^2*f2+16*x2^3*x3*f0*f5^3*f3*f7-16*x2*x1^2*x3*f6*f7^2*f1^3+76*x2*x1*x3*x4*f7^
2*f2^2*f5*f3-8*x2^2*x1^2*f0*f5^4*f2-8*x2^2*x1*x6*f7*f2^3*f6-72*x2*x1*x4^2*f6*
f5^4*f1+16*x2^2*x1*x3*f0*f7^3*f1*f2-32*x3^2*x2*x6*f2^2*f7^2*f4+20*x3^2*x2*x6*
f1*f7^2*f3*f4+24*x3^2*x2*x6*f7*f3^2*f5*f4-256*x3*x2*x4^2*f6^2*f2*f1*f7^2-32*x3
*x2*x4^2*f7^2*f3^3*f6-28*x3*x2*x4^2*f7^3*f1*f3*f4+256*x3*x2*x4^2*f7^3*f0*f5*f3
-320*x3*x2*x4^2*f7^2*f4^2*f6*f1-64*x2^2*x4*x6*f7^2*f3*f4*f1+16*x2^2*x4*x6*f0*
f5*f3*f7^2-112*x2^2*x4*x6*f0*f6*f5*f4*f7+48*x2*x1^2*x4*f0*f4^3*f5*f7-8*x2*x1^2
*x3*f4*f1*f7^2*f2^2-8*x2*x1^2*x3*f7*f2^3*f5^2-16*x2*x5*x3*x8*f7*f4^2*f3+16*x3*
x5*x1*x7*f3*f6*f2*f5-32*x4^2*x7*x5*f6^2*f1*f7-32*x3*x1*x4^2*f7^2*f2^2*f5^2+24*
x3*x1*x2*x7*f7*f3^2*f2*f6-128*x1^3*x3*f6^3*f0^2*f4+112*x1*x6*x3^2*f5^2*f1*f3*
f7-32*x3^2*x1*x6*f4*f6^2*f2*f3-96*x3^2*x1*x6*f0^2*f7^3-32*x4*x1^2*x5*f3^2*f6*
f0*f7+144*x4*x1^2*x5*f0*f5^2*f6*f3-28*x4*x1*x5*x6*f7*f1*f4^2-32*x4^2*x1^2*f0*
f5^3*f7*f4+120*x4^2*x1^2*f0*f4^3*f7^2-32*x4*x1*x3*x8*f7^2*f2^2*f6+32*x3*x6*x2*
x4*f0*f7^3*f2-144*x4*x1*x5*x6*f0*f6*f5^2+72*x4*x1*x5*x6*f7*f2*f3*f4-28*x2^3*x3
*f7*f2*f5*f4^2*f3+16*x2^3*x3*f7^2*f3*f4*f2^2-12*x1^3*x4*f5^3*f1*f4*f3+32*x1*x5
^2*x2*f7*f6*f0^2+36*x4*x5^2*x7*f3*f5^2-8*x5*x4*x6*x7*f7*f3*f4-8*x1*x5^2*x2*f7*
f0*f3^2-4*x2*x5^2*x7*f7*f2^2-12*x1^2*x5^2*f1^2*f6*f4+6*x1^2*x5^2*f3*f7*f1^2+32
*x2^3*x3*f0*f6*f5*f4*f3*f7-16*x1^3*x2*f1*f4*f7*f3^3+88*x4^2*x3*x5*f7*f5^2*f3*
f4+4*x1^2*x6*x7*f3^2*f5*f4-12*x4^2*x5^2*f2^2*f7^2-28*x2^2*x5*x7*f4^2*f1*f7+2*
x6^4*f4^2+4*x1^3*x7*f7*f2*f3^3+32*x2^2*x1^2*f4^2*f0^2*f7^2-32*x2^2*x1*x3*f7*f2
*f5^2*f1*f4+48*x2*x1^2*x6*f3*f4^2*f1*f6-24*x2*x7*x3^2*f3*f5*f2*f6*f7+20*x2^2*
x1*x6*f3*f5*f7*f2^2+36*x3^2*x1*x4*f5^3*f4^3+16*x4^2*x2*x7*f4^3*f7*f6-52*x4*x1^
2*x5*f7^2*f3*f1^2+8*x4*x1^2*x5*f7*f6*f2^3+8*x3^2*x2*x5*f7*f2^2*f4*f6+124*x3*x1
*x4*x6*f7*f4^2*f5*f2+8*x1^2*x4^2*f7*f3*f5^3*f1+16*x1^3*x3*f7^2*f3^2*f1^2+16*x3
^2*x1^2*f0*f5*f6*f3^2*f7+4*x3^2*x1^2*f5^4*f2^2-16*x3^2*x2*x4*f3^3*f6^2*f7+8*x3
*x2*x5*x6*f7*f2^2*f5+32*x3*x2*x5*x6*f5^2*f2*f4+48*x3^2*x1*x4*f7^2*f3^2*f2*f5-\
192*x3^2*x1*x4*f0*f6^2*f5^3-4*x2^3*x4*f1*f7^2*f2*f4*f5-4*x2^2*x3*x4*f7^2*f3^3*
f4-64*x1^3*x4*f0*f6*f7^2*f1*f2+96*x1^3*x4*f5*f4^2*f1*f6*f3-4*x2^3*x4*f7^2*f2^2
*f4^2+40*x3*x4*x1^2*f6*f7^2*f3*f1^2+448*x1^2*x2*x4*f0*f6*f5*f2*f7*f4-80*x1^2*
x2*x4*f6*f2*f5*f7*f3*f1-64*x1^4*f0*f5*f4*f3*f7*f1+8*x6^3*x1*f2*f4*f5-8*x6^3*x1
*f4^2*f3+16*x6^3*x1*f7*f0*f4-8*x6^3*x2*f7*f0*f5+16*x6^3*x2*f7*f1*f4-16*x1^2*x2
*x4*f0*f5*f1*f7^2*f4-352*x1^2*x2*x4*f0*f5*f7^2*f3*f2+8*x1*x2^2*x7*f1^2*f7*f6*
f5+104*x1*x2*x4^2*f7^2*f1^2*f6*f5-16*x2*x1^2*x5*f2*f5^2*f1*f4-96*x2*x1^2*x5*f5
^2*f0^2*f7+16*x1^4*f0*f6*f4*f2*f7*f1-24*x4*x3*x6*x7*f7*f4^2*f5-48*x3*x4*x6*x7*
f7*f2*f5*f6+96*x4*x3*x5*x7*f5^3*f4+32*x4*x3*x5*x7*f4^3*f7-44*x4*x3*x5*x7*f4*f7
^2*f1+32*x1^3*x2*f0*f5^2*f2^2*f7-76*x4^2*x5*x8*f7^2*f2*f5-64*x4^2*x5*x8*f7^2*
f1*f6-96*x4^2*x5*x8*f7*f4*f5^2-24*x4^2*x6*x8*f7^2*f3*f5-36*x4^2*x6*x8*f7^3*f1-\
4*x2^3*x6*f7*f3^3*f4-8*x2^3*x5*f0*f3*f7^2*f2+36*x1^2*x4^2*f7*f5*f4^3*f2-16*x3*
x1*x7^2*f4*f6^2*f2-16*x3*x1*x7^2*f7*f2*f5*f4+24*x3*x2*x5*x7*f5*f4^3-56*x1^2*x2
*x6*f1^2*f7*f6*f3+44*x2^2*x4^2*f7^2*f2^2*f4*f6+8*x2^2*x4^2*f7^2*f2*f1*f5*f6+8*
x4^2*x2^2*f0*f6*f4^2*f7^2+96*x1^3*x3*f0*f6^2*f4^2*f2-2*x2^4*f4^2*f7^2*f1^2-2*
x1^4*f5^2*f4^2*f1^2-8*x3*x2*x5^2*f1*f7*f3*f4+64*x3*x1^2*x5*f0*f6^2*f1*f5+48*x3
*x1*x6^2*f5^3*f1+8*x3*x1^2*x5*f7*f2*f3^3+4*x2^3*x5*f3*f4^4+56*x2*x1^2*x3*f3^2*
f5*f6*f2*f4+16*x2^2*x1*x5*f7*f1*f2^2*f6-16*x2*x1^2*x3*f6^2*f2*f1*f4^2+16*x2*x1
*x6*x8*f7^2*f2*f1+8*x1*x2^2*x7*f7^2*f2^3+32*x1^3*x2*f6*f5^3*f0^2-16*x1^2*x2*x7
*f5^2*f4^2*f1+8*x1^2*x2*x7*f5*f4^3*f2-32*x3^2*x2*x8*f7*f0*f6^2*f5+8*x3^2*x2*x8
*f7^2*f2*f4^2-64*x3*x2*x1*x5*f7*f6^2*f0^2-48*x3*x1*x6*x7*f0*f6*f7*f4+24*x3*x1*
x6*x7*f4^2*f6*f3-32*x3*x1*x6*x7*f0*f5^2*f7-32*x3*x1^2*x5*f0*f5^2*f4^2-16*x3^2*
x2^2*f6^2*f7*f1^2*f5+320*x4*x1^2*x7*f0*f4*f3*f7^2-8*x4*x2^2*x7*f1*f7*f6*f4*f5-\
128*x4^2*x5*x2*f4*f6*f1*f5*f7+176*x4^2*x5*x2*f1*f7*f5^3+192*x4^2*x5*x2*f4^2*f1
*f7^2-8*x4*x1*x7*x8*f7^2*f2*f4+72*x4*x1*x5*x6*f1*f5*f4*f6+24*x3^2*x1*x6*f7*f3^
2*f2*f6+80*x3^2*x1*x6*f0*f4*f3*f7^2+44*x3^2*x1*x7*f7^2*f3*f4*f1+4*x3^2*x6*x7*
f4*f7^2*f1+64*x4*x2*x6^2*f0*f4*f7^2-80*x4*x3*x5^2*f4*f5*f7*f1-32*x4*x2*x6^2*f7
*f4*f6*f1+48*x4*x2*x6^2*f0*f6*f5*f7-48*x4*x3*x5*x6*f5^2*f4^2+36*x4*x1*x2*x5*f5
*f4^3*f3-32*x3*x4^2*x7*f6^2*f2*f7*f5-64*x4^2*x7*x3*f0*f6^2*f7^2-24*x7^2*x2*x4*
f4^2*f7*f5+120*x4*x3*x7^2*f7*f4*f5^2-80*x4*x3*x7^2*f7^2*f2*f5+8*x4*x6*x3*x7*f7
^2*f4*f2-4*x6^2*x8*f7*x3*f3*f5-36*x3*x6*x4*x8*f7*f4*f5^2-2*x6^4*f7*f1-52*x2^3*
x4*f7*f2*f5*f4^3+32*x3*x1*x2*x6*f0*f6*f4*f3*f7+16*x3*x1*x2*x6*f7*f2*f4*f1*f6+
16*x3^2*x1*x8*f7*f4^2*f2*f6-8*x3^2*x1*x8*f7^2*f2^2*f5-8*x3*x2*x6*x8*f7*f6*f3^2
-24*x3*x2*x6*x8*f7*f2*f4*f6-32*x3*x2*x6*x8*f7*f6*f1*f5-48*x3^3*x5*f4*f5^2*f6*
f2-24*x3^3*x5*f3*f4^2*f6*f5-32*x3^3*x5*f7^2*f3*f0*f5+12*x5^3*x4*f1*f5^2-64*x4*
x5^3*f7*f0*f4-8*x5^3*x1*f0*f4^2-8*x3*x1^2*x5*f1^2*f6*f7*f3-64*x3^2*x2*x6*f0*f6
^2*f3*f7+12*x3*x1*x6*x8*f7^2*f2^2-8*x3*x1*x6*x8*f7*f1*f4*f6-20*x3*x1*x6*x8*f7*
f1*f5^2-24*x1^3*x3*f4^3*f2^2*f6-4*x3^2*x2*x8*f7^2*f2*f5*f3+144*x3*x1*x4*x7*f7*
f4*f6*f1*f5-16*x3*x1*x4*x7*f7^2*f2*f1*f6+40*x3*x1*x4*x7*f5^3*f7*f1+4*x3*x2*x5*
x8*f7*f3^2*f5+8*x3*x1*x4^2*f7*f2*f5*f4^2*f6-32*x6*x1*x2*x7*f7^2*f1^2-32*x4*x6*
x7^2*f7*f4*f5-28*x1^2*x6*x7*f7*f4*f2^2-20*x1^2*x6*x7*f3^2*f7*f2-16*x1^2*x6^2*
f0*f5*f7*f2+16*x4^2*x2*x6*f7*f3^2*f5*f6-176*x4^2*x2*x6*f7*f2*f5^3+56*x4^2*x2*
x6*f5*f4^3*f7-140*x4^2*x2*x6*f4*f5*f7^2*f1+432*x4^2*x1*x6*f0*f6*f5^2*f7+192*x1
*x6*x4^2*f3*f7^2*f1*f5+56*x4^2*x1*x6*f7*f2*f5*f3*f6+8*x1^4*f6*f4^2*f2^3-160*x2
^2*x1*x3*f0*f5*f4*f1*f7^2+16*x2^2*x1*x3*f0*f6*f3*f1*f7^2-8*x4*x5*x1*x2*f6*f2^2
*f7*f3-4*x2^2*x1*x4*f7^2*f2*f1*f4^2-2*x2^2*x1^2*f3*f5^3*f2^2+26*x2^2*x3^2*f5^2
*f4^4-16*x2*x1^2*x3*f0*f6*f5^3*f2-28*x2*x1^2*x5*f2*f3^2*f4*f5-64*x2^2*x1^2*f6*
f5*f0^2*f7*f4-12*x2*x1*x7*x8*f7*f5^2*f1-96*x2*x1*x3*x4*f7*f2^2*f5^3-24*x2*x1^2
*x3*f3*f7^2*f2^3+16*x1^4*f0*f6*f5^2*f3*f1+8*x1^2*x2*x3*f7*f2^2*f3^2*f6+16*x2^2
*x1*x5*f0*f4^2*f3*f7-48*x2^2*x1*x5*f0*f4^3*f6-16*x2^2*x1*x5*f7*f3^2*f1*f4+32*
x2^2*x1*x5*f0*f6*f7*f1*f4+4*x2*x1^2*x7*f4^4*f3+4*x2^3*x6*f7*f3^2*f2*f5+40*x2*
x1*x3^2*f2^2*f3*f7^2*f4+96*x1*x2*x3*x6*f0*f4*f2*f7^2+80*x2*x1*x6*x7*f4^2*f2*f6
+44*x2*x1*x6*x7*f7*f4^2*f1+8*x2*x1*x6*x7*f7*f2*f1*f6-48*x2*x1*x6*x7*f0*f7*f4*
f5+12*x3^2*x6^2*f3*f5^3+16*x3^2*x2*x7*f4^2*f5^3-8*x1^3*x2*f4^3*f2^2*f5-24*x2^2
*x4*x7*f3*f5*f6*f2*f7+48*x2^2*x3*x4*f5*f4^4*f6+36*x2^2*x3*x4*f5^3*f4^3+4*x2^4*
f7^2*f2^3*f4-108*x4^2*x2*x5*f5^4*f3-64*x4^2*x5*x3*f3*f5*f2*f7^2+352*x4^2*x5*x3
*f0*f5^2*f7^2+112*x4^2*x5*x1*f0*f6*f5*f4*f7-44*x4^2*x5*x1*f7*f4^2*f2*f5-16*x4*
x1*x7^2*f7*f2*f4*f6+12*x2*x1*x7*x8*f7*f5*f2*f4+8*x2*x1*x3*x4*f1^2*f7^2*f5^2-8*
x2*x1^2*x4*f7*f2^3*f5*f6-12*x2^2*x3*x4*f7*f4^5-392*x4^2*x5*x6*f0*f5*f7^2-148*
x4^2*x5*x6*f4*f7^2*f1-36*x4^2*x5*x6*f5^3*f4+72*x4^2*x5*x6*f7^2*f2*f3+112*x4^2*
x5*x6*f7*f6*f5*f1+188*x4^2*x5*x6*f7*f2*f5^2-8*x3*x4*x1^2*f6*f2^2*f7*f4^2-88*x4
*x5*x3^2*f1*f7*f5^3+4*x3^3*x5*f4*f5^3*f3+4*x3^3*x5*f3*f5^2*f7*f2-4*x3^3*x5*f7^
2*f3*f4*f1+8*x2^2*x3^2*f7*f3^2*f6*f2*f5+24*x1^3*x4*f1^2*f4*f7^2*f3+24*x2^2*x3^
2*f0*f4^3*f7^2+96*x3^3*x4*f6^2*f2*f5^3-256*x3^3*x4*f0*f6^2*f5^2*f7+144*x3^3*x4
*f4*f5^2*f3*f6^2+24*x3^2*x1*x4*f5^5*f2+10*x1^4*f1*f4^2*f7*f2^2-8*x2*x1*x7^2*f1
*f7^2*f2-40*x2^2*x3^2*f7^2*f2*f6*f1*f3-130*x2^2*x4^2*f5^4*f1*f7-8*x1^3*x2*f3^4
*f5*f4-16*x4^2*x6*x8*f7^2*f2*f6+72*x4^2*x7*x8*f7^3*f2+224*x4^2*x7*x8*f7^2*f4*
f5-20*x4^2*x6*x8*f7^2*f4^2+24*x2*x8*f7^2*x4^2*f4^3-24*x1^3*x4*f6*f2*f5*f3^2*f4
+48*x1^3*x4*f5^2*f2*f1*f4*f6-32*x2^2*x3*x5*f5^2*f4^2*f2-16*x1^3*x3*f6*f2^3*f5^
2+24*x3^2*x5*x8*f7^2*f0*f5+36*x1^2*x3*x7*f1*f4^3*f7+8*x1^2*x5*x7*f4^2*f1*f5+16
*x1^2*x5*x7*f3*f5^2*f1-72*x2^2*x3*x4*f5^2*f4^2*f7*f2+4*x1^2*x2*x3*f3*f5^2*f2*
f4^2-16*x1^2*x3*x7*f3*f5*f2*f4*f6+48*x1^4*f0*f3*f2*f7^2*f1+184*x2^2*x4^2*f7*f2
*f5^3*f4+128*x1^3*x4*f5*f0^2*f7^2*f4-68*x1*x4^2*x2*f5*f4^3*f7*f3-48*x4*x1*x2*
x5*f0*f5^4-32*x4^2*x1*x6*f1^2*f7^3+84*x4^3*x2*f7^3*f3*f4*f2-144*x4^3*x2*f7*f3*
f5^2*f6*f4+8*x1^3*x7*f3^2*f5*f1*f6-32*x2^2*x1*x3*f5^2*f4*f6*f2^2+64*x2*x3^3*f0
*f5*f1*f7^3-8*x2^2*x5^2*f1*f4^2*f5+192*x3^2*x2*x4*f0*f4*f3*f7^3+48*x3^2*x2*x4*
f7^2*f3^2*f2*f6-120*x2*x4*x3^2*f3^2*f5*f6*f7*f4-8*x1*x5^2*x7*f7*f2*f1+32*x1^2*
x5^2*f0*f6*f4*f2+48*x1*x5*x2*x7*f1*f0*f7^2-16*x1*x5*x2*x6*f0*f4*f3*f7-16*x4*x1
*x3*x8*f7^2*f0*f5^2-68*x4*x1*x5^2*f1*f7*f3*f4+48*x1*x5^2*x3*f4^2*f6*f0+32*x2^2
*x4*x7*f2*f0*f7^3-60*x2^2*x4*x7*f5^3*f7*f1-32*x4*x1^2*x6*f0*f6*f5*f2*f7-32*x1*
x4^2*x3*f6^2*f2^2*f7*f5-64*x3*x4^2*x6*f7*f3*f5*f4*f6+64*x4*x1^2*x5*f7*f6^2*f0^
2+8*x2^2*x1*x3*f4*f6*f1^2*f7*f5-24*x2^2*x1*x3*f1*f5*f7^2*f2^2+8*x2^2*x1*x3*f3^
2*f5^2*f1*f7-16*x3*x1*x6^2*f4*f6*f1*f5-16*x3^2*x2^2*f1*f6*f5^3*f4+4*x2*x5^2*x8
*f7*f1*f4-4*x2*x5^2*x8*f7*f2*f3-4*x1*x5*x2*x8*f7*f4^2*f1-16*x1*x5*x3*x6*f6*f7*
f1^2+12*x1*x5*x3*x6*f7*f4*f2^2+32*x1*x5^2*x3*f0^2*f7^2-8*x3^2*x5*x8*f7*f5^2*f2
-12*x1*x5*x3*x6*f3^2*f7*f2+8*x3^4*f3^3*f6^2*f7+64*x2*x1^2*x3*f6*f0^2*f7^2*f3+
40*x2*x1*x3*x7*f2*f5^3*f4+4*x2*x1*x3*x7*f4^2*f5^2*f3-56*x1*x2*x3*x6*f1^2*f7^2*
f4-80*x2*x1*x3*x6*f4*f5^3*f1-32*x2*x1*x6*x7*f2*f5^2*f4-16*x2^2*x1*x5*f7*f0*f6*
f3*f2+16*x3*x1*x4^2*f2^2*f7^3*f3-8*x3*x2*x6*x8*f7^2*f1*f4+8*x3*x2*x6*x8*f7^2*
f2*f3-12*x1^3*x2*f7*f2^3*f3*f5-32*x1^3*x2*f4*f7^2*f1^3-16*x1^4*f2*f6*f1*f4^2*
f3+16*x2*x1^2*x7*f4^3*f6*f1+8*x2^2*x1^2*f3*f6*f7*f2^3+48*x2*x1^2*x3*f7^2*f2*f1
*f3^2+16*x2*x1^2*x5*f2*f0*f5^3+8*f7*x3*x8^2*x6*f5^2+16*f7^3*x2*x8^2*x3*f0-4*x3
*x5^2*x7*f7*f2*f3+12*x1*x5^2*x4*f4^2*f2*f5-24*x1*x5^2*x4*f4*f1*f5^2-8*x3^2*x5*
x7*f4^3*f6+48*x4*x5^2*x1*f1*f7^2*f0-64*x3*x4*x2^2*f6*f4*f5*f7*f2*f3-64*x3*x1^2
*x5*f0^2*f6*f7*f5+88*x3*x1*x4*x8*f7^2*f6*f1*f3-432*x3*x2*x4^2*f7*f5^3*f6*f1-\
224*x3*x2*x4^2*f7^3*f1*f2*f5-48*x1^2*x2*x4*f1*f4^2*f7*f2*f6+40*x1^2*x2*x4*f7*
f2^2*f3*f4*f6+16*x1^3*x3*f0*f6*f3^2*f5^2+32*x1^2*x2*x5*f7*f3*f1*f2*f4+24*x5^2*
x2*x6*f0*f5^2-8*x5^2*x2*x6*f4^2*f2-16*x5^2*x3*x6*f2*f4*f5+48*x5^2*x3*x6*f0*f5*
f6+24*x5^2*x3*x6*f1*f4*f6-8*x3*x7^2*x5*f7*f2*f5-8*x3^2*x7^2*f7^2*f4*f2+2*x5^2*
x7^2*f7*f1+4*x5*x7*x3*x8*f1*f7^2+32*x4*x5^2*x1*f7*f0*f3*f5-96*x1^2*x5*x7*f0*f4
*f3*f7-4*x1*x5^2*x3*f1^2*f7*f5-4*x1*x5^2*x3*f1*f5^2*f3+8*x2*x5*x4*x6*f3*f6*f1*
f7+36*x4*x5*x7^2*f5^3-4*x2^3*x6*f2^3*f7^2+8*x1^2*x3*x7*f7*f2^2*f3*f6-16*x2^2*
x1^2*f1*f6*f0*f5^3-12*x2*x1^2*x5*f2*f4^3*f3-128*x2*x1^2*x3*f6^2*f0^2*f7*f4+48*
x2*x1*x3^2*f7*f3*f4^2*f1*f6-96*x3^3*x4*f1*f6^3*f5^2-64*x3^3*x4*f6^2*f2*f1*f7^2
-32*x3^3*x4*f1*f0*f7^4+64*x1^3*x4*f0*f6^2*f7*f3*f1+96*x1^3*x4*f0*f3^2*f6*f7*f4
-64*x3^2*x1*x2*f0*f5^2*f1*f7^2-96*x3*x4*x2^2*f0*f6*f5^2*f4*f7+4*x6*x8^3*f7^2+
24*x1^2*x6^2*f0*f6*f5*f3+8*x2^2*x3*x6*f7*f3*f5^2*f1-64*x1^2*x2*x7*f0*f6*f1*f7*
f5-18*x2^2*x1^2*f5*f4^2*f3^3-64*x2*x1^2*x3*f0^2*f7^3*f2-24*x2*x1^2*x3*f4^2*f6*
f3^3-4*x2^3*x1*f7^2*f2*f3^2*f1+8*x2*x1^2*x3*f7*f3^4*f4-4*x2^3*x1*f7*f2*f5*f3^3
+8*x3^2*x1*x7*f5^4*f2-12*x3^4*f4*f5^3*f7*f2-4*x3^4*f1*f7^2*f3*f5^2+44*x3^4*f0*
f5^2*f4*f7^2+8*x2^2*x1*x6*f5^3*f2^2+36*x4^2*x1*x5*f5^2*f4^3+8*x4*x3*x6^2*f7^2*
f2*f3-64*x4*x3*x6^2*f7*f5^2*f2-168*x4^3*x2*f7^3*f2*f1*f6+64*x2^2*x4*x7*f1*f7^2
*f4^2+16*x2^2*x4*x7*f7^2*f2*f3*f4+4*x1^4*f6*f4^3*f1^2+32*x3^2*x1*x2*f0*f3*f1*
f7^3+96*x3^3*x1*f0*f6*f4*f2*f7^2-64*x3^3*x1*f0*f6*f5^4+6*x3^2*x2^2*f7^3*f2^2*
f1-16*x3^3*x2*f1^2*f6*f7^2*f5-24*x3*x1*x4*x6*f1*f7*f4^2*f6+28*x3*x1*x4*x6*f7*
f4^3*f3-32*x3*x1^2*x7*f7*f3^2*f1*f6+16*x4^2*x1*x2*f7*f2^2*f4*f6^2-4*x2*x5*x3^2
*f5^2*f7*f2^2-64*x3^2*x1^2*f0*f6^3*f5*f1+8*x3^2*x1^2*f7^3*f1^3+14*x3^2*x1^2*f5
*f4^4*f3-16*x3*x1*x4*x8*f7^3*f2*f1-88*x3*x2*x4*x6*f7*f2*f4^2*f6+76*x4^2*x2*x8*
f7^3*f4*f1-96*x2^2*x1*x6*f0*f6*f5*f4^2-8*x2^2*x3*x5*f1*f7*f3*f5*f4+4*x1^4*f2*
f4^3*f3^2-48*x2*x1*x4*x6*f1^2*f6^2*f7-12*x2*x1*x6^2*f3^2*f5*f4+24*x1^3*x4*f3^2
*f5^2*f1*f6-48*x1^3*x4*f0*f5*f7^2*f3*f1+12*x2*x1*x3*x4*f5^3*f4^2*f3-24*x1^2*x2
*x3*f2*f5*f7^2*f1^2+92*x2^2*x4*x7*f4*f5^2*f2*f7+72*x2^2*x4*x7*f4^3*f6*f5-16*x2
^2*x4*x7*f2*f7*f4^2*f6+32*x2^2*x3*x5*f5*f4^2*f1*f6+64*x1^3*x4*f0*f5*f4^2*f3*f7
-96*x1^3*x4*f1*f4*f7*f3^2*f5-32*x2^3*x1*f0*f6*f5*f7*f1*f4+8*x2^3*x1*f4^5*f3+48
*x1^2*x4*x6*f7^2*f0*f4*f2+8*x1^3*x2*f3*f5*f4^3*f1-48*x1^2*x3^2*f1*f7^2*f5*f2^2
-4*x1^3*x7*f5*f4^3*f1-8*x1^2*x2^2*f0*f6*f4^2*f1*f7+32*x1^2*x2^2*f7^2*f3*f0*f4*
f1+20*x2^2*x3*x5*f7^2*f2*f1*f3+8*x2^3*x6*f0*f5^4+4*x2^2*x5*x6*f4*f5^2*f1+8*x2^
2*x5*x6*f7*f2^2*f4+64*x1^3*x3*f0^2*f7^3*f1-8*x2^3*x7*f7*f2^2*f5^2-12*x2^3*x7*
f1^2*f7^2*f5-32*x2^3*x7*f7*f2*f4^3+16*x1^3*x2*f0*f5^2*f3*f1*f7-8*x3*x2*x5*x6*
f4^4-80*x2*x1*x4*x6*f7^2*f1^2*f5+176*x2*x1*x4*x6*f7*f4^2*f5*f1-60*x2*x1*x4*x6*
f7^2*f1*f3^2-36*x1^2*x2*x7*f7*f1*f4^2*f3-32*x2^2*x3*x4*f0*f6^2*f5*f3*f7-112*x2
^2*x3*x4*f0*f5^4*f7-32*x2^2*x1^2*f3*f0^2*f7^2*f5-16*x2*x1^2*x6*f0*f6*f5^2*f2-\
96*x2*x1^2*x6*f0*f6*f5*f4*f3+80*x4*x5*x1*x2*f7*f5*f4*f2^2-64*x4*x5*x1*x2*f7*f3
*f4^2*f2+96*x1^3*x4*f0*f6^2*f5*f2*f4-96*x1^3*x4*f0*f6^2*f5^2*f1+16*x3^4*f0*f4*
f3*f7^3+72*x3^4*f0*f6*f5*f3*f7^2-128*x1^3*x2*f6^2*f5*f4*f0^2+64*x2^3*x1*f4*f6^
2*f0^2*f7-32*x3*x1^2*x6*f0*f6^2*f5*f2+48*x3*x1^2*x6*f0*f6*f5^2*f3+16*x2^3*x7*
f0*f6*f4^2*f7-16*x3*x1*x5*x7*f7*f2*f3*f4-4*x3*x1*x5*x7*f5*f4^2*f3+48*x3^2*x2*
x6*f6^2*f2*f1*f7+288*x3*x1^2*x4*f5*f4*f6^2*f1*f3+48*x2^2*x1*x4*f0*f3*f1*f7^3-4
*x2^2*x1*x4*f7*f3^3*f5*f4-28*x2^2*x3*x6*f2*f7^2*f1*f4-24*x5^2*x4*x6*f5^2*f2+48
*x5^2*x4*x6*f7*f1*f4+104*x5^2*x4*x6*f7*f0*f5-8*x5^3*x6*f0*f5-20*x4^2*x1*x3*f7^
2*f3^3*f5+24*x4*x2*x5^2*f2*f5^2*f4-72*x4^2*x1^2*f3^2*f5^4-156*x4^3*x2*f1*f7^3*
f4^2+280*x4^3*x2*f1*f7^2*f6*f4*f5+132*x4^3*x2*f4*f5^2*f2*f7^2+272*x4^2*x2*x6*
f7*f3*f4*f5^2+96*x1*x4^3*f0*f6*f2*f7^3-24*x4*x1*x7^2*f7*f6*f1*f5-16*x1^2*x2*x3
*f0*f4^2*f6*f2*f7-8*x2^3*x3*f4*f5^2*f1*f3*f7-32*x1^3*x2*f6*f5*f4^2*f1^2-16*x1^
3*x4*f7*f3^3*f1*f6+12*x3^2*x1*x7*f7^2*f2*f3^2-48*x3^2*x1^2*f0*f5*f4^3*f7+120*
x3*x1*x4^2*f3^2*f5^3*f7-16*x3*x1^2*x5*f3^2*f4*f6*f2+40*x3*x1*x2*x7*f7*f2*f1*f5
*f6+24*x3*x2*x7^2*f3*f6*f5^2-4*x6^3*x1*f7*f3*f1-4*x6^3*x2*f3*f5*f4+4*x6^3*x2*
f7*f2*f3+4*x6^3*x3*f7*f3^2+16*x3^2*x1*x6*f4*f5^2*f1*f6+216*x3*x2*x4^2*f7^2*f2*
f5*f4^2-32*x3*x2^2*x5*f7*f6^2*f0*f1-60*x3*x1^2*x4*f5^3*f3^2*f4+96*x3*x2*x4^2*
f7^2*f2^2*f6*f5+152*x3*x2*x4^2*f7^2*f2*f4*f3*f6-80*x3*x2*x4*x7*f3^2*f5*f6*f7+
12*x3*x7*x4*x8*f7^3*f1+8*x4^2*x2*x5*f7*f4^4+32*x3*x4*x1*x5*f1^2*f6^2*f7+32*x1^
3*x3*f0*f4*f5*f7*f3^2-8*x2^2*x3*x4*f7*f3^2*f4*f5^2-8*x2^2*x3*x4*f7^2*f3^2*f1*
f6-96*x3*x4*x1^2*f0*f6^2*f5*f7*f1-16*x2^3*x1*f1*f4^4*f6+18*x1^4*f5^3*f3*f1^2+
40*x4*x2*x3*x5*f7^2*f2^2*f4-32*x1*x4^2*x3*f6^2*f2*f3*f7*f4+68*x4*x2*x5*x6*f7*
f2*f4^2-24*x4*x2*x5*x6*f3^2*f4*f7+16*x2^2*x5*x6*f7*f3*f4*f1+48*x1^3*x3*f0*f6*
f5^2*f2*f4+16*x1^3*x3*f3^2*f5^3*f1+144*x3*x1^2*x4*f0*f6*f5^3*f4-48*x3*x2*x4*x6
*f4*f7*f6*f1*f5+64*x3*x2*x4*x6*f7*f3^2*f6*f4-92*x3*x2*x4*x6*f7^2*f2^2*f5+72*x3
*x2*x1*x4*f3^2*f6*f5^2*f4+48*x3*x1^2*x6*f0*f5^3*f4-128*x2^2*x1*x4*f0*f6*f4*f1*
f7^2+48*x2^2*x1^2*f0*f6*f5^2*f4*f2+160*x2*x1^2*x3*f0*f6^2*f5*f2*f4-48*x1*x2*x4
^2*f7^2*f3^3*f4+160*x2*x1^2*x4*f0*f6*f4^2*f3*f7+16*x2*x1^2*x5*f3^2*f5^2*f1+16*
x2*x1^2*x5*f4^2*f2^2*f5-64*x2*x1^2*x4*f0*f6^2*f2*f7*f3-144*x2*x1^2*x4*f5*f4^2*
f2*f3*f6+16*x2*x1*x4*x8*f7^2*f2*f1*f6-12*x4^2*x3^2*f7^2*f4^4-18*x2^2*x3^2*f7*
f4^4*f3-32*x1^2*x5*x6*f6*f0^2*f7+20*x1^2*x5*x6*f3^2*f5*f2+8*x1^2*x5*x6*f7*f4*
f1^2-8*x1*x5*x2*x8*f7^2*f1^2+16*x1*x5*x2*x8*f7*f4*f0*f5-8*x2*x5*x6*x7*f4^3+8*
x2^3*x4*f3^3*f5^2*f7+8*x2^3*x4*f7*f3*f4*f1*f5*f6-24*x2^3*x4*f1^2*f7^2*f5^2-160
*x4*x1*x3*x5*f0^2*f7^3-24*x4*x2*x5^2*f1*f7*f3*f5-56*x4*x2*x5^2*f1*f7*f4^2+24*
x4*x3^2*x7*f6*f5^3*f4-24*x2^2*x3*x4*f7*f2^2*f5^2*f6-72*x2^2*x3*x4*f6*f5^4*f1+
24*x4*x1*x3*x8*f7^2*f2*f4^2-24*x4*x2*x6*x7*f7*f5*f1*f6+32*x4*x2*x6*x7*f7*f2*f4
*f6-20*x4*x2*x6*x7*f3*f7^2*f2-18*x4^2*x1^2*f5^2*f4^4+6*x1^4*f7*f2^2*f3^3-32*x1
^3*x3*f1*f4^3*f7*f2+8*x1*x3^3*f5^2*f4^2*f1*f7+32*x1*x3^3*f0*f6*f5*f4^2*f7+96*
x1*x3^3*f0*f6*f5^2*f3*f7-24*x2^2*x5*x6*f0*f5^3+112*x1^3*x4*f0*f4^2*f6*f2*f7-32
*x2*x1*x3^2*f0*f5^5-4*x2^2*x1*x7*f7^2*f2*f1*f3+4*x2^2*x1*x7*f7*f3^2*f2*f5+4*x2
^3*x7*f7*f3^2*f4^2-64*x1^2*x2*x5*f7^2*f0*f1*f2-80*x2*x1*x5*x6*f0*f5^2*f4+96*x2
*x1*x5*x6*f0*f6*f4^2+32*x2*x1^2*x3*f0*f5*f6*f1*f7*f4-16*x2*x1*x5*x6*f2^2*f5^2-\
8*x2^2*x1^2*f3*f1*f7^2*f2^2-64*x2^2*x1*x3*f0*f6*f5^2*f1*f7-16*x2^3*x1*f0*f5*f7
^2*f3*f1-28*x2^3*x1*f1*f5*f7*f2*f4^2-12*x2*x1^2*x5*f1^2*f7*f4^2+64*x2*x1^2*x5*
f4*f0^2*f7*f6-48*x2*x1*x3*x4*f0*f6*f5^4+64*x2*x1^2*x4*f0*f5*f6*f7*f3^2-16*x2*
x1*x3*x7*f1*f5^4+64*x2*x1^2*x4*f7^3*f3*f0^2-16*x3^2*x1*x7*f7^2*f2^2*f4+24*x3^2
*x1*x7*f2*f5^2*f4*f6-56*x1^3*x4*f7*f2*f3*f1*f5^2+64*x1^2*x5*x7*f0*f6*f4^2-8*x5
*x4^2*x6*f4^3*f7-4*x2^2*x5*x7*f7*f3^3+12*x2*x5*x3*x7*f3*f7*f2*f5+16*x5*x4*x2*
x6*f2^2*f7*f6+16*x5*x4*x2*x6*f0*f3*f7^2+8*x5^3*x8*f7*f0-16*x5^2*x2*x8*f7*f0*f5
+56*x1^2*x3*x4*f7*f3^2*f5^2*f2+16*x2^3*x1*f0*f4^2*f7^2*f1+64*x1^3*x3*f5^3*f0^2
*f7+48*x1^2*x2*x3*f0*f5*f7^2*f2^2-24*x1^2*x2*x3*f6*f2^2*f5*f4^2-64*x3^2*x2*x8*
f7^2*f0*f6*f4+32*x3^2*x2*x8*f7*f2*f4*f5*f6+32*x1^2*x5*x7*f1*f7*f2*f4+12*x2^2*
x1*x7*f5^2*f3^2*f4-64*x3^2*x2^2*f6^2*f0^2*f7^2+32*x3^2*x2^2*f0*f6^2*f4*f7*f3-\
16*x3^2*x2^2*f6^2*f2*f1*f4*f7-4*x3*x1*x6*x8*f7*f2*f4*f5+8*x3*x1*x5*x7*f4^4-16*
x3*x1^2*x7*f0*f3^2*f7^2+16*x2^2*x3*x5*f1^2*f7^2*f4-16*x2^2*x3*x5*f4^3*f2*f6-16
*x1^3*x6*f3^2*f1*f5^2+72*x1^3*x6*f0*f5*f1*f7*f4-120*x3*x2*x4*x7*f7*f2*f5*f4*f6
-256*x3*x2*x4*x7*f7^2*f0*f6*f4-16*x3*x1*x5*x8*f7*f1*f3*f6+8*x3^2*x2^2*f6^2*f2^
2*f7*f3+16*x3*x2^2*x8*f7*f4^2*f6*f2-32*x3*x1^2*x6*f1^2*f6^2*f5+16*x3*x4*x1*x2*
f6*f4*f7^2*f1^2+16*x2*x1*x4*x6*f7*f3^3*f5+24*x1*x2*x3^2*f7*f2*f5*f1*f4*f6+8*x2
*x1*x3^2*f5*f4^5-48*x2^2*x1*x6*f0*f5*f4*f3*f7+16*x2^3*x1*f2*f1^2*f7^2*f5-16*x2
^3*x1*f0*f5*f2^2*f7^2-32*x2^3*x1*f0*f6*f4*f3^2*f7-16*x2*x1*x4^2*f7*f6^2*f2*f1*
f5+112*x2*x1*x4^2*f7*f3*f5^2*f1*f6+2*x3^4*f3*f5^5+12*x3^2*x6*x7*f3*f7^2*f2+20*
x5*x7*f7*f3^2*x3^2*f5+56*x3^2*x1*x7*f7*f4^2*f1*f6-16*x3^2*x1*x7*f6^2*f2*f3*f5-\
16*x3^2*x1*x7*f1*f5*f6^2*f4-16*x3^2*x1*x7*f2*f4^2*f6^2-64*x1*x7*f0*f6*f4*f7*x3
^2*f5+8*x3^3*x5*f7*f3*f4*f2*f6-32*x3^3*x5*f0*f5^3*f7-24*x4^2*x3^2*f1*f7^3*f4^2
+8*x6^2*x4*x8*f7^2*f2+4*x6^2*x7*x8*f4*f7+8*x6^2*x3*x8*f7*f4^2-20*x1*x4*x2*x7*
f7*f3*f4^3+8*x4*x1*x3*x5*f7*f3^3*f5+156*x4*x3*x5*x6*f7*f2*f4*f5+96*x4*x3*x5*x6
*f2*f5^2*f6+32*x1*x7^2*x5*f7*f0*f5+4*x3^2*x6^2*f2^2*f7^2+4*x1*x6*x2*x8*f7*f4^2
*f2+12*x3*x6^2*x5*f3*f5*f4-8*x4^3*x1*f7^3*f3^2*f2+24*x2^2*x1*x3*f7^2*f2*f4*f1*
f3+32*x2^2*x1*x3*f3*f6*f4*f7*f2^2-32*x2^2*x1*x3*f2*f4^4*f6-8*x2^2*x1*x3*f1*f6*
f4^3*f5-40*x1^2*x2^2*f4*f7^2*f1^2*f2+16*x1^2*x2^2*f0*f5^2*f1*f7*f4-20*x1^2*x2*
x3*f5^2*f4^3*f1+48*x2^3*x1*f6*f4^3*f0*f5+6*x3^2*x5^2*f3*f5*f4^2-16*x1^3*x2*f0*
f6*f5^2*f3*f2+8*x2^2*x1*x5*f4^3*f5*f1+64*x4^2*x3^2*f0*f7^4*f2-16*x1^2*x2*x7*f3
*f5^3*f1+96*x3^3*x4*f0*f6*f7^3*f2+16*x3^3*x4*f7^3*f3*f4*f1-32*x3^3*x4*f0*f6^2*
f7^2*f3+144*x4^2*x1*x3*f3*f5^3*f6*f4+48*x4*x1^2*x7*f2*f5*f4^2*f6+4*x1*x7^2*x2*
f2*f5^3-8*x5*x7*x3*x8*f7*f2*f6-48*x4^2*x1^2*f7*f3^2*f5*f4^2-36*x4*x1^2*x5*f3^3
*f5^2-80*x4*x1^2*x7*f7^2*f3^2*f1-144*x4^2*x1^2*f0*f6*f5^4-16*x1^2*x7^2*f7^2*f1
^2-16*x1^2*x7^2*f1*f6*f5*f4-20*x1^2*x7^2*f7*f3*f4*f2-24*x1^2*x7^2*f0*f6*f7*f3-\
24*x3^2*x6*x8*f7*f6*f2*f5+40*x3^2*x7*x8*f7*f4^2*f6+32*x3^2*x7*x8*f7*f3*f5*f6+
24*x3^2*x7^2*f3*f6^2*f5+12*x2*x1^2*x4*f5^4*f2^2+4*x2^2*x1*x5*f2*f7*f3^3-40*x2*
x1*x3*x5*f4*f5^2*f2*f3-32*x2*x1*x3*x5*f3*f6*f2*f4^2+64*x1*x2^2*x7*f6*f0^2*f7^2
-32*x2^2*x1*x5*f4*f0^2*f7^2+16*x1^2*x2^2*f0*f5^2*f7*f3*f2-8*x2*x3^3*f3^3*f6*f7
*f5+16*x3^3*x2*f0*f4*f2*f7^3-32*x3^3*x2*f7^2*f2*f4*f1*f6+16*x3^3*x2*f7^2*f3^2*
f2*f5-16*x3^3*x5*f3*f6*f5*f7*f1-8*x3^3*x5*f7*f3^3*f6+32*x3^3*x5*f0*f6^2*f3*f7+
8*x4*x5*x3^2*f1^2*f7^3+56*x1^2*x2^2*f1^2*f4*f7*f6*f3-152*x1^2*x3*x4*f5*f4^2*f7
*f2*f3-48*x1^2*x3*x4*f3*f5^2*f4*f6*f2+16*x3^2*x5*x8*f7*f6*f3^2-24*x3^2*x6*x8*
f7*f3*f6*f4+48*x3^2*x6*x8*f7^2*f0*f6-56*x1*x2*x3*x6*f7*f4^2*f2*f3-80*x1*x2*x3^
2*f0*f5*f2*f7^2*f4-288*x2*x1*x4*x6*f7*f0*f6*f4^2+20*x1^2*x4*x6*f7^2*f2*f3*f1-\
48*x1^2*x4*x6*f7*f2^2*f3*f6+8*x3^3*x1*f4^4*f5^2+32*x2^2*x3*x4*f6^2*f4*f7*f2^2-\
40*x1^2*x2^2*f6*f2*f5*f1*f4^2-16*x3^2*x1*x7*f4^4*f6+40*x1^2*x2*x5*f7*f5*f0*f3*
f2+8*x3*x1^2*x5*f3*f2^2*f5*f6+32*x3*x1^2*x5*f7^2*f3*f1*f0-32*x3*x2^2*x8*f7*f0*
f6^2*f4+48*x3*x2*x4*x7*f7*f3*f6^2*f2-48*x4*x5*x2*x3*f3*f6*f7*f2*f4+16*x2^2*x7^
2*f3^2*f5*f7-36*x1^2*x3*x4*f7^2*f2*f3*f1*f5-32*x4*x3*x5*x6*f7*f3*f4^2+8*x4*x3*
x5*x6*f2*f7*f3*f6+64*x1*x4^2*x2*f7^2*f2*f5*f3^2-4*x4*x1*x2*x8*f7^2*f1*f5*f3+48
*x1^2*x2^2*f0*f4*f2^2*f7^2-60*x1^3*x4*f2*f7*f5*f1*f4^2+96*x1*x4^3*f6^2*f2*f1*
f7^2-48*x4*x1^2*x6*f0*f6*f4*f5^2-160*x3*x4^2*x1*f6^2*f7^2*f1^2+16*x4*x5^2*x1*
f7*f2^2*f4-16*x2*x5*x3*x7*f0*f7^2*f3+8*x1*x5*x7^2*f2*f4*f6+4*x2^3*x7*f7*f3^3*
f5-4*x1^4*f1*f4^4*f3+16*x1*x7^2*x4*f7*f3*f5*f4-4*x1*x7*x3*x8*f7^2*f2*f3-4*x1*
x7*x3*x8*f7^2*f1*f4+8*x1^4*f0*f4*f3^3*f7-96*x3*x2*x1*x7*f0*f6^2*f5*f4-64*x3*x2
*x4*x5*f0*f6^2*f3*f7-52*x4*x5*x2*x3*f4*f5^2*f1*f7+144*x3*x2*x4*x5*f5^3*f6*f1-\
24*x4*x5*x2*x3*f6*f2^2*f7*f5+48*x3*x1*x5*x7*f0*f5*f7*f4-40*x3*x1*x5*x7*f1*f7*
f4^2-24*x3*x1*x5*x7*f5^2*f2*f4-8*x3*x1^2*x5*f7*f2*f5*f1*f3-56*x2*x3^3*f6*f4*f5
*f7*f2*f3+16*x3^3*x2*f6^2*f2*f7*f3^2-32*x2*x3^3*f4*f5^3*f7*f1+16*x3^3*x2*f7^2*
f4^3*f1+16*x4^2*x6*x7*f6^2*f2*f7+4*x1*x6^2*x3*f4^4+56*x2^2*x3*x4*f1*f7^2*f4^3-\
60*x2^2*x3*x4*f7^3*f2*f1*f3+16*x1*x7*x3*x8*f7^2*f0*f5-8*x7^3*x3*f2*f7^2+16*x7^
3*x3*f6^2*f4-8*x7^3*x3*f3*f6*f7+16*x7^3*x3*f7*f4*f5+40*x7^3*x4*f7*f5^2+24*x7^3
*x4*f7*f4*f6-12*x7^3*x4*f3*f7^2-8*x7^3*x5*f4*f6-8*x7^3*x6*f5*f6+24*x7^2*x3*x8*
f7*f4*f6+40*x7^2*x4*x8*f7^2*f4+8*x1*x7*x3^2*f3^2*f5*f4*f7-88*x1*x4*x3^2*f5^2*
f4^2*f2*f7-48*x1*x4*x3^2*f7*f2*f5^3*f3+22*x2^2*x3^2*f7^2*f2^2*f4^2-32*x3^2*x1*
x7*f1^2*f7^2*f6+144*x3*x1*x2*x4*f4^2*f6^2*f1*f5+24*x3*x1*x4^2*f7^2*f3^2*f4^2-\
12*x3*x1*x4*x7*f7*f4^4-32*x3^3*x2*f0*f6^2*f4^2*f7-24*x3^3*x2*f7*f3^2*f4^2*f6+
112*x3^3*x2*f0*f6*f4*f3*f7^2+64*x3^3*x2*f0*f6^3*f5*f4+8*x3^3*x2*f5*f4^4*f6-132
*x4^3*x2*f7^2*f3^2*f5^2+108*x4^3*x2*f7^2*f3*f4^2*f5+48*x3*x2*x5*x7*f5^2*f6*f1-\
4*x3*x1*x6*x7*f1*f7*f4*f5-80*x4^3*x1*f3*f6*f4*f2*f7^2-112*x4^3*x1*f7^2*f2^2*f5
*f6-384*x4^3*x1*f0*f6*f5*f7^2*f4+424*x4^3*x1*f4*f5^2*f1*f7^2+72*x4^3*x1*f7*f2*
f5^4-56*x4^3*x2*f7^2*f3^2*f6*f4-80*x4^3*x2*f7^3*f2^2*f5+168*x4^3*x2*f7*f3*f5^4
+16*x2^2*x3*x4*f7^2*f2*f1*f5^2-4*x2^2*x1*x5*f4^4*f2+112*x2^2*x3*x4*f0*f4*f7^3*
f2-136*x2^2*x3*x4*f5*f4^3*f3*f7-16*x3*x2^2*x5*f0*f5^2*f3*f7-8*x3*x2^2*x5*f7*f2
^2*f6*f3+48*x3*x1*x2*x7*f4^2*f6^2*f1-24*x3*x1*x2*x7*f3*f4^3*f6-4*x2^3*x5*f7*f2
^2*f4^2-4*x2^3*x5*f3*f5*f7*f2^2+432*x4^3*x3*f4*f5^3*f6^2-128*x3*x4^3*f7^2*f6^2
*f4*f1+256*x3*x4^3*f7^3*f0*f5^2+168*x4^3*x3*f4*f5^4*f7+160*x3*x4^3*f7^4*f0*f3-\
28*x3*x4^3*f7^3*f4*f5*f1-128*x3*x4^3*f7^2*f0*f6^2*f5-96*x3*x4^3*f7*f2*f5^2*f6^
2-144*x4^3*x3*f2^2*f7^3*f6-32*x1^4*f0*f6^2*f5*f2*f1-8*x1^4*f0*f4^2*f3*f7*f2+8*
x1^4*f0*f6*f3*f2^2*f7-144*x4^3*x7*f7^2*f3*f5^2+40*x4^3*x1*f1*f7^2*f4^2*f6+192*
x4^3*x1*f0*f5*f7^3*f3-288*x4^3*x1*f0*f5^3*f7^2+496*x4^3*x1*f0*f7^4*f1+4*x2^3*
x5*f5^2*f4^2*f1-4*x2^3*x5*f1^2*f7*f5^2+48*x2*x1^2*x4*f5*f4^3*f1*f6-120*x1*x2*
x4^2*f7^2*f2*f1*f4*f6-100*x1*x2*x4^2*f7^2*f3*f4*f1*f5-32*x2^2*x1^2*f6*f0^2*f7^
2*f2+40*x2*x1*x4*x6*f7*f2*f5*f1*f6-16*x2*x1^2*x3*f0*f3^3*f7^2+12*x2^2*x4*x6*f7
^2*f2*f1*f5-4*x2^2*x3*x6*f7^2*f3^2*f1-16*x2^2*x3*x6*f2^2*f7^2*f3+16*x1^4*f0*f6
*f3^2*f7*f1-40*x1^3*x2*f5^2*f7*f1^2*f2+12*x1*x2*x3^2*f7^2*f2*f5*f3*f1+12*x2^2*
x1*x4*f5*f4^5-40*x2*x1*x6^2*f0*f7*f4^2-16*x2^2*x1*x3*f0*f4*f7^2*f3^2-16*x1^3*
x2*f0*f5^3*f4*f2-4*f7*x2*x8^2*x5*f3*f5-8*f7^2*x3^2*x8^2*f2*f6-4*f7*x6^2*x8^2*
f5+8*f7*x6*x8^2*x7*f6+8*x1^3*x6*f6*f2^3*f5+4*x2*x1^2*x7*f2^2*f5^3-8*x2^3*x1*f5
^2*f7*f1^2*f4+16*x1*x2^2*x7*f7*f1*f6*f2*f4-16*x1*x2^2*x7*f0*f3^2*f7^2-48*x2*x1
*x3^2*f6*f5^2*f1*f4^2-4*x4*x5*x1*x2*f7^2*f2^3+4*x2*x1*x3*x8*f5^2*f7*f1*f4+112*
x2*x1*x3*x6*f0*f6*f5^2*f4-4*x2*x1*x3*x8*f5^2*f7*f2*f3-32*x2*x1*x3*x5*f5*f4^3*
f2+4*x2*x1^2*x3*f4^5*f3+124*x1^2*x4*x6*f7*f2*f5^2*f1+36*x1^2*x4*x6*f7^2*f2^3+
128*x1^3*x4*f0*f6*f5*f1*f7*f4+72*x3*x1^2*x4*f3*f5^4*f2-8*x3^2*x1^2*f3^3*f6*f7*
f2-104*x3*x2*x4^2*f7^2*f1*f3*f5*f6-32*x3*x2*x4^2*f7^4*f0*f1+128*x3*x2*x4^2*f0*
f6^2*f3*f7^2-48*x3^2*x1^2*f6^3*f1^2*f4-64*x3*x1*x4*x8*f7*f5^2*f6*f1-16*x3*x2*
x5^2*f4*f5^2*f1+76*x3*x1*x4*x7*f1*f7^2*f4^2+8*x3*x2^2*x6*f7*f3^2*f6*f2+120*x3*
x1*x4^2*f2*f7^3*f1*f4-16*x3*x2*x1*x7*f3*f5^2*f6*f2+16*x3*x2*x5^2*f2*f5*f4^2-48
*x2^2*x3*x6*f0*f6*f1*f7^2-112*x2^2*x3*x6*f0*f5^2*f4*f7-8*x2^2*x3*x6*f1^2*f7^2*
f5+32*x2^2*x3*x6*f0*f5*f2*f7^2-48*x2^2*x3*x6*f0*f6*f5*f3*f7+16*x2^2*x3*x6*f7*
f2*f1*f5*f6+60*x2^2*x3*x6*f7*f4^2*f5*f1-24*x2^2*x3*x6*f7*f2^2*f4*f6+4*x3^4*f5*
f4^4*f7-16*x3^4*f3*f5^2*f6*f7*f2-24*x1*x2*x4^2*f2^3*f7^3-4*x7^3*x6*f7*f4+4*x7^
3*x5*f7*f3-24*x4*x2*x3*x5*f7^2*f2*f3^2-80*x4*x2*x6*x7*f7*f5^2*f2-144*x4*x2*x6*
x7*f4^2*f6*f5+16*x2^2*x3^2*f6^2*f4^3*f2+24*x5*x4*x6*x8*f7^2*f1-8*x4*x5*x2*x8*
f7*f2*f4*f6-8*x5*x4*x2*x8*f7*f4^3-4*x2*x5^2*x3*f7*f4*f2^2+4*x2*x5^2*x3*f3^2*f7
*f2-4*x1^2*x5^2*f4^2*f3*f1-8*x3^2*x5*x8*f7*f2*f4*f6+32*x3^2*x5*x8*f7*f0*f6^2+
16*x2^2*x5*x6*f4^2*f2*f5-8*x3*x5*x2*x6*f7^2*f1^2-8*x1^2*x5^2*f2*f0*f5^2-4*x1^2
*x5*x6*f3*f4*f1*f5-36*x4*x1*x2*x5*f5^2*f3^2*f4-16*x4^2*x1^2*f3^2*f6^2*f7*f1+8*
x4^2*x2^2*f7*f3*f4^3*f6-48*x4*x1*x2*x8*f7^2*f0*f4*f5+12*x4*x1*x2*x8*f7^2*f2*f3
*f4-32*x6^3*x3*f7*f0*f6-8*x6^3*x3*f7*f2*f4-8*x6^3*x4*f0*f7^2+12*x6^3*x4*f7*f2*
f5+16*x1*x7^2*x3*f6*f3*f4*f5-40*x1^2*x7^2*f7*f4*f0*f5+12*x1^2*x7^2*f7*f3*f1*f5
-8*x1^2*x7^2*f3^2*f5^2-4*f7^2*x3*x8^2*x6*f3-32*f7^2*x3*x8^2*x4*f4*f5+24*f7^2*
x3*x8^2*x4*f3*f6-16*f7^3*x3*x8^2*x4*f2+8*f7*x3^2*x8^2*f3*f6^2-6*f7^2*x3^2*x8^2
*f4^2+4*f7*x2*x8^2*x7*f5^2+64*x2*x4*x3^2*f0*f6*f5*f3*f7^2-16*x3^2*x2*x4*f7*f3*
f4^3*f6-16*x1^3*x6*f5^3*f1^2+12*x2^2*x1*x5*f4^2*f2*f7*f1-32*x2^2*x1*x5*f0^2*f6
*f7*f5+16*x2^2*x1*x5*f1*f5^2*f7*f0-12*x1^3*x6*f7*f2^2*f3^2-44*x1*x7*x3^2*f2*f5
*f4^2*f7+20*x1*x7*x3^2*f1*f5^2*f7*f4+48*x1*x7*x3^2*f3*f6*f5*f7*f1-44*x1*x7*x3^
2*f3*f5^2*f7*f2+48*x1*x7*x3^2*f0*f5^3*f7-48*x1*x7*x3^2*f7^2*f3*f0*f5+12*x2*x7*
x3^2*f3^3*f7^2+24*x2^3*x1*f1*f6*f4*f7*f3*f2+64*x3^4*f0*f6*f5^3*f7-16*x3^4*f0*
f5*f2*f7^3+4*x7^3*x5*f5^2+72*x4^2*x2*x5*f4^2*f5^3-140*x2*x5*x4^2*f7^3*f1^2-68*
x2*x5*x4^2*f3*f7^2*f2*f4-2*x3^2*x5^2*f4^4+144*x4*x1*x2*x5*f0*f6*f4*f5^2-64*x6*
x7*x3*x4*f0*f7^2*f6-48*x4*x3*x6*x7*f5^4-32*x3*x4^2*x2*f3^2*f6^2*f4*f7+16*x2^2*
x3*x7*f4^4*f6+32*x4*x5*x2^2*f0^2*f7^3+16*x1^4*f6^2*f2*f4*f1^2-16*x1^4*f0*f6^2*
f4*f2^2+32*x1^2*x3*x7*f4^3*f6*f2-48*x2^2*x3^2*f0*f6*f5^4+8*x1^2*x2*x3*f5*f4^4*
f2-8*x1^4*f6*f2*f7*f3*f1^2+176*x3^2*x1^2*f0*f6*f4^2*f3*f7+32*x3*x1*x4*x6*f6*f7
*f3^3-144*x3*x1*x4*x6*f1*f5*f6^2*f4-40*x3*x1^2*x6*f3^2*f6*f2*f5-32*x1^4*f6*f5*
f4*f3*f1^2+4*x2^3*x6*f4^3*f5*f3-4*x2^3*x6*f1*f5^3*f4+12*x2*x1^2*x7*f3^3*f5^2-\
52*x4*x7*x3^2*f7^2*f5*f4*f2-68*x3^2*x2*x7*f7*f3*f4^2*f5+8*x1^2*x2*x5*f7*f5*f1*
f0*f4-48*x1^2*x2*x4*f5^4*f3*f1+120*x2*x4*x3^2*f1*f7*f5^4-192*x3^2*x2*x4*f0^2*
f7^4-16*x2^2*x3*x8*f7*f0*f6*f5^2-24*x3^3*x4*f7^2*f3*f4^3+16*x3^3*x4*f5^2*f4^3*
f7-16*x3^3*x4*f6*f7^3*f1^2-64*x3^3*x4*f7*f3^2*f6*f5^2+32*x3^3*x6*f4*f6^3*f1-\
120*x3^2*x4*x6*f4*f5^4-72*x1^2*x3*x6*f3*f5^3*f1+36*x1^2*x6^2*f3*f5^2*f1-28*x2*
x3^3*f5^2*f7*f3^2*f4+16*x3^3*x2*f1*f6*f5^4-8*x3^3*x1*f4^5*f6+32*x3^3*x7*f6^2*
f2*f5^2-12*x1^4*f2*f5^2*f1*f4*f3-32*x3^3*x7*f7*f3^2*f5*f6+24*x3^3*x7*f7^2*f3*
f1*f6-64*x3^3*x7*f3*f7*f4^2*f6-12*x3^3*x7*f4*f5^2*f7*f3+16*x1^2*x2^2*f7*f2^3*
f5*f4+24*x3^4*f1*f5^2*f7*f4*f6-8*x3^4*f1*f7^3*f2*f4-16*x3^4*f7^2*f2*f5*f1*f6-\
48*x3^4*f3^2*f5*f6*f7*f4-8*x3^4*f4*f5^3*f3*f6+48*x3^3*x2*f4*f5^3*f6*f2-16*x3^3
*x2*f7*f2*f5^3*f3-144*x3^2*x2*x4*f1*f6^2*f5^3+96*x3^2*x2*x4*f6*f2*f5^4-24*x3*
x1*x6*x7*f3^2*f5*f6+16*x3*x1*x5*x7*f0*f5^2*f6-104*x3*x1*x4*x6*f7^2*f2^2*f4-28*
x3*x2*x4*x6*f7^2*f2*f3*f4-144*x3*x2*x4*x6*f5^3*f4^2+4*x3^2*x7^2*f4*f6*f5^2-16*
x4*x7^2*x2*f4*f6*f3*f7+8*x2*x7*x3*x8*f7*f6*f2*f5-4*x3^2*x1*x7*f7*f3*f4^3-60*x2
*x4*x3^2*f1^2*f7^3*f5-168*x2*x4*x3^2*f7^2*f2*f5*f1*f6+128*x2*x1*x3*x4*f5*f0^2*
f7^3+4*x2*x1*x3*x4*f7^2*f2^2*f4^2-64*x2*x1*x4*x6*f7*f0*f5*f6*f3+16*x2*x1*x4*x6
*f0*f5*f2*f7^2-28*x4*x5*x1*x2*f3^2*f5*f7*f2+16*x3^3*x1*f7^2*f3^2*f2*f4+64*x3^3
*x1*f0*f6^3*f4^2-16*x3^3*x1*f1*f6*f5^3*f4-64*x3^4*f1*f6^3*f5*f4+24*x3^4*f5*f4^
2*f3*f6^2-208*x1^2*x4*x5*f0*f6*f7*f4*f2-16*x4^2*x1^2*f7^2*f3^4+24*x4^3*x6*f7^2
*f4^3-48*x4^3*x6*f7*f5^3*f4-164*x1*x6*x4^2*f3*f7^2*f2*f4+44*x4^2*x1*x6*f7^2*f3
^3+24*x2^2*x3*x8*f7*f4*f6*f1*f5+16*x2^2*x3*x8*f7*f5*f3*f4^2-18*x3^4*f1*f7*f5^4
+16*x6*x2^2*x7*f0*f7^2*f3+8*x1^2*x6^2*f0*f6*f4^2-64*x1^2*x6*x7*f1*f0*f7^2+8*x1
^2*x6*x7*f5*f6*f2^2+2*x2^2*x6^2*f3^3*f7+24*x1^2*x4*x5*f3*f5^2*f2*f4+48*x3*x4*
x1^2*f1*f6*f4^2*f7*f3-4*x1^3*x6*f4^2*f3^3-8*x1^4*f0*f5*f4*f2^2*f7+4*x1^4*f2*f5
*f4^3*f1+32*x1^4*f0*f6*f5*f4^2*f1+48*x1^2*x2*x7*f1^2*f7^2*f3-24*x2^2*x1*x3*f3^
2*f6*f4^3-20*x2^3*x1*f2^2*f7^2*f1*f4+40*x1^4*f0*f5^2*f2*f7*f1+12*x1^4*f0*f4*f5
^2*f3^2-64*x1^3*x2*f1*f6*f5*f3*f4*f2-32*x1^4*f6*f4*f3*f7*f0^2-56*x1^2*x3^2*f1^
2*f4^2*f7^2-28*x1*x7*x4^2*f7^2*f2*f4^2+48*x4^2*x1*x7*f7^2*f3^2*f4-104*x2*x4*x3
^2*f3^2*f5^3*f7-160*x3^2*x2*x4*f1*f7*f4^2*f6^2+40*x2*x4*x3^2*f1*f7^2*f3*f5^2-\
40*x2*x4*x3^2*f1*f5^2*f7*f4*f6+88*x2^2*x4^2*f0*f6*f1*f7^3+32*x2^2*x4^2*f0*f5^2
*f4*f7^2+16*x2*x6^2*x3*f5^2*f1*f6-16*x3*x6^3*f5*f4^2+28*x6^3*x3*f7*f1*f5+128*
x2^2*x1*x3*f4*f6*f0^2*f7^2+8*x3^3*x1*f3*f6*f4^2*f7*f2-32*x3^3*x1*f0*f3*f2*f7^3
+64*x3^2*x7^2*f0*f6*f7^2-176*x1^2*x3*x4*f0*f6*f7^2*f3*f2-16*x1^3*x4*f2^3*f7*f5
^2-28*x3^2*x1*x6*f7^2*f3^2*f1+12*x3^2*x1*x6*f1*f7*f5*f4^2-28*x1^2*x2*x4*f7*f2^
2*f5*f4^2-4*x2^2*x3^2*f3^3*f5^2*f7+32*x1^3*x3*f0*f6^2*f5*f1*f4+16*x1^3*x3*f2^3
*f6^2*f4-32*x3^3*x6*f1*f5^2*f6^2-8*x3^3*x6*f4*f6*f1*f5*f7-160*x3^3*x6*f0*f6*f5
^2*f7+8*x3^3*x6*f5^2*f7*f2*f4+36*x3^3*x6*f4^2*f7*f3*f5-32*x3^3*x6*f0*f6^2*f7*
f4+16*x3^3*x6*f1*f6*f7^2*f2+24*x3^3*x6*f4*f6*f7*f3^2+64*x3^3*x6*f0*f6^3*f5+12*
x3^3*x6*f1*f4^2*f7^2+18*x1^4*f4^2*f7*f3*f1^2+4*x2^2*x3*x5*f7*f2^2*f4*f5+8*x2^2
*x3*x5*f7*f2*f1*f5^2-12*x4*x5*x2^2*f3*f5*f7*f2*f4+212*x2*x4*x3^2*f5*f4^2*f1*f7
^2-32*x3^2*x2*x4*f7^3*f3*f2^2+48*x1^3*x3*f7*f2*f3^2*f1*f6-32*x1^4*f5*f1*f7^2*
f0^2+12*x1^3*x2*f3^2*f5^2*f4*f1-96*x4*x1^2*x7*f0*f6*f5^3+24*x4*x1*x5^2*f0*f5^3
-16*x1^3*x4*f7^2*f0*f3^3-4*x2^2*x1*x8*f7*f1*f5^2*f3-112*x3*x4*x1*x2*f6*f2^2*f5
*f7*f4+120*x2*x1*x3*x4*f5^4*f2*f4+40*x2*x1*x3*x5*f5^2*f4^2*f1+4*x1^3*x6*f3^4*
f5+96*x4*x3*x6^2*f5^3*f4-48*x4^3*x3*f2*f7^3*f4^2-16*x4*x1*x3*x7*f0*f7^2*f6*f3-\
240*x4^3*x1*f7*f5^3*f6*f1-120*x4^3*x1*f7*f2*f5^2*f4*f6-32*x4*x2*x1*x5*f1^2*f5*
f7*f6-8*x4^2*x2^2*f1*f7*f4^2*f6^2+28*x4*x1*x5*x8*f7^2*f2^2-8*x4*x1*x5*x8*f7*f2
*f4*f5-44*x4*x1*x5*x8*f7^2*f3*f1+16*x4*x2^2*x8*f7^2*f2*f4^2-16*x4*x2^2*x8*f7*
f6*f5^2*f1+144*x4*x2*x7^2*f5^2*f6*f4+32*x1^3*x6*f6*f2*f5*f3*f1+24*x4^3*x7*f3^2
*f7^3+96*x4^3*x7*f6^2*f1*f7^2+696*x4^3*x7*f7*f4*f5^2*f6+384*x4^3*x7*f7^3*f5*f1
-96*x4^3*x7*f0*f6*f7^3+192*x4^3*x7*f7*f5^4+8*x1*x2^2*x4*f3*f5*f6*f7*f2^2-28*x1
*x2^2*x4*f7^2*f2*f5*f3*f1+4*x2^2*x1*x8*f7*f3*f5*f2*f4+24*x3*x5*x7^2*f7*f3*f4-\
24*x3*x5*x7^2*f3*f5*f6+16*x3*x5*x7^2*f4*f5^2-32*x3*x5*x7^2*f0*f7^2-44*x4^2*x7*
x5*f7^2*f5*f1-20*x3*x5*x7*x8*f7*f4^2+12*x3*x5*x6*x8*f7*f3*f4-16*x3*x5*x6*x8*f7
^2*f0-24*x3^3*x7*f4*f5*f1*f7^2-8*x3^3*x7*f3*f5*f2*f7^2-4*x6^2*x3*x8*f1*f7^2+4*
x6^3*x4*f7*f3*f4-4*x6^3*x5*f3*f4+8*x2^3*x3*f4^2*f6*f7*f2^2+32*x2^3*x3*f0*f4^3*
f6*f7-16*x4*x7^2*x2*f7^2*f4*f2+8*f7*x2*x8^2*x6*f4*f5+24*f7^3*x4^2*x8^2*f3-2*x2
^4*f7^3*f1^3-16*x3*x2^2*x5*f0*f6*f4*f3*f7-24*x3*x2^2*x7*f7*f2^2*f6*f5+124*x4*
x5*x1*x3*f7^2*f5*f1^2-16*x3*x1*x5*x7*f7*f5*f1*f3+24*x3*x1*x5*x7*f1^2*f7^2+24*
x3*x1*x5*x7*f4*f6*f1*f5+16*x3*x1^2*x6*f0*f6*f3^2*f7+72*x3^2*x1^2*f0*f6*f5^2*f4
^2-4*x3*x1^2*x6*f7*f3^4-72*x4*x5*x1*x3*f7*f4^2*f1*f5-4*x4*x5*x1*x3*f7*f4^3*f2-\
12*x3*x1*x5*x7*f3^2*f5^2-8*x3^3*x1*f5*f4^3*f3*f6+80*x2*x1*x3^2*f4*f5^2*f2*f3*
f6-8*x2*x1*x3*x5*f1^2*f7*f5^2+36*x4*x5*x1*x2*f4^3*f7*f1+48*x2*x1*x3^2*f6^2*f2*
f1*f5^2+4*x1*x2*x3^2*f2*f5*f7*f4^2*f3+4*x1^4*f6*f3^2*f4*f2^2+118*x1^2*x4^2*f7^
2*f3*f5*f2^2-16*x1^4*f0*f5^3*f4*f1-32*x1^3*x2*f0*f6*f5*f2*f1*f7+36*x2^2*x3*x4*
f3*f5^4*f4+148*x2^2*x3*x4*f1*f5^3*f7*f4+48*x2^2*x1*x6*f7*f0*f6*f1*f5+108*x1^2*
x4^2*f7^2*f1^2*f5^2+96*x1^3*x2*f5^2*f4*f0^2*f7+64*x1^3*x2*f0*f3^2*f1*f7^2-32*
x1^3*x3*f0*f5^3*f3*f4+8*x1^2*x3*x7*f2^3*f7^2-112*x1^2*x4^2*f7^2*f1*f4^2*f3-64*
x1^3*x2*f0*f5*f4*f3*f2*f7-56*x1^3*x2*f3*f7^2*f1^2*f2-34*x1^2*x3^2*f7*f3^2*f1*
f5^2-196*x2^2*x4^2*f2*f7^3*f1*f4+168*x2^2*x4^2*f0*f4*f3*f7^3+32*x2*x5*x7*x8*f7
^2*f0-12*x2*x5*x7*x8*f7*f3*f4+16*x2^2*x5*x8*f7*f0*f6*f4+36*x2*x5*x6*x7*f7*f1*
f4+16*x1*x5*x3*x6*f0*f5*f6*f4-8*x1^3*x3*f3^2*f6*f4*f1*f5+8*x2^2*x1*x4*f7*f3^2*
f2*f4*f6-16*x1^2*x6*x7*f4^2*f1*f6+4*x1*x6*x3*x8*f7^2*f3*f1+48*x1^2*x6*x7*f4*f2
*f3*f6-16*x2^2*x1*x3*f4^2*f6*f2*f7*f1+48*x1^3*x7*f0*f4^2*f3*f7-168*x2^2*x4*x7*
f5*f4^2*f7*f3+84*x2^2*x4*x7*f7^2*f5*f1*f3-8*x1*x3^3*f7*f3*f4*f1*f5*f6-40*x3^3*
x1*f3*f6*f2*f7^2*f1-32*x3^3*x1*f0*f4*f1*f7^3+48*x4^2*x1*x7*f7*f2*f5^3-48*x4^2*
x1*x7*f5*f4^3*f7+280*x4^2*x1*x7*f4*f5*f7^2*f1+96*x4^2*x1*x7*f7*f5^2*f3*f4-16*
x4^2*x1*x7*f0*f3*f7^3-32*x2*x6*x3*x7*f4^3*f6+8*x2*x6^2*x8*f1*f6*f7-8*x1*x6^2*
x4*f3*f6*f1*f7-16*x1*x6^2*x4*f0*f7^2*f3+32*x3^2*x1*x2*f1*f6^2*f4^3+24*x3^2*x1*
x6*f3*f4^3*f6-2*x3^2*x1^2*f5^2*f4^2*f3^2-36*x3*x1*x4^2*f5*f4^4*f7-8*x3*x1^2*x7
*f5^2*f4^2*f2-32*x1*x2*x3^2*f0*f5*f6^2*f1*f7+16*x2*x1*x3^2*f5^3*f4^2*f2-48*x2*
x1^2*x7*f0*f6*f5*f4^2+96*x2*x1^2*x7*f3*f5*f1*f4*f6+12*x2^3*x1*f7*f2^2*f4^3+16*
x1^4*f6^2*f5*f1^3+20*x2^2*x1*x3*f7*f3*f4^3*f2+32*x2*x1^2*x3*f0*f5*f4^2*f3*f7-\
32*x4^2*x5*x1*f0*f6*f7^2*f2-64*x3^2*x4*x6*f0*f7^3*f3+56*x3^2*x4*x6*f7^2*f3^2*
f4+68*x4*x2*x7*x8*f7*f4*f5^2+60*x4*x2*x7*x8*f7^2*f2*f5-32*x4^2*x2*x6*f7^2*f3*
f1*f6-16*x4^2*x2*x6*f3*f7*f4^2*f6+8*x1^3*x6*f3^2*f1*f4*f6+16*x1*x5*x2*x6*f1^2*
f5*f7-48*x1*x5*x6*x7*f0*f5*f6-8*x2^2*x5*x6*f6*f7*f1^2-48*x3*x2*x4*x7*f4*f5^4+
28*x3*x2*x4*x5*f7*f2*f5^2*f3+56*x3*x2*x7^2*f5*f4^2*f6+32*x3*x2*x7^2*f0*f7^2*f5
-56*x3*x2*x7^2*f7*f3*f4*f5-16*x3*x2*x7^2*f7*f6*f1*f5-8*x3*x2*x6^2*f7*f2*f4^2+
16*x2*x1^2*x4*f2*f7*f3^3*f6-16*x7*x2*x3*x8*f7^2*f3^2-72*x3^2*x1^2*f3^2*f6*f4*
f1*f7-48*x3*x2*x6*x7*f4^2*f5^2+32*x3*x2*x6*x7*f3^2*f7*f5-72*x3^2*x1^2*f0*f6*f5
^3*f3-24*x1^3*x3*f2^2*f3*f7^2*f1+8*x1^3*x6*f2^3*f7*f4-64*x1^3*x5*f5*f0^2*f4*f7
-8*x1^3*x5*f2*f5*f1*f4^2+96*x2^2*x1*x3*f0*f6^2*f4^3+12*x1*x5*x6^2*f3^2*f4-24*
x4*x1*x6*x7*f4^2*f5^2+24*x2^2*x1*x3*f7*f2^3*f5*f6-28*x2*x1*x3*x4*f7^3*f1*f2^2-\
16*x2*x1*x4*x7*f7*f6^2*f2*f1-80*x2*x1*x4*x7*f7^2*f2*f5*f1+24*x1*x2*x3^2*f7*f3^
2*f5*f1*f6-96*x1*x3^3*f0*f5*f4*f3*f7^2-24*x3^3*x1*f7^2*f2^2*f4^2-32*x3^3*x1*f1
*f6^3*f4*f3-4*x3^3*x8*f7*f3*f5^3+4*x3^3*x8*f7*f4^2*f5^2+24*x3*x2*x1*x7*f3^2*f5
*f4*f6-96*x3*x1^2*x6*f0*f6^2*f4*f3-88*x3*x1*x4*x6*f7*f3*f4*f2*f6+160*x3*x1*x4*
x6*f7*f3*f5*f1*f6-88*x4^2*x1*x7*f7*f2*f4*f5*f6-160*x4^2*x1*x7*f0*f6*f4*f7^2+80
*x4^2*x1*x7*f7^2*f3*f1*f6+32*x4^2*x2*x7*f7*f5^3*f3+136*x4^2*x2*x7*f1*f7^2*f4*
f6-56*x4^2*x2*x7*f7*f2*f5^2*f6+44*x4^2*x2^2*f5*f4*f7^2*f2*f3+224*x3*x4*x5*x8*
f7^2*f0*f6+24*x4*x3*x5*x8*f7^2*f3^2-64*x4*x3*x5*x8*f7^2*f2*f4+16*x2*x1*x4*x7*
f7*f2^2*f6*f5-12*x2*x1^2*x3*f4*f5^2*f3^3+64*x2^2*x3*x4*f0*f6^2*f4^2*f7-4*f7^2*
x7^2*x8^2+4*x2^2*x4*x5*f7^2*f3^2*f1-4*x2^2*x4*x5*f7*f3^3*f5+8*x1^2*x5*x7*f4*f6
*f2^2+4*x1^2*x2*x3*f4^3*f7*f2^2-8*x1^3*x3*f3^4*f6*f4+32*x1^3*x3*f6*f2*f5*f1*f4
^2+32*x3^2*x6^2*f0*f4*f7^2-48*x4^3*x2*f6^2*f2*f7*f4*f5-8*x4^3*x2*f7^3*f3^3-28*
x4^3*x2*f7^2*f4^4+100*x4^3*x2*f1^2*f7^4+8*x1^3*x3*f3^2*f6*f4^2*f2-128*x3^3*x5*
f0*f6^3*f4-32*x3^3*x5*f0*f6*f2*f7^2-736*x1^2*x4^2*f7^3*f0^2*f5-144*x3*x1*x4*x6
*f0*f4^2*f7^2+8*x3*x1^2*x5*f4^3*f3^2-40*x3*x1^2*x7*f3^2*f6*f4^2+32*x3*x2*x6*x8
*f7^2*f0*f5+72*x3*x1*x4*x5*f6*f5^2*f1*f4-32*x2*x1^2*x3*f3^2*f5^2*f6*f1+128*x1^
3*x2*f0^3*f7^3-16*x2^2*x3*x8*f7*f3*f5*f6*f2-32*x2^2*x3*x8*f7^2*f0*f5*f4-4*x2^3
*x1*f5*f4^4*f2-144*x2*x1^2*x4*f0*f6*f5^3*f3+4*x2^3*x1*f7*f2*f5^2*f3*f1-64*x2*
x1^2*x3*f0*f6^2*f5^2*f1+24*x1^4*f5*f3^2*f7*f1^2+12*x2^2*x4*x5*f7*f3*f5^2*f1+20
*x4*x5*x2^2*f5^2*f2^2*f7+36*x1^2*x2*x4*f7^2*f3^3*f1+144*x2^2*x4*x6*f0*f5^3*f7-\
4*x2^2*x5*x6*f3^2*f7*f2+48*x1^2*x5*x7*f0*f6*f5*f3+16*x1^2*x5*x7*f3^2*f7*f1+224
*x4^3*x2*f0*f6^2*f7^2*f4+432*x4^3*x2*f5^4*f6*f4+48*x4*x2*x3*x8*f7^2*f3*f4^2-72
*x4^2*x1*x5*f4*f5^3*f3+32*x2^2*x5*x6*f0*f4^2*f7-16*x2^2*x5*x6*f7*f2*f1*f5+352*
x1^2*x3*x4*f0*f6^2*f2*f7*f4+24*x1^2*x3*x4*f3^2*f6*f4*f7*f2-24*x1^3*x4*f5^4*f2*
f1+8*x3*x2^2*x8*f7*f3^2*f6*f4-32*x2^2*x7^2*f3*f7*f4^2+48*x2*x1^2*x6*f0*f5^3*f3
-64*x4^2*x2*x6*f0*f7^3*f3-64*x4^2*x2*x6*f6*f5^2*f1*f7-64*x4*x1*x6*x7*f5^2*f7*
f1+128*x4*x1*x6*x7*f7*f4*f2*f5+144*x4*x1*x6*x7*f0*f7*f5*f6-36*x4*x1*x6*x7*f3^2
*f7*f5+60*x4*x1^2*x7*f3*f4^2*f5^2+32*x4^2*x2*x7*f4^2*f7^2*f3+12*x4^2*x2*x7*f7^
2*f5^2*f1-152*x4^2*x2*x7*f7*f5^2*f4^2-128*x4^2*x2*x7*f0*f6*f5*f7^2-96*x4^2*x2*
x7*f7*f3*f5*f4*f6-48*x3^2*x1*x4*f5*f4^4*f6-32*x2*x1*x3*x7*f2*f4^2*f6*f5+4*x2*
x1*x3*x4*f1^2*f7^3*f3+128*x3*x4*x1*x2*f6^2*f0^2*f7^2+96*x1*x2*x3^2*f0*f5^3*f3*
f7+32*x3^2*x1*x5*f2^2*f6*f5^2+28*x3^2*x1*x5*f3*f2*f7^2*f1+8*x2^2*x1*x5*f0*f5*
f3^2*f7-48*x2^2*x1*x5*f0*f5*f4*f7*f2+20*x2^2*x1*x5*f4*f5^2*f1*f3-8*x3^2*x1*x6*
f0*f5^2*f4*f7-72*x3^2*x6*x2*f0*f5^3*f7-32*x3^2*x2*x6*f7*f2^2*f6*f5+4*x1^2*x6^2
*f5^2*f2^2-16*x6*x3^2*x7*f4*f6*f2*f7-12*x3*x6*x7*x8*f7*f4*f5-8*x2^3*x5*f2*f5*
f4^3+24*x2^2*x1*x5*f0*f5^2*f4^2-32*x2^2*x1*x5*f3*f5*f4^2*f2-24*x3^3*x2*f1*f6*
f7^2*f3^2-128*x3^3*x2*f6*f0^2*f7^3+144*x4*x5*x1*x3*f7*f0*f5^2*f4-24*x3^2*x2*x7
*f7*f2*f4^2*f6-76*x3^2*x1*x4*f1^2*f7^3*f4+72*x1^2*x2*x3*f1^2*f4*f7^2*f3+72*x3*
x1*x4*x7*f7^2*f5*f1*f3+64*x2^2*x1*x3*f0*f5^2*f3*f7*f4-120*x4*x5*x1*x2*f0*f5*f4
^2*f7-16*x2^2*x1*x8*f7*f0*f5^2*f4+12*x2^2*x1*x8*f7*f1*f4^2*f5-36*x2*x1*x4*x6*
f3^2*f5^3-32*x3^2*x6*x7*f6^2*f2*f5-16*x2*x5*x1*x7*f0*f5^3+4*x2*x5*x6*x8*f7*f3^
2+4*x1*x5*x6*x8*f7*f2*f3+4*x1*x5*x6*x8*f7*f1*f4-8*x2^3*x4*f7*f4^4*f3-16*x2^3*
x4*f7*f2^2*f5^3+8*x2*x1^2*x3*f4^4*f6*f1-48*x2*x1^2*x5*f0*f6*f4^2*f3+32*x2*x1*
x4*x8*f7*f2*f5^2*f4+56*x2*x1*x4*x6*f7*f3*f1*f4*f6+128*x2*x1*x4*x6*f7^2*f0*f4*
f3-24*x1^2*x3^2*f4^2*f6^2*f2^2+12*x2^3*x4*f1^2*f7^3*f3+8*x2^3*x4*f3*f5^3*f7*f1
+32*x3^2*x2*x8*f7*f3*f4^2*f6+32*x3^2*x2*x8*f7^2*f1*f3*f6-24*x3^2*x2*x8*f7^2*f0
*f5^2-32*x3*x1^2*x5*f1^2*f5^2*f6+48*x3*x1^2*x5*f6^2*f1^2*f4+8*x3^2*x1*x2*f7^2*
f3^3*f2-252*x4^3*x7*f7^2*f4^2*f5+64*x4^3*x7*f7^2*f2*f5*f6+32*x5*x7*f7^2*f0*f6*
x4^2-8*x5*x7*f7^2*f3^2*x4^2-208*x2^2*x4^2*f5^2*f4^2*f7*f3-16*x2^2*x4^2*f7*f3^2
*f5*f6*f4+16*x3*x4*x2*x8*f7*f4^3*f6+16*x4*x3*x2*x8*f7*f4*f6^2*f2+24*x4^2*x2^2*
f1*f5^2*f7*f4*f6+112*x4*x3*x5*x7*f7*f5*f3*f4+20*x4*x3*x5*x7*f7^2*f2*f3+48*x4*
x1*x5*x7*f2*f7^2*f1-4*x4*x1*x5*x7*f7*f2*f5*f3-16*x1^3*x5*f1^2*f5*f6*f3-8*x1^2*
x5*x7*f4^3*f2+88*x3^2*x4*x7*f7*f5^2*f4^2+24*x3^2*x1*x7*f3^2*f5^2*f6-200*x4^3*
x2*f1*f5^3*f7^2-128*x3^2*x1*x6*f0*f6*f4^2*f7-60*x3^2*x1*x6*f1*f7^2*f2*f4+98*x4
^2*x7^2*f7^3*f1+4*x3^2*x1*x5*f3^3*f4*f7-4*x1*x5*x3^2*f4*f5*f7*f3*f1-4*x1*x5*x3
^2*f4*f5*f7*f2^2+4*x3^2*x1*x5*f3*f5*f4^3-8*x7^2*x3^2*f1*f7^2*f5+12*x1^2*x2^2*
f4^3*f2^2*f6-64*x2^2*x4^2*f7*f2*f5*f4^2*f6+40*x2^2*x4*x7*f7^2*f2*f1*f6+56*x2^2
*x4*x7*f7*f3^2*f5^2+8*x1^3*x5*f0*f5^2*f3^2+60*x3^3*x6*f1*f7*f5^3-64*x3^3*x6*f6
^2*f2*f4*f5+12*x3^2*x5^2*f2*f5^2*f4+12*x2^2*x3*x5*f4^3*f5*f3-20*x2^2*x3*x5*f7*
f4^3*f1-4*x2^2*x3*x5*f7*f3^2*f2*f5-24*x2^2*x1*x6*f4^4*f3+432*x4^2*x2*x7*f6*f5^
3*f4-16*x2*x7*f2^2*f7^3*x4^2-64*x2^2*x4*x6*f0*f4^2*f7^2+8*x2^2*x1*x7*f0*f5^4-\
48*x3*x1*x4*x6*f0*f5*f3*f7^2-60*x3*x1*x4*x6*f7*f2*f5^2*f3-72*x3*x1*x4*x6*f3^2*
f5^2*f6+88*x3*x1*x4*x6*f7^2*f3*f4*f1-208*x3*x2*x4^2*f7*f3^2*f5^2*f6+40*x3*x2*
x4^2*f7^2*f2*f5^2*f3-48*x2^2*x4*x7*f0*f6*f3*f7^2+16*x1^3*x2*f0*f6*f5^2*f4*f1-4
*x2^3*x6*f7^2*f2*f1*f3+4*x2^3*x6*f7*f2*f1*f5^2+64*x1^3*x3*f0*f6^2*f3^2*f4-20*
x3*x1*x2*x4*f7*f4^4*f3+16*x2*x1*x3^2*f1^2*f7^2*f6*f3+80*x2*x1^2*x6*f0*f4^2*f7*
f3-32*x4*x5*x1*x2*f2*f7^2*f0*f4+128*x4*x5*x1*x2*f0*f5^2*f3*f7+2*x2^4*f4^6-12*
x2*x5*x1*x7*f3^2*f5*f4+32*x1*x5*x2*x6*f0^2*f7^2+8*x2^2*x5^2*f1*f6*f0*f7+4*x1*
x5^2*x3*f4*f5*f2*f3-8*x1*x5*x2*x6*f3*f7*f2^2+4*x3*x5*x6^2*f7*f2*f3-4*x3*x5*x6^
2*f7*f1*f4+16*x2*x5^2*x3*f1*f0*f7^2-4*x3*x5^2*x7*f4^3+12*x2*x5*x6^2*f4^2*f3-36
*x5*x4*x7^2*f1*f7^2+8*x4*x5*x7^2*f7*f3*f5+8*x1*x5*x7^2*f6*f1*f5-44*x3*x2*x4*x6
*f7^2*f1*f4^2-16*x3*x2*x4*x6*f3*f6^2*f1*f7+64*x3^2*x1*x6*f1*f7*f3*f6*f4+8*x4^2
*x5^2*f4*f5*f7*f2-12*x4^2*x5^2*f4^2*f7*f3+8*x1*x5*x3*x8*f6*f7*f2^2-16*x2^2*x5*
x7*f7*f2*f1*f6-16*x4^2*x5^2*f4*f6*f1*f7-8*x3*x5^2*x6*f1*f5^2+88*x4*x1*x5^2*f0*
f4^2*f7+72*x3*x1*x4*x5*f7*f2^2*f5^2-72*x3*x1*x4*x5*f2*f5^3*f4+80*x3*x1^2*x4*f5
*f4^3*f7*f1-4*x3*x1*x4*x5*f2^2*f7^2*f3+16*x3*x2*x7*x8*f7^2*f2*f4+16*x3*x2*x7*
x8*f7*f5*f4^2-32*x1*x3^3*f1^2*f7^2*f5^2+32*x3^3*x1*f4^3*f1*f7*f6+16*x3^3*x1*f4
^2*f7^2*f3*f1-48*x3^2*x1*x5*f0*f4*f2*f7^2+48*x3^2*x1*x5*f0*f6*f4*f3*f7-8*x3^2*
x1*x5*f3*f6*f2^2*f7-16*x5*x4^2*x6*f3^2*f7*f6+64*x5*x4^2*x6*f0*f6^2*f7-4*x7^2*
x6*x8*f7*f5-4*x3*x7*x6*x8*f7^2*f2-16*x3^2*x4^2*f7*f3*f5^4-8*x2^3*x3*f6*f5^2*f1
*f4^2-176*x4*x7*x3^2*f4*f6*f7*f3*f5+64*x3^2*x4*x7*f0*f4*f7^3-80*x4*x7*x3^2*f7^
2*f5*f3^2+54*x4^2*x5^2*f5^3*f3-8*x1*x7^2*x5*f3*f5*f4+16*x1*x7^2*x3*f0*f4*f7^2-\
32*x1*x7^2*x3*f0*f6*f5*f7-4*x2*x7*x3^2*f3*f5*f1*f7^2+32*x3^2*x2*x7*f6^2*f2*f4*
f5-16*x2*x7*x3^2*f1^2*f7^3+64*x2*x1^2*x3*f6*f5^2*f0^2*f7-16*x2*x1^2*x3*f0*f5^3
*f4^2-16*x2^2*x1*x3*f1^2*f6^2*f7*f3+48*x1*x2*x4^2*f7^2*f2^2*f3*f6-112*x2*x1*x3
*x4*f0*f5^2*f2*f7^2+64*x2*x1*x3*x5*f0*f5^3*f4+14*x3^4*f4^2*f5^4+96*x3*x2^2*x4*
f0*f6*f5*f7^2*f2-112*x1^2*x3*x6*f1*f0*f7^2*f4+56*x1^2*x3*x6*f7*f3^2*f1*f5+96*
x3^2*x5^2*f0*f6^2*f4+96*x4*x1*x6^2*f5^2*f6*f1+36*x4^2*x1*x3*f5^4*f4^2+112*x4*
x3*x6^2*f0*f5*f7^2+128*x3*x4*x6^2*f0*f6^2*f7-16*x4^2*x1*x6*f2^2*f7*f6^2+16*x1^
2*x6^2*f0*f6*f7*f1+12*x4*x6^2*x5*f5*f4^2-56*x4*x6^2*x5*f7*f1*f5-24*x4*x6*x7*x8
*f7*f5^2-20*x4*x6*x7*x8*f7^2*f3+16*x6*x3*x5*x8*f7*f1*f6-32*x1*x4^2*x2*f0*f6*f5
*f7^2*f2-64*x1*x4^2*x2*f0*f6*f4*f5^2*f7+96*x3*x4^2*x2*f0*f6*f7^3*f2-48*x4^2*x3
^2*f6^2*f2^2*f7^2+16*x4^2*x3^2*f3^2*f6^2*f5*f7-32*x4*x2*x7*x8*f7^3*f0+12*x4*x2
^2*x8*f7^2*f3^2*f4-68*x4*x2*x6*x7*f4*f7^2*f1+8*x2^3*x7*f2*f5^3*f4-32*x2^3*x7*
f0*f4*f3*f7^2-4*x3^2*x7^2*f7*f5^2*f3+20*x3^2*x7^2*f7*f5*f4^2-48*x3^2*x7^2*f7*
f3*f4*f6-32*x2^2*x3^2*f0*f5^2*f2*f7^2-24*x2^2*x3^2*f4^2*f6*f7*f2*f3+16*x1^2*x2
^2*f0*f5*f7^2*f1*f2+12*x2^2*x1*x5*f4^3*f3^2-16*x1^2*x2^2*f0*f5*f4^2*f7*f2+48*
x3^2*x4*x6*f3*f7*f4^2*f6+24*x4*x6*x3^2*f3^2*f5*f6*f7-248*x4*x6*x3^2*f0*f5^2*f7
^2+144*x3^2*x1*x4*f0*f4*f2*f7^3-16*x3^2*x1*x4*f3*f6*f2^2*f7^2+12*x2*x1*x3*x5*
f1^2*f7^2*f3-16*x2*x1*x3*x5*f7*f2^2*f5*f3-40*x2*x1*x3*x7*f7*f4*f6*f2^2-4*x2*x1
*x3*x7*f4^3*f7*f2+16*x1^3*x3*f1^2*f4*f7*f6*f3+32*x1^2*x2*x3*f2^3*f6*f7*f4+16*
x1^4*f0*f6*f5^2*f2^2+16*x3^4*f5*f4^2*f7*f2*f6-16*x3^2*x4*x7*f7*f5^3*f3+384*x4*
x7*x3^2*f0*f6*f5*f7^2-8*x3^3*x1*f7*f3^3*f6*f4-64*x3^2*x1*x6*f3*f5^2*f6*f2+128*
x3^2*x1*x6*f0*f6*f5^3+32*x3^2*x1*x6*f6^2*f2^2*f5-32*x3*x2^2*x6*f0^2*f7^3+16*x3
*x2^2*x4*f3*f6^2*f1*f4*f7+8*x3*x2^2*x5*f4*f5^3*f1-96*x3*x1*x4*x7*f0*f6^2*f4*f7
-32*x3*x1^2*x7*f6^2*f0*f4^2+64*x7^2*x1*x2*f0*f6*f7*f4-8*x3*x7^2*x6*f5^3-8*x4*
x7^2*x5*f7*f2*f6+4*x1*x7^2*x5*f4^3-60*x1^2*x4^2*f7^2*f6*f1^2*f4+40*x1^4*f0*f4*
f1^2*f7^2-12*x1^4*f7*f2^3*f3*f4-16*x1^4*f6*f5^2*f1^2*f2-72*x1^2*x4^2*f7^3*f1*
f0*f4-24*x2^2*x1*x6*f0*f3*f7^2*f2+16*x2^2*x1*x6*f7*f3*f4^2*f1+232*x3*x4^2*x7*
f7*f5^2*f3*f6+2*x4^2*x1^2*f7*f4^4*f3+24*x4*x3^2*x8*f7^2*f4^3+12*x2^2*x3^2*f4*
f5^4*f2+78*x1^2*x4^2*f7^2*f4^2*f2^2-8*x2^3*x4*f6*f4*f5*f7*f2^2-48*x1^4*f6*f5^2
*f4*f0^2+16*x2^2*x1*x6*f5*f4^3*f2-44*x2^2*x1*x6*f5^2*f4^2*f1+60*x1^2*x2*x4*f1^
2*f4^2*f7^2+96*x4^2*x2*x8*f7*f5^3*f4-248*x4^2*x2*x8*f7^3*f0*f5-12*x2*x8*f7^3*
x4^2*f2*f3-24*x2*x8*f7^2*x4^2*f6*f1*f5+24*x4^2*x2*x8*f7^2*f2*f4*f6+8*x7*x2*x5*
x8*f7*f1*f6-16*x2*x6*x7*x8*f1*f7^2-58*x4^2*x6^2*f5^2*f7*f3+8*x4^2*x6^2*f4*f6*
f3*f7+16*x6^2*x1*x3*f0*f6*f7*f3-24*x3*x2*x5^2*f0*f5^3-24*x3^2*x1*x8*f7*f4*f6*
f1*f5+16*x3^2*x1*x8*f7*f3*f1*f6^2+48*x3*x2*x6*x7*f7*f3*f4^2+32*x3*x1^2*x5*f3^2
*f1*f5*f6+8*x3^2*x1*x8*f7*f5^2*f2*f4-32*x3^2*x1*x8*f7*f0*f6*f5^2-20*x4*x7*x3^2
*f1*f5^2*f7^2-64*x4*x7*x3^2*f1*f6^2*f7*f5-72*x3^2*x4*x7*f4^2*f7^2*f3+20*x1^3*
x2*f1*f4*f7*f2^2*f5+4*x1^3*x7*f4^4*f2-4*f7*x2*x8^2*x3*f4*f5^2+4*f7^2*x2*x8^2*
x7*f3+12*f7*x2*x8^2*x4*f5^3-24*f7*x2*x8^2*x4*f4*f5*f6+12*f7^2*x2*x8^2*x4*f3*f5
+52*x2*x7*x3^2*f1*f4^2*f7^2-48*x3^2*x2*x7*f6^2*f5^2*f1-40*x1^2*x3*x5*f4*f1^2*
f7*f5-28*x4^2*x2*x7*f7^2*f2*f4*f5-16*x4^2*x2*x7*f7^2*f5*f3^2-124*x4^2*x2*x7*f7
^3*f3*f1-176*x4^2*x2*x7*f0*f4*f7^3+4*x5^4*f0*f4-36*x4*x5*x2^2*f4^3*f7*f2+40*x2
^2*x6^2*f0*f5*f7*f4-16*x1^2*x2*x7*f2^2*f5*f4*f6-24*x1^2*x2*x7*f7*f2*f5*f1*f4+
40*x1^2*x3*x5*f4^2*f1*f7*f2-188*x4^2*x3^2*f7^2*f3^2*f5^2+1072*x1^2*x4^2*f7^2*
f0*f5*f3*f4-16*x1^2*x2*x3*f1^2*f4^2*f7*f6-32*x1^3*x2*f0*f5^2*f4^2*f3-8*x1^3*x3
*f7^2*f2^4+64*x1^3*x2*f6*f5*f3*f0^2*f7+4*x2^4*f5^2*f4^3*f2-108*x4^2*x2*x7*f5^5
-48*x2^2*x1*x6*f0*f5^2*f2*f7-40*x2^2*x1*x6*f4*f5^2*f2*f3+64*x2^2*x1*x6*f0*f6*
f4*f2*f7-40*x2^2*x1*x6*f6*f7*f1^2*f4+24*x2^2*x3*x8*f7^2*f2*f1*f6-104*x3*x4*x2^
2*f4*f6*f2*f7^2*f1-16*x1^3*x6*f7*f6*f0*f3*f1+16*x2^3*x7*f7*f2*f1*f5*f6+44*x2^3
*x7*f7*f4^2*f5*f1-16*x2^3*x7*f0*f6*f5*f3*f7-32*x2^3*x7*f0*f5^2*f4*f7+16*x2^3*
x7*f0*f5*f2*f7^2+16*x2^3*x7*f2*f7^2*f1*f4+112*x2^2*x4^2*f7^2*f3*f5^2*f1+2*x2^2
*x1^2*f7*f3^5-16*x3*x4*x2^2*f1^2*f5*f7^2*f6+56*x2^2*x3*x4*f3*f5^2*f6*f1*f7-128
*x3*x4*x2^2*f6*f0^2*f7^3-2*x1^2*x5^2*f5*f3*f2^2-4*x1*x5*x2*x8*f7*f2*f3*f4-44*
x1*x5*x2*x7*f4*f7*f3*f1-24*x1*x5*x2*x7*f4^2*f6*f1-192*x2*x1^2*x4*f6*f0^2*f7^2*
f4-96*x1^2*x3*x4*f4^2*f6*f1*f5^2-104*x1^2*x3*x4*f1*f4^2*f7^2*f2+36*x2*x6*x3^2*
f3*f5^2*f7*f2-36*x1*x6*x3^2*f3*f5*f7*f2*f4-68*x3^2*x2*x6*f5^2*f4^3-208*x1*x4^2
*x2*f0*f5^4*f7-88*x1*x4^2*x2*f5^2*f7*f3^2*f4-24*x3*x4*x6*x8*f7*f3*f5*f6-16*x4*
x3*x6*x8*f7*f6^2*f2+136*x4*x3*x7*x8*f7*f4*f5*f6-32*x4^2*x1^2*f2^3*f6*f7^2+90*
x4^2*x1^2*f3*f5^3*f4^2-192*x4^2*x1^2*f6^2*f0^2*f7^2+48*x4*x1*x5*x6*f5^2*f2*f4+
36*x4*x1*x5*x6*f3^2*f5^2-48*x4*x1*x5*x6*f5^3*f1-36*x4*x1*x5*x6*f3*f5*f4^2-44*
x4*x1*x5*x6*f7*f2^2*f5+40*x1*x7*x3^2*f1*f7^2*f2*f5+48*x3^2*x1^2*f6^2*f5^2*f1^2
+28*x3*x2*x4*x6*f1*f5*f7^2*f3+144*x3*x2*x4*x6*f7^2*f2*f6*f1-192*x3*x2*x4*x6*f0
*f6^2*f7*f4-96*x3*x2*x4*x6*f2*f5^3*f6+64*x3*x2*x4^2*f7^3*f0*f4^2+64*x3*x2*x4^2
*f7*f3*f5*f4^2*f6+8*x3*x1*x5*x6*f1*f4^2*f6-64*x1*x4*x3*x6*f6^2*f2*f1*f7+16*x3^
2*x6*f3*f6^2*f2*f7*x4-56*x4^2*x2*x6*f2^2*f7^2*f6-136*x4^2*x2*x6*f2*f7^2*f4^2-\
64*x4^2*x2*x6*f0*f6^2*f5*f7+20*x1*x2*x3^2*f1^2*f7^2*f4*f5-144*x2*x1*x3*x4*f0*
f5^3*f4*f7+112*x2*x1*x3*x4*f7*f3*f5^3*f1-208*x3*x2*x4*x6*f5^3*f7*f1+32*x3*x1*
x5*x6*f2*f5^2*f3+32*x3*x1*x5*x6*f3*f4*f2*f6-264*x3*x2*x4*x7*f7*f3*f5^2*f4+24*
x3*x2*x4*x7*f7^2*f3^2*f4+16*x4*x1^2*x6*f1*f6*f7*f3^2-24*x4^2*x1*x8*f7^2*f2*f4*
f5-72*x4^2*x1*x8*f7^2*f1*f5^2+36*x4^2*x3^2*f4*f5^4*f6+48*x1*x5*x4*x7*f6*f1*f5^
2+8*x2*x5*x1*x7*f5^2*f2*f3+8*x1^2*x5^2*f1*f5*f4*f2-48*x1^2*x5*x7*f4*f6*f1*f3-\
72*x3*x2*x4^2*f4*f5^5+32*x3*x2*x6*x8*f7*f0*f6^2-12*x3*x2*x6*x8*f7*f5^2*f2+20*
x3*x2*x7*x8*f7*f5^2*f3-12*x3^2*x2*x6*f4*f5^3*f3-32*x1^2*x5*x7*f0*f5^2*f4-4*x1*
x5^2*x2*f4^3*f1-24*x4*x5^2*x2*f7*f6*f2*f1+8*x2*x5*x7^2*f5*f4^2-40*x3^3*x4*f7^2
*f2*f3*f5^2+24*x3*x2*x7*x8*f7*f3*f6*f4+8*x3*x2*x1*x6*f0*f3^2*f7^2-32*x3*x2*x6*
x7*f2*f6*f5^2-32*x3*x1^2*x6*f0*f6*f5*f4^2+112*x1^2*x2*x4*f0*f7^3*f1*f2-128*x1^
2*x2*x4*f4^2*f7^2*f0*f2-96*x1^2*x3*x4*f2*f7*f5^3*f1-24*x2*x6*x7^2*f4^2*f6-48*
x1*x5*x2*x6*f0*f6*f7*f1-8*x1^2*x5*x6*f1*f6*f2*f4+32*x2*x5*x3*x8*f7^2*f0*f4-8*
x2*x5*x3*x8*f7*f1*f4*f6+4*x1*x5^2*x2*f7*f2^3-16*x3*x5*x6^2*f2*f4*f6-2*x1^2*x5^
2*f4^2*f2^2+152*x1*x2*x4^2*f7^2*f3*f4^2*f2-16*x2^2*x1^2*f0*f6*f3^3*f7-4*x1^2*
x5*x7*f5^2*f2^2-8*x2^2*x5*x8*f5*f7*f1*f4+16*x2^2*x5*x7*f0*f6*f7*f3-12*x1*x5*x2
*x7*f7*f2*f3^2-8*f7*x2*x8^2*x3*f4^2*f6+4*x2^2*x6*x8*f7^2*f2^2-16*x1^2*x3^2*f3*
f5^2*f1*f4*f6+4*x5*x6^2*x7*f4^2-32*x3*x4*x2^2*f4^2*f6*f5*f7*f1-48*x1^2*x2*x4*
f4^2*f5^3*f1+16*x1*x5*x6*x7*f2*f4*f5-16*x4*x5*x6*x7*f0*f7^2+72*x5*x4*x6*x7*f7*
f2*f5+40*x5*x4*x6*x7*f7*f1*f6+64*x1^3*x6*f0^2*f6^2*f5-12*x1^3*x6*f3*f5^2*f2^2-\
96*x1^3*x6*f5^2*f0^2*f7-24*x1^3*x6*f1^2*f4^2*f7-28*x2^2*x1*x6*f7*f2^2*f4^2+64*
x2^2*x1*x6*f1*f7*f2*f4*f5+72*x2^2*x1*x6*f0*f5^3*f4+96*x3^2*x2*x6*f0*f6^2*f5^2-\
8*x3^3*x6*f3*f5^4+86*x1^2*x4^2*f7^3*f1^2*f3+8*x1^2*x6*x7*f0*f7*f4^2-16*x1*x6^2
*x2*f0*f6*f7*f2+4*x3*x6^2*x1*f2^2*f7*f5-8*x2^2*x3^2*f1*f5^2*f7*f6*f2+12*x2^2*
x3^2*f1*f7^2*f2*f4*f5+12*x1*x5*x2*x7*f3*f4^3+32*x1*x5*x6^2*f0*f5^2-16*x3*x5*x7
^2*f4^2*f6+12*x1^2*x5*x6*f4^2*f2*f3+8*x1^3*x6*f2*f5^2*f1*f4-16*x1^3*x6*f2^2*f3
*f4*f6-48*x1^2*x3*x4*f6^2*f2^2*f5*f4+48*x1^2*x2*x4*f3*f5^3*f2*f4-12*x3^3*x5*f2
*f5*f4^2*f7+16*x3^3*x5*f0*f6*f5*f7*f4+108*x4^2*x5*x7*f5^4+48*x2*x3^3*f1*f5*f7*
f4^2*f6+16*x2*x3^3*f3*f5^2*f6*f7*f1+64*x3^3*x2*f6^2*f2*f5*f4^2+16*x2*x3^3*f7*
f2^2*f5^2*f6-32*x2*x3^3*f5*f4^3*f7*f3-56*x1^2*x4*x6*f7^2*f1^2*f4-176*x4^2*x2*
x6*f0*f6*f4*f7^2-72*x4^2*x2*x6*f7^2*f2*f3*f5+84*x4^2*x2*x6*f7^2*f3^2*f4+112*x4
^2*x2*x6*f7*f2*f4*f5*f6+296*x4^2*x2*x6*f0*f5^2*f7^2-8*x3^2*x2*x5*f1*f5^4+20*x3
^2*x2*x5*f3*f7*f2*f4*f5+352*x3*x1*x4^2*f0*f6*f1*f7^3-4*x3*x1*x2*x4*f7^2*f3^4-8
*x3^2*x7*x8*f7^2*f3*f4-16*x2^4*f5^2*f0^2*f7^2+32*x6^2*x2*x7*f7*f1*f5+32*x6^2*
x3*x7*f4*f5^2+16*x6^2*x3*x7*f4^2*f6+16*x6^2*x3*x7*f0*f7^2-16*x6^2*x3*x7*f7*f3*
f4-24*x6^2*x3*x7*f7*f2*f5-36*x6^2*x4*x7*f7*f3*f5+72*x6^2*x4*x7*f4*f5*f6-16*x6^
2*x4*x7*f7*f2*f6-20*x2^3*x4*f1*f7^3*f2^2+12*x2^3*x4*f5^2*f4^4+4*x2^3*x5*f7*f3^
2*f2*f4+16*x1*x5*x2*x6*f3^2*f7*f1-16*x1*x5*x2*x6*f2*f4*f7*f1-4*x3*x5^2*x8*f7*
f3^2+96*x4*x1*x3*x7*f3*f5^2*f6*f4-352*x4*x1^2*x7*f0^2*f7^3-36*x4*x2*x5^2*f5^3*
f1+8*x4*x2^2*x6*f7*f2^2*f6*f5-96*x3^2*x4*x6*f6^2*f2*f5^2+160*x3^2*x4*x6*f6^2*
f4*f1*f7+4*x4*x6*x3^2*f4^3*f5*f7-32*x2*x6*x7^2*f0*f7^2-24*x1^2*x6*x7*f5^2*f2*
f3+8*x1^2*x6*x7*f5^2*f1*f4-6*x1^2*x6^2*f3^3*f5-40*x1^2*x6^2*f0*f7*f3*f4+132*x4
*x3*x5*x6*f5^2*f7*f1-168*x3*x4*x5*x6*f4*f6*f7*f1+96*x5^2*x2*x4*f0*f5*f4*f7+12*
x4*x1*x2*x8*f7^2*f1*f4^2-72*x4^2*x1*x6*f2*f5^3*f6+36*x1^2*x6*x7*f2*f5*f7*f1-4*
x1*x6^2*x2*f3*f7*f1*f4-12*x2^2*x1*x6*f1^2*f7^2*f3+12*x2^2*x1*x6*f1*f7^2*f2^2+8
*x3^2*x2^2*f3*f5*f6*f1*f4*f7+216*x3*x2*x4^2*f3*f5^4*f6-144*x3*x1*x4^2*f6^2*f5^
3*f1-4*x3*x1*x4^2*f5^4*f1*f7-36*x3*x1*x4*x5*f3^2*f5^3+40*x3^2*x2*x6*f7*f2*f5*
f4^2-12*x3*x1^2*x4*f4^5*f5-36*x4^2*x6*x8*f7*f5^3+116*x4*x6*x3^2*f2*f7*f5^3+16*
x1*x2^2*x4*f0*f5^2*f4^2*f7+16*x2^2*x1*x3*f0*f5*f4^3*f7-40*x2*x1*x4*x6*f7*f4^3*
f2+12*x2*x1*x4*x6*f7^2*f2^2*f3+8*x2^2*x1^2*f3^2*f1^2*f7^2-16*x3^3*x5*f0*f4^2*
f7^2+16*x3^3*x5*f1^2*f7^2*f6+8*x3^3*x5*f2*f7^2*f1*f5+32*x3^2*x4*x8*f7*f6^3*f1-\
32*x1*x4*x2*x7*f0*f6*f7^2*f2+160*x1*x4*x2*x7*f0*f6*f7*f4*f5-48*x1*x4*x2*x7*f0*
f7^2*f4^2-96*x4*x1^2*x5*f4*f5^3*f0-48*x3*x4^2*x2*f6^2*f2*f7*f4^2+80*x4*x1*x5*
x6*f0*f7*f4*f5-144*x4*x3^2*x5*f3*f5^2*f6*f4+4*x5^2*x6^2*f2*f4-8*x2^3*x3*f1^2*
f5*f7^2*f4-16*x2^3*x3*f0*f6*f5^3*f4+4*x4^4*f4^3*f7^2*f6+1100*x4^4*f0*f4*f7^4-\
16*x4^4*f7^2*f5^3*f3+16*x1*x7^2*x3*f1*f7^2*f3-32*x4*x7^2*x2*f0*f6*f7^2-8*x4*x7
^2*x2*f7*f6*f5*f2+32*x3^2*x1*x5*f1^2*f7*f5*f6-28*x3^2*x1*x4*f7^3*f2*f1*f3+112*
x3^2*x1*x4*f0*f5*f7^3*f1-48*x3^2*x1*x4*f4*f6^2*f1*f5^2-16*x6*x3^2*x8*f7*f6^2*
f1-16*x4*x1*x2*x5*f0*f6*f5*f2*f7+16*x3*x8*f7*x2*x4*f5^2*f6*f2+32*x4^2*x1^2*f6^
2*f2^2*f7*f3, -108*x2^2*x1*x7*f7*f2*f1*f4*f5-40*x2^2*x1*x7*f0*f4^3*f7-104*x2^2
*x1*x7*f0*f5^3*f4-16*x2^2*x3*x8*f5^3*f7*f0-16*x2^2*x3*x8*f5*f7*f3*f1*f6+8*x2^2
*x3*x8*f5^2*f7*f1*f4-36*x2^2*x3*x8*f5*f7^2*f2*f1+48*x2^2*x4*x8*f7^3*f1^2-832*
x1^2*x2*x4*f0*f3*f4^2*f7*f5-72*x1^3*x4*f1^2*f5^4+16*x1^2*x2*x3*f7*f0*f6*f2*f3*
f4+4*x1^2*x2*x3*f4^3*f5*f3*f2+176*x1^2*x2*x3*f0*f5*f7^2*f2*f1-16*x1^3*x5*f3^2*
f1*f4^2+8*x1^3*x5*f1*f4*f2^2*f6-16*x1^3*x5*f2^3*f4*f5-168*x2^2*x1*x3*f6*f2*f5^
2*f1*f4+8*x2*x1*x7^2*f4^4+268*x1^2*x4*x5*f7*f2*f5*f1*f3+4*x1^3*x4*f7*f3^5+76*
x1^2*x2*x4*f4^3*f3*f1*f7+284*x2*x4*x1^2*f1*f3^2*f7*f5*f4+60*x2*x4*x1^2*f2*f5*
f7*f1*f4^2+48*x1^3*x4*f7^2*f3^2*f0*f2+48*x1^3*x4*f3*f6*f4*f2^2*f5+32*x1^3*x4*
f1*f3^2*f7*f2*f6-368*x1^3*x4*f0*f5*f6*f7*f2^2+304*x1^3*x4*f7*f5*f6*f2*f1^2-36*
x1^3*x4*f3*f5^3*f2^2-24*x1^3*x4*f7^2*f2^4-32*x3^2*x5*x6*f4^2*f6*f2+96*x3^2*x5*
x6*f0*f6^2*f4+72*x3^2*x5*x6*f5^3*f1-288*x3^2*x5*x6*f0*f6*f5^2-20*x3^2*x5*x6*f7
*f1*f4^2+24*x3^2*x5*x6*f5^2*f2*f4+16*x3^2*x5*x6*f1*f5*f4*f6-56*x5*x6*f7*f0*f4*
x3^2*f5+40*x3^2*x5*x6*f7*f2*f1*f6-144*x3^2*x1*x6*f0*f5^4-48*x3^2*x1*x6*f5*f4^2
*f1*f6-64*x3^2*x1*x6*f1^2*f6*f7*f5-40*x3^2*x1*x6*f7*f2*f6*f1*f4+8*x3^2*x1*x6*
f7*f2^2*f6*f3-8*x3^2*x1*x6*f6*f4*f5*f2*f3-240*x3^2*x1*x6*f3*f5^2*f6*f1-20*x3^2
*x1*x6*f5^2*f4^2*f2-32*x3^2*x1*x6*f4*f6^2*f2^2+64*x3^2*x1*x6*f7*f3*f5*f1*f4-72
*x3^2*x1*x6*f1*f5^3*f4-48*x1^2*x4*x6*f7*f2*f6*f3*f1-64*x1^2*x3*x7*f2*f6*f7*f3*
f1-60*x1^2*x3*x7*f1*f5*f7*f3^2+36*x1^2*x3*x7*f2^2*f3*f7*f5+8*x3^2*x6*x2*f3^2*
f6*f7*f2-64*x4*x5*x1*x3*f7^2*f2*f1*f3-12*x1*x3*x4*x5*f7*f3*f4*f1*f5+144*x1*x3*
x4*x5*f0*f6*f4*f3*f7+36*x1*x3*x4*x5*f3^2*f5^2*f4+36*x2*x3^2*x4*f5^5*f2+24*x2*
x3^2*x4*f5*f4^4*f6+32*x1*x3^2*x6*f0*f4*f2*f7^2-16*x1*x3^2*x6*f3*f6^2*f4*f1-432
*x1^2*x3*x4*f0*f6*f5^3*f3-16*x3^2*x4*x2*f6^2*f2*f7*f3^2+8*x1*x3^2*x8*f5*f7^2*
f2*f1-96*x1*x3^2*x8*f7*f0*f6*f5*f4+24*x1*x3*x7^2*f1*f5^2*f6-24*x1*x3*x7^2*f7*
f4^2*f2+8*x1*x3*x7^2*f1*f7^2*f2+20*x1*x3*x7^2*f5*f4^3-56*x1*x3*x7^2*f5^2*f3*f4
-72*x1*x3*x6^2*f2*f5^2*f3+4*x1*x3*x6^2*f2*f5*f4^2-32*x4*x5*x2*x3*f2^2*f6*f7*f4
+44*x2*x3*x4*x5*f7*f2^2*f5^2-48*x2*x3*x4*x5*f5*f4^4+80*x2*x3*x4*x5*f7*f4^2*f5*
f1+864*x2*x3*x4*x5*f0*f6*f5^3-72*x1*x3*x4^2*f4^2*f3*f5^2*f6+720*x1*x3*x4^2*f6*
f2*f5^3*f4-144*x1*x3*x4^2*f7*f2^2*f5^2*f6-80*x1*x3*x4^2*f7*f3^3*f5*f6-48*x1^2*
x3*x6*f0*f6*f5^2*f2+2*x1^2*x3^2*f4^5*f3-36*x2^2*x3^2*f0*f5^5-52*x2^3*x4*f1*f5^
3*f7*f2-16*x2^3*x4*f0*f6*f5*f4*f3*f7-72*x2^3*x4*f0*f5^5-8*x2^3*x4*f7*f3^2*f4^3
+40*x2^3*x4*f5*f4^2*f7*f2*f3-48*x2^2*x3*x4*f4^4*f5^2-54*x2^2*x4^2*f5^4*f3*f4-\
12*x2^2*x4^2*f7^3*f1^2*f4+52*x2^2*x4^2*f7*f3^2*f5^2*f4-64*x2^2*x4^2*f7*f3*f5^2
*f1*f6-4*x2^2*x4^2*f5*f4^3*f7*f3-240*x2^2*x4^2*f7^3*f1*f5*f0-232*x2^2*x4^2*f7^
2*f0*f5*f4^2-28*x2^2*x4^2*f7^2*f4^3*f1-16*x1^3*x7*f1^2*f5*f4*f6+24*x1^3*x7*f2^
3*f5*f6+32*x1^3*x7*f1*f6^2*f0*f4-32*x1^3*x7*f0*f4^2*f7*f2-12*x1^3*x7*f3*f5*f4^
2*f1-8*x1^3*x7*f3^2*f6*f4*f1-192*x1^3*x7*f6^2*f0^2*f5+20*x1^3*x7*f1^2*f7*f4^2+
96*x1^3*x7*f0*f6*f3^2*f5+64*x1^3*x7*f0^2*f7*f6*f4+36*x1^3*x7*f1*f5^2*f3^2+160*
x1^3*x7*f5^2*f0^2*f7+8*x1^3*x7*f7*f2^3*f4-16*x1^3*x7*f2^2*f5*f4^2-16*x1^3*x4*
f7^2*f4*f1^2*f2+24*x1^3*x4*f5^2*f2*f3^2*f4-32*x1^3*x4*f7*f0*f3^3*f6+16*x1^3*x4
*f7*f0*f6*f2*f3*f4+128*x1^3*x4*f5^3*f0^2*f7-32*x1^3*x4*f7*f2^2*f1*f4*f6-80*x1^
3*x4*f0*f7^2*f1*f3*f4+576*x1^3*x4*f6*f0^2*f7*f5*f4-68*x1^3*x4*f1^2*f5^2*f3*f7-\
100*x1^3*x4*f1*f5^2*f7*f2^2+68*x1^3*x4*f7*f2^3*f4*f5+16*x1^3*x4*f1*f7^2*f2^2*
f3+12*x1^3*x4*f4^2*f3^3*f5-20*x1^3*x4*f7*f2*f4*f3^3+96*x1^3*x4*f0*f5^2*f4^3+
144*x1^3*x4*f0*f6*f5^3*f1-48*x1^3*x4*f5^2*f2^2*f4^2-32*x1^3*x4*f0*f4^3*f3*f7+
288*x1^3*x4*f0*f6*f5^2*f3^2-48*x1^3*x4*f1^2*f3*f7*f4*f6+108*x1^3*x4*f3^2*f5^3*
f1+24*x1^2*x2^2*f7*f2*f3^2*f1*f5-24*x1^2*x2^2*f7*f2^3*f3*f5+4*x1^3*x2*f1^2*f3^
2*f7*f5+8*x2^3*x7*f7^2*f2*f1*f3-12*x2^3*x7*f5*f4^3*f3+192*x4^2*x7^2*f7^3*f0-48
*x1^3*x6*f0*f6*f5*f2*f3+56*x1^3*x6*f0*f5*f7*f1*f3-12*x1^3*x6*f5^2*f2^3-48*x2^2
*x3*x7*f4^2*f5^2*f3+288*x2^2*x3*x7*f0*f7*f5^2*f4+24*x2^2*x3*x7*f1*f4*f7^2*f2+4
*x2^2*x3*x7*f7*f4^2*f5*f1-48*x2^2*x4*x7*f5^2*f4^3+24*x4^2*x8*f7*f5*f4^2*x3*f6-\
8*x4^2*x3*x8*f7^2*f3^2*f6+32*x4*x3*x5*x8*f7*f6*f1*f5+304*x4*x3*x5*x8*f7^2*f0*
f5-44*x4*x3*x5*x8*f7^2*f1*f4+52*x4*x3*x5*x8*f7*f3*f5*f4-48*x4*x3*x5*x8*f7*f5^2
*f2+20*x4*x3*x6*x8*f7^2*f3^2+24*x4*x3*x6*x8*f7^2*f2*f4+4*x4*x3*x6*x8*f7*f5*f4^
2+96*x4*x3*x6*x8*f7^2*f0*f6-96*x4*x3*x6*x8*f7^2*f1*f5+72*x4*x3*x6*x8*f7*f3*f5^
2-32*x4*x3*x6*x8*f7*f6^2*f1+8*x7*x8*f7*f4^2*x3*x4*f6+64*x4*x3*x7*x8*f7^3*f0-\
352*x4*x3*x7*x8*f7*f4*f5^2-44*x4*x3*x7*x8*f7^2*f3*f4+324*x1^2*x4^2*f0*f5^5-52*
x1^2*x4^2*f5*f4^3*f7*f1-48*x4*x3^2*x7*f0*f7^3*f3+8*x4*x3^2*x7*f2*f7^3*f1+24*x4
*x3^2*x7*f7^2*f3^2*f4-32*x4^2*x7*x3*f6^2*f7*f4*f2-216*x4^2*x3*x5*f6*f5^3*f2+32
*x4^2*x5*f0*f6^2*f7*f4*x3-16*x4^2*x3*x5*f6^2*f2^2*f7-16*x4^2*x3*x5*f3*f5*f6*f2
*f7-80*x4^2*x3*x5*f0*f6*f7^2*f3-64*x1*x4*x5*x6*f0*f4^2*f7+108*x1*x4*x5*x6*f2*
f5^2*f3-36*x1*x4*x5*x6*f3^2*f4*f5+48*x1*x4*x5*x6*f4*f5^2*f1-48*x1*x4*x5*x6*f4^
2*f5*f2-36*x1^2*x4*x6*f4*f5^2*f2*f3-60*x1^2*x4*x6*f4^2*f3^2*f5+24*x1^2*x4*x6*
f5*f4^3*f2+36*x1^2*x4*x6*f5^2*f4^2*f1+96*x1^2*x4*x6*f0*f6*f4*f2*f7-144*x4^2*x3
^2*f6^2*f2*f1*f7^2+64*x2*x4*x7^2*f0*f7^2*f5+148*x2*x4*x7^2*f7*f5^2*f2-56*x2*x4
*x7^2*f7^2*f1*f4+52*x2*x4*x7^2*f7*f3*f4*f5-72*x2*x4*x7^2*f5*f4^2*f6+72*x1*x4*
x3*x7*f5^4*f2+64*x4*x3*x2*x7*f2*f7^2*f1*f6+32*x2*x7*f0*f6^2*f7*f4*x3*x4+16*x4^
2*x3^2*f6^3*f2^2*f7+64*x4^2*x3^2*f0*f6^2*f3*f7^2-4*x4^2*x3*x5*f7*f4^4-4*x4^2*
x3*x5*f7^2*f3^3-24*x4*x3*x5*x6*f3^2*f4*f7+16*x2*x4^2*x7*f7*f3*f4^2*f6-48*x1*x4
*x2*x7*f2*f5*f4^2*f6+120*x1*x4*x2*x7*f2*f5^3*f4-12*x3*x5*x2*x4*f3*f5*f7*f2*f4+
144*x2*x4*x3*x7*f6*f5^3*f2+12*x4*x3*x5*x8*f7^2*f2*f3+24*x1^2*x4*x7*f2^3*f7^2+
12*x1^2*x4*x7*f5^2*f4^2*f2+264*x1*x4^2*x3*f7*f3*f5^3*f2+432*x1*x4*x6^2*f0*f6*
f5^2+252*x1*x4*x6^2*f7*f5*f1*f3+20*x1*x4*x6^2*f1*f7*f4^2-376*x1*x4*x6^2*f0*f5*
f7*f4-96*x1*x4*x6^2*f4*f6*f1*f5-64*x1*x4*x6^2*f7*f2*f3*f4+36*x1*x4*x6^2*f7*f2^
2*f5+48*x1*x4*x6^2*f5*f4^2*f3-24*x1^4*f0*f7^2*f2^2*f1+32*x1^4*f0^2*f7^2*f2*f3+
24*x1^4*f0*f5^3*f3*f1+80*x1^4*f0*f3*f2*f1*f7*f6-64*x1^4*f5^3*f4*f0^2+10*x1^4*
f5*f2^3*f4^2+32*x1^4*f0^2*f7^2*f4*f1-24*x1^4*f0*f7^2*f1^2*f3-4*x2^3*x5*f1*f4^2
*f7*f2+12*x2^2*x3*x5*f1^2*f7^2*f3-8*x2^2*x3*x5*f7*f3^2*f5*f1+4*x2^2*x3*x5*f5*
f4^3*f2-4*x2^3*x6*f1^2*f7^2*f3+4*x2^3*x6*f7*f2^2*f5*f3-4*x2^3*x6*f3*f7*f1*f4^2
-12*x2^2*x5*x8*f7^2*f1^2+8*x2^2*x5*x8*f7*f1*f3*f5-4*x2^3*x8*f7*f1*f5^2*f3+76*
x1^2*x2^2*f5^2*f7*f2*f1^2+16*x2^2*x1*x3*f4^5*f3+64*x2^2*x1*x3*f6^2*f0^2*f7*f4-\
32*x2^2*x1*x3*f1*f4*f7*f3^2*f5-12*x2^2*x1*x3*f5*f4^4*f2+136*x2^2*x1*x3*f4^2*f3
*f1*f5*f6+12*x2^2*x1*x3*f7^2*f2^3*f3+48*x2^2*x1*x3*f0*f4^2*f1*f7^2-32*x2^2*x1*
x3*f4^3*f3*f2*f6-8*x2^2*x1*x3*f7*f2^3*f5^2+16*x2*x1^2*x5*f1*f4^2*f0*f7-256*x2*
x1^2*x5*f5*f0^2*f4*f7+32*x2*x1^2*x5*f2*f5*f1*f4^2-64*x2*x1^2*x5*f3^2*f4*f1*f5+
864*x1*x2*x4*x5*f0^2*f7^2*f5-136*x2*x1*x4^2*f7*f5^2*f4^2*f1+608*x2*x1*x4^2*f0*
f6*f7*f4^2*f5+128*x1*x2*x4^2*f7^3*f1*f0*f4-528*x2*x1*x4^2*f5^3*f7*f2^2+80*x2*
x1*x4^2*f5*f6^2*f7*f1^2-16*x2*x1^2*x4*f0*f7*f4^4+24*x2*x1^2*x4*f7*f2^2*f3^2*f6
-16*x2*x1^2*x4*f7*f3^3*f1*f6+32*x2*x1*x4*x8*f7^2*f6*f1^2+112*x2*x1*x4*x8*f7*f5
^2*f4*f1-96*x2*x1*x4*x8*f7*f0*f5^3+20*x2*x1*x5*x8*f7*f1*f2*f5-8*x2*x1*x5*x8*f7
*f1^2*f6+8*x2*x1*x6*x8*f7^2*f1^2+16*x2*x1*x3*x7*f4^5+64*x2*x1^2*x3*f4^2*f0^2*
f7^2+20*x2*x1^2*x3*f4^4*f3^2+16*x2*x1^2*x3*f7^2*f3^2*f1^2+32*x2*x1^2*x3*f2^2*
f4*f5*f3*f6-24*x2*x1*x3^2*f7^3*f1^3-56*x1*x2*x3^2*f5*f4^2*f7*f3*f1+32*x2*x1*x3
^2*f4^2*f6^2*f2^2+32*x2*x1*x3^2*f4*f5^2*f6*f2^2+60*x2*x1*x3^2*f5^4*f3*f1-12*x2
*x1^2*x5*f2^3*f5^2-16*x2*x1^2*x5*f5^2*f0*f4*f2-48*x2*x1^2*x5*f0*f5^3*f1+20*x2*
x1^2*x5*f2*f3^2*f4^2+288*x2*x1^2*x5*f6*f5^2*f0^2-72*x2*x1^2*x5*f0*f5^2*f3^2+84
*x2*x1*x6*x7*f3^2*f5*f4-336*x2*x1*x6*x7*f0*f6*f5*f4+64*x2*x1*x6*x7*f0*f7*f4^2-\
64*x2*x1*x6*x7*f5^2*f4*f1+64*x2*x1*x6*x7*f1*f6*f4^2+40*x2*x1*x6*x7*f1*f7*f2*f5
-32*x2*x1*x6*x7*f4^3*f3-48*x2*x1^2*x7*f5*f4*f3^3-96*x2*x1^2*x3*f0*f5^3*f3*f4-\
32*x2*x1^2*x3*f0*f6*f3^3*f7-32*x3*x4*x1*x2*f0*f6^2*f5*f1*f7-16*x2^2*x1*x5*f7*
f3*f1*f2*f4+32*x2^2*x1*x6*f0*f6*f7*f3*f2+576*x2*x1^2*x4*f0*f6*f5^3*f2+64*x2*x1
^2*x4*f6^2*f0^2*f7*f4+24*x2*x1^2*x4*f6*f7^2*f1^3+32*x2*x1*x4^2*f3^3*f5^2*f7-\
128*x4^2*x1*x2*f1*f5*f7^2*f2*f4+140*x2*x1*x4^2*f7^2*f4^2*f2^2+224*x4^2*x1*x2*
f0*f3*f2*f7^3+16*x2*x1*x3*x8*f7*f1^2*f6^2-32*x2*x1*x3*x8*f7*f1*f6*f2*f5-60*x2*
x1*x4*x8*f7^2*f2*f5*f1+192*x2*x1^2*x7*f0*f6*f5^2*f2+192*x2*x1^2*x7*f0*f6*f5*f3
*f4-48*x2*x1^2*x6*f3^2*f1*f5^2-16*x2*x1^2*x6*f0*f6*f7*f2^2-32*x2*x1*x4*x6*f7^2
*f2*f3*f1+24*x2*x1*x4*x6*f2*f5^2*f4^2+8*x3^3*x6*f1*f7^2*f2*f5-144*x3^3*x6*f5^3
*f6*f1+44*x3^3*x6*f4*f5^3*f3+288*x3^3*x6*f0*f6^2*f5^2-16*x3^3*x6*f7*f2*f5*f4^2
-48*x3^3*x6*f2*f5^2*f4*f6+16*x3^3*x6*f1^2*f7^2*f6-8*x3^3*x6*f3^3*f6*f7+112*x3^
3*x6*f0*f6*f7*f4*f5+32*x3^3*x6*f0*f6^2*f3*f7+8*x3^3*x6*f7*f2*f5^2*f3+32*x3^3*
x6*f0*f7^2*f5*f3-8*x3^3*x6*f3*f6*f1*f7*f5-8*x3^3*x6*f1*f7^2*f3*f4+60*x3^2*x4*
x6*f7^2*f1*f4^2-240*x3^2*x4*x6*f5^3*f7*f1+104*x3^2*x4*x6*f7*f2*f3*f5*f6-144*x3
^2*x4*x6*f2*f5^3*f6-24*x3^2*x4*x6*f7*f4^4-212*x3^2*x4*x6*f7*f2*f5^2*f4+16*x3^2
*x4*x6*f0*f7^3*f2-48*x3^2*x4*x6*f7*f3^2*f5^2+124*x1^2*x3^2*f1^2*f5^2*f4*f7+16*
x2^2*x1*x5*f1*f0*f7^2*f2-8*x2^2*x1*x5*f0*f4*f3^2*f7+80*x2^2*x1*x5*f0*f5*f3*f7*
f2+16*x2^2*x1*x5*f2*f4^3*f3+104*x2^2*x1*x5*f0*f5*f4^3+224*x2^2*x1*x5*f5^2*f0^2
*f7-648*x4^2*x7^2*f6*f5^3+216*x2*x1*x4*x6*f0*f5^4-1008*x2*x1*x4*x6*f0*f6*f5^2*
f4+6*x2^2*x1^2*f4^3*f3^3+64*x2*x1*x3*x4*f0*f6*f4^3*f7-252*x2*x1*x3*x4*f3^2*f5^
3*f4-40*x3*x4*x1*x2*f3^2*f4*f2*f7*f6+1232*x3*x4*x1*x2*f0*f6*f5^2*f2*f7+8*x3*x4
*x1*x2*f1*f4^2*f7*f3*f6-80*x2*x1*x3*x4*f0*f3*f4^2*f7^2-112*x2*x1*x3*x4*f7*f2^2
*f5^2*f4-48*x2^2*x1*x3*f6^2*f7*f1^2*f2+64*x2*x1^2*x4*f0*f6^2*f7*f3*f1+72*x2*x1
^2*x4*f3^2*f5^3*f2+32*x2*x1^2*x4*f4^3*f7*f2^2-16*x2*x1^2*x4*f7^2*f0*f3^3-64*x2
*x1^2*x4*f7^3*f0^2*f2-56*x2*x1^2*x4*f1*f4*f7^2*f2^2-144*x2*x1*x3*x4*f5*f4^3*f6
*f2-56*x2*x1*x3*x4*f6*f7^2*f3*f1^2+288*x2*x1*x3*x4*f4^2*f6*f1*f5^2+112*x2*x1*
x3*x4*f1*f4^2*f7^2*f2-360*x2*x1*x3*x4*f2*f7*f5^3*f1+28*x2*x1*x3*x4*f7*f3^2*f5^
2*f2-1376*x3*x4*x1*x2*f6*f5*f0^2*f7^2-16*x2*x3^2*x8*f7*f3*f1*f6^2+40*x2*x3^2*
x8*f7^2*f0*f5*f4-4*x2*x3^2*x8*f7*f5^2*f2*f4-80*x2*x3^2*x8*f7*f0*f6*f5^2+96*x1^
2*x2*x3*f0*f6*f7^2*f1^2-28*x1^2*x2*x3*f3^2*f1*f4^2*f7+24*x1^2*x2*x3*f7*f2^2*f4
^2*f3+208*x1^2*x2*x3*f7*f5*f6*f2*f1^2+4*x1^2*x2^2*f4^3*f2^2*f5-64*x1^2*x2^2*f1
^2*f5*f6*f4^2-16*x1^2*x2^2*f1*f5^2*f2*f4^2-52*x1^2*x2^2*f4*f7^2*f1^3+4*x1^2*x2
^2*f7*f2*f3*f1*f4^2-6*x3^4*f2*f5^5+48*x1^3*x7*f0*f6*f5^2*f1+32*x1^3*x7*f1^2*f6
*f7*f2-12*x1^3*x7*f3^4*f5+188*x2*x4*x1^2*f7*f2^3*f5^2-48*x1^2*x2*x4*f7^2*f2^3*
f3+108*x1^2*x2*x4*f1*f5^4*f2-200*x2^2*x4*x6*f7*f4^2*f5*f1+64*x2^2*x4*x6*f7^3*
f0^2+32*x2^2*x4*x6*f7^2*f1*f4*f2+32*x2^2*x4*x6*f7*f2*f5*f1*f6-16*x2^2*x4*x6*f7
*f3*f1*f4*f6-28*x2^2*x4*x6*f7^2*f1^2*f5-32*x1^2*x2*x7*f0*f4*f2*f7*f5-208*x1^2*
x2*x7*f7*f2*f5*f1*f3+48*x1^2*x4^2*f7^2*f1*f4*f0*f6+48*x1^2*x4^2*f7^2*f0*f6*f2*
f3-480*x2*x1^2*x4*f0*f5*f7^2*f3*f1+36*x2*x1*x5^2*f1^2*f5^2-4*x2^3*x1*f7*f3^2*
f2^2*f5+4*x2^3*x1*f3^2*f1^2*f7^2+4*x2^3*x1*f7^2*f2^4+96*x1^3*x5*f5^3*f0^2-16*
x1^2*x4^2*f7^2*f1^2*f6*f3-1072*x1^2*x4^2*f7^2*f6*f0^2*f5+168*x1^2*x4^2*f7^2*f3
^2*f4*f1+460*x1^2*x4^2*f7^2*f1^2*f5*f4+252*x1^2*x4^2*f7^2*f0*f3^2*f5+304*x1^2*
x2*x4*f0*f7^2*f2*f3*f4-104*x1^2*x2*x4*f7*f3^2*f4^2*f2+128*x1^3*x2*f6*f0^3*f7^2
-72*x1^2*x2*x6*f3*f5*f4^2*f1+16*x1^2*x2*x6*f0*f4^3*f5-80*x1^2*x2*x6*f0*f5*f7*
f2*f3-48*x1^2*x2*x6*f0*f7^2*f2*f1-48*x1^2*x2*x6*f0*f6*f7*f1*f3+160*x1^2*x2*x6*
f5^2*f0^2*f7-20*x1^2*x2*x6*f7*f2^2*f3^2-24*x1^2*x2*x6*f7*f2*f4*f3*f1+40*x2^2*
x3*x4*f5*f4^3*f7*f2-64*x3*x4*x2^2*f3*f6*f4*f1*f5*f7+84*x2^2*x3*x4*f5^4*f2*f4+
40*x3*x4*x2^2*f4*f6*f1^2*f7^2-40*x3*x4*x2^2*f4^3*f1*f7*f6+64*x3*x4*x2^2*f6^2*
f7*f1^2*f5-12*x1^2*x3*x6*f7*f2*f3^3-40*x1^2*x3*x6*f7*f2*f4^2*f1-12*x1^2*x2*x5*
f7*f2*f3^2*f1+152*x1^2*x2*x5*f7*f0*f5*f2^2+12*x3^3*x2*f7^2*f2^2*f5*f3+48*x3^3*
x2*f7^2*f2*f5*f1*f4-32*x3^3*x2*f0*f6^2*f5*f2*f7+16*x3^3*x2*f7^2*f3^2*f1*f5-8*
x3^3*x2*f7*f3^2*f6*f2*f5-48*x3^3*x2*f0*f5^3*f7*f4+64*x3^3*x2*f1*f5*f6^2*f4^2-\
96*x3^3*x2*f0*f5*f4*f3*f7^2-24*x3^3*x2*f5*f4^3*f3*f6+16*x3^3*x2*f1*f6^2*f7*f3^
2+24*x3^3*x2*f1*f5^5-8*x2*x3^3*f4*f5^2*f7*f2*f3-96*x3^3*x2*f0*f5^2*f2*f7^2+24*
x3^3*x2*f7*f2*f5*f4^3+16*x1^2*x3*x5*f2*f6*f1*f4^2-12*x1^2*x3*x5*f1*f5^2*f2*f4-\
40*x1^2*x3*x5*f3*f5*f4^2*f1+84*x1^2*x4*x5*f2^2*f4*f5^2+384*x1^2*x4*x5*f0*f4*f2
*f7*f5+120*x2^2*x3^2*f0*f5^2*f4^2*f7+32*x1^3*x3*f0*f6*f5*f3^2*f4+144*x1^3*x3*
f6^2*f5*f2*f1^2+32*x2^2*x4*x5*f0*f6*f5*f2*f7-16*x2^2*x4*x5*f7*f2*f1*f4*f6-128*
x2^2*x4*x5*f6*f0^2*f7^2+128*x2^2*x4*x5*f1*f5*f0*f7^2-508*x2^2*x1*x4*f7*f2*f5^2
*f1*f4+672*x2^2*x1*x4*f1*f5*f0*f7^2*f4-32*x2^2*x1*x4*f1*f6*f5^2*f0*f7+248*x2^2
*x1*x4*f5*f4^2*f1*f3*f7+40*x2^2*x1*x4*f7*f2*f5*f3*f1*f6-152*x2^2*x1*x4*f5^3*f7
*f1^2+64*x2^2*x1*x4*f0*f4^2*f2*f7^2-96*x2^2*x1*x4*f6*f0^2*f7^2*f4+36*x2^2*x1*
x4*f7^3*f1^3+320*x2*x1*x3*x4*f0*f5^2*f1*f7^2-64*x3*x4*x1*x2*f0*f3^2*f6^2*f7+20
*x2*x1*x3*x4*f3^3*f7*f5*f4-120*x2*x1*x3*x4*f1*f5*f7*f4^3+80*x1*x2*x3*x4*f1^2*
f7*f6^2*f4-216*x2*x1*x3*x4*f0*f5^5+16*x2*x1*x3*x4*f0*f5^3*f3*f7-8*x3*x4*x1*x2*
f6*f2^2*f7^2*f1+128*x3*x4*x1*x2*f0*f6*f4*f1*f7^2-48*x2*x1*x5^2*f2*f5*f1*f4+16*
x2*x1^2*x5*f4^2*f6*f1^2-8*x2*x1^2*x5*f4^3*f2^2+136*x2*x1*x5*x7*f0*f5^2*f4+8*x2
*x1*x6*x7*f4^2*f2*f5+72*x2*x1*x6*x7*f0*f5^3-36*x2*x1*x6*x7*f3*f5^2*f2-8*x2*x1*
x6*x7*f7*f6*f1^2-16*x2^2*x1*x6*f0*f5*f7*f3^2+64*x2^2*x1*x6*f6*f0^2*f7*f5+48*x2
*x1*x6^2*f1*f7*f2*f4-88*x2*x1*x6^2*f3*f5*f2*f4-48*x2*x1^2*x6*f0*f5^2*f3*f4+48*
x2*x1^2*x6*f0*f6*f4^2*f3-8*x2*x1^2*x6*f2^3*f7*f4-144*x2*x1^2*x3*f0*f6*f5*f4^2*
f3+4*x2^2*x4*x1*f3^4*f5*f7+20*x2*x1*x3*x7*f3^3*f7*f4-24*x2*x1*x3*x7*f4^2*f6*f3
^2+96*x2*x1*x3*x7*f0*f6^2*f4^2-64*x2*x1^2*x3*f3*f0^2*f5*f7^2+8*x3^2*x5*x6*f4^4
-16*x2^2*x3^2*f0*f6*f5^2*f2*f7-96*x2^2*x3^2*f0*f5^2*f1*f7^2-4*x2^2*x3^2*f1*f5^
3*f7*f2-8*x2^2*x3^2*f5*f4^3*f1*f7+16*x2^2*x3^2*f4*f5^2*f1*f3*f7+52*x2^2*x3^2*
f1^2*f7^2*f4*f5-128*x2^2*x3^2*f0*f5*f2*f7^2*f4+24*x2^2*x3^2*f2*f5*f7*f4^2*f3-\
32*x2^2*x3^2*f7*f4*f5^2*f2^2+720*x2^2*x1*x4*f0*f5^3*f2*f7-1344*x2^2*x1*x4*f5^2
*f0^2*f7^2+144*x2^2*x1*x4*f5*f4^2*f7*f2^2+80*x2^2*x1*x4*f0*f6*f7^2*f2^2-8*x2^2
*x1*x4*f7*f2^3*f5*f6+132*x2^2*x1*x4*f1*f7^2*f2^2*f5-32*x2^2*x1*x4*f1^2*f7^2*f3
*f5+76*x2^2*x1*x4*f7^2*f2*f1*f3*f4-56*x2^2*x1*x4*f7^2*f2^3*f4+24*x2^2*x1*x4*f0
*f4*f7^2*f3^2+28*x2^2*x1*x4*f1*f4^4*f7+8*x2^2*x3^2*f0*f3*f1*f7^3-384*x2^2*x3^2
*f0*f6*f5^3*f4-16*x1^3*x4*f0*f6*f1*f7*f4^2+48*x2^2*x1*x4*f1*f6*f0*f7^2*f3-12*
x2^2*x5^2*f0*f5*f4^2-8*x2^2*x1*x5*f4^4*f1-36*x2^2*x1^2*f1*f5^3*f2*f3-8*x2^2*x1
*x6*f7*f2*f3^3+8*x2*x1*x5^2*f2^2*f4^2-16*x2*x1*x3*x5*f2^2*f4*f5^2+12*x2*x1*x3*
x5*f7*f3*f4*f2^2+16*x2*x1*x3*x5*f4^4*f2-40*x2*x1*x3*x5*f4^3*f1*f5-32*x2*x1*x3*
x5*f4^2*f6*f2^2-624*x1*x2*x4*x5*f0*f5^2*f2*f7-100*x2*x1*x4^2*f7^3*f1^2*f3+120*
x1*x2*x3^2*f6*f2*f5*f7*f3*f1+176*x1*x2*x3^2*f0*f6*f5*f2*f7*f4+72*x2*x1*x3^2*f5
*f4^3*f1*f6-48*x2*x1*x3^2*f4^2*f7^2*f0*f2+32*x2*x1*x3^2*f5*f7^2*f3*f1^2+24*x2*
x1*x3^2*f5*f4^2*f2*f3*f6-24*x2*x1^2*x3*f5^4*f1^2+48*x2*x1^2*x4*f0*f5*f4^3*f6-\
16*x2*x1^2*x4*f2^3*f6*f7*f4-12*x1*x2*x4*x5*f1*f7^2*f2^2-16*x3*x6*x1*x2*f0*f4*
f7^2*f1-64*x3*x6*x1*x2*f7^2*f0*f3*f2+80*x3*x6*x1*x2*f0*f5^2*f2*f7+8*x2*x1*x3*
x6*f5*f4^3*f2-128*x2*x1*x3*x6*f5^2*f4^2*f1+96*x1^2*x4*x5*f0*f7^2*f1*f3-56*x1^2
*x4*x5*f7*f2^3*f5+48*x1^2*x4*x5*f0*f7^2*f2^2-64*x1^2*x4*x5*f1^2*f7^2*f2-48*x1^
2*x4*x5*f1*f5^2*f3*f4-16*x1^4*f6^2*f4*f1^3+16*x1^4*f1*f5*f3^3*f4+4*x1^4*f0*f3^
4*f7-16*x1^4*f4^3*f0^2*f7-40*x1^2*x3*x6*f7*f2*f5*f1*f3-108*x1^2*x3*x6*f1*f5^2*
f3*f4+4*x1^2*x3*x6*f3*f5*f4^2*f2+16*x1^2*x3*x6*f0*f5^2*f4^2-24*x1^2*x3*x6*f2*
f5^3*f1+144*x1^2*x3*x6*f1^2*f5^2*f6+8*x1^2*x3*x6*f2*f4*f5*f1*f6+32*x2^2*x1*x3*
f0*f5*f4^2*f3*f7+8*x2^2*x1*x3*f1^2*f5*f7*f6*f3+160*x3^3*x4*f0*f6*f4^2*f7^2-336
*x3^3*x4*f0*f5^2*f4*f7^2+64*x3^3*x4*f3^2*f5*f6*f7*f4+272*x3^3*x4*f5^2*f4^2*f7*
f3-848*x3^3*x4*f0*f6*f5^3*f7-144*x3^3*x4*f0*f5*f2*f7^3-64*x3^3*x4*f0*f6^2*f7^2
*f2-40*x3^3*x4*f1*f7^2*f3*f5^2+72*x3^3*x4*f6*f2*f5^4+112*x1^2*x2*x6*f1^2*f5*f4
*f6+8*x3^2*x1*x5*f1*f7*f3*f4^2+48*x3^2*x1*x5*f1^2*f6*f7*f4-144*x3^2*x1*x5*f1^2
*f6^2*f5-16*x3^2*x6^2*f0*f6*f7*f4-144*x3^2*x6^2*f0*f6^2*f5-48*x3^2*x6^2*f3*f5^
2*f4+128*x3^2*x1*x6*f0*f5^2*f3*f7+96*x3^2*x2*x6*f5^2*f4^2*f3-72*x3^2*x2*x6*f1*
f5^4-4*x2^4*f7*f2^2*f5*f3*f4+8*x2^4*f1^2*f6*f7*f4^2-4*x2^4*f0*f5*f7^2*f2^2-16*
x2^4*f0*f5*f6*f1*f7*f4+20*x2^4*f5^2*f4^3*f1+16*x2^4*f0*f5*f4^2*f3*f7-8*x2^4*f0
*f4*f3*f7^2*f2-32*x2^4*f5*f0^2*f7^2*f4+4*x2^4*f4*f1*f7^2*f2^2-8*x2^4*f0*f5^2*
f2*f7*f4-4*x2^4*f0*f5^2*f7*f3^2+24*x1^3*x3*f6*f1*f5*f3^3-56*x1^3*x3*f2*f3*f7^2
*f1^2+40*x1^3*x3*f0*f5*f4^4-16*x2^3*x6*f1^2*f7*f4*f6+16*x2^3*x6*f0*f3*f2*f7^2-\
64*x2^3*x6*f5^2*f4^2*f1-8*x2^3*x6*f1*f7^2*f2^2-32*x1^3*x3*f0*f4^3*f2*f7+24*x1^
3*x3*f7*f1^2*f4^3+8*x1^3*x3*f2*f4^3*f6*f1-112*x1^3*x3*f2*f4*f5*f1*f6*f3-24*x1^
3*x3*f4^3*f3*f1*f5+48*x1^2*x2*x3*f0*f3^2*f7*f5*f4-48*x1^2*x2*x3*f5*f7^2*f1^3-\
128*x2^2*x4*x6*f0*f5*f2*f7^2+108*x2^2*x4*x6*f7*f1*f5^2*f3+16*x2^2*x4*x6*f7*f3^
2*f4^2-64*x2^2*x4*x6*f7^2*f0*f4*f3+96*x1^3*x7*f0*f6*f4*f2*f5-12*x1^3*x7*f2^2*
f5^2*f3-8*x2^3*x1*f3*f1*f7^2*f2^2+16*x2^3*x1*f6*f1*f4*f7*f2^2-24*x2^3*x1*f2*f1
^2*f7^2*f4-64*x2^3*x1*f6*f5*f0^2*f7*f4+20*x2^3*x1*f5^2*f4^2*f2^2-16*x2^3*x1*f7
*f3^2*f1*f4^2+64*x2^3*x1*f3*f5^2*f4^2*f1-40*x2^3*x1*f3*f5*f4^3*f2+32*x2^3*x1*
f1*f5^2*f7*f2^2-60*x2^3*x1*f1^2*f5*f7*f4^2-24*x2^3*x1*f7*f2^3*f4*f5+16*x2^3*x1
*f7*f2*f4^3*f1+32*x2^3*x1*f0*f4*f3*f7^2*f1+64*x2^3*x1*f0*f5^2*f4*f7*f1-24*x2^3
*x1*f6*f5*f7*f1^2*f2+32*x2^3*x1*f0*f5*f4^2*f7*f2+96*x1^3*x2*f0*f5^3*f3*f2+12*
x1^3*x2*f1*f5^2*f3^3-40*x1^3*x2*f1*f3^2*f7*f2*f4+6*x2^4*f5*f7^2*f1^2*f2+4*x2^4
*f7*f3^2*f2*f4^2+4*x2^4*f0*f4^4*f7-28*x2^4*f0*f5^3*f4^2-6*x2^4*f5*f4^4*f2+16*
x2^4*f6*f5^2*f0^2*f7+4*x2^4*f0*f7^3*f1^2+96*x2^2*x1*x7*f0*f4*f1*f7^2+288*x2^2*
x1*x7*f0*f5^2*f2*f7+160*x1^2*x3*x7*f0*f4*f3*f7*f5+24*x3^4*f5*f4^3*f7*f3-48*x3^
4*f0*f6*f4*f5^2*f7+4*x3^4*f0*f3^2*f7^3-32*x3^4*f6*f4*f5*f7*f2*f3+12*x3^4*f0*f5
*f1*f7^3-144*x3^4*f0*f6^2*f5^3-80*x3^4*f0*f5^2*f3*f7^2+48*x3^4*f6*f0^2*f7^3+8*
x3^4*f1*f6*f7^2*f3^2-24*x3^4*f3*f6^2*f4^3-14*x3^4*f4*f5^4*f3-8*x3^4*f1*f7^3*f2
*f3+16*x3^4*f4*f5^3*f7*f1-40*x3^4*f0*f5*f4^2*f7^2+4*x3^4*f5*f4^4*f6-8*x3^4*f1*
f7^2*f5^2*f2+32*x3^4*f1*f6^2*f7*f2*f5-192*x1^2*x3*x7*f1^2*f6^2*f5-32*x1^2*x3*
x7*f2*f6*f4^2*f3+40*x1^2*x3*x7*f1^2*f7^2*f3+16*x2^3*x1*f5*f4^4*f1+16*x1^3*x5*
f1^2*f4*f6*f3+48*x1^3*x5*f1*f6*f5*f3*f0+16*x3*x4*x1^2*f7*f2*f3^3*f6+64*x3*x4*
x1^2*f6^2*f7*f3*f1^2+88*x3*x4*x1^2*f6*f5*f7*f2^3+4*x2^2*x1*x4*f7*f2*f3^2*f4*f5
-4*x2^3*x4*f3^2*f5^2*f7*f2-4*x2^3*x4*f7^2*f3^2*f1*f4-12*x2^2*x3*x6*f7^2*f2*f1*
f3-24*x2^2*x3*x6*f1^2*f7^2*f4-8*x2^2*x3*x6*f7*f3^3*f4+4*x2^2*x1*x7*f1^2*f7^2*
f3-20*x2^2*x1*x7*f3*f7*f1*f4^2+44*x2^2*x1*x7*f5^2*f4^2*f1-36*x2^2*x1*x7*f7*f3^
2*f5*f1-16*x2^2*x6^2*f7*f2*f5*f1+8*x2^2*x6^2*f7*f3*f4*f1-128*x1^2*x2*x5*f7*f5*
f2*f1^2+136*x1^2*x2*x5*f7*f0*f3*f5*f1-64*x1^2*x2*x6*f2*f6*f1*f4^2+48*x1^2*x2*
x6*f1^3*f7^2-2*x2^4*f3*f4^5-12*x3^2*x1*x6*f4^3*f3*f5+40*x3^2*x2*x7*f7*f3^2*f5*
f4-4*x3^3*x7*f7*f2*f5^2*f4+12*x3^2*x5*x7*f1*f4*f7*f5-12*x3^2*x1*x7*f1^2*f5*f7^
2-44*x3^2*x1*x7*f7*f2*f3*f5*f4+24*x1*x3^2*x6*f3^2*f4^2*f6+40*x1*x3^2*x6*f4^3*
f6*f2+80*x1*x3^2*x6*f0*f6*f4*f3*f7+216*x1*x3*x4*x6*f3^2*f5^3-216*x1*x3*x4*x6*
f3*f5^2*f6*f2-128*x1*x3*x4*x6*f7*f2^2*f4*f6-48*x1*x3^2*x7*f2^2*f6^2*f5-96*x1^2
*x4^2*f7*f2^2*f4*f5^2+40*x1^2*x4^2*f7^2*f2*f4^2*f1+432*x1^2*x4^2*f7^2*f1*f5^2*
f0-224*x1^2*x4^2*f7*f1*f5^2*f3*f4+48*x1^2*x4^2*f7^3*f1^2*f2-4*x1^2*x4^2*f7^2*
f2*f3^3-48*x1^2*x4*x8*f1^2*f5*f7^2-16*x1^3*x6*f0*f7*f2*f3*f4-24*x1^3*x6*f0*f5^
2*f3^2-28*x1^3*x6*f2*f4^2*f5*f1-96*x2^2*x1*x4*f0*f7^3*f1*f2-88*x2^2*x4*x1*f3^2
*f5^2*f1*f7+16*x2^2*x4*x1*f6*f5*f7*f4*f1^2-36*x2^2*x1*x4*f5^4*f2^2+576*x2^2*x1
*x4*f0*f6*f5^2*f4^2-64*x2^2*x1*x3*f5*f0^2*f7^2*f4+84*x2^2*x1*x3*f5^2*f4^3*f1-\
144*x2^2*x1*x3*f0*f5^3*f4^2-32*x2^2*x1*x3*f0*f7^3*f1^2+16*x2^3*x5*f7*f0*f5*f2*
f4-8*x2^3*x5*f7^2*f0*f2^2+48*x2^3*x5*f0*f5^2*f4^2+12*x2^3*x5*f7^2*f2*f1^2-8*x2
^3*x5*f7*f2*f5*f3*f1+16*x2^3*x5*f7*f6*f1*f0*f4+8*x2^3*x5*f7*f0*f5*f3^2-8*x2^3*
x5*f0*f7^2*f3*f1-36*x2^2*x4*x5*f7^2*f2*f1*f3+24*x2^2*x4*x5*f4^3*f7*f1-8*x2^2*
x4*x5*f1^2*f7^2*f4+8*x2^2*x4*x5*f7*f2*f3^2*f5-4*x2^2*x4*x5*f7*f3^3*f4+4*x2^3*
x5*f7*f2^2*f3*f4+12*x2^2*x1*x5*f7*f2^3*f4-28*x2^2*x1*x5*f4^2*f2^2*f5+48*x1^2*
x2*x7*f1^2*f7^2*f2-448*x1^2*x2*x7*f6*f0^2*f7*f5+8*x1^2*x2*x7*f7*f3^2*f4*f1-16*
x1^2*x2*x7*f1^2*f5*f7*f4+112*x1^2*x2*x7*f1*f5^2*f0*f7+40*x1^2*x2*x7*f7*f3*f4*
f2^2+96*x1^2*x2*x7*f1*f4*f0*f7*f6+112*x1^2*x2*x7*f0*f3^2*f7*f5-8*x2^3*x7*f1*f7
*f4^3-24*x2^3*x7*f0*f5^4+16*x2^3*x7*f4*f5^3*f1-28*x2^3*x7*f7*f2*f5^2*f1+16*x2^
3*x7*f7*f2^2*f5*f4-60*x2^3*x7*f7*f3*f4*f1*f5+16*x2^3*x7*f1^2*f7^2*f4+104*x2^3*
x7*f0*f5*f4^2*f7-16*x2^3*x7*f1*f5*f0*f7^2-32*x2*x1*x3*x7*f1*f5*f0*f7^2+48*x2*
x1*x3*x7*f3*f5^2*f6*f1-16*x2*x1*x3*x7*f7*f4^2*f2*f3+64*x2*x1*x3*x7*f0*f6*f5^2*
f4-144*x2*x1^2*x7*f0*f5^3*f3-16*x2*x1^2*x7*f5*f4^3*f1+128*x2*x1^2*x7*f0^2*f7^2
*f4-48*x2*x1^2*x7*f1*f6*f4^2*f3-48*x2*x1*x3*x7*f5^2*f6*f2^2+48*x2*x1*x3*x7*f0*
f6*f4*f3*f7-248*x2*x1*x3*x7*f1^2*f6*f7*f5-44*x2*x1*x3*x7*f7*f2*f5^2*f1+96*x2*
x1*x3*x7*f4^2*f6*f1*f5+44*x2*x1*x3*x7*f1*f4*f7*f3*f5-128*x2*x1^2*x5*f1*f6*f5*
f0*f4+32*x2*x1^2*x5*f0*f6*f7*f2*f1+72*x2*x1^2*x5*f3*f1*f5^2*f2-8*x2*x1^2*x5*f1
^3*f7*f6-16*x2*x1^2*x5*f1^2*f5^2*f4+712*x2*x1*x3*x4*f1*f5^2*f3*f7*f4+8*x3*x4*
x1*x2*f7*f3^4*f6-24*x3*x4*x1*x2*f3^2*f6*f1*f7*f5-160*x3*x4*x1*x2*f0*f6^2*f4*f2
*f7+24*x3*x4*x1*x2*f3*f6*f5*f2^2*f7+80*x3*x4*x1*x2*f1*f6^2*f7*f3*f2+16*x2^3*x4
*f0*f3*f1*f7^3-36*x2^3*x4*f5^2*f4^3*f3+48*x2^3*x4*f4*f5^4*f1-32*x2^3*x4*f0*f6*
f4*f1*f7^2+32*x2^3*x4*f0*f4^2*f3*f7^2-64*x1^3*x7*f0*f5*f7*f2*f3+16*x1^3*x7*f3*
f6*f4*f2^2-16*x1^3*x7*f0*f6*f7*f1*f3-80*x1^3*x7*f0*f5^2*f4*f3-16*x1^3*x7*f0*f7
*f3^2*f4+32*x1^3*x7*f0*f4^3*f5+8*x1^3*x7*f3^2*f5*f2*f4+44*x1^3*x7*f1*f5^2*f2*
f4-16*x1^3*x7*f0*f4^2*f3*f6-64*x1^3*x7*f1*f4*f0*f7*f5+64*x1^2*x2*x4*f7^2*f2*f3
^2*f1-2048*x2*x4*x1^2*f6*f5^2*f0^2*f7+464*x2*x4*x1^2*f0*f5^3*f1*f7-8*x2^4*f1*
f4^2*f7*f2*f5-12*x2^4*f0*f5^3*f1*f7+4*x2^4*f7*f2*f5^2*f3*f1-16*x2^4*f0*f5*f7^2
*f3*f1+12*x2^4*f5^2*f7*f4*f1^2+4*x2^2*x1*x4*f7^2*f3^2*f2^2+36*x2^2*x1*x4*f7*f3
*f5^2*f2^2-12*x2^2*x1*x4*f7^2*f3^3*f1+4*x2^2*x1*x3*f7*f3^3*f2*f5+12*x2^2*x1*x3
*f7*f3^2*f2*f4^2+20*x2^2*x1*x3*f7*f2*f5*f1*f4^2+2*x2^4*f4*f7^2*f1^2*f3-54*x2^2
*x3^2*f5^2*f4^3*f3-6*x2^2*x3^2*f2^2*f3*f7^2*f4-14*x2^2*x3^2*f5^3*f4^2*f2+8*x2^
2*x3^2*f7*f3^3*f5*f4+4*x2^3*x3*f7^3*f1^3+4*x2^3*x3*f3^3*f7*f4^2+8*x2^2*x1*x3*
f7*f3^4*f4-12*x2^2*x1*x3*f7^2*f2*f1*f3^2-12*x2^2*x6^2*f3*f4^3-32*x2^3*x1*f0*f6
*f4*f3*f7*f2-8*x1^3*x6*f0*f4^4+12*x1^3*x6*f1*f3^2*f7*f2+12*x1^3*x6*f4^3*f3*f1+
4*x1^3*x2*f4^2*f3^4+140*x2*x4*x1^2*f5*f7*f2^2*f3*f4+32*x1^3*x4*f1*f5^2*f0*f7*
f4-12*x1^3*x4*f4^4*f1*f5-336*x1^3*x4*f7*f0*f5*f2*f4^2-12*x1^3*x4*f5*f7*f2^2*f3
^2-288*x1^3*x4*f1*f5^2*f2*f3*f6-24*x1*x3*x2*x6*f2^2*f5^3+80*x1^2*x3*x4*f1*f4*
f6*f7*f3^2-132*x1^2*x3*x4*f4^2*f5^3*f1+192*x1^2*x3*x4*f0*f5^4*f4-36*x1^2*x3*x4
*f5^4*f2^2+72*x2*x3*x6^2*f5^3*f1-32*x2*x3*x6^2*f0*f5*f7*f4+16*x2*x3*x6^2*f2*f7
*f1*f6-60*x2*x3*x6^2*f5*f4^2*f3+128*x2*x3*x6^2*f4*f6*f1*f5+16*x2*x3^2*x8*f7^2*
f2*f1*f6-76*x2*x3*x4*x8*f7^2*f2*f3*f5-76*x2*x3*x4*x8*f7*f3*f5^2*f4+64*x2*x3*x4
*x8*f7^3*f2*f1-368*x2*x3*x4*x8*f7^2*f0*f5^2+176*x2*x3*x4*x8*f7^2*f1*f4*f5-88*
x2*x3*x4*x8*f7^2*f6*f1*f3-36*x2*x3*x5*x8*f7*f1*f4*f5+56*x2*x3*x5*x8*f7*f0*f5^2
+20*x1^2*x3*x6*f5*f4^3*f1+96*x1^2*x3*x6*f0*f6*f5*f4*f3-192*x1^2*x3*x6*f0*f5*f6
^2*f1-112*x2*x3*x4^2*f7^2*f2*f4^3-64*x1^2*x3^2*f0*f6^2*f7*f2^2-6*x1^2*x3^2*f5*
f4^4*f2-360*x1^2*x3^2*f0*f6*f5^2*f3*f4-64*x3^2*x4*x2*f0*f6^3*f2*f7+264*x1*x3*
x2*x4*f4*f5^2*f2*f3*f6-12*x2*x3*x1*x4*f7*f3^2*f4^3+16*x1*x3^2*x7*f7*f3^3*f5+
120*x1*x3*x4*x7*f5^2*f4^3-160*x1*x3*x4*x7*f2*f6*f0*f7^2+24*x1^2*x3^2*f3*f5^2*
f6*f2^2+48*x1^2*x3^2*f6^2*f7*f1^2*f2+32*x1^2*x3^2*f3^2*f6^2*f4*f1-8*x1*x3*x2*
x6*f7*f2*f3^2*f4+4*x1^2*x3*x6*f7*f3^2*f1*f4+32*x2^2*x3*x8*f7*f0*f6*f5*f4-12*x2
^2*x3*x8*f7*f4^2*f5*f2-80*x2^2*x3^2*f0*f6^2*f5*f1*f7+32*x2^2*x3^2*f0*f6*f3*f2*
f7^2+80*x2^2*x3^2*f6*f5*f0^2*f7^2-144*x2^2*x4*x3*f3*f5^3*f7*f1+8*x2^2*x3*x6*f2
^2*f6*f7*f3-112*x3^2*x2*x4*f0*f4*f2*f7^3+16*x3^2*x2*x4*f7^2*f2^2*f6*f3+72*x3^2
*x2*x4*f1*f6*f7^2*f3^2+288*x3^2*x2*x4*f0*f6^2*f4^2*f7+56*x3^2*x2*x4*f1^2*f7^3*
f4+192*x3^2*x2*x4*f4*f5^3*f6*f2-216*x3^2*x2*x4*f4^3*f5^3-8*x2*x4*x3^2*f1^2*f6*
f7^2*f5+120*x2*x4*x3^2*f5*f4^3*f7*f3-188*x2*x4*x3^2*f7^2*f3*f5*f1*f4-160*x2*x4
*x3^2*f0*f5*f1*f7^3+192*x2*x4*x3^2*f0*f5^2*f3*f7^2-96*x3^2*x2*x4*f7*f2*f4^3*f6
-144*x3^2*x2*x4*f3*f5^2*f6*f4^2+284*x2*x4*x3^2*f5^2*f4^2*f2*f7+164*x2*x4*x3^2*
f1*f7^2*f5^2*f2+64*x3^3*x4*f0^2*f7^4+56*x3*x4*x1^2*f6*f4*f7*f1^2*f5-496*x1^2*
x3*x4*f0*f5*f7^2*f2*f3-72*x2^2*x4^2*f5^3*f4^3+208*x1^2*x2*x4*f0*f7^3*f1^2+60*
x1^2*x2*x4*f4^2*f3*f5^2*f2-288*x1^2*x2*x4*f1^2*f5^3*f6+48*x1^2*x2*x4*f0*f5^3*
f4^2-56*x1^2*x2*x4*f6*f7*f1^2*f4^2-144*x1^2*x2*x4*f7^2*f1^2*f4*f3+72*x1^2*x2*
x4*f7*f2*f4*f1*f6*f3-120*x1^2*x2*x4*f4*f5^3*f2^2-48*x2*x4*x1^2*f0*f6*f5*f3*f7*
f2+640*x2*x4*x1^2*f0*f6*f5*f7*f4*f1-36*x1^2*x5*x7*f1*f5^2*f2+96*x1^2*x5*x7*f6*
f1^2*f5-16*x1^2*x5*x7*f1*f5*f3*f4+28*x1^2*x5*x7*f2^2*f5*f4+28*x3^2*x1*x7*f5*f4
^4+32*x3^2*x1*x7*f7*f4*f2^2*f6+16*x3^2*x1*x7*f0*f4*f3*f7^2+128*x3^2*x1*x7*f0*
f5*f2*f7^2+16*x3^2*x1*x7*f4*f6^2*f2*f3-32*x3^2*x1*x7*f0^2*f7^3+28*x3^2*x1*x7*
f5^3*f2*f4-12*x3^3*x8*f7*f5*f4^3-16*x3^3*x8*f7*f4^2*f6*f3+32*x3^3*x8*f7^2*f0*
f6*f4-324*x4^3*x3*f5^6+72*x3^2*x1*x6*f2*f3*f5^3-60*x3^2*x1*x6*f7*f2^2*f4*f5+
144*x3^2*x1*x6*f1*f6^2*f2*f5-40*x3^2*x1*x6*f0*f5*f1*f7^2+40*x3^2*x1*x6*f7*f1*
f4^3+240*x3^2*x1*x6*f0*f6*f5*f2*f7-36*x3^2*x1*x6*f7^2*f1^2*f4+72*x3^2*x1*x6*f3
^2*f5^2*f4-24*x1*x6*f7*f4^2*f0*x3^2*f5-24*x3^2*x1*x6*f7*f2*f4^2*f3+8*x3^2*x1*
x6*f1*f6*f7*f3^2+208*x3^2*x1*x6*f0*f6*f4*f5^2-64*x3^2*x1*x6*f0*f6^2*f4^2-48*x3
^2*x1*x6*f2^2*f6*f5^2-48*x3^2*x7^2*f7*f2*f4*f6+92*x3^2*x7^2*f7*f3*f4*f5+12*x2^
3*x3*f7^2*f2*f1*f3*f4+12*x1^3*x6*f2*f5*f3^3+16*x1^3*x6*f0*f7^2*f1^2-16*x1^3*x6
*f1^2*f6*f4^2-32*x1^3*x6*f3^2*f5*f4*f1+24*x1^3*x6*f2^2*f5*f3*f4+40*x1^3*x6*f1^
2*f5^2*f4-12*x1^3*x6*f7*f2^3*f3-12*x3^2*x1*x7*f7^2*f3^2*f1-16*x3^2*x7^2*f7^2*
f1*f4-4*x3^2*x1*x6*f7*f3^3*f4+28*x3^2*x1*x6*f7*f2*f5*f3^2-8*x3^2*x6^2*f7*f3^2*
f4+16*x3^2*x6^2*f7*f2*f4^2+4*x3^2*x5^2*f1*f7*f3*f4+12*x3^2*x5^2*f7*f2*f1*f5-2*
x3^2*x5^2*f2*f5*f4^2-8*x3^2*x1*x6*f4^5-48*x1^2*x3*x6*f0*f7^2*f1*f3-16*x1^2*x3*
x6*f7*f0*f6*f2*f3-16*x1^2*x3*x6*f1^2*f6*f7*f3-8*x1^2*x3*x6*f7*f3*f4*f2^2+48*x1
^2*x3*x6*f1*f4*f0*f7*f6+24*x1^2*x3^2*f0*f5^3*f4^2-120*x2*x1*x3*x6*f3*f5^3*f1+
48*x1*x2*x3*x6*f0*f6*f3^2*f7-288*x3*x6*x1*x2*f5*f0^2*f7^2+128*x3*x6*x1*x2*f7*
f5^2*f1^2-56*x3*x6*x1*x2*f7*f1*f6*f2*f3+24*x2*x1^2*x6*f5^3*f1^2+8*x2*x1^2*x6*
f4^4*f1-12*x2*x1^2*x6*f4^2*f3^3-128*x2*x1^2*x6*f6*f0^2*f7*f4+64*x2*x1^2*x6*f0*
f6*f5*f2*f4+16*x2^2*x1*x6*f1*f4*f7*f3^2+64*x2*x1^2*x3*f0^2*f7^3*f1+24*x2*x1^2*
x3*f6*f2^3*f5^2+16*x2*x1^2*x7*f0*f4^3*f6-8*x2*x1^2*x7*f4^4*f2-24*x2*x1^2*x4*f5
*f4^4*f2-16*x2*x1^2*x4*f6^2*f7*f1^2*f2-44*x2*x1*x3*x4*f7^2*f2^2*f3*f4+144*x2*
x1*x3*x4*f4^2*f6*f7*f2^2-304*x2*x1*x3*x4*f1^2*f4*f7^2*f5+24*x2*x1*x3*x4*f1*f4*
f7^2*f3^2-48*x2*x1*x3*x4*f4^3*f3*f5^2+108*x2*x1*x3*x4*f3*f5^4*f2+120*x2*x1*x3*
x4*f4*f5^4*f1+128*x3*x4*x1*x2*f6^3*f0^2*f7+104*x2^2*x1^2*f0*f5*f1^2*f7^2-24*x2
^2*x1^2*f0*f4^3*f2*f7+32*x2^2*x1^2*f0*f5^3*f4*f2+16*x1*x2^2*x7*f7*f3*f5*f2^2-\
72*x2*x1*x3*x7*f0*f5^4-192*x1^2*x2*x3*f7*f0*f5*f2*f4^2-16*x1^2*x2*x3*f5*f7*f2^
2*f3^2+36*x1^2*x2*x3*f1*f5^3*f2*f4+148*x1^2*x2*x3*f3*f5^2*f4^2*f1-304*x1^2*x2*
x3*f0*f5*f6*f7*f2^2+8*x1^2*x2*x3*f1^2*f3*f7*f4*f6+40*x1^2*x2*x3*f1*f3^2*f7*f2*
f6+60*x1^2*x2*x3*f7*f2^3*f4*f5-8*x1^2*x2*x3*f7*f2^3*f3*f6+84*x1^2*x2*x3*f1^2*
f5*f7*f4^2-176*x1^2*x2*x3*f1^2*f5^2*f4*f6-84*x1^2*x2*x3*f7*f2*f4*f3*f1*f5-1264
*x1^2*x4^2*f7^2*f0*f4*f2*f5+90*x1^2*x4^2*f7^2*f2^3*f5-364*x1^2*x4^2*f7^2*f2*f5
*f1*f3-64*x1^4*f0^3*f7^2*f5+40*x1^4*f0*f5^2*f4^2*f1-8*x1^4*f6*f2^2*f4^2*f1-4*
x1^4*f4^3*f5*f1^2-8*x1^4*f1*f4^3*f3^2-16*x1^4*f6*f7*f2^2*f1^2+8*x1^4*f1*f5*f7*
f2^3-40*x1^4*f0*f5*f2^2*f7*f3+32*x1^4*f0*f6^2*f4*f2*f1-64*x1^4*f6*f0^2*f7*f2*
f4+16*x1^4*f0*f6*f1^2*f7*f4-16*x1^4*f0*f6*f4^2*f2*f3-16*x1^4*f0*f6*f5*f2^2*f4+
72*x1^4*f0*f5^2*f4*f2*f3-12*x1^4*f2*f5^2*f1*f3^2-48*x1^4*f0*f6*f5^2*f2*f1-32*
x1^4*f5*f1*f0^2*f7*f6+24*x1^4*f1*f6*f3*f5*f2^2-224*x1^2*x4*x5*f1*f5^2*f0*f7+4*
x1^2*x4*x5*f7*f3*f4*f2^2+864*x1^2*x4*x5*f6*f0^2*f7*f5-200*x1^2*x4*x5*f1^2*f5*
f7*f4-216*x1^2*x4*x5*f0*f3^2*f7*f5+16*x1^3*x2*f0*f2^3*f7^2-32*x1^3*x2*f3^2*f0^
2*f7^2+128*x3*x4*x1^2*f7*f1*f0*f6^2*f4+704*x1^2*x3*x4*f5^2*f0^2*f7^2+8*x1^2*x3
*x4*f2*f7^2*f4*f3*f1+12*x2^2*x3^2*f7*f3^2*f4^3+8*x2^2*x3^2*f0*f2^2*f7^3-88*x1^
2*x3*x4*f3*f5*f4^2*f1*f7-576*x1^2*x3*x4*f1^2*f5^2*f6^2+144*x1^2*x3*x4*f6*f2*f5
^3*f1-288*x1^2*x3*x4*f0*f6*f5^2*f4^2-32*x1^3*x5*f4^2*f0^2*f7-12*x1^3*x5*f3^3*
f1*f5-8*x2^2*x3^2*f5*f4^5+16*x2^2*x3*x6*f0*f3^2*f7^2-148*x2^2*x3*x6*f4*f5^3*f1
-64*x2^2*x3*x6*f6*f0^2*f7^2+32*x2^2*x3*x6*f0*f4*f2*f7^2-32*x2^2*x3*x6*f1^2*f7*
f6*f5-88*x2^2*x3*x6*f0*f5*f4^2*f7-112*x2^2*x3*x6*f1*f4^2*f5*f6-16*x1^3*x5*f7*
f2^2*f1*f3-72*x1^3*x5*f2*f6*f1^2*f5+16*x1^3*x5*f0*f3^2*f5*f4-64*x1^3*x5*f1*f5^
2*f0*f4-16*x1^3*x5*f0*f4*f6*f2*f3+8*x1^3*x5*f1^2*f3^2*f7+8*x1^3*x5*f5*f7*f1^3-\
32*x1^3*x5*f0*f6*f7*f1^2+12*x1^3*x5*f1^2*f5^2*f3+48*x1^3*x5*f0*f5*f4^2*f2+24*
x1^3*x5*f2*f4*f3*f1*f5+16*x1^3*x5*f1*f4*f3*f0*f7-96*x1^3*x5*f0*f5^2*f3*f2-16*
x1^3*x5*f0*f4*f2^2*f7+96*x1^3*x5*f0*f6*f5*f2^2-64*x1^3*x5*f5*f6*f4*f0^2+16*x1^
3*x5*f0*f4^3*f3+24*x1^2*x6*x7*f1^2*f5*f7+324*x4^2*x6*x7*f5^4+32*x1*x2*x3^2*f0*
f5*f7^2*f3*f2-144*x2*x1*x3^2*f6*f2*f5^3*f1+8*x2*x1*x4*x7*f7*f1*f6*f2*f5+48*x2*
x1*x4*x7*f7*f3*f5*f2*f4-116*x2*x1*x4*x7*f7*f4^2*f1*f5+336*x2*x1*x4*x7*f1*f6*f4
*f5^2+48*x2*x1^2*x3*f3^2*f5^3*f1+12*x2*x1^2*x3*f3*f5^3*f2^2-24*x2*x1^2*x3*f5*
f4^4*f1-36*x2*x1^2*x3*f3^3*f5*f4^2+48*x2*x1^2*x3*f0*f5^4*f2-272*x2*x1*x4*x7*f0
*f5^2*f4*f7-552*x2*x1*x4*x7*f7^2*f1^2*f5+48*x2*x1*x4*x7*f4^4*f5-16*x2*x1*x4*x7
*f7^2*f3^2*f1-40*x2*x1*x4*x7*f1*f7*f6*f3*f4-112*x2*x1*x4*x7*f0*f6*f5*f3*f7+16*
x2*x1*x4*x7*f1^2*f7*f6^2-320*x2*x1*x4*x7*f2^2*f7*f5^2-24*x2*x1*x7^2*f3*f5*f4^2
-16*x2*x1*x7^2*f0*f7*f5*f4+56*x2*x1*x7^2*f5*f4*f1*f6-64*x2*x1^2*x5*f0*f3*f4*f7
*f2+4*x2^2*x1*x5*f7*f3^2*f2^2-6*x3^2*x5^2*f3*f4^3+32*x1^2*x2*x6*f1*f4*f0*f7*f5
+16*x1^2*x2*x6*f2*f4^3*f3+20*x1^3*x4*f7*f2*f4^3*f1-68*x2^2*x1*x5*f4^2*f5*f3*f1
-16*x2^2*x1*x5*f0*f4^2*f7*f2-128*x2^2*x1*x5*f1*f4*f0*f7*f5+28*x2^2*x1*x5*f1^2*
f7*f4^2+32*x2^2*x1*x5*f4*f0^2*f7*f6-40*x2^2*x1*x5*f1*f7*f2^2*f5+84*x2^2*x1*x5*
f2*f5^2*f1*f4-52*x2^2*x1*x6*f7*f2*f1*f4^2+8*x2^3*x6*f3*f4^4-32*x2^2*x4*x8*f7^2
*f3*f5*f1-64*x1^3*x6*f0*f6*f7*f2*f1+96*x1^3*x6*f6*f5^2*f0^2+72*x2^2*x1*x3*f6*
f5^3*f1^2-48*x2^2*x1*x3*f4^3*f3^2*f5+128*x2^2*x1*x3*f0*f5*f6*f1*f7*f4-28*x2^2*
x1*x3*f4*f1*f7^2*f2^2+208*x2^2*x1*x3*f0*f5^2*f2*f7*f4+32*x2^2*x1*x3*f0*f4*f3*
f7^2*f2-32*x2^2*x1*x3*f7*f3*f4^3*f1-448*x2^2*x1*x3*f6*f5^2*f0^2*f7-48*x2^2*x1*
x3*f0*f6*f4*f7*f3^2+88*x2^2*x1*x3*f7*f2*f4*f1*f6*f3+8*x1^3*x3*f4^2*f3*f2^2*f6-\
8*x1^3*x3*f7*f2^2*f3^2*f4+256*x3*x4*x2^2*f6^2*f0^2*f7^2-52*x2^2*x3*x4*f1^2*f7^
3*f3-16*x2^2*x3*x4*f7*f2^2*f5^3+72*x2^2*x3*x4*f7^2*f2*f1*f3*f6-16*x3*x4*x2^2*
f7*f3^2*f6*f2*f5-48*x2^2*x3*x4*f1*f4*f7^2*f2*f5+80*x2^2*x3*x4*f7*f3*f4*f5^2*f2
-36*x2^2*x3*x4*f7^3*f1*f2^2-144*x3^2*x1*x4*f6^2*f2*f1*f4*f7+48*x3^2*x1*x4*f0*
f4*f1*f7^3+8*x3^2*x1*x4*f3^3*f5^2*f7-96*x3^2*x5^2*f0*f6*f4*f5+24*x3^2*x5^2*f1*
f4^2*f6-20*x3^2*x5^2*f1^2*f7*f6+16*x3^2*x5^2*f0*f4^2*f7-64*x3^2*x1*x5*f1*f4*f5
*f3*f6+144*x3^2*x1*x5*f2*f5^2*f6*f1-28*x3^2*x1*x5*f1^2*f7*f5^2+32*x3^2*x2*x5*
f4^3*f6*f2+28*x3^2*x2*x5*f7*f4^3*f1-128*x3^2*x2*x5*f6*f0^2*f7^2+64*x3^2*x2*x5*
f0*f6*f4*f3*f7-88*x3^2*x2*x5*f4*f5^3*f1-20*x3^2*x2*x5*f1*f7*f5^2*f2+4*x3^2*x2*
x5*f7*f3*f5*f1*f4-16*x3^2*x2*x5*f0*f5^2*f3*f7-224*x2*x4*x1^2*f0*f5^2*f4*f7*f2-\
480*x2^2*x1*x4*f0*f4^3*f5*f7-12*x1^2*x2*x3*f7*f1*f3^3*f5+4*x1^3*x3*f4^2*f3^2*
f2*f5-4*x1^3*x3*f7*f2^3*f3*f5+40*x1^2*x3*x4*f1^2*f7^2*f4^2+32*x1^2*x3*x4*f7^2*
f1*f3^3-20*x2*x4*x1^2*f7*f2*f3^3*f5+20*x2^2*x1*x3*f5^3*f2^2*f4-176*x2^2*x1*x3*
f0*f6*f5*f7*f2*f3-228*x2^2*x1*x3*f1^2*f5^2*f7*f4+48*x1^2*x3*x7*f2*f5^2*f6*f1-\
32*x1^2*x3*x7*f7*f2*f4*f1*f5-96*x1^2*x3*x7*f5*f4*f2^2*f6-12*x1^3*x2*f4^4*f3*f1
+16*x1^3*x2*f0*f4*f3^3*f7-48*x1^3*x2*f0*f6*f4^3*f2+52*x1^3*x2*f1^2*f3*f7*f4^2-\
32*x1^3*x2*f6*f1*f4*f2^2*f5-32*x1^3*x2*f0*f4^3*f1*f7+32*x1^3*x2*f0*f4^2*f3*f2*
f7+96*x1^3*x2*f0*f6*f4*f2*f1*f7+64*x1^3*x2*f0*f6*f5*f4*f3*f2-96*x1^3*x2*f0*f6*
f5^2*f2^2-32*x1^3*x3*f0*f6*f3^2*f2*f7+176*x1^3*x3*f0*f6*f5^2*f1*f4+40*x1^3*x3*
f7*f2^2*f1*f6*f3+8*x1^3*x3*f7*f2*f3^4-8*x1^3*x3*f3^4*f5*f4-12*x1^3*x3*f5^2*f2*
f3^3+24*x2*x1^2*x4*f6*f2^2*f5*f4^2-80*x2*x1^2*x4*f0*f4^2*f1*f7^2+160*x3*x6*x1*
x2*f0*f5*f4*f3*f7-100*x3*x6*x1*x2*f7*f1*f5*f2*f4+40*x2*x1*x3*x7*f5^3*f4*f1+32*
x2*x1*x3*x7*f2*f5^2*f4^2+36*x2*x1*x3*x7*f2*f5^3*f3-84*x2*x1*x3*x7*f3^2*f5^2*f4
-16*x2*x1*x3*x7*f5*f4^3*f3-32*x2*x1*x3*x7*f0*f3^2*f7^2+12*x1^2*x2*x6*f7*f1*f3^
3+44*x1^2*x2*x6*f1^2*f5*f7*f3-48*x1^2*x3*x7*f7*f1*f4^2*f3-8*x2^3*x8*f7*f1*f4^2
*f5+16*x2^3*x8*f7*f0*f5^2*f4-12*x2^3*x8*f5*f7^2*f1^2+32*x2^3*x3*f4^3*f1*f5*f6+
16*x2^3*x3*f1*f4^2*f7*f2*f6+12*x2^3*x4*f5^3*f4^2*f2-8*x2^3*x4*f7^2*f2*f1*f4^2-\
8*x2^3*x4*f2^2*f3*f7^2*f4+40*x2^3*x4*f6*f5^2*f7*f1^2+208*x2^3*x4*f0*f5^3*f3*f7
+56*x2^3*x4*f5*f4^3*f1*f7+40*x2^3*x4*f1^2*f5*f7^2*f4-8*x2^3*x4*f0*f5*f3^2*f7^2
+32*x2^3*x4*f7*f2^2*f4*f5^2+48*x2^3*x4*f0*f5^2*f4^2*f7-16*x2^3*x4*f0*f6*f5^2*
f2*f7+80*x2*x1*x4*x7*f0*f4*f3*f7^2+32*x2*x1*x4*x7*f7^2*f1*f2*f4+632*x2*x1*x4*
x7*f7*f3*f5^2*f1-16*x2^2*x1^2*f0*f6*f3^2*f2*f7+32*x2^2*x1^2*f6*f5*f3*f0^2*f7+4
*x2^2*x1^2*f1*f4*f7*f2^2*f5-16*x2^2*x1^2*f6*f4*f7*f1^2*f2-40*x2*x1^2*x3*f3^2*
f6*f4^2*f2+64*x1*x2*x4*x5*f0*f5*f3*f7*f4+72*x2*x1*x4*x5*f5^3*f2^2-44*x1*x2*x4*
x5*f7*f1*f4^2*f3+20*x2*x1*x4*x5*f7^2*f1^2*f3+408*x2*x1*x4*x5*f0*f5^3*f4+112*x2
^2*x1^2*f0*f6*f5^2*f4*f1-40*x2^2*x1^2*f0*f6*f5*f4^2*f2+16*x2^2*x1^2*f0*f6*f4*
f2^2*f7-20*x2^2*x1^2*f3*f7^2*f1^2*f2+32*x2^2*x1^2*f0*f3^2*f1*f7^2-48*x2^2*x1^2
*f0*f5^2*f4^2*f3+32*x2^2*x1^2*f0*f3*f2^2*f7^2-16*x2*x1*x3^2*f2*f6*f7^2*f1^2-\
448*x1*x2*x3^2*f6^2*f0^2*f7*f5-44*x2*x1*x3^2*f7*f4^4*f1-32*x1*x2*x3^2*f3*f5^2*
f7*f2^2-64*x1*x2*x3^2*f1*f7^2*f5*f2^2-24*x2*x1*x3^2*f4^3*f3^2*f6-48*x2*x1^2*x3
*f4*f7^2*f1^2*f2-8*x2*x1^2*x3*f7^2*f2^4+192*x2*x1^2*x3*f0*f6*f5^3*f1-50*x2^2*
x1^2*f3^2*f5*f4^2*f2+12*x2^2*x1^2*f6*f5*f7*f1^3+14*x2^2*x1^2*f3*f5^2*f4*f2^2+
104*x2^2*x1*x6*f5*f4^2*f2*f3-124*x2^2*x1*x6*f3*f5^2*f1*f4+16*x2^3*x6*f1*f6*f5*
f0*f7-32*x2^3*x6*f0*f5*f4*f3*f7-8*x2^3*x6*f7*f2*f3^2*f4+56*x2^2*x3*x6*f5^2*f4^
2*f2+60*x2^2*x3*x6*f5*f4^3*f3+72*x2^2*x3*x6*f0*f5^4-64*x1^2*x4*x5*f1*f4*f0*f7*
f6-24*x1^2*x4*x5*f3*f5*f4^2*f2-72*x1^2*x4*x5*f0*f5^2*f4^2-108*x1^2*x4*x5*f2*f5
^3*f1+288*x1^2*x4*x5*f1^2*f5^2*f6+8*x1^3*x5*f7*f2^4-40*x1^2*x3*x4*f1*f5^2*f7*
f2*f4-304*x1^2*x3*x4*f1*f4*f0*f7^2*f5+40*x1^2*x3*x4*f7*f2^2*f5*f4^2+172*x1^2*
x3*x4*f1^2*f5*f7^2*f3+64*x1^2*x3*x4*f0*f7^3*f2*f1-28*x3^4*f4^3*f5^3-468*x3^2*
x4^2*f4*f5^5-36*x3^2*x5^2*f0*f5^3-36*x3^2*x6^2*f5^3*f2-16*x3^2*x6^2*f4^3*f5-52
*x3^2*x7^2*f4*f5^3-8*x1^3*x2*f1*f3^4*f7+64*x1^3*x2*f6^2*f4^2*f0^2-96*x1^2*x3^2
*f1^2*f5^3*f6+80*x1^2*x3^2*f0*f3*f4^2*f7*f5+84*x1^3*x3*f7*f1^2*f4*f3*f5-64*x1^
3*x3*f1^2*f5^3*f4-160*x1^3*x3*f0*f5*f1*f7*f4^2+8*x1^3*x3*f7*f2^3*f4^2+8*x1^3*
x2*f0*f4^5+32*x1^3*x2*f1*f6*f4^2*f2*f3+48*x1^3*x2*f4^2*f3^2*f1*f5+28*x1^3*x2*
f2^3*f4*f5^2+12*x1^3*x2*f7*f2^2*f3^3-12*x1^3*x2*f1^2*f5^3*f3-24*x1^3*x2*f1*f5^
3*f2^2+128*x1^3*x2*f5*f4^2*f0^2*f7+64*x1^3*x2*f3*f5^2*f0^2*f7+8*x1^3*x2*f6*f2^
3*f4^2-28*x1^3*x2*f4^2*f3*f2^2*f5-112*x1^3*x2*f0*f5^2*f2*f1*f7+40*x1^3*x2*f2*
f1^2*f5*f7*f4-32*x1^3*x2*f0*f5*f4^3*f3+8*x1^3*x2*f7*f2^3*f3*f4-64*x1^3*x2*f4*
f2*f0^2*f7^2-64*x1^3*x2*f0*f5*f3^2*f2*f7-32*x1^3*x2*f0*f6*f4^2*f3^2+72*x1^3*x2
*f7*f2^2*f3*f1*f5-64*x1^3*x2*f6*f4*f3*f0^2*f7-40*x1^3*x2*f3*f7^2*f1^3+20*x1^2*
x3*x6*f2^2*f4*f5^2+16*x1^3*x2*f0*f4*f1^2*f7^2+16*x1^3*x2*f0*f5*f4*f2^2*f7+112*
x1^3*x2*f0*f5^3*f4*f1-16*x1^3*x2*f2*f4*f5*f3^3+32*x1^3*x2*f2*f4^3*f5*f1+96*x1^
3*x2*f0*f3*f2*f1*f7^2+72*x1^3*x2*f6*f5^2*f2*f1^2-32*x1^3*x2*f6*f5^2*f4*f0^2-24
*x1^3*x2*f7^2*f1^2*f2^2+16*x1^4*f0*f6*f7*f2^3+68*x1^3*x4*f1^2*f5*f7*f4^2+72*x1
^3*x4*f5^2*f2^3*f6-48*x1^3*x4*f1^2*f5^2*f4*f6+12*x1^3*x4*f7*f2*f4*f3*f1*f5-256
*x1^3*x4*f0*f5*f6*f7*f1*f3+96*x1^3*x4*f0*f4*f7^2*f2^2+240*x1^3*x4*f0*f5*f7^2*
f2*f1+48*x1^3*x4*f7*f1*f3^3*f5-30*x1^4*f5^2*f4*f1^2*f3+8*x1^4*f6*f3*f4*f2^3-12
*x1^4*f6*f5*f3^2*f1^2+32*x1^4*f0*f4^2*f2^2*f7+12*x1^4*f4*f7*f3^2*f1^2-28*x1^4*
f5^2*f1*f4*f2^2+32*x1^4*f4*f3*f0^2*f7*f5-12*x1^4*f6*f2^4*f5+16*x1^4*f2*f6*f1^2
*f5*f4-6*x1^4*f4^3*f3*f2^2-32*x1^4*f0*f5*f4^3*f2+32*x1^4*f5^2*f2*f0^2*f7+20*x1
^4*f7*f1^2*f2*f5*f3-8*x1^4*f7*f1*f0*f3^2*f5+28*x1^4*f2*f5*f1*f4^2*f3-12*x1^4*
f2*f1*f3^3*f7+8*x1^4*f0*f4^4*f3-20*x1^4*f0*f4^2*f5*f3^2-32*x1^4*f6*f0^2*f7*f3^
2-20*x1^4*f5*f2^2*f3^2*f4-24*x1^4*f6*f7*f1^3*f3+18*x1^4*f5^3*f2*f1^2+32*x2^2*
x3*x4*f0*f5*f4*f3*f7^2+124*x2^2*x3*x4*f1^2*f7^2*f5^2+36*x2^2*x3*x4*f7*f3^2*f5*
f4^2+288*x3*x4*x2^2*f0*f6*f5^2*f3*f7-16*x3*x4*x2^2*f6*f2^2*f5*f7*f4-224*x3*x4*
x2^2*f0*f6*f5*f1*f7^2-8*x1^2*x3*x5*f2*f4^3*f3-40*x1^2*x2*x6*f1^2*f7*f4^2+36*x1
^2*x2*x6*f1*f5*f7*f2^2+4*x1^3*x7*f4^2*f3^3-32*x2^2*x4*x5*f1^2*f7*f6*f5-12*x2^2
*x4*x5*f7*f3*f4*f1*f5-4*x2^2*x4*x5*f7*f2^2*f5*f4-108*x2^2*x4*x5*f4*f5^3*f1+36*
x2^2*x4*x5*f7*f2*f5^2*f1+12*x2^2*x4*x5*f5^2*f4^2*f2+104*x2^2*x4*x5*f0*f5*f4^2*
f7+64*x2^2*x4*x5*f0*f4*f2*f7^2-128*x2^2*x4*x5*f0*f5^2*f3*f7+32*x2^2*x4*x5*f0*
f3^2*f7^2-36*x2^2*x1*x5*f5^3*f1^2+120*x1^2*x4^2*f7*f3*f5*f4^2*f2+144*x1^2*x4^2
*f7*f2*f5^3*f1-24*x1^2*x4^2*f7*f2*f4*f5*f1*f6-32*x2*x4^2*x1*f0*f6^2*f5*f2*f7-\
28*x1*x4*x3*x7*f7*f4^3*f3+112*x1*x4*x3*x7*f0*f4^2*f7^2-16*x1*x4^2*x7*f7^2*f2*
f1*f6-4*x1^2*x4*x6*f7*f3^4-12*x2^2*x4*x8*f7*f3*f5*f4^2-16*x2^2*x4*x8*f7*f5^2*
f2*f4+12*x2^2*x4*x8*f7*f3^2*f5^2-32*x2^2*x4*x8*f7^2*f2^2*f5-48*x2^2*x4*x8*f7*
f0*f6*f5^2+48*x2^2*x4*x8*f7^2*f0*f4*f5+8*x2^2*x4*x8*f7^2*f1*f4^2+24*x2^2*x4*x8
*f7*f5^3*f1+16*x2^2*x4*x8*f7*f4*f6*f1*f5+24*x2*x4*x3*x8*f7*f3^2*f6*f5+40*x2*x4
*x3*x8*f7*f5^2*f6*f1-30*x2^2*x4^2*f7^2*f2*f5*f3^2+4*x2^2*x4^2*f1*f5*f7*f4^2*f6
-44*x2^2*x4^2*f7*f2^2*f5^2*f6+8*x2^2*x4^2*f0*f6*f5*f7^2*f2-16*x4^2*x5*x1*f7*f2
^2*f6*f4-32*x4^2*x5*x1*f6^2*f7*f1^2+16*x3*x4^2*x1*f6^2*f2*f7*f3^2-64*x3*x4^2*
x1*f0*f6^3*f2*f7-92*x1*x4^2*x3*f5*f4^3*f3*f7-108*x4*x3*x7^2*f5^4-6*x5^2*x7^2*
f3*f4-36*x5^2*x6^2*f0*f5+16*x5^2*x7^2*f7*f0-8*x2*x5*x7^2*f4^3-2*x6^4*f3*f4-6*
x6^4*f2*f5+4*x6^4*f7*f0-16*x6^2*x7^2*f4*f5-8*x1*x6*x7^2*f4^3+8*x6*x5*x7^2*f4^2
+108*x4*x6*x7^2*f5^3-12*x7^4*f5*f6-12*x7^3*x3*f5^3+12*x7^3*x6*f5^2-64*x3*x4^2*
x2*f0*f6^2*f5*f4*f7+64*x3*x6*x1*x4*f0*f6^2*f7*f2-40*x1^2*x4^2*f1*f6*f7*f4^2*f3
+4*x1^2*x4^2*f7*f3^4*f6+18*x1^2*x4^2*f5^3*f4^2*f2+656*x1^2*x4^2*f4*f0^2*f7^3-\
144*x1^2*x4^2*f4*f5^4*f1+24*x1*x4*x3*x8*f7*f3*f5*f6*f2-16*x1*x4*x7^2*f0*f6*f7*
f5+36*x1*x4*x7^2*f5^2*f4^2+216*x1*x4*x7^2*f5^2*f6*f2+28*x1*x4*x7^2*f7*f3^2*f5-\
108*x1*x4*x7^2*f5^3*f3+16*x2*x4^2*x5*f7*f2*f4*f3*f6+52*x2^2*x4^2*f1*f7^3*f2*f3
-352*x1^2*x4^2*f0*f4^2*f3*f7^2+12*x1^2*x4^2*f4^2*f6*f7*f2^2-4*x1^2*x4^2*f7*f2*
f4^4+304*x1^2*x4^2*f7*f3^2*f5^2*f2-12*x2*x4*x5*x8*f7*f3^2*f5-12*x2*x4*x5*x8*f7
*f1*f5^2-16*x2*x4*x5*x8*f7*f1*f4*f6+44*x2*x4*x5*x8*f7^2*f3*f1+48*x2*x4*x5*x8*
f7*f0*f5*f6-16*x2*x4*x5*x8*f7*f2*f4*f5+24*x2*x4*x6*x8*f7*f5^2*f2+8*x2*x4*x6*x8
*f7^2*f0*f5-16*x2*x4*x6*x8*f7*f6*f1*f5-40*x2*x4*x6*x8*f7^2*f1*f4-60*x7*x8*f7*
f4^2*x2*x4*f5+48*x2*x4*x7*x8*f7^2*f1*f5-144*x2*x4*x3*x6*f5^3*f6*f1-72*x2*x4^2*
x3*f4^3*f5^2*f6+24*x3*x4^2*x2*f7*f3*f4^3*f6+56*x1*x4*x5*x6*f7*f3*f4*f1+16*x3^2
*x2*x5*f0*f6*f5*f2*f7-64*x3^2*x2*x5*f5*f4^2*f1*f6+20*x3^2*x2*x5*f7*f2^2*f4*f5-\
16*x3^2*x2*x5*f1*f6*f7*f3^2+32*x3^2*x2*x5*f0*f4*f7^2*f2+72*x3^2*x2*x5*f0*f5^4+
480*x3^2*x2*x5*f0*f6*f4*f5^2-16*x3^2*x2*x5*f7*f2*f6*f1*f4+12*x3^2*x2*x5*f5*f4^
3*f3-96*x3^2*x2*x5*f0*f6^2*f4^2-96*x2*x5*f0*f4^2*f7*x3^2*f5+88*x3^2*x2*x5*f0*
f5*f1*f7^2-8*x3^3*x5*f7*f3^2*f4^2+24*x3^3*x5*f3*f7*f2*f4*f5+32*x1^3*x6*f6*f7*
f1^3-64*x1^3*x6*f6^2*f0^2*f4-8*x1^3*x6*f2^3*f4*f6-16*x1^3*x6*f0*f5^2*f4*f2+24*
x1^3*x6*f0*f5*f7*f2^2+48*x1^3*x6*f1^2*f5*f6*f3+24*x1^3*x6*f1*f6*f2^2*f5-64*x1^
3*x6*f0^2*f7*f5*f4+48*x1^3*x6*f0*f6*f2*f4^2-40*x1^3*x6*f1^2*f5*f7*f2+32*x1^3*
x6*f0*f6*f4*f3^2+16*x1^3*x6*f0*f7*f1*f4^2-32*x1^3*x6*f2*f4*f1*f6*f3-48*x1^3*x6
*f0*f5^3*f1+28*x1^3*x6*f7*f2^2*f1*f4-28*x1^3*x6*f1^2*f3*f7*f4+16*x1^3*x6*f0*f3
*f4^2*f5-32*x2^3*x4*f4*f0^2*f7^3-32*x2^3*x4*f2*f7^3*f1^2+8*x2^3*x4*f7*f3*f4^2*
f1*f6+8*x2^2*x6*x8*f7*f1*f4*f5-8*x2^2*x6*x8*f7*f0*f5^2+324*x4^3*x6*f5^5+28*x2^
2*x3^2*f7^2*f2*f1*f4^2-48*x2^2*x3^2*f0*f6^2*f5*f4^2+16*x2^2*x3^2*f7*f3^2*f5*f1
*f6+184*x2^2*x3^2*f6*f5^2*f1*f4^2-24*x2^2*x3^2*f1^2*f7^2*f6*f3+44*x2^2*x3^2*f7
^2*f2*f5*f3*f1+80*x2^2*x3^2*f4*f5^4*f1-16*x2^2*x3^2*f0*f6*f4*f1*f7^2-32*x2^2*
x3*x6*f7*f2*f1*f4*f6+240*x2^2*x3*x6*f0*f6*f5^2*f4-8*x2^2*x3*x6*f7*f4^2*f2*f3+
20*x2^2*x3*x6*f7*f2^2*f5*f4+32*x2^2*x3*x6*f0*f6*f4*f3*f7+20*x2^2*x3*x6*f7*f2*
f5^2*f1-36*x2^2*x3*x6*f7*f3*f4*f1*f5-24*x2^2*x3*x4*f4^2*f5^2*f2*f6+216*x2^2*x3
*x4*f6*f5^3*f1*f4-28*x2^2*x3*x4*f2*f7^2*f3^2*f4-128*x2^2*x3*x4*f5*f0^2*f7^3-\
432*x2^2*x3*x4*f0*f6*f5^4+8*x3*x4*x2^2*f7*f3^3*f6*f4-64*x3*x4*x2^2*f0*f6*f3^2*
f7^2+64*x2^2*x3*x4*f0*f3*f2*f7^3+32*x2^2*x3*x4*f0*f5^3*f4*f7-36*x2^2*x6^2*f0*
f5^3-4*x1^3*x5*f2*f4^3*f1+4*x1^3*x5*f2^2*f3*f4^2+4*x1^3*x3*f4^4*f3*f2-4*x1^3*
x3*f7*f1*f4*f2^2*f5-4*x1^3*x3*f4^5*f1+4*x1^3*x3*f4^3*f3^3-8*x1^2*x3^2*f7*f2*f5
*f3^3+48*x1^2*x3^2*f7*f2^2*f5*f3*f4+28*x1^2*x3^2*f7^2*f2*f3^2*f1-16*x1^2*x3^2*
f7^2*f2^3*f3+8*x1^2*x5*x8*f1^2*f5*f7-324*x4^2*x3*x7*f5^5-48*x1^2*x2*x7*f0*f7^2
*f2^2+16*x1^2*x2*x7*f0*f5^2*f4^2+36*x1^2*x2*x7*f2*f5^3*f1+76*x1^2*x2*x7*f1*f5^
2*f3*f4-36*x2^2*x1*x4*f5^2*f4^3*f2+36*x2^2*x1*x4*f3*f5^4*f1-8*x2^2*x1*x4*f1*f4
*f6*f7*f3^2+32*x2^2*x1*x4*f0*f6^2*f1*f7*f4+16*x2^2*x1*x4*f3*f6*f4*f7*f2^2-96*
x2^2*x1*x4*f5*f4^3*f1*f6+48*x2^2*x1*x4*f4^4*f3*f5-144*x2^2*x1*x4*f4^2*f5^2*f3^
2-48*x2^2*x1*x4*f0*f6*f5*f2*f7*f4-72*x2^2*x1*x4*f4^3*f7*f2*f3-88*x2^2*x1*x4*f1
^2*f7^2*f6*f2+32*x3*x4*x2^2*f4*f6^2*f2*f7*f1-72*x3*x4*x2^2*f1*f5^2*f7*f6*f2-\
288*x3*x4*x2^2*f0*f6*f5*f4^2*f7+316*x2^2*x3*x4*f5^2*f4^2*f7*f1+4*x2^2*x3*x4*f3
*f7^2*f1*f4^2+48*x2^2*x3*x4*f7^2*f3^2*f5*f1-144*x2^2*x3*x4*f5^3*f4^2*f3+40*x2^
2*x3*x4*f7^2*f2^2*f5*f3-4*x1^3*x7*f4^4*f1+4*x1^3*x7*f7*f1*f3^3-4*x1^3*x6*f3^4*
f4+4*x1^3*x6*f3^2*f4^2*f2-8*x1^2*x6^2*f3*f4^2*f2+4*x1^3*x5*f2*f4*f3^3-4*x1^3*
x5*f1^2*f5*f4^2-120*x2^2*x5*x6*f0*f5^2*f4+56*x2^2*x5*x6*f1*f4^2*f5+16*x2^2*x1*
x6*f0*f4^2*f7*f3-40*x2^2*x1*x6*f0*f3*f1*f7^2-16*x2^2*x1*x6*f1*f4*f6*f0*f7+48*
x1^3*x3*f0*f5*f7^2*f1^2-36*x1^3*x3*f3*f5^2*f4*f2^2+64*x1^3*x3*f6*f5*f3*f0^2*f7
-16*x1^3*x3*f0*f3^3*f5*f7+48*x1^2*x3^2*f0*f7^3*f1^2-112*x1^2*x3^2*f0*f6*f4*f1*
f7*f5-144*x3^3*x1*f1*f6^2*f5^2*f2-48*x3^3*x1*f6^2*f7*f4*f1^2-8*x3^3*x1*f7^2*f3
^2*f1*f4+40*x3^3*x1*f3*f6*f4*f5^2*f2-64*x3^3*x1*f0*f6^2*f5*f4^2-32*x1*x3^3*f7*
f0*f5^3*f3+880*x3^2*x4^2*f7*f4*f5^3*f3-356*x3^2*x4^2*f7^2*f2*f5*f4^2-208*x3^2*
x4^2*f0*f6*f2*f7^3+8*x3^2*x4^2*f7^3*f2*f3^2+104*x3^2*x4^2*f7^3*f0*f4^2+400*x3^
2*x4^2*f5^2*f4^3*f7-496*x3^2*x4^2*f7^2*f4*f5^2*f1-32*x3^2*x4^2*f7*f5^3*f6*f1+
176*x3^2*x4^2*f7^3*f1*f2*f5+32*x3^2*x4^2*f7^3*f2^2*f4-228*x3^2*x4^2*f1^2*f7^3*
f6-504*x3^2*x4^2*f5^3*f4^2*f6-336*x3^2*x4^2*f7*f3*f5*f4^2*f6-32*x3^2*x4^2*f7^2
*f3*f4^3+152*x3^2*x4^2*f7^4*f0*f1-24*x2^2*x4*x7*f7*f5*f1*f6*f3+48*x2^2*x4*x7*
f7^2*f0*f4^2-96*x2^3*x4*f0*f5^2*f1*f7^2+16*x2^3*x4*f0*f2^2*f7^3+8*x2^3*x4*f7^2
*f2^3*f5-140*x2^3*x4*f3*f5^2*f1*f4*f7+36*x2^3*x4*f7^2*f2*f5*f3*f1+32*x2^3*x4*
f6*f5*f0^2*f7^2-32*x2^3*x4*f6*f2*f5*f1*f4*f7+24*x1^3*x5*f1*f5^2*f2^2+16*x2^2*
x3*x6*f0*f6*f5*f2*f7+108*x2^2*x4*x6*f4^2*f5^2*f3-48*x2^2*x4*x6*f2*f5^3*f4-144*
x2*x3*x4*x7*f1*f7^2*f4^2+160*x2*x3*x4*x7*f0*f5*f4*f7^2-240*x2*x3*x4*x7*f0*f6*
f5^2*f7+420*x2*x3*x4*x7*f4*f5^2*f2*f7-112*x2*x3*x4*x7*f2*f7*f4^2*f6+8*x2*x3*x5
*x7*f2*f7*f1*f6-96*x2*x3*x5*x7*f4*f6*f1*f5-224*x2*x3*x5*x7*f0*f5*f7*f4+12*x2*
x3*x5*x7*f7*f5*f1*f3-24*x2*x3*x5*x7*f1*f5^3+32*x2*x3*x5*x7*f4^2*f2*f6+288*x2*
x3*x5*x7*f0*f5^2*f6+40*x2*x3*x5*x7*f1*f7*f4^2+8*x1*x3*x2*x8*f7*f3*f4*f1*f6+16*
x1*x3^2*x8*f7*f4^2*f1*f6+12*x1*x3^2*x8*f5^2*f7*f2*f3+24*x1*x3^2*x8*f5*f7*f4^2*
f2-24*x1*x3^2*x8*f6*f7*f2^2*f5-36*x1*x3*x6^2*f3^2*f5*f4-48*x1*x3*x6^2*f0*f7*f4
^2+10*x2^2*x3^2*f7^2*f2^3*f5-16*x2^2*x3^2*f1*f6^2*f4^3+64*x2^2*x3^2*f6^3*f0^2*
f7+64*x1^2*x3*x4*f7^3*f3*f0^2+24*x1^2*x3^2*f6^2*f2^3*f5-32*x1^2*x3^2*f0^2*f7^3
*f2+8*x1^2*x3^2*f0*f4^2*f1*f7^2+128*x1*x3*x4*x7*f7*f0*f5^3+80*x1*x3*x4*x7*f7^2
*f3*f0*f5-336*x1*x3*x4*x7*f3*f5^3*f4-260*x1*x3*x4*x7*f7*f2*f5*f4^2+112*x1*x3*
x4*x7*f7*f5^2*f1*f4-4*x1*x3*x4*x7*f7*f2*f5^2*f3+16*x1*x3*x4*x7*f7^2*f1^2*f6-\
168*x1*x3*x4*x7*f7*f5*f1*f6*f3-8*x2*x3*x4^2*f1*f7^2*f3*f6*f4-64*x2*x3*x4^2*f7^
2*f1^2*f6^2-408*x2*x3*x4^2*f7^2*f4^2*f5*f1+208*x2*x3*x4^2*f6*f5^2*f7*f1*f4-48*
x2*x3*x4^2*f3^2*f5^3*f7-4*x1^2*x3*x7*f5*f4^3*f2+64*x1*x3*x4*x7*f0*f6^2*f3*f7+
96*x1*x3*x4*x7*f1*f5*f6^2*f4-8*x1*x3*x7^2*f4^2*f6*f3+80*x1*x3*x7^2*f2*f6*f4*f5
-28*x1*x3*x7^2*f7*f3*f5*f2-8*x1*x3*x7^2*f7*f3*f6*f1+16*x1*x3*x7^2*f1*f6^2*f4+
48*x1*x3*x7^2*f5^2*f7*f0+48*x1^2*x3*x5*f0*f6*f4^2*f3+8*x1^2*x3*x5*f7*f3^2*f2^2
-12*x1^2*x3*x5*f1^2*f7*f4^2-112*x1^2*x3*x5*f0*f6*f5*f4*f2-12*x2^3*x5*f1^2*f4*
f7*f5+24*x2^3*x5*f0*f5^2*f1*f7-16*x2^3*x5*f4^3*f5*f1-32*x2^3*x5*f6*f0^2*f7*f5+
216*x2^2*x4*x5*f0*f5^4+8*x1^3*x3*f1^2*f5*f6*f4^2+68*x1^3*x3*f1*f5^2*f3^2*f4-\
128*x1^3*x3*f4*f3*f0^2*f7^2-8*x1^3*x3*f5^2*f7*f2*f1^2+24*x1^3*x3*f4^2*f3^2*f1*
f6+16*x1^3*x3*f0*f5^2*f7*f2^2-56*x1^3*x3*f6*f5*f7*f1^3-96*x1^3*x3*f0*f5^2*f7*
f1*f3-112*x1^2*x2*x3*f1*f5^2*f0*f7*f4-8*x2^3*x3*f3*f6*f4*f7*f2^2-16*x2^3*x3*f0
*f6*f4^2*f3*f7+16*x2^3*x1*f0*f6*f5*f2^2*f7-64*x2^3*x1*f0*f5^2*f3*f7*f2+8*x2^3*
x1*f3*f7*f4^2*f2^2-48*x2^3*x1*f0*f5^2*f4^3+24*x2^3*x1*f3*f6*f1^2*f7*f4+16*x2^3
*x1*f1*f5*f7*f2*f3*f4+80*x1^4*f6*f5*f0^2*f4^2+48*x1^4*f0*f6^2*f1^2*f5+720*x3*
x4*x1^2*f0*f5^2*f1*f6*f7-32*x3*x4*x1^2*f1*f4^2*f7*f2*f6-552*x3*x4*x1^2*f2*f6*
f1*f7*f3*f5+48*x1^2*x3*x4*f7^3*f1^3-8*x1^2*x5*x7*f3*f4^2*f2+20*x1^2*x2*x7*f3*
f5*f4^2*f2-144*x1^2*x3*x4*f0*f6*f4*f2*f7*f5-64*x3*x4*x1^2*f7*f2*f3*f0*f6^2-512
*x4*x7*x3^2*f0*f6^2*f5*f7-100*x3^2*x4*x7*f7^2*f2*f5*f3-16*x3^2*x4*x7*f7*f3*f6^
2*f2+384*x3^2*x4*x7*f7^2*f0*f6*f4-128*x3^2*x4*x7*f7*f3*f4^2*f6+568*x3^2*x4*x7*
f7*f3*f5^2*f4+144*x3^2*x4*x7*f7*f1*f6^2*f4-312*x3^2*x4*x7*f4*f5^4-264*x4*x7*x3
^2*f4*f5*f1*f7^2+40*x4*x7*x3^2*f3^2*f5*f6*f7-360*x4*x7*x3^2*f0*f5^2*f7^2+84*x4
*x7*x3^2*f2*f7*f5^3-144*x3^2*x4*x7*f5*f6^2*f3*f4-336*x3^2*x4*x7*f6*f4^2*f5^2-\
56*x4*x7*x3^2*f1*f5^2*f6*f7-352*x4*x7*x3^2*f7*f4*f6*f2*f5+24*x3^2*x5*x7*f7*f2*
f4^2-48*x3^2*x5*x7*f1*f6^2*f4+288*x3^2*x5*x7*f0*f6^2*f5+48*x3^2*x5*x7*f3*f4^2*
f6-28*x3^2*x5*x7*f5*f4^3-48*x3^2*x5*x7*f5^2*f6*f1-16*x3^2*x5*x7*f2*f5*f4*f6-\
128*x3^2*x5*x7*f0*f6*f7*f4-24*x3^2*x5*x7*f7*f6*f3*f1+16*x2^3*x1*f5*f7^2*f1^3-\
64*x2^3*x1*f5^3*f0^2*f7-40*x2^3*x1*f1*f5^3*f2*f4+12*x2^3*x1*f5^4*f1^2+20*x1^2*
x3*x5*f2^2*f5*f4^2+48*x1^2*x2^2*f4^3*f3*f1*f5-32*x1^2*x2^2*f0*f5*f1*f7*f4^2+80
*x1^2*x2^2*f0*f5*f4*f7*f2*f3+48*x1^2*x2^2*f5^2*f0^2*f7*f4+32*x1^2*x2^2*f2*f4^3
*f6*f1+20*x1^2*x2^2*f7*f2^2*f3^2*f4+32*x1^2*x2^2*f0*f6*f4*f7*f1*f3-24*x1*x3*x2
*x7*f3^2*f6*f7*f1+24*x1*x3^2*x7*f1*f5^4-36*x1^2*x3*x7*f3^3*f5^2-24*x1^2*x3*x7*
f3^3*f6*f4+60*x1^2*x3*x7*f3*f5^3*f1-16*x1*x3^2*x7*f4^3*f6*f3+64*x1^2*x3*x5*f0*
f6*f7*f2^2-24*x1^2*x3*x5*f2^3*f6*f5+144*x1*x3^2*x4*f4^2*f6^2*f1*f5-4*x2*x3*x4^
2*f7^2*f3^2*f4^2+4*x2^2*x3*x4*f7^2*f2^2*f4^2+16*x2*x3*x5^2*f1*f4^2*f5+24*x2*x3
*x7^2*f7*f5^2*f1-12*x2*x3*x7^2*f1*f7^2*f3+60*x2*x3*x7^2*f7*f2*f5*f4-20*x2*x3*
x6^2*f7*f2^2*f5-4*x1*x3*x2*x5*f7*f3^2*f1*f4+16*x1*x3*x2*x5*f0*f7^2*f3*f1-160*
x1*x3*x2*x5*f0*f5^2*f1*f7+48*x1*x3*x2*x5*f7*f0*f6*f3*f2-160*x1*x3*x2*x5*f7*f0*
f5*f2*f4-24*x1*x3*x2*x6*f7*f2^2*f4^2-12*x1^2*x3*x4*f5^2*f4^3*f2+12*x1^2*x3*x4*
f4^4*f3*f5+36*x1^2*x3*x4*f4^2*f5^2*f3^2-108*x1^2*x3*x4*f3^3*f5^3+168*x1*x3*x4^
2*f7^2*f3^2*f6*f1-96*x1*x3*x4^2*f7*f0*f5^4+180*x1*x3*x4^2*f5^3*f4^3+32*x1*x3^2
*x8*f5*f7*f3*f1*f6+36*x1*x3^2*x8*f5^2*f7*f1*f4+100*x1*x3*x4*x8*f7^2*f3*f5*f1+
96*x1*x3*x4*x8*f7*f1*f5^3-4*x1*x3*x4*x8*f7^3*f1^2-36*x1*x3*x4*x8*f7^2*f2^2*f5-\
192*x1*x3*x4*x8*f7*f0*f6*f5^2+32*x1*x3*x4*x8*f7*f1*f5*f4*f6+60*x1^2*x3*x6*f3^2
*f5^2*f2+32*x1^2*x3*x6*f0*f6^2*f4*f2+40*x1^2*x3*x6*f3^2*f2*f4*f6-972*x4^4*f6*
f5^5+8*x2*x1*x4*x6*f7*f3^2*f5*f2+192*x2*x1*x4*x6*f1*f5*f4^2*f6+64*x2^2*x4*x1*
f6^2*f5*f0^2*f7+992*x2*x1*x4*x7*f2*f5*f0*f7^2-144*x2*x1*x4*x7*f3*f5^2*f4^2+28*
x2*x1*x4*x7*f7*f3^3*f5+8*x2*x1*x5*x7*f1*f7*f2*f4+24*x2*x1*x5*x7*f2^2*f5^2-24*
x2*x1*x5*x7*f3*f5^2*f1+192*x2*x1*x3*x5*f4*f1*f6*f2*f5-16*x2*x1*x3*x5*f4^2*f1*
f7*f2-152*x2*x1*x3*x5*f4*f3*f5^2*f1-288*x2*x1^2*x3*f7*f3*f0*f6*f1*f5+136*x2^2*
x1*x3*f5^3*f1*f4*f3-16*x2^2*x1*x3*f2^3*f6*f7*f4-8*x2*x1^2*x3*f4^5*f2-216*x2*x1
*x4^2*f4^2*f3*f5^3+72*x2*x1*x4^2*f4^4*f5^2+16*x4^2*x1*x2*f3^4*f7^2+40*x1^2*x3*
x7*f2*f3^2*f7*f4-52*x2^2*x4^2*f7*f2*f5^3*f3-128*x2^2*x4^2*f7*f0*f6*f5^2*f4+444
*x2^2*x4^2*f7*f4*f5^3*f1+8*x2*x1*x3^2*f4^6+24*x2^3*x6*f7*f2*f1*f4*f5+24*x2^3*
x6*f5*f4^3*f2+64*x2^3*x6*f5*f0^2*f7^2-12*x2^3*x6*f1^2*f7*f5^2-16*x2^3*x6*f0*f4
^3*f7+64*x2^3*x6*f0*f5^3*f4+204*x1^2*x4*x6*f7*f1^2*f5^2+52*x1^2*x4*x6*f7^2*f1^
2*f3+40*x1^2*x4*x6*f7*f1^2*f6*f4-48*x1^3*x3*f0*f6*f4^3*f3+128*x1^3*x3*f6*f0^2*
f7*f4^2+96*x1^3*x3*f0*f6*f5*f7*f2*f1-48*x1^3*x3*f0*f6*f5*f2*f4^2+16*x1^3*x3*f0
*f4^2*f3^2*f7-96*x1^3*x3*f0*f6*f4*f7*f1*f3-16*x1^3*x3*f7*f1*f4*f3^3+72*x1^3*x3
*f1*f5^2*f2*f4^2+48*x1^3*x3*f0*f5^4*f1-64*x1^3*x3*f5*f2*f0^2*f7^2+64*x1^3*x3*
f0*f3*f2^2*f7^2-288*x1^3*x3*f6*f5^3*f0^2+352*x1^3*x3*f5^2*f0^2*f7*f4-128*x1^3*
x3*f0*f5*f4*f7*f2*f3+16*x2^2*x4*x5*f0*f6*f4*f3*f7+8*x2^2*x4*x5*f7*f4^2*f2*f3-\
32*x2^3*x1*f0*f5*f2*f7^2*f1+16*x2^3*x1*f3^2*f0*f7*f4*f5+32*x2^3*x4*f0*f5*f4*f2
*f7^2-176*x3*x4*x2^2*f0*f6*f4*f2*f7^2-64*x3*x4*x2^2*f0*f6^2*f5*f2*f7-32*x3*x4*
x2^2*f0*f6^2*f4*f3*f7-16*x1^2*x3^2*f7*f2^3*f5^2-32*x1^2*x3^2*f0*f7^2*f2*f3*f4-\
32*x1^2*x3^2*f0*f6*f4^3*f5+12*x1^2*x3^2*f1*f5^4*f2-16*x1^2*x3^2*f4*f5^3*f2^2+
164*x2*x1*x3*x5*f4*f1^2*f7*f5+328*x2*x1*x3*x5*f4^2*f0*f5^2+16*x2*x1*x3*x5*f7*
f3*f1^2*f6-12*x2*x1*x3*x5*f4^2*f3*f5*f2-144*x2*x1*x3*x5*f1^2*f5^2*f6-36*x2*x1*
x3*x5*f1*f5*f7*f2*f3-576*x2*x1^2*x3*f6^2*f5^2*f0^2+40*x2*x1*x3*x7*f1^2*f7^2*f4
-48*x2*x1*x3*x7*f4^3*f6*f2-68*x2*x1*x3*x7*f1*f4^3*f7-128*x2*x1*x3*x7*f6*f0^2*
f7^2-500*x2*x1*x4*x6*f7*f1*f4*f3*f5+136*x2*x1*x4*x6*f7^2*f1^2*f4-96*x2*x1*x4*
x6*f5*f4^3*f3+136*x2*x1*x4*x6*f7*f4^2*f2*f3+48*x2*x1*x4*x6*f0*f5^2*f3*f7+36*x2
^2*x1^2*f0*f5^3*f3^2+16*x2*x1^2*x5*f0*f6*f4^2*f2+144*x2*x1^2*x5*f0*f5*f4^2*f3-\
24*x2*x1^2*x5*f3*f4^3*f1-16*x2*x1^2*x5*f3*f2^2*f5*f4-72*x1^3*x3*f1^2*f5^2*f6*
f3-16*x1^3*x3*f4^3*f2^2*f5+16*x1^3*x3*f0*f5^3*f2*f4+240*x1^3*x3*f0*f6*f5^2*f2*
f3+32*x1^3*x3*f0*f6^2*f4^2*f1+64*x1^3*x3*f0*f3^2*f1*f7^2+120*x2^2*x1*x4*f5^3*
f2*f3*f4+192*x2^2*x1*x4*f0*f5^2*f3*f7*f4-104*x2^2*x1*x4*f1^2*f7^2*f4^2+132*x2^
2*x1*x4*f4^2*f5^3*f1-312*x2^2*x1*x4*f0*f5^4*f4-144*x2^2*x1*x4*f0*f5*f2*f7^2*f3
+4*x1^2*x4*x7*f7*f1*f5^2*f2-376*x1^2*x4*x7*f7*f6*f1^2*f5-132*x1^2*x4*x7*f7*f1*
f5*f3*f4-16*x2^3*x7*f7*f1*f6*f2*f4+16*x2^3*x7*f1^2*f7*f6*f5+96*x2^3*x7*f0*f5^2
*f3*f7+56*x2^2*x3*x7*f1^2*f7^2*f5+20*x2^2*x3*x7*f7*f3^2*f4^2+28*x2^2*x3*x7*f2*
f5^3*f4-16*x2^2*x3*x4*f0*f4*f1*f7^3-48*x1^2*x3*x5*f7*f1^2*f2*f6-16*x1^2*x3*x5*
f1*f7*f2^2*f5-32*x1^2*x3*x5*f3^2*f1*f4*f6+24*x1^2*x3*x5*f1*f7*f2*f3*f4-288*x1^
2*x3*x5*f5^2*f0^2*f7+80*x1^2*x3*x5*f1*f6*f0*f7*f3+240*x1^2*x3*x5*f0*f5^2*f3*f4
-48*x1^2*x3*x5*f2*f0*f5^3+24*x1^2*x3*x5*f5^3*f1^2-48*x1^2*x3*x5*f3^2*f5^2*f1-\
472*x2*x3*x4*x6*f4*f5^2*f1*f7-72*x2*x3*x4*x6*f5^4*f2-48*x2*x3*x4*x6*f2*f5^2*f4
*f6+144*x2*x3*x4*x6*f5^2*f4^3-32*x2*x3*x4*x6*f1*f7*f6^2*f2-44*x2*x3*x4*x6*f7*
f2*f5^2*f3-96*x1*x3*x6*x7*f0*f6^2*f4-72*x1*x3*x6*x7*f2*f5*f3*f6+48*x2^2*x3*x5*
f0*f6*f4*f2*f7+16*x2^2*x3*x5*f1*f4^3*f6-16*x2^2*x3*x5*f2*f6*f7*f3*f1-16*x2^2*
x3*x5*f0*f3*f7^2*f2+64*x2^2*x3*x5*f0*f6*f5*f1*f7+16*x2^2*x3*x5*f0*f6*f3^2*f7-8
*x2^2*x3*x5*f1^2*f6*f7*f4+64*x1^2*x3^2*f0*f6^3*f4*f1+72*x1^2*x3^2*f0*f5^4*f3-\
144*x1^2*x3^2*f6^2*f2*f3*f1*f5+64*x1*x3^2*x2*f0*f6^2*f1*f7*f4+12*x2^2*x3^2*f4^
2*f6*f7*f2^2+256*x1*x3^2*x4*f6^2*f0^2*f7^2-24*x1*x3^2*x4*f6*f7*f3^3*f4-16*x1*
x3*x6*x7*f4^4-48*x1*x3*x4*x5*f0*f5^2*f3*f7+12*x1*x3*x4*x5*f7*f3^3*f4+144*x1*x3
*x4*x5*f2^2*f5^2*f6-96*x1*x3*x4*x5*f1*f4^2*f5*f6+324*x1*x3*x4*x5*f7*f2*f5^2*f1
-16*x1*x3*x4*x5*f0*f3^2*f7^2+48*x1*x3*x4*x5*f7*f2*f3^2*f5-512*x1*x3*x4*x5*f1^2
*f7*f6*f5+16*x1^2*x3*x6*f1*f7*f2^2*f6+4*x2^2*x3*x5*f3*f5*f7*f2^2+4*x2^2*x3*x5*
f7*f3^2*f2*f4-8*x2*x3*x5*x8*f7^2*f2*f1+4*x2*x3*x6*x8*f7^2*f3*f1+8*x2*x3*x6*x8*
f7*f3^2*f5+4*x2^2*x3*x8*f7^2*f3*f4*f1-4*x2^2*x3*x8*f7*f3^2*f5*f4+4*x2*x3*x6^2*
f1^2*f7^2+16*x4*x5*x2*x3*f3^2*f6*f7*f2+32*x4*x5*x2*x3*f6^2*f7*f1^2+160*x2*x3*
x4*x5*f0*f4*f3*f7^2-64*x1*x3^2*x2*f0*f5^2*f3*f7*f4-32*x1*x3^2*x2*f0*f6^2*f2*f7
*f3+64*x1^2*x3*x7*f0*f5^3*f4+384*x1^2*x3*x7*f0*f5*f6^2*f2+64*x2*x3*x4*x6*f0*f5
*f3*f7^2-16*x2*x3*x4*x6*f7*f4^3*f3+16*x2*x3*x4*x6*f7^2*f3^2*f2+96*x2*x3*x4*x6*
f1*f0*f7^3+128*x2*x3*x4*x6*f0*f5^3*f7+32*x2*x3*x4*x6*f0*f4^2*f7^2+32*x2*x3*x4*
x6*f7^2*f2^2*f4+16*x2*x3*x4*x6*f1^2*f6*f7^2+16*x2^2*x3*x5*f7*f2*f1*f4*f5-32*x2
^2*x3*x5*f0*f5*f4*f3*f7-24*x2^2*x3*x5*f1^2*f7*f5^2+192*x2^2*x3*x5*f0*f5^3*f4+
64*x2^2*x3*x5*f5*f0^2*f7^2+8*x1*x3^2*x2*f3^2*f5^2*f1*f7+12*x2*x3^2*x7*f5^4*f2+
8*x2*x3^2*x7*f4^4*f6-16*x1*x3*x2*x5*f3*f1*f4^2*f6+608*x1*x3*x2*x5*f6*f0^2*f7*
f5+8*x1*x3*x2*x5*f7*f0*f5*f3^2-192*x1^2*x3*x7*f0*f5^2*f2*f7-144*x1^2*x3*x7*f0*
f6*f5^2*f3+96*x1^2*x3*x7*f0*f6^2*f4*f3+8*x1^2*x3*x7*f4^3*f6*f1+16*x1^2*x3*x7*
f7*f2^3*f6-32*x1^2*x3*x7*f0*f6*f4*f2*f7+64*x1^2*x3*x7*f1*f6*f5*f0*f7+16*x1^2*
x3*x7*f7*f2^2*f4^2+48*x1*x3*x6^2*f5^2*f1*f4-32*x1*x3*x6^2*f0*f5*f4*f6+120*x1*
x3*x6^2*f5*f1*f6*f3+8*x1*x3*x6^2*f7*f2^2*f4-300*x1*x3*x4*x6*f7^2*f1^2*f5-168*
x1*x3*x4*x6*f7*f2^2*f5^2+424*x1*x3*x4*x6*f7*f2*f5*f1*f6-56*x1*x3*x4*x6*f7*f3*
f1*f4*f6-80*x1*x3*x4*x6*f7*f2*f3*f5*f4-48*x1*x3*x4*x6*f5*f4^4-144*x1*x3^2*x4*
f6^2*f2^2*f5^2-32*x2*x3*x5*x7*f5^2*f2*f4+24*x2*x3*x5*x7*f5*f4^2*f3-224*x2*x3*
x6*x7*f0*f5^2*f7+24*x2*x3*x6*x7*f3*f7*f1*f6-20*x2*x3*x6*x7*f7*f2*f3*f5-16*x2*
x3*x6*x7*f7*f2*f4^2+72*x2*x3*x6*x7*f5^2*f3*f4-24*x2*x3*x6*x7*f5^3*f2-16*x2*x3*
x6*x7*f2*f5*f4*f6+4*x2^2*x3*x7*f2^2*f7^2*f3-16*x2*x3*x5*x7*f4^4-20*x2*x3*x5*x7
*f1^2*f7^2-40*x2*x3*x6*x7*f3^2*f7*f4+32*x2*x3*x6*x7*f1*f7*f4*f5+16*x1*x3^2*x2*
f4^2*f3*f1*f6^2+16*x1*x3^2*x2*f7*f2^3*f5*f6-8*x2*x3*x5^2*f4^3*f2+4*x2*x3*x5^2*
f2*f7*f1*f4-4*x2*x3*x4*x6*f7^2*f3*f4*f1-8*x2*x3*x5*x6*f7*f2^2*f4+4*x2*x3*x5*x6
*f7*f3*f4*f1-4*x2^2*x3*x6*f2^3*f7^2-8*x2*x3*x4^2*f7*f3*f5^2*f6*f2-96*x2*x3*x4^
2*f7^2*f2*f3*f5*f4+152*x2*x3*x4^2*f5*f4^4*f7-24*x2*x3*x4^2*f7^2*f3^2*f2*f6-56*
x2*x3*x4^2*f7^2*f3^3*f5+108*x2*x3*x4^2*f2*f7^3*f1*f4-432*x2*x3*x4^2*f4^2*f5^4+
448*x2*x3*x4^2*f0^2*f7^4-224*x2*x3*x4^2*f6^2*f2*f0*f7^2+32*x1*x3^2*x4*f3^2*f6^
2*f1*f7-96*x1*x3^2*x4*f0*f6^2*f4*f3*f7+108*x1^2*x3*x4*f5^3*f2*f3*f4-400*x1^2*
x3*x4*f0*f5^3*f2*f7+12*x2*x4*x3*x8*f7*f2*f5^3+16*x2*x4*x3*x8*f7*f2*f5*f4*f6-16
*x1*x4^2*x2*f7*f4^3*f1*f6-72*x1*x4^2*x2*f5^2*f4^2*f6*f2-96*x2*x4^2*x1*f7*f3^2*
f5*f4^2+108*x1*x4^3*f4^2*f5^4+16*x2*x4*x1^2*f6*f5*f7*f3*f1^2-772*x2*x4*x1^2*f7
*f3*f1*f5^2*f2+480*x2*x4*x1^2*f7^2*f1^2*f2*f5-448*x2*x4*x1^2*f0*f5*f2^2*f7^2+
544*x2*x4*x1^2*f0*f5^2*f7*f3^2-36*x1^3*x4*f3^4*f5^2-50*x4^2*x7^2*f7^2*f3*f4+
276*x4^2*x7^2*f7*f4*f5^2-246*x4^2*x7^2*f7^2*f2*f5-644*x4^2*x6^2*f0*f5*f7^2+228
*x4^2*x6^2*f7*f5^2*f2-8*x2^2*x4*x7*f2*f7^2*f3^2+36*x2^2*x4*x7*f2*f5^4-40*x2^2*
x4*x7*f7*f2^2*f6*f5-32*x2^2*x4*x7*f0*f7^3*f1+16*x2^2*x4*x7*f7*f2*f4*f3*f6+80*
x1^2*x4*x6*f0*f4*f1*f7^2+72*x1^2*x4*x6*f1*f5^2*f6*f2+108*x1^2*x4*x6*f3^3*f5^2+
112*x1^2*x4*x6*f0*f5^2*f2*f7+4*x2^2*x4*x6*f7^2*f2^2*f3-144*x4*x3^2*x6*f1*f5^2*
f6^2+48*x4*x3^2*x6*f7^2*f2^2*f5-24*x4^2*x3*x6*f3*f7*f4^2*f6+32*x4^2*x3*x6*f6^2
*f2*f3*f7+32*x1*x4*x2*x6*f2^3*f7^2+72*x1^2*x4*x7*f3*f5^3*f2-20*x1^2*x4*x7*f7*
f4^3*f1+32*x1^2*x4*x7*f0*f3^2*f7^2+56*x1^2*x4*x7*f1^2*f7^2*f4-128*x1^2*x4*x7*
f6*f0^2*f7^2-24*x1^2*x4*x7*f5^2*f3^2*f4+8*x2*x4^2*x1*f7*f3^2*f6*f2*f5-8*x2*x4^
2*x1*f7*f2^2*f4*f6*f5-32*x2*x4^2*x6*f7*f2*f3*f5*f6-24*x4*x1*x2*x7*f7*f3^2*f4^2
-72*x1*x4*x2*x7*f5^4*f1-48*x1*x4*x3*x5*f3*f5*f6*f2*f4-108*x1*x4*x3*x5*f3*f5^3*
f2+180*x1*x4^2*x2*f4*f5^4*f2+8*x1*x4*x2*x5*f2^3*f6*f7+56*x1*x4*x2*x5*f0*f4^3*
f7-132*x1*x4*x2*x5*f4*f5^2*f2*f3-32*x3*x4^2*x2*f6^2*f2*f7*f3*f4+216*x1*x4*x3*
x5*f0*f5^4-108*x2*x4^2*x5*f2*f5^4+176*x1^2*x3*x6*f0*f4*f2*f7*f5-48*x1^2*x3*x6*
f0*f7^2*f2^2+12*x1^2*x3*x6*f7*f2^3*f5+64*x1^2*x3*x6*f1^2*f7^2*f2-76*x1^2*x3*x6
*f1^2*f5*f7*f4+208*x1^2*x3*x6*f1*f5^2*f0*f7-256*x1^2*x3*x6*f6*f0^2*f7*f5+192*
x3^3*x5*f0*f6^2*f5*f4+32*x3^3*x5*f0*f4*f5^2*f7+64*x3^2*x4*x5*f0*f6*f2*f7^2+152
*x3^2*x4*x5*f1^2*f7^2*f6+864*x3^2*x4*x5*f0*f6^2*f5^2-144*x3^2*x4*x5*f5^3*f6*f1
-84*x3^2*x4*x5*f5^2*f4^3-64*x3^2*x4*x5*f0*f7^3*f1+24*x1*x3*x2*x7*f7*f2*f3^2*f5
+72*x1*x3*x4^2*f7*f3^2*f5^2*f4-8*x1*x3^2*x5*f7*f2^2*f4^2-12*x1*x3^2*x5*f2^2*f5
^3-40*x1*x3*x4^2*f7^2*f2^2*f3*f6-548*x1*x3*x4^2*f7*f5^2*f4^2*f2-216*x1*x3*x4^2
*f7^2*f2*f3^2*f5-176*x1*x3*x4^2*f7^3*f0*f4*f2-28*x1*x3*x4^2*f7^2*f3^3*f4-504*
x1*x3*x4^2*f5^4*f3*f4+1376*x1*x3*x4^2*f7^2*f1^2*f6*f5+32*x1*x3*x4^2*f7^3*f0*f3
^2+144*x1*x3*x4^2*f4*f5^2*f6^2*f1-4*x1*x3*x2*x5*f7*f2^3*f5-48*x1*x3*x2*x5*f7*
f6*f1*f0*f4+16*x2*x3^2*x4*f0*f3^2*f7^3+24*x3^2*x4*x2*f7*f3^2*f4^2*f6+4*x1^2*x3
*x5*f4^4*f1-4*x1*x3*x5^2*f2^2*f5*f4+4*x1*x3*x2*x5*f2*f7*f3^3+8*x1*x3^2*x5*f2*
f7*f3^2*f4-16*x1*x3^2*x5*f3*f6*f2*f4^2+240*x1*x3*x4*x5*f0*f6*f5^2*f4+32*x1^2*
x3^2*f6*f0^2*f7^2*f3+72*x1^2*x3^2*f0*f6*f5^3*f2+16*x1^2*x3^2*f4^3*f3^2*f5-8*x2
*x3^2*x5*f7*f3*f4^2*f2-256*x2*x3*x4*x5*f0^2*f7^3+32*x2*x3*x4*x5*f0*f5*f2*f7^2-\
288*x2*x3*x4*x5*f6*f5^2*f1*f4-72*x2*x3*x4*x5*f5^4*f1+96*x2*x3*x4*x5*f5*f4^2*f6
*f2-304*x2*x3*x4*x5*f0*f6*f4^2*f7-36*x1*x3*x4^2*f7^2*f4^3*f1+56*x1*x3*x4^2*f7^
3*f1^2*f4+1088*x1*x3*x4^2*f7^3*f6*f0^2-496*x1*x3*x4^2*f7^2*f0*f6*f4*f3-16*x2*
x7*f7*f6*f2^2*x3^2*f5+32*x3^2*x2*x7*f1^2*f7^2*f6+32*x3^2*x2*x7*f0*f6^2*f7*f3+
144*x3^2*x2*x7*f0*f5^3*f7-16*x3^3*x7*f5*f4^3*f6-192*x3^3*x7*f0*f6^3*f5-48*x3^3
*x7*f3*f5*f6*f2*f7-48*x3^3*x7*f6^2*f4^2*f3+48*x3^3*x7*f5^2*f6^2*f1-8*x3^3*x7*
f5^3*f7*f1-12*x3^3*x7*f3*f5^4+88*x3^3*x7*f7*f3*f5*f4^2+16*x3^3*x7*f2*f5*f4*f6^
2-56*x3^3*x7*f4*f7*f6*f1*f5-8*x3^3*x7*f1^2*f7^3-48*x3^3*x7*f7*f2*f4^2*f6-32*x3
^3*x7*f0*f7^2*f6*f3+16*x3^3*x7*f7*f3^2*f6*f4+16*x3^3*x7*f3*f6^2*f1*f7+32*x3^3*
x7*f1*f6^3*f4+128*x3^3*x7*f0*f6^2*f7*f4+16*x3^3*x7*f1*f5*f7^2*f3-52*x4^2*x1*x5
*f4^2*f5*f7*f1-4*x4^2*x6^2*f4*f7^2*f1+40*x4^2*x6^2*f7*f5*f3*f4-44*x4^2*x6^2*f7
*f5*f1*f6-480*x4^2*x1*x6*f3*f5^2*f7*f2+28*x2*x6*x4^2*f4^2*f1*f7^2+112*x2*x6*x4
^2*f5*f7^2*f2^2-36*x4^2*x2*x6*f7*f3*f4^2*f5-304*x4^2*x2*x6*f4*f5^2*f2*f7+104*
x2*x6*x4^2*f3*f7^2*f2*f4+40*x4^2*x2*x6*f1*f7*f6*f4*f5+160*x4^2*x2*x6*f0*f6*f5^
2*f7-228*x4^2*x2*x6*f1*f5^3*f7-48*x4^2*x2*x6*f0*f7^3*f2-48*x4^2*x2*x6*f7*f3^2*
f5^2+216*x4^2*x2*x6*f4^2*f5^3+72*x2*x6*x4^2*f7^3*f1^2-12*x2*x6*x4^2*f3^3*f7^2-\
56*x2*x6*x4^2*f7^2*f2*f1*f6-212*x2*x6*x4^2*f3*f7^2*f1*f5+48*x2*x6*x4^2*f0*f6*
f7^2*f3+952*x2*x6*x4^2*f0*f5*f7^2*f4+612*x4^2*x3*x6*f4*f5^4-88*x4^2*x3*x6*f2^2
*f7^2*f6-112*x3*x6*f0*f7^3*f3*x4^2+304*x4^2*x3*x6*f7^2*f2*f3*f5+72*x4^2*x3*x6*
f7^2*f3^2*f4-492*x4^2*x3*x6*f7*f2*f5^3-60*x4^2*x3*x6*f2*f7^3*f1+2120*x4^2*x3*
x6*f0*f5^2*f7^2+96*x4^2*x3*x6*f7*f3^2*f5*f6-240*x4^2*x3*x6*f0*f6*f4*f7^2-64*x4
^2*x3*x6*f0*f6^2*f5*f7+304*x4^2*x3*x6*f4*f5*f7^2*f1+256*x4^2*x3*x6*f6*f5^2*f1*
f7+256*x4^2*x3*x6*f7*f2*f4*f5*f6-404*x4^2*x3*x6*f7*f5^2*f3*f4-148*x4^2*x3*x6*
f5*f4^3*f7+60*x4^2*x3*x6*f2*f7^2*f4^2-48*x3*x6*f3*f6*f1*f7^2*x4^2-96*x4^3*x6*
f2^2*f7^3-48*x4^3*x6*f7*f3*f5*f4*f6+216*x4^3*x6*f6*f5^3*f4+252*x4^3*x6*f7^2*f2
*f4*f5-20*x4^3*x6*f4^2*f7^2*f3-228*x4^3*x6*f7*f5^2*f4^2+48*x4^3*x6*f5*f6^2*f1*
f7+24*x4^3*x6*f1*f7^2*f4*f6-72*x4^3*x6*f7*f2*f5^2*f6+48*x4^3*x6*f2*f7^2*f3*f6-\
240*x4^3*x6*f0*f6*f5*f7^2-360*x4^3*x6*f7*f5^3*f3-8*x4^3*x6*f0*f4*f7^3-68*x4^3*
x6*f7^3*f3*f1+204*x4^3*x6*f7^2*f5*f3^2+716*x4^3*x6*f7^2*f5^2*f1+32*x4^2*x5*x6*
f7^2*f3*f1-60*x4^2*x5*x6*f5^2*f7*f1+80*x4^2*x5*x6*f0*f6*f5*f7+72*x4^2*x5*x6*f5
^2*f4^2-164*x4^2*x5*x6*f7*f2*f4*f5-60*x4^2*x5*x6*f7*f5*f3^2+104*x4^2*x5*x6*f0*
f4*f7^2+56*x4^2*x5*x6*f2^2*f7^2+528*x4^2*x1*x6*f0*f5*f7^2*f3-512*x4^2*x1*x6*f0
*f6*f5*f4*f7-48*x4^2*x6^2*f7^2*f2*f3-24*x4^2*x1*x6*f6*f7^2*f1^2-2*x3^4*f7^2*f3
^3*f4-2*x3^4*f3^2*f7^2*f2*f5-4*x3^3*x2*f4^2*f5^2*f1*f7-4*x3^3*x2*f7^2*f3*f4^2*
f1+4*x3^3*x1*f1*f5*f7^2*f2*f3-16*x3^2*x2*x4*f7^2*f3^3*f4+68*x2*x4*x3^2*f5^2*f7
*f3^2*f4-12*x2*x6*x3^2*f7*f3^3*f5-16*x3^2*x2*x6*f7*f2*f4^3-4*x3^3*x6*f7*f3*f4^
3+96*x1^3*x4*f0*f6*f7^2*f1^2+144*x1^3*x4*f0*f5^2*f2*f7*f3-112*x1^3*x4*f0*f3^2*
f7*f5*f4-24*x1^3*x4*f3^2*f6*f4*f1*f5+288*x1^3*x4*f0*f6*f5^2*f2*f4-48*x1^3*x4*
f0*f6*f5*f3*f4^2-240*x1^3*x4*f0*f5^3*f4*f3-36*x1^3*x4*f3*f5^2*f4^2*f1-24*x1^3*
x4*f7*f2^2*f4^2*f3+96*x1^3*x4*f0*f6^2*f4*f1*f5+40*x2*x4*x3^2*f7^2*f2*f5*f3^2+
288*x3^2*x2*x4*f1*f6^2*f5^2*f4+48*x2*x4*x3^2*f0*f5*f4^2*f7^2+240*x2*x4*x3^2*f4
*f5^3*f7*f1-16*x2*x4*x3^2*f7*f3^3*f5*f6-96*x3^2*x2*x4*f6^2*f2*f5*f4^2-80*x3^2*
x2*x4*f1*f7^2*f4^3+144*x3^2*x2*x4*f1*f6*f5^4-108*x3^2*x2*x4*f4*f5^4*f3+88*x3^2
*x2*x4*f7^2*f2*f6*f1*f4+48*x1^3*x7*f0*f7^2*f2*f1-32*x1^3*x7*f0*f6*f7*f2^2+32*
x1*x3*x5*x7*f1^2*f7*f6-8*x2^2*x3^2*f7*f3^2*f2*f4*f6+4*x2^2*x3^2*f7*f2*f4^4-8*
x1*x3^2*x4*f7^3*f1*f2^2-30*x1^2*x3^2*f4*f5^2*f3^3+288*x1^2*x3^2*f0*f6^2*f5^2*
f1+64*x1^2*x3^2*f6^2*f0^2*f7*f4+304*x1*x3*x4^2*f1*f4^2*f7*f5*f6-360*x1*x3*x4^2
*f7*f3*f5^2*f1*f6-168*x1*x3*x4^2*f7^2*f2*f1*f4*f6+96*x1*x3*x4^2*f7^2*f3*f4^2*
f2-2048*x1*x3*x4^2*f7^2*f0*f6*f5*f2-144*x1*x3*x4^2*f7^3*f1*f5*f0-292*x1*x3*x4^
2*f7^2*f3*f4*f1*f5+256*x1*x3*x4^2*f7^2*f0*f5*f4^2+24*x1*x3*x4*x5*f7^2*f2^3+88*
x1*x3*x4*x5*f0*f5*f4^2*f7+72*x1*x3^2*x4*f5^5*f1-16*x2*x3*x1*x5*f1*f6*f7*f2^2+
32*x2*x3*x1*x5*f4*f0^2*f7^2-16*x2*x3*x1*x5*f0*f4^2*f3*f7-24*x1*x3*x5^2*f2*f4*
f1*f6-36*x1*x3*x5^2*f2*f5^2*f1-40*x1*x3*x5^2*f0*f5*f4^2+32*x3^2*x6*x2*f0*f6^2*
f7*f2+16*x3^2*x6*x2*f6^2*f7*f1^2-8*x1^2*x3*x5*f7*f2^3*f4-48*x1*x3*x5*x7*f5*f1*
f6*f3-64*x1*x3*x6*x7*f4*f6*f1*f5+48*x1*x3*x6*x7*f4^2*f2*f6+72*x1*x3*x6*x7*f3^2
*f5^2+112*x1*x3*x6*x7*f3*f7*f5*f1-144*x1*x3*x6*x7*f0*f5^2*f6+72*x1*x3*x6*x7*f7
*f4^2*f1-160*x1*x3*x6*x7*f0*f7*f4*f5-48*x1*x3*x6*x7*f1*f5^3-44*x1*x3*x6*x7*f7*
f2^2*f5+24*x1*x3*x6*x7*f3^2*f6*f4+12*x1*x3*x2*x6*f3*f7*f1*f4^2-4*x1*x3*x2*x6*
f1*f7*f3^2*f5-16*x3^2*x7*x8*f7^2*f2*f4-32*x7*x8*f7*f3*f5^2*x3^2-24*x3^2*x6*x8*
f7^2*f0*f5+48*x3^2*x4*x8*f7^2*f1*f5^2+12*x3^2*x2*x8*f7^3*f1^2-32*x3^2*x2*x8*f7
^2*f1*f5*f3-8*x3^2*x2*x8*f7*f4^2*f6*f2+56*x3^2*x2*x8*f7*f4*f6*f1*f5-8*x3^2*x2*
x8*f7*f3^2*f6*f4-20*x3^2*x2*x8*f7*f3*f5*f4^2+8*x3^3*x8*f7^3*f2*f1-8*x3^3*x8*f7
^2*f2*f4^2+72*x3^3*x8*f7^2*f0*f5^2-16*x3^3*x8*f7*f3^2*f6*f5-96*x3^3*x8*f7*f0*
f6^2*f5+16*x3^3*x8*f7*f1*f6^2*f4-28*x3^3*x8*f7^2*f1*f4*f5-8*x3^3*x8*f7^2*f1*f3
*f6+48*x2^2*x6*x7*f3*f7*f5*f1+16*x3^4*f7^2*f2*f4*f1*f6-8*x3^4*f1^2*f7^3*f4+48*
x3^4*f1*f6*f5^4+12*x3^4*f1^2*f6*f7^2*f5-72*x3^4*f0*f6*f5*f2*f7^2-4*x3^4*f3*f5^
3*f7*f2-480*x1*x3*x4^2*f7^2*f2*f5^2*f1+444*x1*x3*x4^2*f7^2*f2^2*f5*f4-16*x2*x3
*x1*x4*f7*f2^3*f6^2-12*x1^2*x3*x4*f7*f3^4*f5-24*x1^2*x3*x4*f7*f4^2*f3^3-112*x1
^2*x3*x4*f0*f4^2*f2*f7^2+512*x1^2*x3*x4*f6*f0^2*f7^2*f4-120*x2*x3*x5^2*f0*f5^2
*f4+48*x2*x3*x5^2*f0*f4^2*f6-40*x1*x3*x4*x5*f3^2*f6*f7*f1+32*x4*x5*x1*x3*f7^2*
f2*f4*f0-96*x1*x3*x4*x5*f7*f2^2*f5*f4-32*x1*x3*x4*x5*f7*f4^2*f2*f3-24*x1^2*x3*
x6*f3*f5*f2^2*f6-144*x1^2*x3*x6*f0*f5^3*f3+64*x1^2*x3^2*f0*f6*f7^2*f1*f2-64*x1
^2*x3^2*f0*f6^2*f7*f1*f3-8*x1^2*x3^2*f0*f3^3*f7^2+32*x2^2*x3*x6*f0*f6^2*f1*f7-\
8*x1*x3^2*x2*f5*f4^2*f7*f2^2+1040*x2*x3*x4*x6*f0*f6*f5*f4*f7+32*x2*x3*x4*x6*f7
*f3*f4*f2*f6-16*x2*x3*x4*x6*f7*f3*f5*f1*f6-76*x2*x3*x4*x6*f7^2*f2*f1*f5+216*x2
*x3*x4*x6*f3*f5^3*f4-156*x2*x3*x4*x6*f7*f4^2*f5*f2+32*x1*x3*x7^2*f0*f7*f6*f4-\
12*x1^2*x3*x7*f2^2*f5^3+928*x4^2*x1*x5*f7^2*f0*f2*f5-96*x4^2*x2*x5*f0*f6*f5*f7
*f4+12*x4^2*x2*x5*f7^2*f2*f3^2-160*x4^2*x2*x5*f0*f4^2*f7^2-72*x4^2*x2*x5*f5^2*
f4^3-8*x4^2*x2*x5*f7*f3^2*f4*f5+32*x2*x5*f6*f7^2*f1^2*x4^2-64*x4^2*x2*x5*f7^2*
f2^2*f4-76*x4^2*x2*x5*f3*f5^2*f7*f2+384*x4^2*x2*x5*f0*f5^3*f7-36*x4^2*x2*x5*f7
^2*f4*f3*f1+56*x4^2*x2*x5*f7*f6*f5*f3*f1-148*x4^2*x2*x5*f7^2*f2*f1*f5+204*x4^2
*x2*x5*f7*f2*f5*f4^2-112*x4^2*x2*x5*f0*f7^3*f1+112*x4^2*x2*x5*f0*f6*f7^2*f2+
544*x4^2*x2*x5*f0*f5*f7^2*f3-108*x4^2*x2*x5*f4*f5^2*f1*f7+108*x4^2*x2*x5*f4*f5
^3*f3-120*x4^2*x3*x5*f7^2*f2^2*f5+2368*x4^2*x3*x5*f0*f6*f5^2*f7+112*x4^2*x3*x5
*f0*f7^3*f2+188*x4^2*x3*x5*f7*f3*f4^2*f5+192*x4^2*x3*x5*f1*f6*f7^2*f2+216*x4^2
*x3*x5*f3*f5^2*f6*f4-40*x4^2*x3*x5*f7^2*f3*f4*f2-256*x4^2*x3*x5*f1*f7^2*f3*f5+
124*x4^2*x3*x5*f1^2*f7^3-84*x4^2*x3*x5*f1*f5^3*f7-24*x4^2*x3*x5*f7*f3^2*f5^2-\
180*x4^2*x3*x5*f4^2*f5^3-60*x4^2*x3*x5*f1*f7^2*f4^2-536*x4^2*x3*x5*f1*f7*f6*f4
*f5+368*x4^2*x3*x5*f4*f5^2*f2*f7+16*x4^2*x3*x5*f0*f5*f7^2*f4+1592*x4^3*x5*f0*
f5^2*f7^2-20*x4^3*x5*f2*f7^2*f4^2+36*x4^3*x5*f7*f2*f5^3+252*x4^3*x5*f2*f7^3*f1
+324*x4^3*x5*f7*f5^2*f3*f4+48*x4^3*x5*f7^2*f3^2*f4+96*x4^3*x5*f0*f6*f4*f7^2-\
108*x4^3*x5*f4*f5^4-48*x4^3*x5*f7^2*f3*f1*f6-24*x4^3*x5*f2^2*f7^2*f6-12*x4^3*
x5*f5*f4^3*f7+48*x4^3*x5*f6*f5^2*f1*f7+24*x4^3*x5*f7*f3^2*f5*f6-460*x4^3*x5*f4
*f5*f7^2*f1-96*x4^3*x5*f0*f6^2*f5*f7-148*x4^3*x5*f7^2*f2*f3*f5+48*x4^3*x5*f7*
f2*f4*f5*f6-144*x4^3*x5*f0*f3*f7^3+208*x4^2*x1*x5*f7*f0*f4*f5^2+44*x4^2*x1*x5*
f7^2*f2^2*f3-96*x4^2*x1*x5*f1*f7^2*f3^2-72*x4^2*x1*x5*f1*f6*f4*f5^2+40*x4^2*x1
*x5*f7*f3^3*f5+60*x4^2*x1*x5*f2^2*f5^2*f7+36*x4^2*x1*x5*f5^2*f3*f4^2+140*x4^2*
x1*x5*f7*f3*f5^2*f1+448*x1^2*x2*x3*f6*f0^2*f7*f5*f4+64*x1^2*x2*x3*f0*f5^2*f2*
f7*f3-24*x1^2*x2*x3*f7*f2^2*f1*f4*f6-40*x1^2*x2*x3*f5^2*f2^2*f4^2+24*x2^2*x3*
x8*f6*f7^2*f1^2+44*x2^2*x7^2*f1*f4*f7*f5-6*x2^2*x7^2*f5^2*f3*f4-36*x2^2*x6^2*
f2*f5*f4^2+68*x2^2*x6^2*f5^2*f1*f4+24*x2^2*x6^2*f0*f7*f4^2-48*x2^2*x4^2*f7^3*
f0*f3^2-64*x1^3*x2*f3*f5*f1^2*f6*f4-128*x1^3*x2*f0*f5*f4*f3*f1*f7+16*x1^3*x2*
f6*f4^3*f1^2-56*x1^3*x2*f6*f4*f7*f1^3-8*x1^3*x2*f6*f3*f7*f2*f1^2-28*x1^3*x2*f7
*f2^2*f1*f4^2-48*x1^3*x2*f0*f6*f5^2*f3*f1-32*x1^3*x2*f0*f5^2*f4^2*f2-64*x1^3*
x2*f5*f1*f0^2*f7^2+4*x3^2*x6*x5*f3^3*f7+4*x3*x5^2*x8*f7*f1*f4-8*x3*x5*x6*x8*f7
*f3^2+4*x3*x5*x2*x8*f7*f3^2*f4-36*x4*x5*x7^2*f4*f5^2-112*x4*x5*x7^2*f0*f7^2-8*
x2*x7*f7*f6*f2^2*x4*x5+16*x4^2*x7*x5*f4*f6*f2*f7+8*x4^2*x5*x7*f3^2*f6*f7+16*x1
*x5^2*x2*f7*f0*f4*f1-160*x1*x5^2*x2*f7*f0^2*f5+8*x1*x5^2*x2*f7*f1*f2^2-60*x1*
x5*x6^2*f3*f1*f5+16*x1*x5*x6^2*f2*f3*f4+88*x1*x5*x6^2*f0*f4*f5+12*x1*x5*x6^2*
f7*f1^2-8*x1*x5*x6^2*f1*f4^2-16*x3*x5*x2*x6*f1*f0*f7^2+24*x3*x5*x7^2*f7*f2*f4-\
64*x3*x5*x7^2*f7*f0*f6-20*x3*x5*x7^2*f5*f4^2+144*x3*x5*x6^2*f0*f5*f6+4*x2*x6*
x4*x5*f3^3*f7-4*x7*x8*f7*f4^2*x4*x5-4*x5^2*x8*f7*f2*f4*x4+4*x4^2*x5*x8*f7^2*f3
^2-4*x3*x8*f7*f4^3*x4*x5-4*x2*x8*f7^2*f2^2*x4*x5-4*x4*x5^2*x6*f7*f3*f1+4*x4^2*
x6*f7*f4^2*f3*x5-12*x6*x7*x4*x5*f7*f3^2-4*x4^2*x5*x7*f7*f4^3-4*x3*x6*x2*x5*f3^
2*f7*f2+8*x6^3*x2*f4^2*f3-24*x6^3*x2*f1*f5^2-16*x6^3*x2*f7*f0*f4+24*x6^3*x2*f2
*f4*f5+24*x6^3*x3*f5^2*f2-48*x6^3*x3*f6*f1*f5+56*x6^3*x3*f7*f0*f5-12*x6^3*x3*
f7*f1*f4+20*x6^3*x3*f3*f5*f4+36*x6^3*x4*f3*f5^2-88*x6^3*x4*f7*f1*f5+24*x6^3*x5
*f1*f5+24*x6^3*x1*f2*f3*f5-48*x6^3*x1*f0*f5^2-8*x6^3*x1*f1*f4*f5-12*x6^3*x1*f7
*f2*f1-36*x6^2*x2*x7*f3*f5*f4+8*x6^2*x2*x7*f7*f2*f3-4*x6^2*x2*x7*f7*f1*f4+104*
x6^2*x2*x7*f7*f0*f5-36*x6^2*x3*x7*f3*f5^2-32*x6^2*x3*x7*f5*f4^2-32*x6^2*x4*x7*
f7^2*f0-16*x6^2*x4*x7*f7*f1*f6+84*x6^2*x4*x7*f7*f2*f5-96*x6^2*x4*x7*f4*f5^2+12
*x6^3*x7*f3*f5+144*x6^2*x1*x7*f0*f5*f6-32*x6^2*x1*x7*f7*f0*f4+4*x6^2*x1*x7*f2*
f4*f5+16*x6^2*x1*x7*f4^2*f3+8*x6^2*x1*x7*f2^2*f7-36*x6^2*x1*x7*f3^2*f5-32*x6^2
*x1*x7*f1*f4*f6+16*x6^2*x3*x8*f7*f1*f6+24*x6^2*x4*x8*f1*f7^2-24*x6^2*x3*x8*f0*
f7^2+24*x1^2*x6*x7*f2*f6*f5*f1+16*x2^2*x6*x7*f4^2*f1*f7+24*x3^2*x6^2*f0*f7^2*
f3-16*x3^2*x6^2*f1*f6^2*f4+24*x3^2*x6^2*f2*f6*f4*f5+72*x3*x6^2*x4*f2*f6*f5^2-\
16*x1*x6^2*x2*f0*f5*f2*f7-16*x1*x6^2*x2*f0*f4*f3*f7+8*x1*x6^2*x2*f3*f7*f2^2-28
*x1^2*x3^2*f5*f7^2*f2*f1^2+640*x1^2*x3^2*f6*f0^2*f7*f5^2-56*x1^2*x3^2*f7*f2*f4
*f1*f6*f3+84*x1^2*x3^2*f3*f5^3*f1*f4-56*x1^2*x3^2*f4^2*f6*f2^2*f5-36*x2^2*x5*
x7*f5^2*f1*f4-8*x1^2*x2*x8*f1^2*f5^2*f7-16*x1^2*x3*x8*f1^2*f5*f7*f6+120*x3^3*
x1*f1*f6*f5^3*f3-16*x3^3*x1*f2^2*f6*f7^2*f1-12*x3^3*x2*f4*f5^4*f2-4*x1*x3^2*x2
*f7^2*f3^3*f1-248*x1*x3*x5*x6*f0*f5^2*f4+120*x1*x3*x5*x6*f1*f5^2*f3+152*x1*x3*
x4*x6*f7*f4^2*f5*f1-288*x1*x3*x4*x6*f0*f6^2*f4*f5-24*x2*x3*x7^2*f5*f3*f6*f4+80
*x2*x3*x7^2*f0*f6*f7*f5-24*x2*x3*x7^2*f4*f7*f1*f6+12*x2^2*x3*x7*f5^4*f1-16*x1*
x3^2*x7*f7*f2*f5*f1*f6-72*x1*x3*x2*x7*f7*f2^2*f5*f4-16*x2^2*x3^2*f1*f6*f7^2*f2
^2-16*x2^2*x3^2*f0*f6^2*f3^2*f7+8*x1^2*x3^2*f7*f2^2*f4^3+16*x1^2*x3^2*f7*f2^3*
f4*f6-8*x1^2*x3^2*f6*f7^2*f1^3+16*x1^2*x3^2*f0*f6*f4*f7*f3^2-32*x1^2*x3^2*f5^2
*f4^3*f1-48*x1^2*x3^2*f0*f6*f4^2*f2*f7+56*x2*x3*x4*x7*f7*f4^4+168*x2*x3*x4*x7*
f5^3*f7*f1-160*x2*x3*x4*x7*f2*f0*f7^3-8*x2*x3*x4*x7*f7*f4*f6*f1*f5-48*x2*x3*x4
*x7*f3*f6^2*f1*f7+576*x1*x3*x2*x7*f0*f6*f5*f2*f7+88*x1*x3*x2*x7*f3*f5*f4*f6*f2
+8*x1*x3*x2*x7*f7^2*f2^3+8*x1*x3*x2*x7*f7*f2^2*f3*f6-16*x1*x3^2*x2*f0*f6*f3*f1
*f7^2+16*x2*x3^2*x7*f1*f0*f7^3-8*x2^3*x3*f0*f4*f7^2*f3^2+20*x2^3*x3*f7*f1^2*f5
^3-20*x2^3*x3*f5*f4^4*f3+16*x2^3*x3*f7*f2*f5*f3*f1*f6+64*x2^3*x3*f0*f5*f4^3*f7
-8*x2*x1*x3^2*f7*f2^2*f3*f4*f6-68*x1*x2*x3^2*f5^3*f7*f1^2+64*x2*x1*x3^2*f6*f0^
2*f7^2*f4+32*x2*x1*x3^2*f7^2*f2*f3*f1*f4+64*x2*x1*x3^2*f4^3*f0*f6^2-32*x2*x1^2
*x3*f6^2*f4^2*f1^2+32*x2^2*x1*x3*f0*f6^2*f7*f2^2+8*x2^2*x1*x3*f6*f7^2*f1^3-8*
x2^2*x1*x3*f7*f2^2*f3^2*f6-256*x2*x1*x4*x7*f0^2*f7^3+192*x2*x1*x4*x7*f0*f7*f4^
2*f6-64*x2*x1*x4*x7*f7*f4^3*f2-32*x2^2*x4*x1*f0*f6*f5*f3^2*f7-256*x2*x1*x3*x6*
f5*f4*f6*f1*f3+28*x3*x6*x1*x2*f7^2*f1*f2^2+8*x3*x6*x1*x2*f7*f6*f4*f1^2+64*x2*
x1*x3*x6*f3*f6*f4^2*f2+144*x2*x1*x3*x6*f2*f6*f5^2*f1-80*x2*x1*x3*x6*f2^2*f5*f4
*f6+36*x3*x6*x1*x2*f7*f3*f2^2*f5+576*x2*x1^2*x4*f0*f6*f5^2*f3*f4-16*x2*x1^2*x4
*f7*f1*f5*f2^2*f6-432*x2*x1^2*x4*f0*f5^4*f3+64*x2*x1^2*x4*f7^2*f0^2*f3*f6-32*
x2*x1*x7*x8*f7*f5^2*f0+44*x2*x1*x7*x8*f7*f5*f1*f4-20*x2*x1*x6*x8*f7*f1*f3*f5+8
*x2*x1^2*x7*f1^2*f7*f6*f3+6*x2^2*x1^2*f5^3*f2^3-128*x2^2*x4*x7*f7*f0*f5^3-16*
x2^2*x1*x7*f0*f3*f2*f7^2+20*x2^2*x1*x7*f7*f2^2*f4^2+192*x2^2*x1*x7*f0*f6*f5*f4
^2+40*x2^2*x1*x7*f4*f5^2*f2*f3-288*x2^2*x1*x7*f5*f0^2*f7^2-100*x2^2*x1*x7*f1^2
*f7*f5^2+12*x2^2*x1*x7*f3*f5^3*f1+16*x2^2*x1*x7*f4^4*f3-48*x2^2*x1*x7*f4^2*f3^
2*f5+28*x1^2*x2^2*f7*f1^2*f4^3-64*x1^3*x4*f7^2*f3*f0^2*f5+12*x1^3*x4*f4^3*f5*
f3*f2-64*x1^3*x4*f7^2*f6*f2*f0^2-32*x4^2*x3*x5*f3*f6^2*f1*f7+16*x2*x7*f7*f6^2*
f2^2*x3*x4+144*x4*x3^2*x7*f6^2*f2*f5^2+144*x1*x4*x7*x8*f7*f5^2*f2+16*x1*x4*x7*
x8*f7^2*f1*f4+12*x1*x4*x2*x8*f7*f2*f5^2*f3+12*x1*x4*x2*x8*f7*f4^2*f5*f2+32*x1^
2*x4*x7*f1*f5*f0*f7^2+432*x1^2*x4*x7*f5^2*f6*f1*f3+216*x1^2*x4*x7*f0*f5^4-80*
x1^2*x4*x7*f7^2*f2*f1*f3+672*x1^2*x4*x7*f0*f6*f5*f7*f2-96*x1^2*x4*x7*f1*f5^3*
f4-144*x1^2*x4*x7*f2^2*f5^2*f6+120*x1^2*x4*x7*f7*f3^2*f2*f5+20*x4*x3*x7*x8*f7^
2*f2*f5+8*x4*x3*x7*x8*f7^2*f1*f6-80*x4*x3*x7*x8*f7*f3*f5*f6+8*x2*x8*f7^2*f2^2*
x3*x4*f6-48*x4*x3*x2*x8*f7^2*f0*f6*f4-12*x4*x3*x2*x8*f7^2*f3^2*f4-8*x4*x3*x2*
x8*f7^2*f2*f4^2+72*x4*x3^2*x8*f7*f5^2*f6*f2+8*x3^2*x8*f7*f4^3*x4*f6-24*x4*x3^2
*x8*f7^2*f3*f4^2+16*x1*x4^2*x2*f1*f7*f6^2*f4*f2-96*x2*x4*x3*x8*f7*f0*f6^2*f5+
32*x2*x4*x3*x8*f7*f1*f6^2*f4-24*x3*x8*f7*f4^3*x2*x4*f5+32*x2*x4*x7^2*f7*f4^3-\
72*x2*x4*x7^2*f4*f5^3+64*x3*x4^2*x1*f6^3*f7*f1^2-16*x2*x4^2*x7*f7*f1*f6^2*f4-\
48*x2*x4*x5*x7*f5*f4^3-44*x2*x4*x5*x7*f7*f2*f5*f3-64*x2*x4*x5*x7*f0*f6*f7*f4+
12*x1*x4*x2*x8*f7^2*f3*f4*f1-144*x1*x4*x3*x8*f7^2*f0*f5*f4+24*x1*x4*x3*x8*f7^2
*f1*f4^2-108*x1*x4*x6^2*f5^2*f3^2-120*x4*x3*x5*x7*f4^2*f5^2-144*x4*x3*x5*x7*f5
^2*f6*f2+64*x4*x3*x5*x7*f3*f7*f4^2+544*x4*x3*x5*x7*f0*f6*f7*f5-168*x4*x3*x6*x7
*f7*f5^2*f2+408*x4*x3*x6*x7*f5^3*f4-64*x6*x7*x3*x4*f0*f6^2*f7+304*x4*x3*x6*x7*
f0*f5*f7^2-208*x4*x3*x6*x7*f7*f5*f3*f4+112*x4*x3*x6*x7*f7*f2*f4*f6+56*x4*x3*x6
*x7*f3*f7^2*f2+16*x6*x7*x3*x4*f7*f6*f3^2-56*x4*x3*x6*x7*f4^3*f7+48*x4*x3*x6*x7
*f4^2*f6*f5+168*x6*x7*x3*x4*f1*f6*f5*f7+120*x4*x3*x6*x7*f4*f7^2*f1+40*x4*x3^2*
x6*f7*f3^2*f4*f6-16*x4*x3^2*x6*f6^2*f2^2*f7-24*x4*x3^2*x6*f5*f4^3*f6-8*x1*x4^2
*x7*f2*f7*f4^2*f6-432*x1^2*x4*x6*f0*f6*f5^2*f3+144*x1^2*x4*x6*f3*f4*f1*f5*f6+
32*x1^2*x4*x6*f0*f6*f3^2*f7-48*x1^2*x4*x6*f0*f6*f5*f4^2-64*x1^2*x4*x6*f6^2*f0^
2*f7+32*x1*x4*x7^2*f4*f7*f1*f6-16*x1*x4*x7^2*f3*f7*f4^2+96*x1*x4*x7^2*f7*f5^2*
f1+64*x1*x4*x7^2*f0*f7^2*f4-352*x1^2*x4*x5*f4*f0^2*f7^2+8*x1^2*x4*x5*f1*f6*f7*
f2^2+16*x1*x4*x6^2*f2*f7*f1*f6+12*x1*x4*x6^2*f4*f5^2*f2-36*x1*x4*x6^2*f1^2*f7^
2+4*x1*x4^2*x5*f7*f2*f4^3+16*x1*x4^2*x6*f7*f3*f4*f2*f6+32*x4*x3*x1*x5*f0*f6^2*
f1*f7+24*x4*x3*x1*x5*f3*f5*f4^3+8*x1*x4^2*x2*f7*f4^4*f3-112*x1*x4^2*x2*f0*f4^3
*f7^2-16*x1*x4^2*x2*f4^2*f6*f7*f2*f3+72*x1*x4*x5*x7*f1*f5^3+24*x1*x4*x5*x7*f1^
2*f7^2-40*x1*x4*x5*x7*f7*f2*f3*f4+24*x1*x4*x3*x5*f1*f5^3*f4-36*x4*x3^2*x5*f5^4
*f2-8*x4*x3^2*x5*f7^2*f2*f3^2+16*x4*x3^2*x5*f6^2*f2*f1*f7+32*x4^2*x3*x8*f7^2*
f0*f6^2+32*x3^2*x5*x7*f7*f2*f5*f3+8*x3^2*x5*x7*f0*f7*f5^2-48*x3^2*x6*x7*f2*f6*
f5^2+100*x3^2*x6*x7*f4^2*f5^2-12*x3^2*x6*x7*f7*f4*f2*f5+36*x3^2*x6*x7*f5^3*f3+
72*x3^2*x6*x7*f1*f7*f4*f6+16*x3^2*x6*x7*f0*f7^2*f4+12*x6*x7*x3^2*f1*f5^2*f7+64
*x6*x7*x3^2*f0*f5*f7*f6+24*x3^2*x6*x7*f3*f7*f2*f6+32*x3^2*x6*x7*f4*f6^2*f2-24*
x3^2*x6*x7*f7*f3*f4^2-124*x3^2*x1*x7*f1*f7*f3*f5^2-24*x3^2*x1*x7*f3^2*f5*f4*f6
+64*x3^2*x1*x7*f0*f6*f5*f3*f7-24*x3^2*x1*x7*f1*f7*f3*f6*f4-36*x3^2*x1*x7*f3^2*
f5^3-24*x3^2*x1*x7*f7*f2*f4^3-16*x3^2*x1*x7*f7*f3^2*f6*f2-60*x3^2*x1*x7*f3*f4^
2*f5^2+128*x1^3*x2*f0*f6*f5*f1^2*f7+16*x1^3*x2*f0*f6*f3*f2^2*f7+8*x1^3*x2*f0*
f5^2*f4*f3^2+64*x3^4*f0*f6^2*f5*f3*f7+16*x3^4*f3*f5^2*f6*f7*f1+16*x3^4*f7*f3^2
*f4^2*f6-12*x3^4*f7*f2^2*f5^2*f6+28*x3^4*f7^2*f3*f5*f1*f4+8*x3^4*f7*f3^3*f5*f6
-128*x3^4*f0*f6^3*f5*f4-8*x3^4*f6^2*f2*f5*f4^2-36*x3^4*f1*f5*f7*f4^2*f6+32*x3^
4*f6^2*f4*f1*f5^2+20*x1^2*x3^2*f6*f7*f1^2*f4^2+8*x1^2*x3^2*f7^2*f1*f4*f2^2+32*
x1^2*x3^2*f1*f5^2*f2*f4*f6-144*x1^2*x3^2*f1^2*f5*f6^2*f4-8*x1^2*x3^2*f4^3*f2*
f3*f6+104*x1^2*x3^2*f3*f5*f6*f1*f4^2+24*x1^2*x3^2*f7*f3^2*f4^2*f2-128*x1^2*x3^
2*f0^2*f7^2*f5*f4-16*x1^2*x3^2*f2*f4^2*f6^2*f1+40*x2*x6*x3^2*f5^2*f7*f2^2-16*
x2*x6*x3^2*f4^2*f1*f7*f5-72*x2*x6*x3^2*f5^2*f1*f3*f7-64*x3^3*x6*f0*f6^3*f4+32*
x3^3*x6*f6^2*f2*f4^2+24*x3^3*x6*f5^4*f2+8*x3^3*x6*f7*f2*f4*f3*f6-16*x3^3*x6*f7
*f3^2*f5*f4+200*x3^3*x6*f0*f5^3*f7+8*x3^3*x6*f2*f7^2*f3^2-8*x3^3*x6*f4^4*f6-32
*x3^3*x6*f6^2*f2*f1*f7+24*x3^3*x6*f7*f2^2*f6*f5+40*x3^3*x6*f4^2*f6*f1*f7-44*x3
^3*x6*f7*f4*f5^2*f1-16*x3^3*x6*f6^2*f4*f5*f1+44*x3^3*x6*f4^3*f5^2-8*x5^3*x2*f0
*f4^2+16*x5^3*x3*f0*f5*f4+72*x5^3*x4*f0*f5^2-12*x5^3*x4*f1*f4*f5+48*x5^2*x2*x6
*f4*f0*f5+24*x5^2*x4*x6*f2*f4*f5-56*x5^2*x4*x6*f7*f0*f4+8*x5^3*x6*f0*f4+36*x5^
2*x1*x6*f2*f5*f1-72*x5^2*x2*x7*f0*f5^2-144*x5^2*x3*x7*f0*f5*f6+32*x5^2*x3*x7*
f7*f0*f4+24*x5^2*x3*x7*f1*f4*f6-12*x5^2*x3*x7*f4^2*f3+36*x5^2*x4*x7*f7*f1*f4-\
152*x5^2*x4*x7*f7*f0*f5-36*x5^2*x4*x7*f3*f5*f4+24*x5^3*x7*f0*f5-32*x5^2*x1*x7*
f0*f5*f4+12*x5^2*x1*x7*f3*f1*f5-40*x5^2*x3*x8*f7*f0*f5+16*x5^2*x6*x8*f7*f0-8*
x5^2*x2*x8*f7*f0*f4-24*x1^2*x5*x7*f3^2*f5*f2-8*x1^2*x5*x7*f1^2*f4*f7+144*x1^2*
x5*x7*f0*f5^2*f3-48*x1^2*x5*x7*f0*f6*f4*f3-96*x1^2*x5*x6*f0*f4*f5*f3+32*x1^2*
x5*x6*f0*f3*f7*f2+12*x2*x5*x3*x7*f2^2*f5*f7+4*x2*x5^2*x3*f7*f3^2*f1-4*x2^2*x5*
x6*f3*f7*f2^2+16*x2*x5*x6*x8*f7*f1*f4-4*x2*x5^2*x8*f7*f3*f1-4*x2^2*x5*x8*f7*f4
^2*f1+8*x2*x5^2*x4*f4*f7*f3*f1-16*x1^2*x5*x7*f0*f3^2*f7+32*x1^2*x5*x7*f7*f2*f3
*f1-8*x1^2*x5*x7*f7*f2^3-16*x1^2*x5*x7*f1*f5*f0*f7+128*x2*x7*x1*x5*f7^2*f0^2-\
288*x2*x7*x1*x5*f0*f7*f2*f5-16*x1*x5^2*x3*f7*f1^2*f4-8*x1*x5^2*x2*f4^3*f0-32*
x1*x5*x2*x6*f6*f0^2*f7+16*x1*x5*x2*x6*f0*f4*f2*f7+8*x1*x5*x2*x6*f0*f3^2*f7-40*
x1*x5*x2*x6*f1^2*f7*f4+4*x1*x5^2*x2*f3*f4^2*f1+4*x1*x5^2*x3*f1*f4^3+8*x1*x5^2*
x3*f7*f2*f3*f1-96*x4*x5^2*x1*f0*f7*f2*f5-48*x4*x5^2*x1*f7*f4*f0*f3-16*x4*x5^2*
x1*f1*f7*f0*f6-36*x1*x5^2*x4*f5^2*f2^2+32*x2*x5^2*x3*f0^2*f7^2-16*x4*x5^2*x2*
f0*f6*f7*f2-80*x2*x5^2*x4*f0*f5*f3*f7+96*x4*x5^2*x1*f7^2*f0^2+12*x4*x5^2*x1*f7
*f3^2*f1-16*x1^2*x5*x6*f0*f6*f4*f2-24*x1^2*x5*x6*f2*f5*f1*f4+96*x1^2*x5*x6*f1*
f6*f0*f5-72*x3*x5*x6^2*f1*f5^2+16*x3*x5*x1*x6*f0*f6*f4^2-8*x2*x5*x4*x6*f7^2*f1
^2+16*x2*x5*x4*x6*f1*f6*f7*f2-192*x1^2*x5*x7*f0*f6*f5*f2+12*x1^2*x5*x7*f3^3*f4
+8*x1*x5*x3*x7*f7*f3*f1*f4-576*x1^2*x4*x5*f0*f6*f5^2*f2-608*x4^2*x1*x5*f0^2*f7
^3-8*x4^2*x5*x1*f3^2*f6*f7*f2+32*x4^2*x5*x1*f0*f6^2*f7*f2-128*x4^2*x1*x5*f7*f2
*f3*f5*f4+52*x4^2*x1*x5*f2*f7^2*f1*f4+304*x4^2*x1*x5*f0*f4*f3*f7^2+128*x4^2*x1
*x5*f0*f6*f1*f7^2-160*x4^2*x1*x5*f0*f6*f5*f3*f7-636*x4^2*x1*x5*f1^2*f7^2*f5+4*
x1*x4^2*x3*f7*f4^5-360*x1*x4^3*f7*f2*f5^3*f4+648*x1*x4^3*f6*f5^4*f2+12*x1*x4^3
*f5*f4^4*f7-324*x1*x4^3*f3*f5^5+8*x1^2*x4^2*f7*f3^2*f4^3+18*x1^2*x4^2*f5^2*f4^
3*f3+36*x1*x4*x5^2*f3*f5^2*f1+40*x1^2*x4*x7*f7*f3*f4^2*f2+168*x1^2*x4*x7*f7*f0
*f4^2*f5-8*x1^2*x4*x7*f7*f2^2*f5*f4-1040*x2*x4*x3^2*f0*f6*f4*f5^2*f7-256*x2*x4
*x3^2*f0*f6^2*f5*f3*f7+24*x3^2*x2*x4*f7*f4^5-32*x3^2*x2*x4*f3*f6^2*f1*f4*f7-16
*x2*x4*x3^2*f0*f5^4*f7+8*x2*x4*x3^2*f3*f5^2*f6*f7*f1-32*x3^2*x2*x4*f1*f7^3*f2*
f3+448*x3^2*x2*x4*f6*f0^2*f7^3-16*x3^2*x2*x4*f7^3*f2^3-72*x2*x4*x3^2*f7*f2^2*
f5^2*f6-24*x2*x4*x3^2*f6*f4*f5*f7*f2*f3-864*x3^2*x2*x4*f0*f6^2*f5^3+16*x1^3*x3
*f1^2*f3^2*f7*f6+16*x1^3*x3*f4*f6*f7*f2*f1^2+64*x1^3*x3*f2^3*f4*f5*f6-72*x1^3*
x3*f1*f5^2*f2^2*f6-96*x1^3*x3*f0*f5^2*f4^2*f3-32*x1^3*x3*f6^2*f4*f1^2*f3-192*
x1^3*x3*f0*f6^2*f5*f2^2-96*x1^3*x3*f0*f6^2*f5*f1*f3+32*x1^3*x3*f0*f6^2*f4*f2*
f3+64*x1^3*x3*f0*f6^2*f7*f1^2-16*x1^3*x3*f1*f6^2*f4*f2^2-8*x1^3*x3*f2*f4*f6*f3
^3-64*x2^2*x1*x3*f5^2*f4^2*f2*f3-80*x2^2*x1*x3*f0*f6*f4^2*f2*f7-80*x2^2*x4^2*
f7^2*f2*f5^2*f1+88*x2^2*x4^2*f7^2*f1^2*f6*f5+68*x2^2*x4^2*f7*f5^2*f4^2*f2-408*
x2^2*x4^2*f7*f0*f5^4+32*x1^2*x3*x7*f0*f6*f3^2*f7+32*x1^2*x3*x7*f0*f4*f1*f7^2+8
*x1*x3^2*x2*f7^2*f2^2*f3^2+32*x2^2*x3*x7*f7*f2*f3*f5*f4+32*x2^2*x3*x7*f1^2*f7*
f6^2+208*x2^2*x3*x7*f0*f6*f5*f3*f7-64*x1^2*x3*x6*f4*f0^2*f7^2+24*x1^2*x3*x6*f3
^3*f4*f5+32*x1^2*x3*x6*f1^2*f6^2*f4+4*x1^3*x7*f2*f4^3*f3-4*x1^3*x7*f1^2*f5*f7*
f3-4*x1^3*x7*f1*f5*f7*f2^2-44*x1^4*f0*f5^2*f1^2*f7+24*x1^4*f6*f4^2*f1^2*f3-8*
x2*x6*x3*x4*f3^3*f6*f7+224*x4*x3*x7^2*f0*f6*f7^2+124*x4*x3*x7^2*f7*f5*f4^2-48*
x4*x3*x6^2*f0*f4*f7^2-16*x4*x3*x6^2*f2^2*f7^2-24*x4*x3*x6^2*f7*f3^2*f5-152*x2*
x4*x5*x7*f0*f7*f5^2-72*x2*x4*x5*x7*f2*f5^3+80*x2*x4*x5*x7*f7*f2*f4^2+8*x2*x4*
x5*x7*f1*f4*f7*f5-20*x2*x4*x5*x7*f2*f7^2*f1+72*x2*x4*x5*x7*f3*f5^2*f4+80*x6*x7
*x2*x4*f0*f5*f7*f6-108*x2*x4*x6*x7*f7*f4*f2*f5+4*x2*x4*x6*x7*f3*f7^2*f1+144*x2
*x4*x6*x7*f4^2*f5^2-156*x6*x7*x2*x4*f1*f5^2*f7-16*x2*x4*x6*x7*f0*f7^2*f4+16*x2
*x4*x6*x7*f1*f7*f4*f6-16*x2*x4*x6*x7*f7*f3*f4^2-36*x6*x7*x2*x4*f7*f3^2*f5-16*
x2*x4*x5*x7*f3^2*f4*f7+8*x2*x4*x5^2*f7*f2^2*f4-8*x2*x4*x5*x6*f7*f2^2*f5+40*x2*
x4*x5*x6*f1*f5*f7*f3-4*x2^2*x6*x4*f3^3*f7*f5+16*x4^2*x3*x6*f6^2*f4*f1*f7+72*x4
^2*x3*x6*f5^2*f4^2*f6-96*x4*x3*x5*x6*f2*f4*f5*f6-76*x4*x3*x5*x6*f4*f5*f7*f1+
1920*x1^2*x4^2*f0*f6*f5^2*f7*f2-216*x1^2*x4^2*f6*f2^2*f5^3-4*x5^3*x3*f1*f4^2+4
*x5^2*x1*x7*f2*f3*f4+4*x5^3*x1*f2*f1*f4+4*x5^3*x4*f7*f2*f1-8*x5^2*x4*x6*f7*f2^
2-8*x5^2*x1*x6*f4*f2^2+24*x5^2*x2*x7*f5*f1*f4-8*x5^2*x2*x7*f2*f4^2+4*x5^2*x3*
x7*f2*f4*f5+8*x5^2*x3*x7*f7*f3*f1-4*x5^3*x7*f1*f4+8*x5^2*x6*x7*f2*f4+4*x5^2*x4
*x7*f7*f2*f3+72*x3*x5^2*x6*f0*f5^2-48*x3*x5^2*x6*f0*f6*f4-96*x3*x6*x1*x5*f0*f7
*f2*f5+72*x1*x3*x4*x6*f3^2*f5*f6*f4+144*x1*x3^2*x7*f0*f7*f5^2*f4+8*x1*x3^2*x7*
f1*f4*f7^2*f2-32*x1*x3^2*x7*f0*f6^2*f5*f4+16*x1*x3^2*x7*f2^2*f3*f7^2-16*x1*x3^
2*x7*f7*f4^2*f5*f1+72*x1*x3^2*x7*f3*f5^2*f6*f2+56*x1*x3^2*x7*f2*f4^2*f6*f5+48*
x1*x3^2*x7*f3*f5*f6^2*f1-32*x1*x3^2*x7*f1^2*f7*f6^2+64*x1*x3^2*x7*f0*f6*f4^2*
f7+48*x1*x3^2*x7*f4*f5^2*f1*f6+64*x2^2*x3*x4*f0*f5^2*f2*f7^2+36*x2^2*x3*x4*f5^
5*f1-76*x2*x3*x4^2*f1^2*f7^3*f5+84*x2*x3*x4^2*f7^3*f3^2*f1-288*x2*x3*x4^2*f0*
f4*f3*f7^3+264*x2*x3*x4^2*f5^4*f1*f7-216*x2*x3*x4^2*f6*f5^3*f3*f4+264*x2*x3*x4
^2*f5^2*f4^2*f7*f3-96*x2*x3*x4^2*f7^2*f2^2*f5^2-608*x2*x3*x4^2*f0*f5^2*f4*f7^2
-4*x1^2*x6^2*f0*f4^2*f5+8*x1^2*x4*x5*f7*f2*f4^2*f1+12*x1^2*x2*x5*f7*f2^3*f3+4*
x1^2*x2*x5*f7*f1*f4*f2^2+44*x1^2*x2*x5*f7*f1^2*f4*f3-16*x3^2*x1*x5*f0*f4^3*f7+
160*x3^2*x1*x5*f4*f5^3*f0-60*x3^2*x1*x5*f1*f5^3*f3+12*x3^2*x1*x5*f2*f5*f7*f1*
f4+16*x3^2*x1*x5*f7*f0*f6*f1*f5+96*x1*x5*f0*f7*f2*f5^2*x3^2-24*x3^2*x1*x5*f1*
f6*f7*f2*f3-32*x3^2*x1*x5*f0*f5*f4*f3*f7+32*x3^2*x1*x5*f7^2*f0^2*f5+16*x3^2*x1
*x5*f2^2*f5*f4*f6-20*x3^2*x1*x5*f3*f4*f5^2*f2-12*x3^2*x1*x5*f1*f5^2*f4^2+48*x3
^2*x1*x5*f6^2*f2*f1*f4+12*x3^2*x1*x5*f3^2*f5*f4^2+112*x3^2*x1*x5*f0*f6*f5*f4^2
-12*x2^2*x1*x7*f5^3*f2^2+16*x1*x2^2*x7*f7*f3^2*f4*f2+256*x4^2*x1*x2*f6^2*f0^2*
f7^2+144*x4^2*x1*x2*f1*f6*f3*f7^2*f2-240*x4^2*x1*x2*f0*f6*f7^2*f2*f4-828*x4^2*
x1*x2*f1^2*f5^2*f7^2-704*x4^2*x1*x2*f5*f0^2*f7^3-36*x4^2*x1*x2*f2^2*f7^3*f1-16
*x2*x1*x3*x5*f4^3*f6*f0+72*x2*x1*x3*x5*f1*f5^3*f2-16*x2*x1*x3*x5*f0*f2^2*f7^2+
16*x2*x1*x3*x5*f2*f7^2*f1^2+96*x4^2*x1*x2*f1*f4^2*f7^2*f3-92*x4^2*x1*x2*f7^2*
f3^2*f2*f4-96*x2*x1*x4^2*f5*f4*f6*f1*f3*f7-128*x2*x1*x4^2*f0*f6*f5^2*f3*f7-192
*x2*x1*x4^2*f7*f5*f4^3*f2-108*x4^2*x1*x2*f5*f7^2*f2^2*f3-64*x2^2*x1^2*f4*f3*f0
^2*f7^2-8*x2^2*x1^2*f0*f3^3*f5*f7-24*x2^2*x1^2*f0*f6*f4^3*f3+4*x2^2*x1^2*f7*f2
^4*f6+64*x1^3*x4*f7*f0^2*f6^2*f3+132*x1^3*x4*f1*f5^3*f2*f4-8*x2^2*x7^2*f5*f4^3
-16*x2^2*x1*x6*f7*f3*f4*f2^2+132*x2^2*x1*x6*f1^2*f5*f7*f4-16*x2^2*x1*x6*f0*f5*
f2*f7*f4-24*x2^2*x1*x6*f0*f2^2*f7^2-32*x2^2*x1*x6*f4*f5^2*f2^2-88*x2^2*x1*x6*
f0*f5^2*f1*f7-32*x2^2*x1*x6*f4*f0^2*f7^2+36*x2^2*x1*x6*f1*f5^3*f2-40*x2^2*x1*
x6*f5*f4^3*f1+40*x2^2*x1*x6*f0*f5^2*f4^2-72*x1^2*x2*x4*f1*f5^2*f2*f4*f6+1344*
x1^2*x2*x4*f0^2*f7^2*f5*f4+228*x1^2*x2*x4*f3*f5^3*f1*f4-24*x1^2*x5*x7*f0*f4^2*
f5-24*x1^3*x7*f1^2*f5^3-8*x3^3*x2*f1*f6*f7^2*f2*f3+56*x3^3*x2*f1*f5^2*f7*f6*f2
-20*x3^3*x2*f7*f2^2*f5^3-32*x3^3*x2*f5^2*f4^4+8*x3^3*x2*f7^2*f2^2*f4^2+64*x3^3
*x2*f0*f6^3*f4^2+12*x3^3*x2*f5^2*f7^2*f1^2+8*x3^3*x2*f4^5*f6+128*x3^3*x2*f5*f0
^2*f7^3-64*x3^3*x2*f0*f6^2*f4*f7*f3-24*x3^3*x2*f7*f2^2*f4*f6*f5+40*x3^3*x2*f6*
f2*f5^2*f4^2-8*x3^3*x2*f7^3*f2^2*f1+128*x3^3*x2*f0*f6*f5*f4^2*f7+16*x3^3*x2*f7
*f2*f4^2*f3*f6-44*x3^3*x2*f5^3*f4^2*f3-8*x3^3*x2*f7^3*f3*f1^2+24*x3^3*x2*f1^2*
f6*f7^2*f4-16*x3^3*x2*f0*f4^3*f7^2-112*x3^3*x2*f0*f6*f5*f1*f7^2-4*x1^3*x2*f3^2
*f4^3*f2-8*x1^2*x2^2*f4^4*f3*f2-24*x1^2*x2^2*f7*f1*f4*f3^3-16*x1^2*x3*x5*f0*f4
^3*f5+32*x1^2*x3*x5*f1^2*f5*f4*f6-16*x1^2*x3*x5*f1^2*f5*f7*f3+12*x1^3*x3*f7*f2
*f3^2*f1*f5-8*x1^3*x3*f7^2*f2^3*f1+24*x1^3*x3*f0*f5^3*f3^2-16*x1^4*f4^2*f7*f2*
f1^2+8*x1^4*f7^2*f2*f1^3-8*x1^4*f2*f6*f3^2*f4*f1-64*x1^4*f0*f6*f5*f3*f4*f1+12*
x1^4*f5^2*f2^3*f3-16*x1^4*f0*f4^3*f6*f1+44*x2^2*x1*x3*f4*f7^2*f1^2*f3+112*x2^2
*x1*x3*f0*f5^3*f1*f7-24*x3^3*x2*f3*f5*f6*f1*f4*f7+8*x3^3*x2*f7*f3^3*f5^2+32*x3
^3*x2*f7*f3^2*f5*f4^2+12*x3^3*x2*f7*f3*f4^4-32*x3^3*x2*f6^2*f2*f4^3+32*x3^3*x1
*f4*f5^4*f1+80*x3^3*x1*f0*f5*f4*f2*f7^2-24*x3^3*x1*f3*f5^4*f2+16*x3^3*x1*f4^2*
f5^3*f2+48*x3^3*x1*f0*f5^5-16*x3^3*x1*f6^2*f2^2*f5*f4-20*x3^3*x1*f5*f4^3*f1*f7
-8*x1*x3^3*f7^2*f2^3*f5+12*x3^3*x1*f4^5*f5+32*x2^3*x3*f6*f0^2*f7^2*f4+48*x2^3*
x3*f1^2*f5*f7*f4*f6-32*x2^3*x3*f0*f6^2*f1*f7*f4-64*x2^3*x3*f5^2*f0^2*f7^2-88*
x2^3*x3*f0*f5^4*f4-92*x4^2*x5*x7*f4*f7^2*f1-108*x4^2*x5*x7*f5^3*f4-8*x4^2*x5*
x7*f7*f5*f1*f6+216*x4^2*x5*x7*f7*f5*f3*f4+120*x4^2*x5*x7*f0*f5*f7^2+108*x4^2*
x5*x7*f7*f5^2*f2+36*x6*x7*x4^2*f3^2*f7^2+396*x6*x7*x4^2*f1*f5*f7^2-172*x4^2*x6
*x7*f7*f4^2*f5+216*x4^2*x6*x7*f4*f5^2*f6-112*x6*x7*x4^2*f0*f6*f7^2+112*x4^2*x6
*x7*f7^2*f2*f4+44*x4^3*x7*f7^3*f4*f1-40*x4^2*x1*x7*f1*f7^2*f4^2-460*x4^2*x1*x7
*f1*f7^2*f3*f5+116*x4^2*x1*x7*f7^2*f3*f4*f2-256*x4^2*x1*x7*f0*f7^3*f2+112*x4^2
*x1*x7*f0*f6*f7^2*f3+168*x4^2*x1*x7*f7^2*f2^2*f5+216*x4^2*x1*x7*f1*f7*f6*f4*f5
+180*x4^2*x1*x7*f7*f3^2*f5^2+528*x4^2*x1*x7*f0*f5*f7^2*f4-144*x4^2*x1*x7*f0*f6
*f5^2*f7+108*x4^2*x1*x7*f4^2*f5^3+648*x4^2*x1*x7*f5^3*f6*f2-324*x4^2*x1*x7*f4*
f5^2*f2*f7+240*x4^2*x1*x7*f1*f5^3*f7+84*x4^2*x1*x7*f1^2*f7^3-324*x4^2*x1*x7*f3
*f5^4-112*x4^2*x1*x7*f7*f3*f4^2*f5+48*x4^2*x3*x8*f7*f2*f5*f6^2-480*x4^2*x3*x8*
f7*f5^3*f4-168*x4^2*x3*x8*f7*f5^2*f3*f6-188*x4^2*x3*x8*f7^2*f5*f3*f4+88*x4^2*
x3*x8*f7^3*f4*f1-432*x4^3*x8*f7*f5^4-12*x4^3*x8*f7^3*f3^2+96*x4^3*x8*f7^2*f6*
f2*f5+20*x4^3*x8*f7^2*f5*f4^2-172*x4^3*x8*f7^3*f1*f5-56*x4^3*x8*f7^3*f2*f4-228
*x4^3*x8*f7^2*f3*f5^2+48*x4^3*x8*f7^3*f0*f6+96*x4^2*x5*x8*f7^2*f1*f5+28*x5*x8*
f7^2*f2*f4*x4^2-24*x4^2*x5*x8*f7*f6*f2*f5+84*x4^2*x5*x8*f7*f3*f5^2-60*x4^2*x6*
x8*f7^2*f2*f5+136*x4^2*x6*x8*f7^3*f0-40*x4^2*x6*x8*f7^2*f1*f6+48*x4^2*x6*x8*f7
*f4*f5^2-468*x4^2*x7*x8*f7*f5^3+36*x4^2*x7*x8*f7^3*f1-120*x4^2*x7*x8*f7^2*f3*
f5+8*x7*x8*f7^2*f4^2*x4^2+24*x4^2*x2*x8*f7*f3*f5^3+20*x4^2*x2*x8*f7^3*f2^2-100
*x4^2*x2*x8*f7^3*f3*f1+72*x4^2*x2*x8*f7^2*f2*f4*f5-72*x4^2*x2*x8*f7^3*f0*f4-72
*x4^2*x2*x8*f7*f4^2*f5^2+56*x4^2*x2*x8*f7^2*f4*f6*f1+36*x4^2*x2*x8*f7^2*f5^2*
f1+24*x4^2*x2*x8*f7*f2*f6*f5^2-488*x4^2*x3*x8*f7^3*f0*f5-104*x4^2*x3*x8*f7^2*
f5*f1*f6+132*x4^2*x3*x8*f7^2*f5^2*f2+12*x3*x8*f7^2*f4^3*x4^2-48*x4^2*x3*x8*f7^
2*f6*f2*f4+8*x3^3*x5*f7*f2^2*f5^2-32*x3^3*x5*f0^2*f7^3-64*x3^3*x5*f0*f6*f4^2*
f7+144*x3^3*x5*f0*f6*f5^3-24*x3^3*x5*f1*f5^4-12*x3^3*x5*f1^2*f5*f7^2+8*x3^3*x5
*f7*f2*f4^3-80*x3^3*x5*f0*f6*f5*f3*f7+32*x3^3*x5*f1^2*f7*f6^2+48*x3^3*x5*f0*f5
*f2*f7^2-48*x3^3*x5*f1*f6^2*f4^2+12*x3^3*x5*f1*f7*f5*f4^2-8*x3^3*x5*f7^2*f2*f1
*f4+32*x3^3*x5*f0*f4*f3*f7^2+24*x3^3*x5*f4^3*f3*f6-40*x3^3*x5*f1*f7*f6*f2*f5-8
*x3^3*x5*f1*f7*f3*f6*f4-32*x3^3*x5*f1*f5^2*f4*f6+8*x3^3*x5*f2*f5*f4^2*f6-12*x3
^3*x5*f5*f4^4-12*x3^3*x5*f5^3*f2*f4+8*x2^3*x3*f7*f3*f4^3*f2+64*x2^3*x3*f6^2*f0
^2*f7*f5-64*x2^3*x3*f1*f6*f5^2*f0*f7-44*x2^3*x3*f7*f2*f5^2*f1*f4-48*x2^3*x3*f0
*f6*f5*f2*f7*f4+16*x2^3*x3*f1^2*f7^2*f4^2+24*x2^3*x3*f1*f7^2*f2^2*f5-96*x2^3*
x3*f0*f6*f4^2*f5^2-24*x2^3*x3*f1^2*f7^2*f6*f2+16*x2^3*x3*f0*f6*f7^2*f2^2-12*x2
^3*x3*f5*f4^2*f1*f3*f7-48*x2^3*x3*f0*f5*f2*f7^2*f3+80*x2^3*x3*f0*f5^2*f3*f7*f4
-16*x2^3*x3*f0*f4^2*f2*f7^2+48*x1^2*x2*x3*f0*f7^2*f1*f3*f4-24*x3^3*x8*f7*f5^2*
f3*f4+16*x3^3*x8*f7*f5^2*f6*f1+8*x3^3*x8*f7*f2*f5*f4*f6-104*x3^2*x4*x8*f7*f4*
f5*f6*f3-56*x3^2*x4*x8*f7^2*f3^2*f5+16*x3^2*x4*x8*f7^3*f2^2-148*x3^2*x4*x8*f7*
f5^2*f4^2-24*x3^2*x4*x8*f7^2*f2*f3*f6+64*x3^2*x4*x8*f7^2*f1*f4*f6-84*x4*x8*f7*
f3*f5^3*x3^2-384*x3^2*x4*x8*f7^2*f0*f5*f6-8*x3^2*x5*x8*f7*f2*f4*f5-16*x3^2*x5*
x8*f7*f1*f4*f6+128*x3^2*x5*x8*f7*f0*f5*f6+16*x3^2*x6*x8*f7*f6*f3^2+16*x3^2*x6*
x8*f7*f2*f4*f6-32*x3^2*x6*x8*f7*f6*f1*f5+16*x3^2*x6*x8*f7*f3*f5*f4-24*x3^2*x7*
x8*f7^2*f1*f5-24*x3^2*x7*x8*f7*f3*f6*f4+32*x3^2*x7*x8*f7^2*f0*f6-56*x3^2*x7*x8
*f7*f5*f4^2-4*x6^3*x2*f7*f3*f1-12*x6^2*x5*x8*f7*f1+16*x6^2*x3*x7*f7*f2*f4+16*
x6^2*x4*x7*f7*f3*f4-4*x6^3*x7*f7*f1+4*x6^2*x3*x7*f7*f3^2+8*x6^2*x1*x7*f7*f3*f1
-12*x3*x6^2*x5*f2*f4*f5+16*x3*x6^2*x5*f1*f4*f6-16*x3*x6^2*x1*f0*f6*f7*f2+24*x3
*x6^2*x1*f7*f3*f1*f4-32*x1*x6*x3*x7*f2*f5^2*f4-16*x1*x6*x3*x7*f7*f2*f1*f6-32*
x1*x6*x3*x7*f2*f4*f3*f7-12*x1*x5^3*f1^2*f5-12*x5^2*x3*x6*f7*f2*f1+8*x5^2*x3*x6
*f4^2*f2+4*x5^3*x3*f7*f1^2-32*x1^3*x3*f4*f7^2*f1^3-50*x1^2*x4^2*f7^2*f3*f4*f2^
2-160*x1^2*x4^2*f7^3*f0*f1*f3-976*x1^2*x4^2*f7*f1^2*f5^2*f6+464*x1^2*x4^2*f7*
f0*f5^2*f4^2+40*x2^2*x4^2*f7^2*f2*f1*f4*f6-40*x2^2*x4^2*f7^2*f3*f4^2*f2+108*x2
^2*x4^2*f7^2*f3*f4*f1*f5-160*x2*x1*x4*x6*f7*f2^2*f5*f4+324*x2*x1*x4*x6*f7*f2*
f5^2*f1+252*x2*x1*x4*x6*f3^2*f5^2*f4-192*x2*x1*x4*x6*f5^3*f4*f1-108*x2*x1*x4*
x6*f2*f5^3*f3+144*x2*x1*x3*x4*f5^3*f6*f3*f1+32*x2*x1^2*x4*f0*f6^2*f7*f2^2-144*
x2*x1^2*x4*f4*f5^2*f3^3+192*x2*x1*x3*x4*f0*f6*f5^3*f4-200*x3*x4*x1*x2*f6*f5^2*
f7*f1^2+288*x2*x1*x3*x4*f0*f6^2*f5*f4^2-48*x2*x1*x5*x7*f0*f4^2*f6+16*x2*x1*x5*
x7*f4^3*f2-24*x2*x1*x5*x7*f4^2*f1*f5+160*x2*x1*x5*x7*f1^2*f7*f5-832*x2*x1*x3*
x4*f0*f5^2*f4^2*f7+48*x2*x1*x3*x4*f4^5*f5+336*x2*x1*x3*x4*f0*f5*f2*f7^2*f4+168
*x2*x1*x3*x4*f7^2*f2*f3*f1*f5-28*x2*x1*x3*x4*f5*f4^2*f7*f2*f3-96*x2*x1^2*x6*f6
*f1*f5^2*f0+8*x2*x1^2*x6*f1^2*f6*f7*f2-12*x2*x1^2*x6*f3*f5^2*f2^2+32*x2*x1^2*
x6*f0*f3^2*f7*f4+128*x1^3*x3*f0^3*f7^3-4*x1^3*x2*f7*f1^3*f5^2+16*x1^2*x3^2*f4^
2*f3*f5^2*f2-28*x1^2*x3^2*f4^3*f3*f1*f7+32*x1^2*x3^2*f7^2*f1^2*f4*f3-60*x1^2*
x4*x6*f7*f1*f4^2*f3+64*x1^3*x4*f0^2*f7^2*f4^2-576*x1^3*x4*f5^2*f6^2*f0^2-8*x1^
3*x4*f1^2*f3^2*f7^2+24*x3^4*f5^2*f7*f3^2*f4-68*x3^4*f0*f5^4*f7-16*x3^4*f1^2*f6
^3*f7-16*x3^4*f7*f2*f4^3*f6+64*x3^4*f0*f6^2*f4^2*f7+24*x3^4*f4*f5^3*f6*f2-56*
x3^4*f0*f6*f4*f3*f7^2+32*x3^4*f1*f6^3*f4^2+8*x2^2*x3^2*f7^2*f3^2*f1*f4+4*x2^3*
x3*f3^2*f5^2*f1*f7-4*x2^3*x3*f7*f4^4*f1-4*x2^3*x3*f7*f3*f5^2*f2^2+4*x2^3*x3*f5
*f4^2*f7*f2^2+4*x2^3*x3*f1^2*f7^2*f3*f5+4*x2^3*x3*f7*f2*f3^2*f4*f5+28*x2^2*x1*
x3*f7*f2*f5^2*f3*f1+4*x2^3*x4*f7*f3^3*f5*f4+128*x1^3*x3*f0*f4*f2*f1*f7^2-16*x1
^3*x3*f7*f2^4*f6+24*x4^2*x7^2*f7*f3*f5*f6-4*x4^2*x7^2*f7*f4^2*f6+36*x1^2*x7^2*
f0*f5^3-12*x2*x7^2*x5*f5^2*f2-8*x2*x7^2*x6*f7*f2*f4+16*x6*x7^2*x2*f7*f0*f6-16*
x4*x7*x6*x8*f7^2*f2-48*x2*x1^2*x6*f0*f5^3*f2+80*x2*x1^2*x6*f2*f3^2*f5*f4+40*x2
*x1*x3^2*f1*f6*f7*f4^2*f2+304*x2*x1*x3^2*f3*f5^2*f1*f4*f6+32*x2*x1*x3^2*f0*f4^
3*f5*f7-320*x2*x1*x3^2*f0*f6*f5^2*f4^2-192*x2*x1*x3^2*f6^2*f2*f5*f1*f4-32*x2*
x1*x3^2*f0*f3^2*f7^2*f4-52*x2*x1*x3^2*f3*f5^3*f2*f4-24*x2^2*x1*x6*f1^2*f7*f6*
f3-16*x2^2*x1*x6*f1*f7*f2^2*f6-256*x3^2*x1*x4*f5*f0^2*f7^3+144*x3^2*x1*x4*f1*
f6*f5^3*f4-96*x3^2*x1*x4*f0*f6*f4*f2*f7^2+144*x3^2*x1*x4*f5^2*f6^2*f1*f3+48*x3
^2*x1*x4*f0*f4^3*f7^2+48*x3^2*x1*x4*f3*f5*f6^2*f4*f2+12*x3^2*x1*x4*f7*f3^2*f5*
f4^2+28*x3^2*x1*x4*f7^2*f2^2*f5*f3+40*x3^2*x1*x4*f7^2*f2*f5*f1*f4-32*x3^2*x1*
x4*f0*f3*f2*f7^3+56*x3^2*x1*x4*f1*f6*f7*f4^3-96*x3^2*x1*x4*f0*f6^2*f5^2*f4-112
*x3^2*x1*x4*f0*f5^3*f7*f4-56*x3^2*x1*x4*f3*f5^3*f7*f1+16*x3^3*x2*f0*f3*f2*f7^3
-480*x3^3*x2*f0*f6^2*f5^2*f4+16*x3^3*x2*f6^2*f2*f1*f4*f7+128*x3^3*x2*f6^2*f0^2
*f7^2-144*x3^3*x2*f0*f6*f5^4-8*x3^3*x2*f3^2*f7^2*f2*f4-64*x3^3*x2*f0*f6*f4*f2*
f7^2+176*x3^3*x2*f1*f6*f5^3*f4-48*x3^3*x2*f1*f6*f7*f4^3+40*x3^3*x2*f3*f5^3*f7*
f1-144*x4^2*x6^2*f5^3*f4-12*x1*x3^2*x2*f7*f2*f3^2*f4*f5+12*x1^2*x3*x5*f3^3*f4^
2-144*x1^2*x3*x5*f0*f6*f5*f3^2-192*x1^2*x3*x5*f1*f6*f5^2*f0-16*x1^2*x3*x5*f0*
f4*f3^2*f7+32*x1^2*x3*x5*f0*f4^2*f7*f2-8*x1^2*x3*x5*f4*f6*f2^2*f3+576*x1^2*x3*
x5*f0^2*f6^2*f5+56*x1*x3*x4*x5*f1^2*f7^2*f4+128*x1*x3*x4*x5*f7*f2*f1*f4*f6+416
*x1*x3*x4*x5*f0*f6*f5*f2*f7+32*x1*x3*x4*x5*f1*f5*f0*f7^2-320*x1*x3*x4*x5*f6*f0
^2*f7^2-144*x1*x3*x4*x5*f3*f5^2*f1*f6+160*x1*x3*x4^2*f7^3*f2*f1*f3+148*x1*x3*
x4^2*f7*f4*f5^3*f1+72*x1*x3*x5^2*f1^2*f5*f6+16*x1*x3*x5^2*f1*f4*f3*f5-8*x3^2*
x2*x5*f4^5-12*x1^2*x2^2*f0*f5*f4^4-48*x1^2*x2^2*f7*f1^2*f4*f3*f5+64*x1^2*x2^2*
f0*f4*f2*f1*f7^2-112*x1^2*x2^2*f0*f5^2*f7*f2^2-120*x1^2*x2^2*f0*f5^2*f7*f1*f3-\
96*x1^3*x2*f5^4*f0^2+16*x3^3*x7*f7^2*f2*f1*f6-96*x3^3*x7*f0*f7^2*f4*f5+24*x3^3
*x7*f6*f5^3*f2-68*x3^3*x7*f5^3*f4^2+36*x3^3*x7*f7*f3^2*f5^2-8*x3^3*x7*f7^2*f1*
f4^2-56*x3^2*x4*x7*f7^2*f2*f4^2+32*x3^2*x4*x7*f7^2*f2^2*f6+144*x3^2*x4*x7*f7*
f5*f4^3+48*x3^2*x4*x7*f7^2*f1*f3*f6+8*x3^2*x4*x5*f1*f7^2*f3*f4-80*x3^2*x4*x5*
f0*f4^2*f7^2-176*x3^2*x4*x5*f1*f7*f3*f5*f6-104*x3^2*x4*x5*f1*f7^2*f2*f5-28*x3^
2*x4*x5*f7*f3^2*f5*f4+96*x3^2*x4*x5*f7*f2*f5^2*f3-136*x3^2*x4*x5*f4^2*f6*f1*f7
-48*x3^2*x4*x5*f2*f5^2*f4*f6-144*x3^2*x4*x5*f6^2*f4*f1*f5-16*x3^2*x4*x5*f2^2*
f7^2*f4+144*x3^2*x4*x5*f3*f5*f4^2*f6-24*x3^2*x4*x5*f7*f2^2*f6*f5+424*x3^2*x4*
x5*f0*f5^3*f7+28*x3^2*x4*x5*f7*f3*f4^3-8*x3^2*x4*x5*f7*f4*f5^2*f1+272*x3^2*x4*
x5*f0*f6*f7*f4*f5+136*x3^2*x4*x5*f7*f2*f5*f4^2-64*x3^2*x4*x5*f0*f7^2*f5*f3-24*
x3^2*x1*x5*f1*f6*f4^3+48*x2*x1^2*x6*f0*f4^2*f2*f7-160*x3*x6*x1*x2*f7*f1*f0*f6*
f5+140*x2*x1*x3*x6*f3*f5^2*f2*f4+48*x2*x1*x3^2*f0*f7^3*f1*f2-32*x2*x1*x3^2*f7*
f3*f1^2*f6^2+16*x2*x1*x3^2*f4^2*f3^3*f7+4*x2*x1*x3^2*f4^3*f7*f2*f3+144*x2*x1*
x3^2*f1^2*f5^2*f6^2-16*x2^2*x1*x3*f1*f6*f4^4+48*x2*x1^2*x3*f0*f3^2*f7^2*f2-56*
x2*x1^2*x3*f3^2*f5^2*f2*f4-80*x2*x1^2*x3*f0*f4^3*f3*f7+64*x2*x1^2*x3*f6^2*f0^2
*f3*f7+144*x2*x1^2*x3*f0*f6*f3^2*f5^2+64*x2*x1^2*x3*f0*f4*f2^2*f7^2+32*x2^2*x1
*x3*f0*f6*f7^2*f1*f2+504*x2*x1*x4^2*f4*f5^3*f6*f1-784*x2*x1*x4^2*f0*f5^3*f4*f7
-32*x2*x1*x4^2*f7*f2*f6*f5^2*f1+392*x2*x1*x4^2*f7*f3*f5^2*f2*f4-128*x4^2*x1*x2
*f0*f6*f3^2*f7^2+128*x4^2*x1*x2*f7^2*f3^2*f1*f5+48*x2*x1*x4*x5*f5*f4^3*f2-72*
x2*x1*x4*x5*f5^2*f4^2*f1-64*x2*x1*x4*x5*f7*f4^2*f2^2+4*x1*x2*x4*x5*f7*f3*f5*f2
^2-80*x1*x2*x4*x5*f1*f0*f7^2*f4-64*x1*x2*x4*x5*f6^2*f0^2*f7+32*x1*x2*x4*x5*f0*
f6*f3^2*f7-8*x1*x2*x4*x5*f1^2*f7*f4*f6+172*x1*x2*x4*x5*f1^2*f7*f5^2-72*x2*x1*
x4*x5*f3*f5^3*f1+8*x2*x1^2*x5*f0*f4^4-16*x1^2*x3*x4*f0*f4*f7^2*f3^2+144*x1^2*
x3*x4*f3^2*f5^2*f6*f2-72*x1^2*x3*x4*f3^3*f5*f6*f4+24*x1^2*x3*x4*f5*f4^3*f1*f6+
16*x2*x3*x5*x8*f7*f1*f3*f6-16*x2*x3*x6*x8*f7*f0*f5*f6+16*x2*x3*x6*x8*f7*f2*f4*
f5-48*x2*x3*x7*x8*f7^2*f0*f5-28*x2*x3*x7*x8*f7*f3*f5*f4-4*x2*x3*x7*x8*f7^2*f1*
f4+32*x2*x3^2*x6*f4^2*f6^2*f1+208*x1*x3*x4*x6*f7*f0*f5*f6*f3-20*x1*x3*x4*x6*f7
^2*f1*f3^2+176*x1*x3*x4*x6*f7^2*f0*f4*f3+16*x1*x3*x4*x6*f7*f2*f3^2*f6+56*x1*x3
*x4*x6*f7*f4^3*f2+24*x1*x3*x5*x6*f2^2*f5^2+16*x1*x3*x5*x6*f3*f4*f1*f6+32*x1*x3
*x5*x6*f2^2*f4*f6-144*x1*x3*x5*x6*f2*f5*f1*f6-16*x1*x3*x5*x8*f7*f1*f3*f5+12*x1
*x3*x5*x8*f7*f2^2*f5-32*x1*x3*x6*x8*f7*f1*f4*f5+12*x1*x3*x6*x8*f7^2*f2*f1-16*
x1*x3*x6*x8*f7*f3*f1*f6+160*x3^2*x4*x2*f6^2*f2*f1*f5*f7-32*x3^2*x4*x2*f6^3*f7*
f1^2-120*x3^2*x4*x2*f5*f4^2*f1*f6*f7+96*x3^2*x4*x2*f0*f6^2*f1*f7^2+4*x1^2*x3*
x7*f4^4*f3+20*x1*x3*x7^2*f1*f4*f7*f5+72*x2*x3*x4*x6*f1*f7*f4^2*f6-192*x2*x3*x5
*x6*f0*f6*f5*f4-144*x2*x3*x5*x6*f0*f5^3+8*x2*x3*x5*x6*f4^2*f5*f2+16*x2*x3*x5*
x6*f7*f2*f1*f5+152*x2*x3*x5*x6*f4*f5^2*f1-32*x2*x3*x5*x6*f1*f4^2*f6+4*x1^2*x3^
2*f1*f5*f7*f2^2*f6-576*x1^2*x3^2*f6^3*f0^2*f5-30*x1^2*x3^2*f3^2*f5^3*f2-144*x2
*x3*x4*x7*f6*f5^2*f3*f4-8*x2*x3*x4*x7*f7^2*f2*f3*f4-32*x2*x3*x4*x7*f0*f6*f3*f7
^2+208*x2*x3*x4*x7*f5*f4^2*f7*f3+56*x2*x3*x4*x7*f3^2*f7*f6*f4-100*x2*x3*x4*x7*
f7^2*f5*f1*f3-288*x2*x3*x4*x7*f5^3*f4^2-8*x2*x3*x4*x7*f3*f5*f6*f2*f7-8*x2^2*x3
*x4*f3^3*f5^2*f7+12*x1^2*x2*x3*f7*f2*f4*f3^3+44*x1^2*x2*x3*f7*f2*f4^3*f1-32*x1
^2*x2*x3*f1^2*f5^2*f3*f7-32*x1^2*x2*x3*f1*f5^2*f7*f2^2+144*x3^3*x4*f3*f5*f6^2*
f1*f7-576*x3^3*x4*f0*f6^3*f5^2+48*x3^3*x4*f0*f6*f5*f3*f7^2+32*x3^3*x4*f1^2*f7^
3*f5+144*x3^3*x4*f1*f6^2*f5^3-232*x3^3*x4*f5*f4^2*f7*f2*f6-8*x3^3*x4*f1*f7^2*
f3*f6*f4+16*x3^3*x4*f6^2*f2^2*f7*f5-36*x3^3*x4*f3*f5^5+52*x3^3*x4*f5*f4^4*f7-\
128*x3^3*x4*f1^2*f6^2*f7^2+20*x3^3*x4*f7^2*f3^3*f5+16*x3^3*x4*f7^2*f3^2*f4^2+8
*x3^3*x4*f7^3*f3^2*f1-80*x3^3*x4*f1*f5^2*f7*f4*f6-16*x3^3*x4*f7^2*f2*f4^3-48*
x3^3*x4*f4^3*f5^2*f6-32*x3^3*x4*f7^2*f2^2*f5^2+96*x3^3*x4*f0*f6*f1*f7^3-256*x3
^3*x4*f0*f6^2*f5*f4*f7+160*x3^3*x4*f7^2*f2*f5*f1*f6-204*x3^3*x4*f5^4*f4^2+16*
x3^3*x1*f6*f2^2*f5*f7*f3-16*x3^3*x1*f7*f2*f6*f4*f3^2-8*x3^3*x1*f4^4*f6*f3+24*
x3^3*x1*f5^3*f6*f2^2-16*x3^3*x1*f4^3*f5^2*f3-36*x3^3*x1*f3^2*f5^3*f4-32*x3^3*
x1*f3^2*f5^2*f7*f2-224*x3^3*x1*f0*f6*f5^2*f2*f7-24*x3^3*x1*f3^2*f5*f6*f4^2+40*
x3^3*x1*f6*f5^2*f7*f1^2-92*x3^3*x1*f3*f5^2*f1*f4*f7-32*x3^3*x1*f6^3*f2*f1*f4-\
20*x3^3*x1*f5*f4^2*f7*f2*f3+8*x3^3*x1*f7^3*f2*f1^2-16*x2^2*x1*x3*f0*f6*f5*f4^3
+56*x2^2*x1*x3*f4^2*f6*f2^2*f5-24*x2^2*x1*x3*f7*f2^2*f5*f3*f4+20*x2^2*x1*x3*f7
*f2^2*f4^3-36*x2^2*x1*x3*f1*f5^4*f2-12*x2^2*x1*x7*f5*f4^3*f2-32*x2^2*x1*x7*f4^
3*f6*f1+128*x2^2*x1*x7*f0*f5*f4*f3*f7+16*x2^3*x7*f7*f3*f4^2*f2+32*x2^2*x3^2*f0
*f6*f5*f4*f3*f7+8*x2^2*x3^2*f0*f5^3*f3*f7-8*x2^2*x3^2*f5*f4^3*f6*f2-48*x2^2*x3
^2*f0*f4^2*f3*f7^2+48*x2^2*x3^2*f4*f0^2*f7^3+52*x2^2*x3^2*f1^2*f5^2*f7*f6-52*
x2^2*x3^2*f0*f5*f3^2*f7^2-8*x2^2*x3^2*f2*f7^3*f1^2+64*x2^2*x1*x3*f0*f5*f7^2*f1
*f3-56*x2^2*x1*x3*f5*f7^2*f1^2*f2-32*x2^2*x1*x3*f0*f4^4*f7+8*x1^2*x3*x7*f1*f7^
2*f2^2-192*x1^2*x3*x7*f0^2*f7^2*f5-96*x1^2*x3*x7*f0*f6*f4^2*f5+128*x1^2*x3*x7*
f3*f5*f1*f4*f6-64*x1^2*x3*x7*f0*f7^2*f2*f3+48*x1^2*x3*x7*f1^2*f5^2*f7+36*x3^2*
x1*x7*f7*f2^2*f5^2+44*x3^2*x2*x7*f7*f3*f4^3-32*x3^2*x2*x7*f6^2*f2*f4^2+8*x3^2*
x2*x7*f2*f7^2*f3^2-288*x3^2*x2*x7*f0*f6^2*f5^2+16*x3^2*x2*x7*f2^2*f7^2*f4-32*
x3^2*x2*x7*f1*f7^2*f3*f4-64*x3^2*x2*x7*f0*f7^2*f4^2-32*x3^2*x2*x7*f7*f4*f5^2*
f1+48*x3^2*x2*x7*f5^3*f6*f1+288*x3^2*x2*x7*f0*f6*f7*f4*f5-56*x3^2*x2*x7*f1*f7*
f3*f5*f6-48*x3^2*x2*x7*f3*f5*f4^2*f6-72*x3^2*x2*x7*f4^3*f5^2+96*x3^2*x2*x7*f6^
2*f4*f1*f5-64*x3^2*x2*x7*f0*f6*f7^2*f2+64*x3^2*x2*x7*f2*f5^2*f4*f6+64*x2*x7*f2
*f7^2*f1*x3^2*f5+60*x3^2*x2*x7*f7*f2*f5*f4^2-8*x3^2*x2*x7*f3^3*f6*f7-72*x3^2*
x2*x7*f4^2*f6*f1*f7-36*x3^2*x2*x7*f4*f5^3*f3-96*x1^2*x2*x7*f1^2*f5^2*f6-24*x1^
2*x2*x7*f2*f4*f5*f1*f6-40*x1^2*x2*x7*f2^2*f4*f5^2+32*x3^3*x4*f7^2*f4*f2^2*f6+
48*x3^3*x4*f6^2*f4*f5^2*f2-16*x3^3*x4*f6^2*f2*f3*f7*f4-64*x3^3*x4*f0*f4*f3*f7^
3-144*x3^3*x4*f6^2*f3*f5*f4^2-16*x3^3*x4*f7^3*f2^2*f3+128*x3^3*x4*f1*f6^2*f7*
f4^2+88*x3^3*x4*f4*f5^3*f7*f2-56*x3^3*x4*f7*f3*f4^3*f6-144*x3^3*x4*f3*f5^2*f6*
f7*f2-44*x3^3*x4*f7^2*f3*f4*f2*f5+96*x3^3*x4*f1*f6^3*f5*f4-104*x3^3*x4*f5*f4^2
*f1*f7^2+16*x3^3*x4*f7^2*f3^2*f2*f6-16*x2^3*x3*f0*f5*f6*f7*f3^2+80*x2^3*x3*f4^
2*f5^3*f1-48*x2^3*x3*f1*f5*f0*f7^2*f4+16*x2^3*x3*f0*f6*f3*f1*f7^2-20*x2^3*x3*
f5^2*f4^3*f2+64*x3^3*x1*f0*f5^2*f4^2*f7-64*x3^3*x1*f6*f5*f0^2*f7^2+16*x3^3*x1*
f6*f2*f5*f1*f4*f7+80*x3^3*x1*f0*f5^2*f1*f7^2+52*x3^3*x1*f4*f5^2*f7*f2^2+32*x3^
3*x1*f0*f6*f4^3*f7+32*x3^3*x1*f0*f6*f4*f1*f7^2+16*x3^3*x1*f6^2*f2*f1*f3*f7+32*
x3^3*x1*f1*f6^2*f4^3+96*x3^3*x1*f6^3*f1^2*f5-8*x3^3*x1*f6*f7^2*f3*f1^2+16*x3^3
*x1*f7^2*f2^2*f4*f3-16*x3^3*x1*f3*f6*f4^2*f1*f7-8*x3^3*x1*f7*f2*f4^4+16*x3^3*
x1*f3^3*f7*f5*f4+16*x3^3*x1*f4^2*f6*f7*f2^2+16*x3^3*x1*f6^2*f2*f4^2*f3+40*x3^3
*x1*f1*f6*f5^2*f4^2-176*x3^3*x1*f0*f6*f5^3*f4+64*x3^3*x1*f1*f6^2*f5*f4*f3-28*
x1^3*x2*f7*f2^4*f5-4*x3^3*x1*f1^2*f5*f7^2*f4-4*x3^3*x5*f7*f3^3*f5+4*x3^2*x2*x5
*f7*f2*f3^2*f5+4*x3^2*x2*x5*f1*f7^2*f2*f3-20*x3^2*x2*x5*f7^2*f1^2*f4-4*x3^2*x1
*x5*f1*f7*f3^2*f5+4*x3^2*x1*x5*f4^4*f3+8*x3^2*x1*x5*f2*f5*f4^3-16*x3^2*x5*x6*
f7*f2^2*f5-12*x3^2*x5*x6*f7*f2*f3*f4-4*x3^2*x5*x6*f1*f5*f7*f3-8*x3^2*x4*x6*f7^
2*f3^3-36*x3^2*x1*x6*f1*f7^2*f2*f3+16*x2^2*x4*x7*f7*f3^2*f4*f5+288*x2^2*x4*x7*
f7^2*f3*f0*f5-36*x2^2*x4*x7*f3*f5^3*f4+32*x2^2*x4*x7*f7*f2*f5*f4^2+280*x2^2*x4
*x7*f7*f5^2*f1*f4-32*x2^2*x4*x7*f7*f2*f5^2*f3-40*x2^2*x4*x7*f7^2*f3*f4*f1+56*
x2^2*x4*x7*f7^2*f1^2*f6-104*x2^2*x4*x7*f7^2*f2*f5*f1-64*x2^2*x4*x7*f7*f0*f5*f4
*f6+72*x2^2*x5*x7*f0*f5^3+64*x1*x5*x4*x7*f2*f0*f7^2+16*x2^2*x7*x5*f0*f7^2*f1-\
16*x2^2*x5*x7*f6*f7*f1^2+56*x4*x5*x7^2*f7*f2*f5+36*x4*x5*x7^2*f7*f3*f4-12*x5*
x1*x3*x6*f7*f2^2*f3+36*x3*x5^2*x4*f5^3*f1-16*x3*x5^2*x4*f0*f7^2*f2-8*x2*x7*x3*
x5*f7*f4*f2*f3+12*x4*x5*x6^2*f7*f1*f4+16*x4*x5*x6^2*f7*f2*f3+304*x4*x5*x6^2*f7
*f0*f5-16*x4*x5*x1*x6*f0*f6*f7*f2-16*x2*x6*x4*x5*f0*f6*f7*f3+32*x3*x6*f0*f7^2*
f3*x4*x5-16*x4^2*x5*x6*f2*f6*f7*f3-36*x4*x5^2*x6*f1*f5^2-32*x4*x5*x1*x6*f7^2*
f0*f1-8*x1*x5*x7*x8*f7*f1*f4+32*x1*x5*x7*x8*f7*f0*f5+64*x1^2*x5*x7*f6*f0^2*f7+
12*x3*x5*x7*x8*f7*f3*f4-16*x3*x5*x7*x8*f7^2*f0+16*x3*x5*x2*x8*f7*f0*f6*f4+8*x3
^2*x5*x8*f7*f4^2*f3+8*x2*x5*x6*x7*f2*f4*f5-4*x2*x5^2*x7*f7*f2*f1-4*x2^2*x5*x7*
f7*f4*f2^2+12*x2*x5*x7^2*f7*f1*f4+8*x4^2*x5^2*f1*f6*f7*f3-8*x4^2*x5^2*f7*f3^2*
f4+54*x4^2*x5^2*f2*f5^3-16*x4^2*x5^2*f0*f6*f7*f4+24*x4^2*x5^2*f0*f7^2*f3+4*x4^
2*x5^2*f4^2*f2*f7+4*x4^2*x5^2*f7*f6*f2^2-88*x2*x5*x7^2*f7*f0*f5+72*x2*x5*x6^2*
f0*f5^2+48*x1*x5*x3*x8*f7*f0*f5*f4-8*x1*x5*x3*x8*f7*f1*f4^2-4*x5^2*x1*x4*f7*f2
^2*f3+12*x3*x5^2*x7*f1*f5^2+24*x3*x5*x6*x7*f5^2*f2-32*x3*x5*x6*x7*f7*f0*f5-32*
x3*x5*x6*x7*f2*f4*f6-20*x3*x5*x6*x7*f7*f2*f3-8*x3^2*x6*x5*f7^2*f1^2-16*x3^2*x6
*x5*f0*f6*f7*f3-48*x1*x5*x4*x7*f1*f5*f4*f6+4*x1^2*x5*x7*f4^3*f1+24*x1*x5*x4*x7
*f3*f4^2*f5+16*x1^2*x5^2*f0*f6*f1*f4-32*x1*x5*x4*x7*f0*f6*f3*f7-12*x1*x5^2*x7*
f7*f1^2-32*x4^2*x5*x7*f0*f6^2*f7+36*x4*x5^2*x7*f5^2*f2+48*x4*x5*x6*x7*f5*f4^2-\
64*x4*x5*x6*x7*f7*f2*f4+48*x6*x7*x4*x5*f7*f0*f6-48*x6*x7*x4*x5*f7*f1*f5+8*x3*
x8*f7*f2*f4*f6*x4*x5-12*x4^2*x8*f7*f5*f4^2*x5-16*x4^2*x5*x8*f7^2*f0*f6-12*x4*
x5^2*x8*f7*f1*f5-88*x4*x5*x6*x8*f7^2*f0+16*x4*x5*x6*x8*f1*f6*f7+40*x4*x5*x7*x8
*f7*f3*f5-12*x4*x5*x7*x8*f1*f7^2+48*x4*x5*x2*x8*f7^2*f0*f4+24*x3^2*x5^2*f0*f5*
f7*f3+8*x3^2*x5^2*f5^2*f1*f4+24*x3*x5*x6*x8*f1*f5*f7-32*x3*x5*x6*x8*f7*f0*f6+2
*x1^2*x5^2*f3*f4*f2^2-4*x1*x5^2*x6*f4*f3*f1-12*x3^2*x5*x7*f5^3*f2-8*x3^2*x5*x7
*f1*f7^2*f2+16*x3^2*x5*x7*f0*f7^2*f3-8*x3^2*x5*x7*f7*f3^2*f4-32*x1*x5*x3*x7*f0
*f7*f4^2-16*x5*x3*x2*x7*f0*f6*f7*f3+12*x5*x1*x2*x7*f3^2*f7*f1-4*x3*x5^2*x6*f1*
f4*f5+64*x2*x5*x4*x7*f0*f7^2*f3-16*x2*x5^2*x3*f0*f4*f3*f7+32*x2*x5*x3*x7*f0*f7
^2*f2+224*x4^4*f7^4*f0*f3+480*x4^4*f7^3*f4*f5*f1+756*x4^4*f7*f4*f5^4+264*x4^4*
f7^3*f2*f5*f3+28*x4^4*f7^3*f2*f4^2-16*x4^4*f7^2*f6^2*f4*f1+44*x4^4*f7^2*f5*f4^
3-36*x4^4*f7*f6*f4^2*f5^2-240*x4^4*f7^2*f6*f5^2*f1+8*x4^4*f7^2*f3*f4^2*f6+80*
x4^4*f7^3*f3*f1*f6-84*x4^4*f7^2*f3^2*f5*f6-160*x4^4*f7^3*f0*f6*f4-488*x4^4*f7^
2*f5^2*f3*f4+216*x4^4*f7*f3*f5^3*f6-744*x4^4*f7^2*f5^3*f2-908*x4^4*f7^3*f0*f5^
2-332*x4^4*f7^4*f2*f1+336*x4^4*f7^2*f0*f6^2*f5-76*x4^4*f7^3*f3^2*f4+36*x4^4*f7
^3*f2^2*f6-144*x4^4*f7^2*f2*f4*f5*f6+360*x4^3*x1*f6*f4*f5^2*f7*f1-80*x2*x4^3*
f7^2*f0*f5^3+48*x4^3*x2*f6*f4^2*f7*f5*f3-56*x2*x4^3*f1^2*f7^3*f6+12*x1^2*x4*x7
*f4^3*f3*f5-36*x1^2*x4*x7*f7*f4*f3^3-480*x1^2*x4*x7*f0*f6*f5^2*f4+48*x1^2*x4*
x7*f5*f4^2*f1*f6-144*x1^2*x4*x7*f3*f5*f6*f2*f4+144*x1^2*x4*x7*f0*f6*f4*f3*f7+
12*x2*x4*x5^2*f7*f2*f1*f5+36*x1^2*x4*x6*f5^3*f2^2-180*x1^2*x4*x6*f3*f5^3*f1+16
*x1*x4^2*x6*f1*f7*f4^2*f6-8*x1*x4^2*x6*f7*f4^3*f3-108*x1*x4^2*x6*f5^4*f2-24*x1
*x4^2*x2*f7^2*f2^3*f6-32*x1^2*x4^2*f0*f3^2*f6^2*f7+648*x1^2*x4^2*f5^3*f1*f6*f3
-36*x1^2*x4^2*f5^3*f3^2*f4-108*x1*x4^2*x2*f5^5*f1-8*x1*x4*x5*x7*f1*f7*f4^2-4*
x1*x4*x5*x7*f7*f2^2*f5-48*x1*x4*x5*x7*f5^2*f2*f4+52*x1*x4*x5*x7*f7*f5*f1*f3+80
*x1*x7*x3*x4*f4*f6*f7*f2*f3+48*x4*x3^2*x8*f7^3*f0*f4-40*x4*x3^2*x8*f7^2*f2*f4*
f5-16*x4*x3^2*x8*f7*f5*f6^2*f1-156*x4*x3*x7^2*f1*f7^2*f5+260*x4*x3*x7^2*f7*f5^
2*f3-432*x4*x3*x7^2*f5^2*f6*f4-64*x4*x3*x7^2*f4*f7^2*f2-72*x4*x3*x7^2*f7*f3*f4
*f6-88*x4*x3*x7^2*f7*f5*f2*f6-16*x1*x4^2*x3*f6*f4^3*f7*f2+108*x1*x4^2*x3*f5^5*
f2-160*x3*x4^2*x1*f0*f6^2*f1*f7^2+8*x1^2*x4*x6*f0*f4^3*f7-24*x1^2*x4*x6*f7*f2^
2*f4^2+24*x1^2*x4*x6*f0*f5^3*f4+8*x4*x3*x5^2*f7*f2^2*f5+4*x4*x3*x5^2*f7*f2*f3*
f4-96*x1*x4*x3*x6*f2*f5^3*f4-16*x4*x1*x3*x6*f0*f6*f4^2*f7+12*x1^2*x4*x5*f4^3*
f5*f1-72*x1^2*x4*x5*f3^2*f2*f5^2+432*x1^2*x4*x5*f3*f0*f5^3-144*x1^2*x4*x5*f3*
f0*f5*f6*f4+36*x1^2*x4*x5*f3^3*f5*f4-96*x1*x4*x5^2*f0*f5^2*f4+12*x1*x4*x5^2*f2
*f3*f5*f4+124*x1*x4*x5^2*f1^2*f7*f5-28*x1*x4*x5^2*f2*f7*f1*f4-72*x1*x4*x6*x7*
f5^3*f2-48*x1*x4*x6*x7*f5*f4^3-288*x1*x4*x6*x7*f5^2*f6*f1+8*x1*x4*x2*x6*f3^2*
f7*f1*f6-16*x1*x4*x2*x6*f2^2*f6*f7*f3-32*x1*x4*x2*x6*f0*f6^2*f1*f7+72*x1^2*x4^
2*f5^2*f4^2*f1*f6-16*x2*x4*x6^2*f2*f7^2*f1-108*x2*x4*x6^2*f3*f5^2*f4+8*x2*x4*
x6^2*f7*f2*f5*f3-40*x2*x4*x6^2*f0*f7*f5^2+232*x2*x4*x6^2*f1*f4*f7*f5-224*x2*x4
^2*x8*f7^2*f0*f5*f6+56*x2*x4^2*x8*f7^2*f3^2*f5-16*x2*x4^2*x3*f1*f6^2*f7*f4^2+
32*x4*x3*x5^2*f1*f7*f4^2-432*x4*x3*x5^2*f0*f6*f5^2-36*x4*x3*x5^2*f3*f5*f4^2+12
*x4*x3*x5^2*f2*f5^2*f4+72*x4*x3*x5^2*f4*f6*f1*f5+52*x4*x3*x5^2*f1*f7*f3*f5-80*
x4*x3*x5^2*f0*f5*f7*f4-44*x4*x3*x5^2*f1^2*f7^2-16*x4*x3*x5^2*f7*f2*f1*f6+48*x1
^2*x3*x6*f0*f3^2*f7*f5-528*x4^2*x1*x2*f0*f5*f4*f7^2*f3-160*x4^2*x1*x2*f0*f6*f5
*f7^2*f1-8*x3*x6*x1*x2*f7*f3^4+4*x2*x1^2*x3*f7*f3^5-84*x2*x1*x3^2*f3^2*f5^2*f4
^2+40*x2*x1*x5*x6*f2^2*f5*f4-232*x1*x2*x3^2*f5*f6*f7*f4*f1^2-64*x1*x2*x3^2*f0*
f5^3*f2*f7-40*x2*x1*x3^2*f4^4*f6*f2+60*x2*x1*x3^2*f1^2*f4^2*f7^2+84*x2*x1*x3^2
*f4^2*f5^3*f1+12*x2*x1*x3^2*f5^2*f4^3*f2+16*x2*x1*x3*x7*f7^2*f2*f3*f1+40*x2*x1
*x3*x7*f0*f4^2*f7*f5+48*x2*x1*x3*x7*f0*f5^2*f3*f7+16*x1*x2^2*x7*f1*f7^2*f2^2+
16*x1*x2^2*x7*f6*f1^2*f4*f7-16*x2*x1^2*x3*f2^2*f3*f7^2*f1-8*x1^4*f7*f2^4*f4+12
*x1^4*f4*f7*f1^3*f5+64*x1^4*f6^2*f0^3*f7-4*x1*x7*x3*x8*f7^2*f3*f1-4*x1*x7*x5*
x8*f7*f2*f3-12*x5*x8*f7*x2*x7*f1*f5-8*x6*x8*f7^2*x2*x7*f0+8*x6*x8*f7*x2*x7*f3*
f4+4*x2*x7*x6*x8*f7*f2*f5+8*x7^2*x8*f7*x2*f3*f5+24*x1*x7*x4*x8*f7^2*f2*f3-24*
x2*x7^2*x1*f7*f3*f4*f2-48*x2*x7^2*x1*f7*f2^2*f5+48*x2*x7^2*x1*f7^2*f0*f2-16*x1
*x7^2*x2*f0*f6*f7*f3+4*x1*x7*x2*x8*f5*f7*f2*f3+2*x1^2*x7^2*f4^2*f2*f5-16*x3*x7
^2*x2*f3^2*f5*f7-32*x4*x7^2*x2*f0*f6^2*f7+16*x4*x7^2*x2*f4*f6*f2*f7-12*x1*x7^2
*x6*f5^2*f2-4*x1*x7^2*x6*f7*f2*f3-24*x3*x7^2*x5*f6*f2*f5+24*x1*x7^2*x4*f7^2*f2
^2-8*x2*x7^2*x3*f4^3*f6+8*x2*x7^2*x3*f2^2*f7^2+24*x1*x7^2*x8*f7*f2*f5+16*x1^2*
x7^2*f0*f6*f7*f2-8*x3*x7^2*x8*f7*f3*f6-8*x3*x7^2*x8*f2*f7^2+32*x3^2*x7*x8*f7*
f6*f2*f5-4*x6*x7^2*x2*f7*f3^2-32*x3*x8*f7*x2*x7*f0*f6^2-12*x3*x8*f7^2*x2*x7*f2
*f3+8*x2*x7*x3*x8*f7*f5^2*f2+4*x7^2*x6^2*f7*f2-8*x7*x6*x3*x8*f7*f2*f6+8*x4*x7^
2*x2*f3^2*f7*f6-8*x5*x7^2*x2*f7*f2*f3+8*x1*x7*x3*x8*f7*f2*f3*f6+16*x3*x7^2*x6*
f0*f7^2+8*x3*x7^2*x6*f4^2*f6+6*x7^2*x5^2*f2*f5+2*x1^2*x7^2*f4^3*f3+4*x7^2*x5*
x8*f7*f3+8*x7*x5*x6*x8*f7*f2+12*x1*x7^2*x5*f1*f5^2-8*x1*x7^2*x5*f7*f2^2+16*x4^
2*x7^2*f7^2*f6*f1-8*x4*x7^2*x5*f7*f1*f6+24*x4^2*x7*x8*f7^2*f2*f6-8*x4*x7*x5*x8
*f7*f2*f6+40*x4*x7*x6*x8*f7*f4*f5+8*x4*x7*x2*x8*f7*f6*f2*f5+16*x4*x7*x3*x8*f7*
f6^2*f2-20*x3*x7*x5*x8*f7*f2*f5+24*x3^2*x7^2*f5*f6^2*f2+20*x1*x7^2*x2*f4*f5^2*
f2-8*x1*x7^2*x2*f4^2*f6*f2+8*x4*x7^2*x2*f5*f6*f1*f7+8*x2*x7^2*x4*f7^2*f2*f3+4*
x7*x8^3*f7^2+72*x3^3*x4*f3^2*f5^3*f7+76*x3^3*x4*f1*f7*f5^4+84*x3^2*x1*x4*f4*f5
^4*f2-180*x3^2*x1*x4*f3*f5^3*f4^2-48*x3^2*x1*x4*f2^3*f6*f7^2+40*x3^2*x1*x4*f7^
2*f2^2*f4^2+64*x3^2*x1*x4*f7*f2*f4^2*f3*f6-16*x3^2*x1*x4*f0*f6*f5*f1*f7^2-584*
x3^2*x1*x4*f1*f5^2*f7*f6*f2+216*x3^2*x1*x4*f3*f5^3*f6*f2-168*x3^2*x1*x4*f7*f2*
f5*f4^3-60*x3^2*x1*x4*f7^2*f3*f4^2*f1-88*x3^2*x1*x4*f7*f3^2*f6*f2*f5-108*x3^2*
x1*x4*f3^2*f5^4+32*x1^2*x2*x7*f7*f2*f4^2*f1+56*x1^2*x2*x7*f7*f2^3*f5+48*x2^2*
x3*x5*f0*f6*f5*f4^2-92*x2^2*x3*x5*f5^2*f4^2*f1+12*x1^3*x3*f5^3*f2^3-48*x2^2*x1
^2*f0*f6*f5*f2*f1*f7+64*x2^2*x1^2*f0^3*f7^3+48*x2*x1*x3*x6*f0*f6*f5*f4^2+72*x2
*x1*x3*x6*f0*f4^3*f7+84*x2*x1*x3*x6*f3^2*f5*f4^2-40*x2*x1*x3*x6*f0*f5^3*f4-28*
x2*x1*x3*x6*f7^2*f1^2*f3+32*x2*x1*x3*x6*f4^3*f1*f6+96*x3*x6*x1*x2*f0*f6*f4*f2*
f7-64*x3*x6*x1*x2*f6^2*f0^2*f7-32*x2*x1*x3*x6*f4^4*f3+24*x2^2*x1*x5*f1^2*f6*f7
*f2-16*x2^2*x1*x5*f0*f6*f7*f2^2-112*x2*x1^2*x7*f0*f4^2*f3*f7+8*x2*x1^2*x7*f4^2
*f6*f2^2+24*x2*x1^2*x7*f3^2*f5^2*f2-72*x2*x1*x6^2*f1^2*f7*f5+60*x2*x1*x6^2*f3*
f5^2*f1+32*x2*x1*x3^2*f0*f6*f7^2*f2^2-32*x2^2*x3*x7*f0*f5*f2*f7^2-68*x2^2*x3*
x7*f7*f1*f5^2*f3-16*x2^2*x3*x7*f5*f4^4+16*x2^2*x3*x7*f0*f6*f4^2*f7-8*x2^2*x3*
x7*f2*f4^2*f6*f5+64*x2^2*x3*x7*f0^2*f7^3-144*x2^2*x3*x7*f0*f6*f5^3+72*x2^2*x3*
x7*f4*f5^2*f1*f6-64*x2^2*x3*x7*f0*f4*f3*f7^2+48*x1*x3^2*x7*f1*f6^2*f4^2+80*x2*
x3*x4^2*f7*f3^2*f5*f6*f4-256*x2*x3*x4^2*f7*f2*f5*f4^2*f6-1600*x2*x3*x4^2*f0*f6
*f5^3*f7+8*x2*x3*x1*x6*f7*f2^3*f6+48*x2^2*x3*x6*f0*f5*f7^2*f1+544*x1*x3*x4*x6*
f0*f5*f2*f7^2+320*x1*x3*x4*x6*f7*f0*f5^2*f4-256*x1*x3*x4*x6*f7^3*f0^2+8*x1^2*
x3^2*f3^2*f5*f6*f2*f4+64*x2*x3*x4*x5*f7*f2*f4^3-96*x2*x3*x4*x5*f2*f5^3*f4+72*
x2*x3*x4*x5*f5^2*f4^2*f3+240*x2*x3*x4*x5*f0*f5^2*f4*f7-104*x2*x3*x4*x5*f7*f2*
f1*f5*f6-52*x2*x3*x4*x5*f7*f3*f5^2*f1-56*x2*x3*x4*x5*f2*f7^2*f1*f4-80*x2*x3*x4
*x5*f0*f6*f1*f7^2+288*x2*x3*x4*x5*f0*f6*f5*f3*f7+28*x2*x3*x4*x5*f1^2*f7^2*f5+
64*x4*x5*x2*x3*f0*f6^2*f7*f2-64*x1^2*x3*x5*f0*f6^2*f1*f4+80*x1^2*x3*x5*f0*f5*
f3*f7*f2+80*x1^2*x3*x5*f1*f4*f0*f7*f5-128*x1^2*x3*x5*f4*f0^2*f7*f6-12*x1^2*x3*
x5*f3*f5^2*f2^2-8*x2^2*x3*x4*f7^2*f2^3*f6+32*x3^2*x4*x2*f6^2*f2^2*f7*f4-24*x1^
2*x3^2*f4^2*f6*f3^3+288*x1^2*x3^2*f0*f6^2*f5*f2*f4+8*x1^2*x3^2*f6^2*f2^2*f3*f4
-56*x1*x3*x4*x7*f7^2*f3*f4*f1-16*x1*x3*x4*x7*f7*f3^3*f6+480*x1*x3*x4*x7*f2*f5^
2*f4*f6-32*x1*x3*x4*x7*f1*f0*f7^3-24*x1*x3*x4*x7*f7^2*f3^2*f2+28*x1*x3*x4*x7*
f7*f3^2*f4*f5+64*x1*x3*x4*x7*f7^2*f2^2*f4+144*x1*x3*x4*x7*f7*f0*f5*f4*f6+8*x1*
x3*x4*x7*f7*f2^2*f6*f5-48*x2^2*x3*x7*f1*f7*f3*f6*f4+8*x2^2*x3*x7*f7*f2*f4^3+88
*x3^2*x4^2*f7^2*f3^2*f5*f4-1416*x3^2*x4^2*f7^2*f0*f5^3-48*x3^2*x4^2*f7*f6^2*f2
*f3*f5+72*x3^2*x4^2*f7*f3^2*f5^2*f6+432*x3^2*x4^2*f7*f6^2*f4*f1*f5-216*x3^2*x4
^2*f3*f6^2*f4*f5^2-520*x4^2*f7*f2*f6*f4*f5^2*x3^2-20*x3^2*x2*x5*f4^2*f5^2*f2-4
*x3^3*x5*f7^2*f3^2*f1-4*x3^3*x5*f1*f7*f3*f5^2+8*x3^2*x5*x8*f7*f3^2*f5-12*x3^2*
x5*x8*f7*f1*f5^2-12*x3^2*x6*x8*f7^2*f2*f3+12*x3^2*x6*x8*f7^2*f1*f4-12*x3^2*x2*
x8*f7^2*f1*f4^2+4*x3^2*x2*x8*f7^2*f2*f3*f4-8*x2*x8*f7^2*f2^2*x3^2*f5-8*x3^2*x2
*x8*f7*f3^2*f5^2-36*x1*x5*x3*x7*f5^2*f2*f3+8*x1*x5*x3*x7*f5^2*f1*f4-64*x1*x5*
x3*x7*f0*f7*f3*f5+16*x1^2*x5^2*f1^2*f2*f7-16*x1^2*x5^2*f4*f0*f5*f2-144*x1^2*x5
^2*f6*f5*f0^2-4*x1^2*x5^2*f2*f1*f4^2+24*x1^2*x5^2*f0*f5^2*f1+48*x1^2*x5^2*f4*
f0^2*f7+4*x2*x5*x6^2*f7*f2*f1-16*x1*x5^2*x2*f7*f0*f2*f3+136*x1*x5*x2*x6*f1*f5*
f0*f7+8*x3*x5*x6^2*f7*f3*f1+4*x5*x3*x2*x7*f7*f3^3+16*x3*x5*x6*x7*f4^3-32*x3*x5
*x6*x7*f7*f1*f4+8*x1*x5*x3*x8*f7*f2*f1*f6-12*x1^2*x5*x6*f1*f7*f2^2+16*x1*x5*x2
*x6*f1*f4^3+16*x2^2*x5^2*f7*f6*f0^2-8*x2^2*x5^2*f7*f0*f4*f2-4*x4*x5^2*x2*f3^2*
f7*f2-64*x2*x7*x1*x5*f7*f4*f0*f3-96*x2^2*x5*x7*f0*f7*f5*f3+32*x1^2*x5*x7*f0*f4
*f2*f7-20*x1^2*x5*x6*f3^2*f2*f4-12*x1*x5*x4*x6*f7*f3^2*f2-160*x1*x5*x4*x6*f7*
f0*f5*f3-12*x1*x5^2*x7*f2^2*f5+8*x3*x5*x1*x7*f3^2*f7*f2-16*x3*x5*x1*x7*f4*f2*
f3*f6-16*x3^2*x5*x8*f7^2*f0*f4+24*x3*x5*x7^2*f3*f6*f4-16*x1^2*x5*x6*f1^2*f4*f6
-8*x1^2*x5*x6*f0*f4^3-24*x1^2*x5*x6*f5^2*f1^2+4*x3^2*x5*x8*f7^2*f3*f1+8*x3*x5*
x6^2*f7*f2^2+28*x3*x6*x1*x5*f7*f1^2*f5+24*x3*x6*x1*x5*f7*f2*f1*f4-16*x1^2*x5^2
*f7*f2^2*f0-24*x1^2*x5^2*f0*f4^2*f3-16*x1^2*x5^2*f1*f3*f0*f7+36*x1^2*x5^2*f0*
f3^2*f5+8*x1^2*x5^2*f3^2*f4*f1+20*x1^2*x5^2*f4*f1^2*f5-8*x3*x6*x2*x5*f6*f7*f1^
2-36*x1^2*x5^2*f1*f2*f3*f5+48*x1*x5*x6*x7*f0*f6*f4+16*x1*x5*x6*x7*f1*f4*f5+36*
x1*x5*x6*x7*f2*f3*f5-64*x2*x5*x6^2*f1*f4*f5+48*x1^2*x5*x6*f3^2*f5*f1+48*x1^2*
x5*x6*f0*f5^2*f2+24*x1^2*x5*x6*f3*f1*f4^2+12*x1^2*x5*x6*f3*f5*f2^2+16*x1*x5*x3
*x7*f0*f7^2*f1+12*x2*x5*x7^2*f3*f5*f4-4*x5*x1*x2*x7*f3*f7*f2^2+4*x1*x5^2*x7*f1
*f4^2-8*x2^2*x5*x8*f7*f4*f0*f5+12*x2^2*x5*x6*f1^2*f5*f7-32*x2*x5*x3*x6*f0*f5*
f3*f7+12*x1*x5^2*x4*f1*f5*f4^2+64*x3*x6*x1*x5*f7^2*f0^2-32*x3*x6*x1*x5*f7*f4*
f0*f3-16*x3*x6*x1*x5*f1*f7*f0*f6-8*x1*x5*x7^2*f1*f4*f6-16*x1*x5*x7^2*f7*f0*f4-\
8*x1*x5*x2*x6*f7*f2^3-4*x1*x5^2*x8*f7*f2*f1+8*x1*x5*x6*x8*f7*f3*f1-4*x1*x5*x3*
x8*f7^2*f1^2-8*x4*x5^2*x2*f6*f7*f1^2+16*x2*x5^2*x4*f0*f7^2*f1-16*x1^2*x5*x6*f1
*f4*f0*f7+32*x1^2*x5*x6*f5*f0^2*f7-20*x1^2*x5*x6*f1^2*f3*f7-8*x2*x5*x6*x8*f7*
f0*f5+8*x1*x5^2*x6*f0*f4^2+8*x1^2*x5*x6*f2^2*f4^2-44*x1*x5*x2*x7*f3*f5*f2*f4-4
*x1*x5*x2*x8*f7*f4*f3*f1+4*x1*x5*x7^2*f4^2*f3+8*x2*x5^2*x6*f1*f4^2+24*x2*x5*x4
*x7*f3*f7*f1*f6-16*x3*x6*x2*x5*f0*f6*f7*f2-72*x1*x5*x6*x7*f0*f5^2+4*x2^2*x5^2*
f7*f1*f3*f2-4*x2^2*x5^2*f4^3*f1-4*x2^2*x5^2*f7*f0*f3^2-12*x2^2*x5^2*f7*f0*f5*
f1-16*x1*x5*x6*x7*f2*f4^2-12*x1*x5*x6*x7*f3^2*f4+8*x1*x5*x6*x7*f7*f2*f1+8*x1*
x5*x4*x7*f3^3*f7-16*x3*x5*x4*x7*f7^2*f2^2+72*x1*x5*x3*x7*f0*f5^3+8*x1*x5*x3*x7
*f3*f4^3-16*x2^2*x5*x6*f0*f6*f7*f1+8*x1*x5*x4*x6*f7*f1^2*f6+6*x1^2*x5^2*f2^3*
f5+128*x4^2*x1*x6*f0*f4^2*f7^2+36*x4^2*x1*x6*f7^2*f2*f3^2-72*x4^2*x1*x6*f5^2*
f4^3+164*x4^2*x1*x6*f7*f2*f5*f4^2+96*x4^2*x1*x6*f7*f3^2*f4*f5-120*x4^2*x1*x6*
f7^2*f4*f3*f1+8*x4^2*x1*x6*f1*f7*f3*f5*f6-336*x4^2*x1*x6*f0*f5^3*f7-432*x4^2*
x1*x6*f5^3*f6*f1+180*x4^2*x1*x6*f4*f5^3*f3-104*x4^2*x1*x6*f7^2*f2^2*f4+80*x4^2
*x1*x6*f0*f7^3*f1+48*x4^2*x1*x6*f0*f6*f7^2*f2-28*x4^2*x1*x7*f7^2*f3^3+368*x4^2
*x2*x7*f0*f5^2*f7^2+24*x2*x7*f7^2*f6*f2^2*x4^2+36*x4^2*x2*x7*f7^2*f3^2*f4-176*
x4^2*x2*x7*f0*f3*f7^3+104*x4^2*x2*x7*f4*f7*f6*f2*f5+40*x4^2*x2*x7*f7*f3^2*f5*
f6+8*x4^2*x2*x7*f6*f5^2*f1*f7+176*x4^2*x2*x7*f0*f6*f4*f7^2-340*x4^2*x2*x7*f4*
f5*f7^2*f1+80*x4^2*x2*x7*f2*f7^3*f1+468*x4^2*x2*x7*f7*f2*f5^3-160*x4^2*x2*x7*
f0*f6^2*f5*f7+56*x4^2*x2*x7*f7^2*f2*f3*f5+176*x4^2*x2*x7*f5*f4^3*f7-216*x4^2*
x2*x7*f4*f5^4-216*x4^2*x2*x7*f4^2*f5^2*f6+108*x4^2*x2*x7*f7*f5^2*f3*f4-168*x4^
2*x2*x7*f2*f7^2*f4^2-64*x4^2*x2*x7*f7^2*f3*f1*f6-368*x4^2*x3*x7*f7*f3*f5*f4*f6
+24*x4^2*x3*x7*f2*f7^2*f3*f6-72*x4^2*x3*x7*f4^2*f7^2*f3+48*x4^2*x3*x7*f2^2*f7^
3-112*x4^2*x3*x7*f0*f6*f5*f7^2+272*x4^2*x3*x7*f0*f4*f7^3+32*x4^2*x3*x7*f7^2*f5
*f3^2-668*x4^2*x3*x7*f7^2*f2*f4*f5-1296*x4^2*x3*x7*f6*f5^3*f4+700*x4^2*x3*x7*
f7*f5^2*f4^2+816*x4^2*x3*x7*f7*f5^3*f3-648*x4^2*x3*x7*f7^2*f5^2*f1+232*x4^2*x3
*x7*f1*f7^2*f4*f6-48*x4^2*x3*x7*f7*f2*f5^2*f6-768*x4^3*x7*f5^2*f7^2*f2+792*x4^
3*x7*f7*f5^3*f4+72*x4^3*x7*f7^3*f2*f3+16*x4^3*x7*f7^2*f4^3+96*x4^3*x7*f0*f6^2*
f7^2-24*x4^3*x7*f3^2*f7^2*f6-48*x4^3*x7*f4*f6*f2*f7^2-32*x4^3*x7*f5*f6*f1*f7^2
+440*x4^3*x7*f0*f5*f7^3-1296*x4^3*x7*f6*f5^4+144*x4^3*x7*f7*f5^2*f3*f6-316*x4^
3*x7*f7^2*f5*f3*f4-24*x4^3*x7*f7*f4^2*f6*f5-64*x1^2*x2*x5*f7^2*f0*f1^2-96*x1^3
*x7*f2*f5*f1*f6*f3-16*x1^3*x7*f1^3*f7^2-32*x2*x1^2*x3*f0*f6^2*f4^2*f2-64*x2*x1
^2*x3*f6*f0^2*f7^2*f2+24*x2*x1^2*x3*f4^3*f2^2*f6+160*x2*x1^2*x3*f0*f6*f5^2*f2*
f4-144*x2*x1^2*x3*f6*f2*f5^2*f3*f1+256*x2*x1^2*x3*f0*f6^2*f5*f1*f4+128*x2*x1^2
*x3*f3^2*f6*f4*f1*f5-16*x2*x1^2*x3*f0*f6*f4^2*f1*f7-64*x2*x1*x3*x4*f7*f4^4*f2-\
80*x2*x1*x3*x4*f1^2*f7^3*f2+96*x2*x1*x3*x4*f0*f7^3*f2^2+96*x2*x1*x3*x4*f4^2*f5
^3*f2-512*x3*x4*x1*x2*f2*f6*f1*f7*f4*f5-208*x3*x4*x1*x2*f0*f6*f5*f4*f3*f7+12*
x2*x1*x5*x7*f4^2*f3^2+36*x2*x1*x4*x5*f4^2*f3^2*f5-144*x2*x1*x4*x5*f0*f6*f5*f4^
2+24*x1*x2*x4*x5*f7*f3^2*f4*f2+4*x1*x2*x4*x5*f7*f3^2*f1*f5+64*x1*x2*x4*x5*f0*
f6*f7*f4*f2+48*x1*x2*x4*x5*f0*f6*f1*f7*f5-40*x1*x2*x4*x5*f1*f6*f7*f3*f2+20*x2*
x1^2*x7*f4^3*f3^2-24*x1^2*x3*x6*f4^2*f6*f2^2+8*x2^2*x3*x5*f1*f7^2*f2^2-64*x2^2
*x3*x5*f6^2*f0^2*f7-36*x2*x3*x4*x5*f7^2*f3^2*f1+8*x2*x3*x4*x5*f7*f3^3*f5-8*x2*
x3*x4*x5*f2^2*f7^2*f3-4*x2*x3*x4*x5*f7*f3^2*f4^2-4*x2^2*x3*x5*f7*f2^2*f4^2-32*
x2^2*x3*x7*f0*f6*f1*f7^2-72*x2^2*x3*x7*f7*f2*f1*f5*f6+36*x1^2*x3*x7*f4*f5^2*f2
*f3+48*x1^2*x3*x7*f3^2*f6*f2*f5+12*x1^2*x3*x7*f4^2*f3^2*f5-12*x2*x4*x1*x3*f2^3
*f5*f7^2-96*x1^2*x3*x6*f3^2*f6*f1*f5-20*x1^2*x3*x6*f4^3*f3^2+8*x1^2*x3*x6*f4^4
*f2+80*x1^2*x3*x6*f0*f4^2*f7*f3-208*x1*x3*x4*x6*f7*f1*f5^2*f3+16*x1*x3^2*x4*f6
^2*f2^2*f7*f3+32*x1*x3*x5*x7*f7*f2*f5*f1+48*x1*x3*x5*x7*f2^2*f6*f5-32*x1*x3*x5
*x7*f1*f6*f4^2+12*x1*x3*x5*x7*f3^2*f5*f4+80*x1*x3*x5*x7*f0*f5*f4*f6-16*x1*x3*
x5*x7*f7*f2^2*f4+24*x3*x4*x1^2*f4*f2^2*f7*f3*f6-40*x1^2*x3*x4*f7^2*f2^2*f3^2+
28*x1^2*x3*x4*f7*f2*f4^3*f3-288*x1^2*x3*x4*f6*f2^2*f5^2*f4-96*x1^2*x3*x4*f4^2*
f5*f6*f2*f3+120*x1^2*x3*x4*f5^2*f2^2*f7*f3+128*x1^2*x3*x4*f0*f4^3*f7*f5+76*x1^
2*x3*x4*f1*f5*f7^2*f2^2+60*x1^2*x3*x4*f1*f5^2*f7*f3^2-288*x1^2*x3*x4*f0*f5^2*
f4*f3*f7+76*x1^2*x3*x4*f3^2*f5*f7*f2*f4-76*x3^2*x1*x4*f7^2*f3^2*f1*f5+208*x3^2
*x1*x4*f7*f2^2*f4*f6*f5+528*x3^2*x1*x4*f6^2*f7*f1^2*f5+132*x3^2*x1*x4*f7*f2^2*
f5^3-32*x3^2*x1*x4*f0*f6*f5*f4^2*f7+144*x3^2*x1*x4*f5^2*f7^2*f1^2-60*x3^2*x1*
x4*f4*f5^2*f7*f2*f3+64*x3^2*x1*x4*f0*f6*f5^2*f3*f7-112*x3^2*x1*x4*f0*f5^2*f2*
f7^2+168*x3^2*x1*x4*f6*f2*f5^2*f4^2+104*x3^2*x1*x4*f1*f6*f7^2*f2*f3-40*x3^2*x1
*x4*f1^2*f6*f7^2*f4-56*x3^2*x1*x4*f3*f5*f6*f1*f4*f7+80*x3^2*x1*x4*f0*f5*f4*f3*
f7^2-72*x3^2*x1*x4*f3^2*f6*f5^2*f4-12*x3^2*x1*x4*f7*f4^4*f3+4*x3^2*x1*x4*f4^2*
f5^2*f1*f7-480*x3^2*x1*x4*f0*f6^2*f5*f2*f7-4*x1^2*x6^2*f2^2*f5*f4+12*x1^2*x6^2
*f1*f5^2*f2-48*x1^2*x6^2*f6*f1^2*f5+24*x1^2*x6^2*f1*f5*f3*f4+32*x1^2*x6^2*f1*
f6*f2*f4-12*x1^4*f0*f5^3*f2^2+4*x1^4*f2*f4^2*f3^3+8*x1^4*f7*f2^3*f3^2+4*x1^4*
f1*f4^4*f2+40*x1^2*x3^2*f1*f5^2*f7*f2*f3-40*x1^2*x3^2*f0*f7^2*f3*f5*f1+72*x1^2
*x3^2*f1^2*f5*f7*f6*f3-12*x1^2*x3^2*f7*f2*f5*f1*f4^2+24*x1^2*x3^2*f0*f5*f7^2*
f2^2-192*x1^2*x3^2*f0*f5^3*f1*f7-192*x1^2*x3^2*f0*f6*f7*f3*f5*f2-72*x1^2*x3^2*
f3^2*f5*f4*f7*f1-264*x1^2*x3^2*f0*f5^2*f2*f7*f4-8*x3^2*x2*x6*f1^2*f5*f7^2+24*
x3^2*x2*x6*f5*f4^4+288*x3^2*x2*x6*f0*f6*f5^3-72*x2*x6*f1*f6*f7*f2*x3^2*f5+48*
x3^2*x2*x6*f0*f5*f2*f7^2-4*x2*x6*f7*f4*f2*f3*x3^2*f5+112*x2*x6*x3^2*f0*f6*f5*
f7*f3+48*x3^2*x2*x6*f4*f5^3*f2+32*x3^2*x2*x6*f0*f4*f3*f7^2-24*x3^2*x2*x6*f7^2*
f2*f1*f4+16*x3^2*x2*x6*f0*f6*f4^2*f7-304*x3^2*x2*x6*f1*f5^2*f4*f6-16*x3^2*x2*
x6*f2*f5*f4^2*f6+192*x3^2*x2*x6*f0*f6^2*f5*f4-32*x3^2*x2*x6*f0^2*f7^3-12*x3^2*
x2*x6*f7*f3^2*f4^2+16*x3^2*x2*x6*f0*f6*f1*f7^2+120*x2*x6*x3^2*f0*f5^2*f7*f4+56
*x1*x4*x5*x6*f7*f2^2*f4+144*x1*x4*x5*x6*f0*f6*f5*f4-216*x1*x4*x5*x6*f0*f5^3-\
180*x1*x4*x5*x6*f7*f2*f1*f5+216*x1*x4^2*x8*f7*f5^3*f2-64*x1*x4^2*x8*f7^3*f2*f1
+96*x1*x4*x5*x8*f7*f0*f5^2+28*x1*x4*x5*x8*f7^2*f2*f1-12*x1*x4*x5*x8*f7*f2*f3*
f5-16*x1*x4*x5*x8*f7*f1*f4*f5-96*x1*x4*x6*x8*f7*f1*f5^2-28*x1*x4*x6*x8*f7^2*f3
*f1-12*x1*x4*x6*x8*f7*f2*f4*f5-24*x2*x4*x5*x6*f7*f2*f3*f4-424*x2*x4*x5*x6*f0*
f7*f4*f5+24*x2*x4*x5*x6*f5^2*f2*f4+72*x2*x4*x5*x6*f5^3*f1-36*x2*x4*x5*x6*f7*f1
*f4^2-8*x2^2*x4^2*f7^3*f2^3-72*x1^2*x4*x5*f7*f3^2*f1*f4+176*x1^2*x4*x5*f0*f4^2
*f3*f7-32*x2*x4*x3*x6*f7*f3^2*f5*f4+64*x2*x4*x3*x6*f0*f6*f2*f7^2-40*x1*x4*x6*
x7*f2*f7^2*f1+48*x1*x4*x6*x7*f2*f5*f4*f6-392*x1*x4*x6*x7*f0*f5^2*f7-164*x1*x4*
x6*x7*f7*f2*f3*f5-160*x1*x4*x6*x7*f0*f6*f7*f4+56*x1*x4*x6*x7*f7*f2*f4^2+24*x1*
x4*x6*x7*f3^2*f7*f4+120*x1*x4*x6*x7*f5^2*f3*f4+172*x1*x4*x6*x7*f1*f7*f4*f5-96*
x3*x4^2*x1*f6^2*f2*f1*f5*f7+4*x1*x4^2*x7*f7*f4^4+32*x3*x4^2*x1*f6^2*f2^2*f7*f4
+240*x3*x4^2*x1*f3*f5*f6*f7*f2*f4-32*x3*x4^2*x1*f3*f6^2*f4*f1*f7-72*x1*x4^2*x5
*f2*f5^3*f4+64*x4^2*x3*x7*f0*f6^3*f7-16*x4^2*x3*x7*f3^2*f6^2*f7-96*x4^2*x3*x7*
f1*f7*f6^2*f5-160*x4*x3*x5*x7*f1*f7*f4*f6+144*x4*x3*x5*x7*f3*f5*f4*f6-192*x4*
x3*x5*x7*f0*f4*f7^2-28*x4*x3*x5*x7*f3*f7^2*f1-36*x4*x3*x5*x7*f7*f5^2*f1+208*x4
*x3*x5*x7*f7*f2*f4*f5-36*x2^2*x4*x6*f1*f5^4+24*x1*x4^2*x6*f7*f2^2*f6*f5+72*x1*
x4^2*x6*f2*f5^2*f4*f6-16*x1*x4^2*x6*f1*f7*f6^2*f2-32*x2*x4^2*x5*f7*f2^2*f6*f5+
32*x2^2*x4^2*f6*f4*f5*f7*f2*f3+64*x3*x4^2*x2*f6^2*f2^2*f7*f5-48*x2*x4*x3*x7*f5
*f4^3*f6+216*x2*x4^2*x3*f6*f2*f5^4+112*x4*x1*x3*x6*f0*f6*f1*f7^2+24*x1*x4*x3*
x6*f3*f5^2*f4^2-64*x3*x6*x1*x4*f6^2*f7*f1^2+40*x4^2*x3*x5*f7*f6*f4*f3^2-416*x1
^2*x4*x6*f7^2*f0^2*f5-224*x1^2*x4*x6*f7*f1*f5*f3^2+60*x1^2*x4*x6*f7^2*f1*f2^2+
80*x1^2*x4*x6*f7*f2*f3^2*f4-32*x1^2*x4*x6*f7*f2^2*f3*f5-128*x1^2*x4*x6*f7^2*f0
*f2*f3-108*x1^2*x4*x6*f7*f2*f4*f1*f5+560*x1^2*x4*x6*f7*f0*f4*f3*f5+36*x2*x6^2*
x3*f3*f7*f1*f5+48*x3*x6*x5*x7*f6*f1*f5+16*x1*x6*x3*x7*f0*f6*f3*f7+16*x2^2*x6^2
*f0*f5*f7*f3+16*x1*x6*x4*x7*f3*f7*f1*f6-12*x2^2*x6*x7*f5^3*f1-60*x4*x6*x7^2*f7
*f3*f5+60*x4*x6*x7^2*f1*f7^2-32*x4*x6*x7^2*f7*f4^2-16*x3*x6^2*x1*f7^2*f0*f1-8*
x2*x7*f7*f6*f2^2*x3*x6-8*x3^2*x6*x7*f4^3*f6-40*x3^2*x7*x6*f5*f7*f3^2-36*x4*x6^
2*x5*f5^2*f2-36*x1*x6*x7*x8*f7*f1*f5-24*x1*x6*x2*x8*f7*f4*f0*f5-16*x1^2*x6*x7*
f0*f6*f4^2-40*x1^2*x6*x7*f1*f4*f7*f2+48*x1^2*x6*x7*f4*f6*f1*f3-32*x1^2*x6*x7*
f0*f6*f7*f1+80*x1^2*x6*x7*f0*f4*f3*f7-12*x1^2*x6*x7*f4*f5*f2*f3+12*x1^2*x6*x7*
f4^2*f1*f5-12*x1^2*x6*x7*f3^2*f7*f1+8*x1^2*x6*x7*f0*f5^2*f4-144*x1^2*x6*x7*f0*
f6*f5*f3+32*x7*x8*f7*f3*f5*x3*x6+12*x3*x6*x7*x8*f1*f7^2-8*x6*x3*x2*x8*f7*f4^2*
f3+16*x2*x8*f7^2*x3*x6*f0*f4+16*x2*x6*x5*x7*f7*f0*f4+24*x2*x6*x5*x7*f1*f5^2-16
*x6^2*x3*x7*f7*f0*f6+24*x3*x6^2*x7*f6*f2*f5+32*x1*x7*f7^2*f0*f2*x3*x6-4*x3^2*
x6^2*f3*f7*f2*f5-4*x6^2*x5^2*f1*f4-12*x6*x5^2*x7*f1*f5-12*x6^2*x5*x7*f2*f5-12*
x6*x5*x7^2*f1*f7-24*x1*x6*x2*x7*f7*f4*f2^2+32*x1*x6*x4*x7*f0*f7^2*f3-48*x1*x6*
x7^2*f6*f1*f5+28*x1*x6*x7^2*f7*f1*f4-88*x1*x6*x7^2*f7*f0*f5+72*x1*x6^2*x4*f5^3
*f1-264*x4^2*x6*x7*f5^2*f7*f3+16*x4^2*x6*x7*f6^2*f1*f7-8*x4^2*x6*x8*f7^2*f3*f4
+12*x4*x6*x5*x8*f7*f2*f5+12*x4*x6^2*x8*f7*f3*f5-8*x4*x6*x2*x8*f7^2*f2*f3+8*x6^
2*x3*x8*f7*f3*f4-24*x1^3*x2*f1*f5^2*f2*f3*f4-36*x1^3*x2*f1^2*f5^2*f4^2+32*x1^3
*x2*f0*f6*f3^2*f1*f7+384*x1^2*x3*x4*f3*f6*f4*f1*f5^2-1792*x3*x4*x1^2*f7*f0^2*
f6^2*f5-64*x3*x4*x1^2*f0*f6*f2^2*f7^2+32*x3*x4*x1^2*f2*f6*f1^2*f7^2-20*x3^2*x7
^2*f7*f6*f1*f5-56*x3^2*x7^2*f0*f7^2*f5-24*x3^2*x7^2*f6^2*f3*f4+64*x3^2*x7^2*f0
*f6^2*f7-56*x3^2*x7^2*f5*f4^2*f6+40*x3^2*x6^2*f1*f4*f7*f5+144*x3^2*x6^2*f5^2*
f6*f1-12*x3^2*x6^2*f7*f2^2*f6-8*x3^2*x6^2*f7*f6*f3*f1-192*x6^2*f7*f0*f5^2*x3^2
+8*x3*x8*f7*x2*x7*f6*f3^2-12*x3*x8*f7*x2*x7*f4^3+8*x7^2*x6*x8*f7*f4-16*x7^2*x4
*x8*f7^2*f3-12*x7^2*x2*x8*f7*f4^2-4*x7^3*x6*f7*f3-4*x7^3*x5*f4*f5+4*x7^3*x1*f5
*f4^2-16*f7^2*x2*x8^2*x3*f0*f6+12*f7^2*x2*x8^2*x3*f1*f5-4*f7*x2*x8^2*x6*f3*f5-\
4*f7*x2*x8^2*x5*f3*f4+4*f7*x2*x8^2*x3*f3*f5^2+8*f7*x3^2*x8^2*f3*f5*f6-4*f7*x3^
2*x8^2*f4^2*f6+2*f7^2*x3^2*x8^2*f3*f4+2*f7^2*x3^2*x8^2*f2*f5+24*f7*x2*x8^2*x4*
f4*f5^2+16*f7^2*x2*x8^2*x4*f2*f5-48*f7^3*x2*x8^2*x4*f0+24*f7^2*x2*x8^2*x4*f3*
f4+8*f7^2*x2*x8^2*x5*f0+4*f7*x2^2*x8^2*f3*f5*f4+28*f7^2*x2^2*x8^2*f0*f5-4*f7^2
*x2^2*x8^2*f1*f4+8*f7*x2*x8^2*x3*f3*f6*f4+8*f7*x2*x8^2*x7*f4*f5+8*x7^3*x2*f7*
f3*f4-8*x7^3*x2*f4^2*f6-8*x7^3*x2*f4*f5^2-16*x7^3*x2*f0*f7^2+16*x7^3*x2*f7*f2*
f5-16*x7^3*x3*f7*f2*f6+28*x7^3*x3*f7*f3*f5-48*x7^3*x3*f4*f5*f6-8*x7^3*x3*f1*f7
^2+32*x7^3*x4*f7*f4*f5-144*x7^3*x4*f6*f5^2-24*x7^3*x4*f2*f7^2+8*x7^3*x5*f7*f2+
8*x7^3*x6*f4*f6-8*x7^3*x1*f7*f2*f4+12*x7^3*x1*f7*f1*f5-12*x7^3*x1*f3*f5^2+24*
x7^3*x1*f6*f2*f5-168*x7^2*x4*x8*f7*f5^2-20*x7^3*x8*f7*f5-64*x7^2*x3*x8*f7*f4*
f5+16*x2^2*x7^2*f0*f7^2*f3-8*x2^2*x7^2*f2*f7^2*f1-8*x2^2*x7^2*f7*f6*f2^2+8*x2^
2*x7^2*f2*f7*f4^2+6*x2^2*x7^2*f2*f5^3+24*x2*x7^2*x3*f5^2*f6*f2-4*x5*x8*f7*x2*
x7*f3^2+4*x2^2*x8*f7*x7*f3^2*f5-24*x1^2*x7^2*f4*f2*f3*f6+8*x1^2*x7^2*f4^2*f1*
f6-16*x1^2*x7^2*f3*f7*f1*f4+72*x1^2*x7^2*f3*f5*f1*f6+12*f7*x3*x8^2*x7*f5^2-8*
f7^3*x3^2*x8^2*f0+12*f7*x3^2*x8^2*f4*f5^2+8*f7*x2*x8^2*x3*f5*f4^2-12*f7*x6*x8^
2*x7*f5+4*f7*x5*x8^2*x6*f3+4*f7*x5*x8^2*x7*f4+16*f7^3*x4^2*x8^2*f2-28*f7^2*x4^
2*x8^2*f4*f5+36*f7*x4^2*x8^2*f6*f5^2+12*f7*x4*x8^2*x5*f4*f5-12*f7^2*x4*x8^2*x6
*f3-36*f7*x4*x8^2*x6*f5^2-16*f7^2*x4*x8^2*x7*f4+24*f7*x4*x8^2*x7*f5*f6+36*f7*
x3*x8^2*x4*f5^3-12*f7^2*x3*x8^2*x4*f4^2-12*f7^3*x3*x8^2*x4*f1+36*f7^2*x3*x8^2*
x4*f3*f5+8*f7^2*x3*x8^2*x4*f2*f6-8*f7*x3*x8^2*x6*f3*f6-12*f7*x3*x8^2*x6*f4*f5+
4*f7*x3*x8^2*x5*f4^2-4*f7*x3*x8^2*x5*f3*f5-4*f7^2*x3*x8^2*x7*f3+4*f7^2*x3*x8^2
*x6*f2+4*f7*x7^2*x8^2*f6-4*f7^2*x4*x8^2*x5*f2-16*x2^2*x5*x7*f0*f7*f4^2-16*x2^2
*x6*x7*f2*f5^2*f4+36*x2^2*x6*x7*f5*f4^2*f3+16*x2^2*x1*x3*f0*f5*f7^2*f2^2+80*x2
^2*x1*x3*f7*f1*f5*f2^2*f6+56*x2^2*x1^2*f3^2*f5^2*f4*f1+64*x2^2*x1^2*f6*f4^2*f0
^2*f7+16*x2^2*x1^2*f3^2*f7*f6*f1^2-32*x2^2*x1^2*f5*f2*f0^2*f7^2-72*x2*x1*x3*x4
*f4^2*f3^2*f5*f6-144*x2*x1*x3*x4*f5^3*f6*f2^2-88*x2*x1*x3*x4*f0*f5*f3^2*f7^2+
32*x2*x1*x3*x4*f4*f0^2*f7^3-32*x2*x1*x3^2*f0*f6*f4^2*f3*f7-16*x2*x1*x3^2*f0*f5
^4*f4+8*x2*x1*x3^2*f4^4*f3*f5+64*x1*x2*x3^2*f7*f2*f5^2*f1*f4-8*x2^2*x1*x8*f7^2
*f1^2*f4+16*x2^2*x1*x8*f7*f1*f4*f3*f5-16*x2^2*x1*x8*f7*f1*f5^2*f2+8*x2^2*x1*x8
*f7*f1^2*f6*f5-48*x2*x1*x3*x8*f5^2*f7*f0*f4+28*x2*x1*x3*x8*f5^2*f7*f3*f1+192*
x1*x2*x3^2*f5^2*f0^2*f7^2+192*x1*x2*x3^2*f0*f5^2*f6*f1*f7-48*x1*x2*x3^2*f0*f5*
f1*f7^2*f4-80*x1*x2*x3^2*f0*f6*f5*f7*f3^2-4*x1*x2*x4*x5*f3^4*f7-64*x2*x1^2*x4*
f0*f3^2*f6*f7*f4-160*x2*x1^2*x4*f0*f6*f7^2*f1*f2-144*x2*x1^2*x4*f5*f4^2*f1*f6*
f3-48*x3^2*x4^2*f7^3*f1*f3*f4-376*x3^2*x4^2*f7^2*f2*f5^2*f3-2336*x3^2*x4^2*f7*
f0*f6^2*f5^2-32*x3^2*x4^2*f7^3*f0*f5*f3+32*x3^2*x4^2*f7^2*f0*f6*f4*f5+400*x3^2
*x4^2*f7^2*f1*f3*f5*f6+160*x3^2*x4^2*f7^2*f4^2*f6*f1+192*x3^2*x4^2*f7^2*f2^2*
f6*f5+84*x3^2*x1*x4*f5^2*f4^4+8*x3^2*x1*x4*f7^3*f3*f1^2-256*x3^2*x2*x4*f0*f6*
f4*f3*f7^2-224*x2*x4*x3^2*f0*f6*f5*f2*f7^2+12*x2*x1^2*x4*f4*f7*f3^4-48*x2*x1^2
*x4*f5^2*f4^3*f1-96*x2*x1^2*x4*f0*f4^2*f6*f2*f7+44*x2*x1*x3*x8*f5*f7*f1*f4^2-\
24*x2*x1*x7^2*f1^2*f7^2+120*x2*x1*x7^2*f3*f5*f7*f1-20*x2*x1*x7^2*f7*f1*f4^2+32
*x2*x1*x6^2*f4^2*f1*f5+56*x2*x1*x6^2*f0*f5^2*f4+12*x2*x1*x3*x5*f4^3*f3^2+32*x4
^2*x1*x2*f6*f4*f7^2*f1^2+832*x2*x1*x4^2*f7*f3*f5^3*f1+1840*x4^2*x1*x2*f0*f2*f7
^2*f5^2+60*x2*x1^2*x4*f4^3*f3^2*f5+8*x1*x2*x3^2*f3^4*f5*f7+840*x2*x1*x4*x6*f0*
f4^2*f7*f5+8*x2*x1*x4*x6*f7*f1^2*f6*f5+128*x2*x1*x5*x6*f3*f5*f1*f4-192*x2*x1*
x5*x6*f0*f4^2*f5-72*x2*x1*x5*x6*f2*f5^2*f1-32*x2*x1*x5*x6*f3*f4^2*f2+4*x2^3*x7
*f5^2*f4^2*f2+12*x2^2*x3*x7*f1*f7^2*f3^2+4*x2^2*x5*x7*f2*f5*f4^2+32*x2^2*x5*x7
*f7*f2*f5*f1+12*x2^2*x5*x7*f7*f3*f4*f1-4*x2^2*x1^2*f4^5*f1-8*x2^2*x1^2*f7^2*f1
*f2^3+24*x2^2*x1^2*f0*f5^4*f1+4*x2^2*x1^2*f7*f2*f3^4-4*x2^2*x1^2*f4*f5^3*f1^2-\
144*x2^2*x1^2*f6*f5^3*f0^2-20*x2^2*x6*x7*f7^2*f1^2+4*x3*x4^3*f1*f7^3*f4^2-28*
x4^2*x3*x8*f7^3*f2*f3+184*x4^2*x1*x6*f7^2*f2*f1*f5+4*x4^2*x3*x7*f7^3*f3*f1-36*
x4^2*x5*x7*f7^2*f2*f3-128*x1^2*x4^2*f7*f3^3*f5*f4+32*x1^2*x4^2*f2*f6^2*f7*f1*
f3-76*x4*x3*x5*x6*f7*f2*f3*f5+48*x4*x3*x5*x6*f4^3*f5+56*x4*x3*x5*x6*f2*f7^2*f1
+24*x4*x3*x5*x6*f2^2*f7*f6-48*x4*x3*x5*x6*f7*f2*f4^2+72*x4*x3*x5*x6*f5^3*f2+
144*x4*x3*x5*x6*f6*f5^2*f1-800*x4*x3*x5*x6*f0*f5^2*f7+8*x4*x3*x5*x6*f7*f3*f1*
f6+256*x4*x3*x5*x6*f0*f6*f7*f4+12*x4*x1*x3*x6*f7*f3^2*f4^2+260*x1*x4^2*x6*f4*
f5^2*f1*f7+240*x2*x4^3*f5^2*f4^3*f7-160*x2*x4^3*f0*f6*f2*f7^3-24*x1^2*x2*x3*f2
*f4^2*f5*f1*f6-12*x2^2*x1*x5*f1^3*f7^2+12*x2^2*x4*x6*f7^2*f1*f3^2-20*x2^2*x4*
x6*f7*f2^2*f5^2-4*x2^2*x3*x6*f7*f2*f3^2*f5+20*x2^2*x1*x6*f7*f2^3*f5+28*x2^2*x1
*x6*f1^2*f2*f7^2+64*x1^3*x4*f7^3*f1*f0^2+44*x1^3*x4*f3^2*f1*f4^2*f7-88*x1^3*x4
*f5*f7^2*f1^3+192*x3*x4^3*f0*f6^3*f7*f5-128*x3*x4^3*f0*f6^2*f4*f7^2-456*x4^3*
x3*f7*f3*f5^2*f6*f4-112*x3*x4^3*f7^2*f6*f4*f3^2+984*x4^3*x3*f4^2*f5^3*f7+288*
x3*x4^3*f7^3*f2^2*f5+224*x3*x4^3*f0*f5*f7^3*f4+256*x3*x4^3*f0*f6*f7^3*f3-288*
x3*x4^3*f1*f5^2*f7*f6^2-48*x3*x4^3*f3^2*f6^2*f5*f7-1272*x3*x4^3*f4*f5^2*f2*f7^
2-208*x3*x4^3*f7^2*f3*f4^2*f5+296*x3*x4^3*f1*f7^3*f3*f5+76*x3*x4^3*f7^3*f3*f4*
f2-848*x3*x4^3*f5^3*f7^2*f1-1296*x4^3*x3*f4*f5^4*f6+96*x4^3*x3*f1*f6^2*f7^2*f3
+12*x4^3*x3*f7^2*f4^4+196*x4^3*x1*f1*f7^3*f3^2-96*x4^3*x1*f7^3*f2^2*f3+48*x4^3
*x1*f7^2*f2^2*f6*f4+12*x4^3*x1*f7^2*f4^2*f3^2+1244*x4^3*x1*f1^2*f7^3*f5+16*x4^
3*x1*f0*f6*f4^2*f7^2-544*x4^3*x1*f0*f4*f7^3*f3-156*x4^3*x1*f7^2*f3^3*f5-96*x4^
3*x1*f0*f6^2*f7^2*f2-240*x4^3*x1*f0*f6*f7^3*f1-208*x4^3*x1*f1*f7^2*f6*f2*f5-24
*x4^3*x1*f5*f4^2*f2*f6*f7-40*x4^3*x1*f1*f7^2*f5*f4^2+1024*x4^3*x1*f0^2*f7^4+
264*x4^3*x1*f7^2*f5^2*f2^2+180*x4^3*x1*f1*f5^4*f7-192*x4^3*x1*f3*f4^2*f5^2*f7-\
288*x4^3*x1*f0*f6*f5^3*f7+624*x4^3*x1*f0*f6*f5*f7^2*f3+380*x4^3*x1*f5*f4*f7^2*
f2*f3+288*x4^3*x1*f7*f3^2*f5^3-80*x4^3*x1*f1*f7^2*f3*f6*f4-16*x4^3*x1*f7^2*f4^
3*f2+20*x4^3*x1*f1*f7^3*f2*f4+96*x4^3*x1*f6^2*f7^2*f1^2-1144*x4^3*x1*f7^2*f3*
f5^2*f1+24*x4^3*x1*f7^2*f3^2*f2*f6+784*x4^3*x1*f0*f5^2*f7^2*f4-2192*x4^3*x1*f0
*f5*f7^3*f2-54*x4^2*x5^2*f5^2*f3*f4-60*x4^2*x5^2*f2*f7^2*f1-624*x4^2*x5^2*f0*
f5^2*f7+132*x4^2*x5^2*f4*f5*f7*f1+20*x4^2*x5^2*f7*f2*f3*f5+56*x4^2*x1*x5*f2*f5
*f7*f1*f6+4*x3*x6^2*x1*f7*f3^2*f2-48*x3^2*x6*x7*f1*f5*f6^2-24*x2^2*x6*x7*f3*f7
*f2*f4+8*x1*x6*x3*x7*f3*f5*f4^2+24*x1*x6^2*x3*f5*f6*f2^2-16*x1*x6^2*x3*f4^2*f6
*f1-80*x2*x7*x1*x6*f7^2*f0*f1-8*x1*x6*x2*x7*f7*f2*f3^2+64*x2*x6*x3*x7*f0*f7^2*
f3-48*x2*x6*x3*x7*f5^2*f1*f6+4*x7*x8*f7*f4^2*x3*x6-4*x5*x8*f7*f2*f4*x3*x6-4*x2
*x8*f7^2*f2^2*x3*x6+72*x4*x6*x7^2*f4*f5*f6+16*x4*x6*x2*x7*f2^2*f7^2-16*x4*x6*
x2*x7*f3*f6*f2*f7-24*x4^2*x6*x7*f7*f5*f2*f6-16*x4^2*x6*x7*f4*f6*f3*f7-64*x1^2*
x6*x7*f0^2*f7^2+32*x3*x6*x7^2*f7*f1*f6-4*x7^2*f7*f2*f5*x3*x6+68*x3*x6*x7^2*f4*
f5^2-24*x3*x6*x7^2*f7*f3*f4+12*x2*x6^2*x7*f5^2*f2+4*x3*x6^2*x2*f3^3*f7-16*x1^2
*x7^2*f6*f7*f1^2+8*x1^2*x7^2*f7*f4*f2^2+8*x1^2*x7^2*f3^2*f7*f2+8*x1^2*x7^2*f1*
f0*f7^2+72*x1^2*x7^2*f0*f5*f7*f3+12*x1^2*x7^2*f5^2*f2*f3-16*x1^2*x7^2*f5^2*f1*
f4-80*x1^2*x7^2*f0*f6*f5*f4-4*x1^2*x7^2*f3^2*f5*f4-24*x1^2*x7^2*f5*f6*f2^2-16*
x1^2*x7^2*f2*f5*f7*f1+12*x1*x7^2*x3*f5^3*f2+16*x1*x7^2*x3*f2^2*f6*f7-12*x1*x7^
2*x2*f5^3*f1-4*x2^2*x7^2*f3*f7*f2*f5-16*x2^2*x7^2*f0*f6*f7*f4-4*x2^2*x7^2*f3^2
*f7*f4-8*x1*x7^2*x5*f2*f4*f5+8*x1*x7^2*x6*f2*f4*f6-80*x4*x8*f7^2*x2*x7*f0*f6+
20*x4*x8*f7^2*x2*x7*f3^2+32*x4*x8*f7*x2*x7*f3*f5^2+40*x4*x8*f7^2*x2*x7*f2*f4-\
12*x5*x8*f7*x2*x7*f2*f4+16*x5*x8*f7*x2*x7*f0*f6+4*x1*x7^2*x2*f7*f3^3+16*x2^2*
x8*f7^2*x7*f0*f4-8*x2^2*x8*f7^2*x7*f2^2-16*x2^2*x8*f7*x7*f0*f5*f6+12*x2^2*x8*
f7*x7*f1*f5^2-8*x2^2*x8*f7*x7*f4^2*f3+16*x3*x8*f7*x2*x7*f2*f4*f6+24*x3*x8*f7*
x2*x7*f6*f1*f5-112*x3^2*x4*x6*f7*f3*f5*f4^2+88*x3^2*x4*x6*f1*f5*f7^2*f3+1696*
x3^2*x4*x6*f0*f6*f7*f5^2-88*x3^2*x4*x6*f7^2*f2*f6*f1-256*x3^2*x4*x6*f0*f6^2*f7
*f4+80*x3^2*x4*x6*f7*f2*f4^2*f6-32*x3^2*x4*x6*f0*f7^2*f6*f3+20*x3^2*x4*x6*f7^2
*f2*f3*f4+264*x3^2*x4*x6*f0*f7^2*f4*f5+300*x3^2*x4*x6*f5^3*f4^2+184*x3^2*x4*x6
*f4*f7*f6*f1*f5+16*x3^2*x4*x6*f1^2*f7^3+108*x3^2*x4*x6*f3*f5^4+96*x3^2*x4*x6*
f2*f5*f4*f6^2+8*x2^3*x1*f3^3*f4*f7*f2+16*x2^3*x1*f0*f4*f2^2*f7^2-60*x2^2*x4^2*
f7^2*f2^2*f5*f4-24*x2^2*x4^2*f7^2*f0*f6*f4*f3-88*x2^2*x4^2*f7^3*f0*f4*f2+272*
x2^2*x4^2*f7^2*f0*f5^2*f3+6*x2^2*x4^2*f7^2*f3^3*f4+192*x2^2*x4^2*f7^3*f6*f0^2+
144*x1^2*x3*x5*f2*f5*f1*f6*f3-48*x1^2*x3*x5*f1*f0*f7^2*f2+144*x1*x3*x6^2*f0*f5
^3+16*x1*x3*x6^2*f3*f4^3-32*x1*x3*x6^2*f3*f6*f2*f4+12*x1*x3*x6^2*f7*f2*f5*f1-\
12*x4*x5*x1*x3*f7*f4^3*f1+4*x1*x3*x5^2*f4^2*f2*f3-144*x1*x3*x4*x6*f1*f5^4+144*
x1*x3*x4*x6*f6*f2*f5*f4^2-192*x1*x3*x4*x6*f1*f4*f6*f5^2+28*x1*x3*x4*x6*f7*f3^3
*f5-432*x1*x3*x4*x6*f0*f6*f5^3+32*x1*x3*x4*x6*f7^2*f2^2*f3-88*x1*x3*x4*x6*f7^2
*f1*f4*f2+80*x1*x3*x4*x7*f7*f1*f6*f4^2+144*x1*x3*x4*x7*f5^3*f1*f6-48*x1*x3*x4*
x7*f3*f4^2*f5*f6+8*x1*x3^2*x5*f1^2*f7^2*f3+8*x1*x3^2*x5*f1*f7^2*f2^2+96*x1^2*
x3^2*f3^2*f5^2*f6*f1+144*x1^2*x3^2*f0*f6^2*f5*f3^2-64*x2^2*x3^2*f0*f6^2*f2*f7*
f4-8*x2^2*x3^2*f3*f5*f6*f7*f2^2-16*x2^2*x3^2*f1*f6*f7*f4^2*f3+16*x2^2*x3^2*f6^
2*f7*f1^2*f4+16*x2^2*x3^2*f2*f6^2*f7*f1*f3-8*x1*x3^2*x2*f7*f2*f6*f3^3+216*x1*
x3*x4^2*f6*f5^4*f1+320*x1*x3*x4^2*f0*f6^2*f5*f3*f7-72*x1*x3*x4^2*f2^3*f7^3+112
*x2*x3*x4^2*f7^2*f2^2*f4*f6+432*x2*x3*x4^2*f0*f6*f4^2*f7^2+448*x2*x3*x4^2*f7^2
*f2*f1*f5*f6-864*x2*x3*x4^2*f0*f6*f5*f3*f7^2+208*x2*x3*x4^2*f0*f6*f1*f7^3+160*
x2*x3*x4^2*f7^2*f3*f5^2*f1-160*x2*x3*x4^2*f0*f5*f2*f7^3+784*x2*x3*x4^2*f7*f2*
f5^3*f4-112*x2*x3*x4^2*f3*f5*f6^2*f7*f1-4*x1^2*x3*x5*f2*f3^2*f4*f5-4*x1^2*x3*
x5*f7*f3^3*f1-12*x1*x3*x5*x6*f3^2*f4^2-16*x1*x3*x5*x6*f4^3*f2+32*x1*x3*x5*x6*
f1*f4^2*f5+4*x1*x3*x5*x6*f3*f5*f2*f4-16*x1^2*x3*x4*f1*f4^4*f7+1152*x1^2*x3*x4*
f0*f6^2*f5^2*f2+4*x1^2*x3^2*f7*f3^4*f4-32*x1^2*x4^2*f1*f6*f7^2*f2^2+16*x1^2*x4
^2*f0*f4^3*f6*f7+108*x1^2*x4^2*f3*f5^4*f2+64*x2*x4*x5^2*f0*f4^2*f7-216*x2*x4*
x5^2*f0*f5^3+72*x2*x4*x5^2*f4*f5^2*f1-24*x2*x4*x5^2*f2*f5*f4^2+108*x1*x4^2*x5*
f5^4*f1+16*x4^2*x1*x5*f3*f6*f4*f1*f7-24*x1^2*x4*x6*f6*f2^2*f5*f4+56*x4^2*x3^2*
f7^2*f3*f4*f2*f6-16*x4^2*x3^2*f7*f2*f4^2*f6^2+264*x4^2*x3^2*f7*f2*f5^4+8*x3^2*
x4^2*f3^3*f7^2*f6-48*x4^2*x3^2*f3^2*f6^2*f7*f4+216*x4^2*x3^2*f6^2*f2*f5^3+4*x4
^2*x3^2*f7*f4^4*f6+32*x4^2*x3^2*f1*f6^3*f7*f3-576*x1*x4*x2*x6*f0*f5*f7^2*f1-48
*x1*x4*x2*x6*f7*f4^3*f1-16*x1*x4*x2*x6*f0*f3^2*f7^2+64*x1*x4*x2*x6*f6*f0^2*f7^
2-48*x1*x4*x2*x6*f0*f4*f7^2*f2-16*x1*x4*x2*x6*f7*f2*f4*f1*f6-12*x4*x3*x6^2*f3*
f7^2*f1-108*x4*x3*x6^2*f3*f5^3-704*x4*x3*x6^2*f0*f6*f5*f7-32*x4*x3*x6^2*f2*f7*
f3*f6-96*x4*x3*x6^2*f5^2*f4^2+252*x4*x3*x6^2*f7*f5^2*f1+124*x4*x3*x6^2*f7*f2*
f4*f5-32*x6^2*f7*f1*f4*x3*x4*f6+32*x2*x6*x3*x4*f0*f6^2*f7*f3-48*x2^2*x6*x4*f3*
f5*f7*f2*f4+16*x2^2*x6*x4*f0*f6*f5*f7*f3+32*x2^2*x4*x6*f0*f6*f1*f7^2-16*x1*x4*
x7^2*f1*f7^2*f3-92*x1*x4*x7^2*f7*f2*f5*f4-160*x1^2*x4*x7*f0*f4*f7^2*f2+64*x1^2
*x4^2*f6^3*f0^2*f7-24*x1^2*x4^2*f3*f5*f6*f7*f2^2-720*x1^2*x4^2*f0*f6*f5^3*f4+
544*x1^2*x4^2*f0*f6*f5*f4*f3*f7-96*x1^2*x4^2*f0*f6^2*f5*f1*f7-216*x1^2*x4^2*f3
*f5^2*f6*f2*f4+8*x1^2*x4^2*f7*f3^2*f1*f5*f6+32*x1^2*x4^2*f6^2*f7*f1^2*f4-64*x1
^2*x4^2*f0*f6^2*f4*f7*f2+4*x2^2*x4*x5*f7^2*f2^3+236*x1*x4*x2*x5*f1*f7*f2*f4*f5
+16*x4*x3*x6^2*f3*f7*f4^2-16*x4*x3*x5*x7*f7*f5*f3^2-680*x1^2*x4^2*f0*f5^3*f3*
f7-32*x1*x4*x3*x8*f7^2*f2*f1*f6+96*x1*x4^2*x8*f7^2*f2*f3*f5-48*x1*x4^2*x8*f7^2
*f0*f5^2+8*x1*x4^2*x8*f7^2*f1*f4*f5-304*x1^2*x4*x6*f7*f0*f6*f1*f5-4*x2*x4^2*x5
*f7*f3*f4^3+32*x4*x1*x2*x7*f0*f6*f1*f7^2+54*x2^2*x4^2*f5^5*f2-192*x3*x4*x1^2*
f0*f6*f3*f7^2*f1+496*x3*x4*x1^2*f0*f6*f5*f3^2*f7+12*x1^2*x6*x7*f5^2*f2^2-20*x1
^2*x6*x7*f4^2*f3^2-8*x2*x6^2*x4*f3^2*f7*f4+24*x2*x6*x7^2*f5*f4^2-32*x2*x7*x1*
x6*f7*f3*f0*f5-96*x3*x6^2*x1*f7*f3*f0*f5-16*x1^2*x6^2*f0*f4*f7*f2-28*x1^2*x6^2
*f1*f5*f0*f7-24*x1^2*x6^2*f0*f6*f5*f2+32*x1*x6^2*x2*f0^2*f7^2+12*x1*x6^2*x2*f2
^2*f5^2+8*x2^2*x6^2*f6*f7*f1^2+4*x2^2*x6^2*f3^2*f7*f2+8*x2*x6^2*x4*f3*f6*f1*f7
+16*x2*x6^2*x4*f0*f7^2*f3+36*x2*x6^2*x4*f5^3*f2-48*x1*x6*x3*x7*f7^2*f1^2+8*x1^
2*x6*x7*f4^3*f2-8*x1^2*x6*x7*f4*f6*f2^2-60*x1^2*x6*x7*f5^2*f3*f1-12*x1^2*x6*x7
*f3*f7*f2^2-24*x2*x6*x7^2*f7*f1*f5+16*x1*x6^2*x2*f0*f6*f7*f1-24*x1*x6*x3*x8*f7
*f0*f5^2+72*x1^2*x6^2*f0*f5^2*f3-30*x1^2*x6^2*f3^2*f5*f2+12*x1^2*x6^2*f7*f4*f1
^2-208*x2^2*x6*x7*f0*f5*f7*f4-12*x2^2*x6*x7*f5*f7*f2^2+16*x2^2*x6*x7*f7*f2*f1*
f6+36*x1^2*x6*x7*f3^3*f5+96*x1^2*x6*x7*f0*f5*f7*f2+6*x1^2*x6^2*f4*f3^3-4*x1^2*
x6^2*f4^3*f1-12*x1^2*x6^2*f0*f3^2*f7+48*x1^2*x6^2*f6*f0^2*f7+16*x1^2*x6^2*f1*
f3*f7*f2-4*x3^2*x8*f7*f4^3*x6+24*x1*x6^2*x7*f1*f5^2-16*x2*x6*x3*x8*f7*f1*f4*f6
+4*x1^2*x6^2*f2^3*f7-24*x1^2*x6^2*f0*f6*f4*f3-4*x1*x6*x3*x7*f7*f3^3+8*x2^2*x6*
x8*f7^2*f2*f1-16*x3*x6^2*x2*f0*f6*f7*f3+20*x1*x6*x7^2*f3*f5*f4-4*x1*x6^2*x8*f7
*f1*f4+16*x2*x6^2*x3*f4^2*f1*f7-12*x1*x6^2*x5*f2^2*f5+24*x1*x6^2*x8*f7*f0*f5+
16*x1*x6*x2*x7*f4*f7*f3*f1+4*x1*x6*x2*x8*f7*f4^2*f1-48*x4^3*x2*f1*f5*f7*f6^2*
f4+240*x2*x4^3*f7^2*f0*f6*f4*f5+176*x2*x4^3*f7^4*f0*f1-64*x2*x4^3*f7^2*f2*f4*
f3*f6+504*x2*x4^3*f7*f2*f5^4-832*x2*x4^3*f7^3*f0*f5*f3+296*x2*x4^3*f7^3*f1*f2*
f5-216*x4^3*x2*f4*f5^5+48*x2*x4^3*f7*f3^2*f5^2*f6+16*x2*x4^3*f7^2*f3*f4^3+112*
x2*x4^3*f7^3*f2^2*f4-440*x2*x4^3*f7^2*f4*f5^2*f1-96*x4^3*x2*f7^2*f6*f5*f3*f1+
72*x2*x4^3*f5*f6*f7^2*f2^2-216*x4^3*x2*f5^3*f4^2*f6+112*x2*x4^3*f7^3*f0*f4^2-\
28*x2*x4^3*f7^2*f3^2*f5*f4+72*x4^3*x2*f4*f5^3*f3*f7+136*x2*x4^3*f7^2*f2*f5^2*
f3+48*x2*x4^3*f7^3*f1*f3*f4-48*x2*x4^3*f7*f5^3*f6*f1-192*x2*x4^3*f7*f0*f6^2*f5
^2-380*x2*x4^3*f7^2*f2*f5*f4^2+168*x2*x4^3*f7*f2*f5^2*f4*f6-8*x4^3*x2*f1*f4^2*
f7^2*f6-100*x3*x4^3*f1^2*f7^4-96*x3*x4^3*f2*f5*f4*f6^2*f7+12*x3*x4^3*f7^2*f3^2
*f5^2-432*x4^3*x3*f1*f6*f7^3*f2+8*x4^3*x3*f7^3*f3^3+896*x3*x4^3*f1*f7^2*f6*f4*
f5+8*x3*x4^3*f2*f7^2*f4^2*f6-2848*x3*x4^3*f0*f6*f5^2*f7^2+56*x3*x4^3*f3*f5*f6*
f2*f7^2+216*x3*x4^3*f7*f2*f5^3*f6-192*x4^3*x3*f0*f7^4*f2+864*x4^3*x3*f7*f3*f5^
4+48*x4^3*x3*f6^2*f2^2*f7^2+16*x2*x3^2*x4*f7^2*f3*f4^2*f2+8*x1*x3^2*x6*f7^2*f2
^3-128*x1*x3^2*x6*f6*f0^2*f7^2-192*x1^2*x3*x4*f0*f6*f4^2*f3*f7+180*x1^2*x3*x4*
f3*f5^4*f1+288*x1^2*x3*x4*f0*f6^2*f5*f3*f4+36*x1*x3*x7*x8*f7*f5^2*f1+48*x1*x3*
x7*x8*f7*f5*f2*f4-64*x1*x3*x7*x8*f7*f0*f5*f6+16*x1*x3*x7*x8*f7*f1*f4*f6-12*x1*
x3*x6*x8*f7*f2*f3*f5+156*x1*x3*x4*x8*f7*f2*f5^2*f4-8*x1*x3*x2*x8*f7^2*f1*f4*f2
+16*x1*x3*x2*x8*f5*f7^2*f1^2+12*x1*x3*x2*x8*f7*f3*f5*f2*f4-12*x1*x3*x2*x8*f5^2
*f7*f2^2-44*x1^2*x3*x7*f5^2*f4^2*f1-128*x1^2*x3*x7*f6^2*f0^2*f7-36*x2*x3*x6*x7
*f2*f7^2*f1+48*x2*x3*x6*x7*f5*f4^3-24*x2*x3*x4*x7*f7^2*f3^3+12*x2*x3*x4*x7*f7^
2*f2^2*f5-4*x2^2*x3*x7*f7*f3^3*f5+12*x1*x3^2*x2*f5^4*f2^2+40*x2*x3*x7^2*f3*f7*
f4^2-64*x2*x3*x7^2*f0*f7^2*f4-48*x2*x3*x7^2*f5^2*f4^2-60*x2*x3*x6^2*f4*f5^2*f2
-144*x2*x3*x6^2*f0*f6*f5^2+32*x1*x3^2*x4*f0*f6*f3^2*f7^2-48*x1*x3^2*x4*f4^3*f6
*f3*f5-56*x2*x3*x4*x7*f7*f3^2*f5^2+76*x2*x3*x4*x7*f1^2*f7^3, x1^4*f3^6-8*x1^4*
f1*f6*f5*f2^3-8*x1^2*x2^2*f6*f4^3*f1^2-16*x1*x2^2*x6*f1^3*f7^2+120*x4^2*x3*x6*
f7*f3*f4^2*f5-184*x4^2*x3*x6*f7^2*f2^2*f5+72*x4^2*x3*x6*f1*f7^2*f4^2-16*x4^2*
x3*x6*f0*f7^3*f2+32*x1^3*x2*f0*f6*f5*f2^2*f4+32*x1^3*x2*f0*f6*f4^2*f2*f3+8*x1^
4*f0*f4^4*f2+20*x1*x4*x5*x7*f7*f2*f5*f1+48*x1*x4*x5*x7*f0*f5^3+24*x1^2*x4*x5*
f2*f3^2*f4*f5+4*x1*x4^2*x6*f7*f4^3*f2-16*x1^3*x2*f2^2*f5*f1*f6*f3+2*x1^2*x2^2*
f7*f1^3*f5^2+4*x1^2*x2^2*f1*f3^4*f7-32*x1^2*x2^2*f6^2*f4^2*f0^2+4*x1^2*x2*x6*
f5^2*f2^3-16*x3^3*x4*f7*f3^3*f5*f6+48*x3^3*x4*f6*f5^4*f1+8*x2*x3*x4*x8*f7^2*f2
^2*f5+72*x2*x3*x4*x8*f7*f1*f5*f4*f6+16*x1*x3*x2*x7*f5^2*f4^2*f1-16*x1*x3*x2*x7
*f5*f4^3*f2-8*x2^2*x7*x8*f7*f5^2*f0-80*x1*x4*x3*x6*f0*f6*f5*f2*f7+24*x3^2*x4*
x7*f6*f5^3*f2+16*x1^2*x2*x6*f0*f5^2*f4*f2-32*x1^2*x2*x6*f0*f6*f4*f3^2+16*x1^3*
x6*f6*f2^3*f3-48*x1^2*x2*x4*f0*f5^2*f4^3+192*x4^2*x3*x8*f7*f5^2*f6*f2+112*x4^2
*x3*x8*f7^2*f5^2*f1-168*x4^2*x7*x8*f7^3*f0-72*x2*x3*x4*x6*f1*f5^4+4*x2^4*f2^2*
f4^2*f5^2+16*x2^2*x1*x3*f6^2*f4^2*f1^2+16*x3^2*x1*x6*f7*f2^2*f4^2-24*x5^2*x4*
x6*f2*f3*f5+36*x5^2*x4*x6*f7*f2*f1-8*x6^2*x2*x8*f7*f1*f4-4*x2^3*x7*f5*f4^3*f2+
8*x2^3*x7*f5^2*f4^2*f1+12*x2^2*x1*x4*f1*f4*f7^2*f2^2+224*x2^2*x1*x4*f6*f5^2*f0
^2*f7-160*x4^2*x2^2*f0*f5*f4*f3*f7^2+16*x3^3*x4*f7*f3^2*f4*f5^2+32*x2^2*x3*x5*
f6*f0^2*f7*f5-16*x2^2*x3*x5*f7*f6*f1*f0*f4+32*x2*x3*x1*x6*f4*f0^2*f7^2-4*x2^3*
x6*f1*f4*f3*f5^2-4*x3*x6^2*x8*f7*f2*f4+16*x2*x5*x3*x6*f0*f4*f3*f7-8*x2*x5*x3*
x6*f3^2*f7*f1+4*x1*x5*x3*x6*f7*f2^3+10*x1^4*f3^3*f2^2*f5-4*x1*x2^2*x4*f7*f2*f5
*f3^3-8*x1*x2*x4*x5*f7*f3*f4*f2^2-8*x1^2*x2*x3*f2*f4^3*f6*f1+4*x2^2*x1*x5*f2*
f5*f1*f4^2+16*x2^2*x1*x5*f0*f3*f4*f7*f2-16*x3^2*x1*x7*f2^3*f7^2+48*x1^3*x6*f0*
f5^2*f2*f3-88*x1*x2*x4^2*f7*f2*f4*f5*f1*f6+16*x1^2*x2*x6*f0*f6*f5*f2*f3-4*x1*
x2^2*x7*f1*f5^2*f3*f4+8*x2^3*x3*f5^3*f2^2*f4-8*x2^3*x3*f0*f7*f4^4+180*x4^2*x3*
x8*f7^2*f2*f4*f5-28*x3^2*x4*x5*f7^2*f3^2*f1-32*x2^2*x1*x5*f5*f0^2*f4*f7+16*x2^
2*x1*x5*f1*f4^2*f0*f7+128*x1^3*x2*f6*f0^2*f7*f4*f2+32*x2^3*x7*f5*f0^2*f7^2-4*
x2^3*x7*f3*f5^3*f1-4*x2^3*x7*f1^2*f7^2*f3+4*x1*x4*x6*x7*f7^2*f1^2-208*x3*x4*x7
*x8*f7^2*f0*f6+36*x3*x4*x7*x8*f7^2*f1*f5+32*x1*x4*x6*x7*f7*f2^2*f5+48*x1*x4^2*
x3*f0*f4^3*f7^2+4*x2^3*x6*f1^2*f4*f7*f5+16*x1^2*x2*x7*f1^3*f7^2+48*x2^2*x1*x4*
f1^2*f4^2*f7*f6+12*x2^2*x1*x4*f7*f2*f3^2*f4^2+24*x3^2*x2^2*f0*f5*f4*f1*f7^2+96
*x3^2*x4*x6*f3*f5*f4^2*f6-12*x2*x4*x3^2*f3*f5*f7^2*f2^2-144*x3^2*x2*x4*f3*f5^2
*f1*f6^2+32*x1^4*f0*f6*f1^2*f7*f3+48*x3^3*x5*f6^2*f2*f5*f1-4*x3^3*x5*f7*f2*f1*
f5^2-16*x3^3*x5*f3^2*f7*f1*f6-32*x1^4*f6*f5*f3*f1^2*f2+12*x2^3*x6*f5*f4^2*f2*
f3+4*x2^3*x6*f7*f2^2*f3*f4+4*x2^3*x6*f7*f1*f4^2*f2+8*x1^4*f6*f2^4*f4-128*x1^2*
x2*x3*f0^3*f7^3-8*x2^3*x7*f0*f4^3*f7+36*x2^2*x1*x4*f3*f5^2*f2*f4^2-32*x2^2*x1*
x4*f0*f4^2*f1*f7^2-8*x2^2*x1*x5*f4^2*f6*f1^2+88*x4*x6*x3^2*f2*f5*f4^2*f7-96*x1
^4*f6*f5*f3*f0^2*f4+12*x1*x3^3*f5*f7^2*f3*f1^2+4*x3^3*x1*f7^2*f3^2*f2^2+8*x2*
x5*x3*x6*f0*f5*f2*f7+12*x1^4*f2^2*f3^2*f4^2-8*x6^2*x3*x8*f7*f1*f5+16*x6^2*x4*
x8*f7^2*f0-32*x3*x4*x1*x5*f7^2*f0^2*f5-8*x2^3*x6*f0*f5^2*f1*f7+16*x1^3*x6*f0*
f4^3*f3+32*x2*x5*x4*x7*f2*f0*f7^2+4*x3^2*x5^2*f7*f3^2*f1-8*x3^2*x5^2*f0*f4*f3*
f7-16*x1^3*x6*f1*f4^2*f3^2-16*x1^3*x6*f5*f2^2*f3^2-8*x2^3*x3*f1*f6*f4^4-224*x1
*x4^2*x2*f0*f6*f5^2*f2*f7-24*x1*x4^2*x3*f7*f2^2*f5^3+36*x2*x4*x6^2*f5*f4^2*f3+
20*x2*x4*x5*x6*f7*f3*f4*f1+4*x3^3*x5*f7*f3*f4^2*f2+8*x1^3*x6*f1*f3*f7*f2^2+64*
x1^3*x6*f6*f0^2*f4*f5+4*x6^3*x8*f7*f1+4*x6^2*x1*x7*f1*f4*f5-8*x6^2*x1*x7*f0*f5
^2-4*x6^2*x1*x7*f4^2*f2-40*x1^3*x2*f1*f4^2*f5*f2*f3-80*x2*x4*x7^2*f0*f6*f7*f5-\
84*x2*x4*x7^2*f7*f2*f5*f4-24*x2*x4*x7^2*f3*f7*f4^2-8*x1*x2^2*x7*f2*f4*f5*f1*f6
+24*x1*x2*x4*x5*f7*f2^3*f5+12*x1^2*x2^2*f7^2*f1^2*f2^2+8*x1^3*x6*f1*f5*f3^3+32
*x1*x3*x5*x7*f3*f6*f4*f1-64*x1^3*x2*f0*f6^2*f2*f4*f1-32*x1^3*x2*f6*f5*f2*f4*f1
^2+10*x1^4*f3^3*f1*f4^2-32*x1*x3*x2*x4*f0*f5*f1*f7^2*f4+96*x1*x3^2*x4*f1^2*f6^
3*f5-8*x2*x3*x5*x6*f3^2*f4^2-32*x1*x3*x5*x7*f1^2*f6^2+12*x3^2*x6^2*f1^2*f7^2-\
144*x1*x4^2*x3*f0*f6*f5^4+96*x2*x4*x5*x6*f0*f6*f5*f4-24*x1*x4*x5*x7*f7*f2^2*f4
-4*x2^3*x7*f1^2*f7*f5^2-4*x1^2*x2*x3*f5^3*f2^3-32*x1^2*x2*x5*f5^3*f0^2-32*x3^2
*x5*x7*f6*f3^2*f4-72*x3^2*x5*x7*f0*f5*f7*f4-16*x2*x7*f0*f6*f7*f3*x3*x6+8*x2*x3
*x4*x7*f7^2*f3^2*f2+8*x1*x3^2*x2*f6*f7^2*f1^3-16*x1*x3^2*x2*f0*f4*f6*f7*f3^2+
88*x1*x2*x4*x5*f0*f4*f2*f7*f5-4*x1^2*x2^2*f6*f2^3*f4^2-6*x1^2*x2^2*f2^3*f4*f5^
2+16*x1*x2*x4*x7*f7*f3*f4^2*f2-8*x1*x2*x4*x5*f1^2*f5*f7*f4+16*x1^2*x2*x3*f4^3*
f3*f1*f5+96*x2^2*x1*x7*f6*f5*f0^2*f7-16*x2^2*x1*x3*f0*f4*f2^2*f7^2-24*x2^2*x1*
x7*f0*f5*f3^2*f7+16*x1^4*f0*f6*f5*f2*f1*f4-192*x3^3*x4*f0*f6^3*f5*f4+28*x3^2*
x4*x7*f1^2*f7^3+16*x3*x6^2*x8*f7*f0*f6+4*x2^2*x6*x8*f7*f4^2*f1+32*x1^3*x6*f0*
f4*f7*f2^2+8*x6^2*x1*x7*f2*f3*f5-8*x6^2*x1*x7*f2^2*f6+8*x6^3*x1*f2*f1*f6-4*x2^
2*x4*x7*f2^2*f7^2*f3-96*x3^2*x4*x8*f7^2*f0*f6*f4+8*x2*x6^2*x8*f7*f0*f5-4*x1*x6
^2*x2*f7*f2^3-12*x1^2*x6^2*f0*f3*f7*f2+8*x1*x6*x3*x8*f7*f2*f1*f6-16*x1*x3^3*f6
*f2*f5*f7*f3*f1+4*x2^3*x3*f7^2*f2^3*f3-16*x1^3*x6*f0*f6*f7*f1^2+48*x1^3*x6*f1^
2*f4*f6*f3-16*x1^3*x6*f2^2*f6*f4*f1-32*x1^3*x6*f0*f5*f6*f2^2+160*x3^2*x4*x5*f3
*f6*f4*f1*f7+4*x1*x3^2*x4*f7^2*f2*f3^3-8*x1*x3*x5*x7*f4^2*f1*f5-4*x1*x3*x5*x7*
f3*f5^2*f1-160*x3^3*x4*f6^2*f2*f5*f7*f1-8*x3^3*x4*f5^2*f6*f1*f3*f7-8*x2^3*x7*
f4^3*f1*f6+64*x1^3*x6*f0*f6^2*f2*f1-16*x1^3*x6*f1*f6*f3^2*f2+8*x3^3*x5*f7*f3^2
*f2*f5-40*x2*x3*x4*x7*f7*f3*f4^3+80*x2*x3*x4*x7*f1*f0*f7^3+32*x2*x3*x4*x7*f7*
f3^2*f4*f5-4*x2*x5*x3*x6*f7*f2*f1*f4-64*x1^4*f0^3*f7^2*f4+32*x1^3*x6*f6*f1^2*
f5*f2+32*x1^3*x6*f0*f5^2*f1*f4-32*x1^4*f5^2*f1*f0^2*f7-38*x4^4*f7^2*f3*f4^2*f5
-32*x1^4*f3^2*f0^2*f7*f5+16*x3^2*x6*x7*f3*f7*f1*f6+16*x2^3*x7*f0*f6*f4^2*f5+2*
x4^2*x7^2*f4^2*f5*f7+4*x2^4*f0*f5^2*f4^3-288*x1^2*x4^2*f0*f5*f6*f7*f3^2+12*x3*
x4*x2*x8*f7^2*f2*f3*f4+48*x1^2*x4*x6*f0*f5^3*f3+32*x1*x4^2*x3*f7*f2*f4*f6^2*f1
+40*x1^4*f0*f6*f1*f7*f2^2+64*x1^4*f4^2*f3*f0^2*f7-96*x1^2*x4*x5*f0*f5^2*f3*f4+
8*x1^2*x2*x7*f3^2*f6*f4*f1+32*x1^2*x2*x7*f0*f4^2*f7*f2+4*x1^4*f0*f5^2*f4*f2^2+
64*x1^3*x2*f0*f5*f2*f7*f4*f1+32*x1^4*f0*f6*f5*f3^2*f1+8*x1^2*x5*x7*f2^3*f6+24*
x3^2*x1*x6*f0*f3*f7^2*f2-80*x1^2*x4*x7*f0*f6*f4*f2*f7-48*x1^2*x4*x7*f5^2*f2*f1
*f6-12*x3^2*x1*x6*f3*f5^3*f1-16*x3^2*x1*x6*f0*f6*f5*f4^2+96*x1^2*x3*x4*f0*f6*
f5*f7*f2*f3-16*x2*x5*x4^2*f7^2*f3^2*f1-4*x2*x5*x4^2*f7^2*f3*f2^2+108*x4^3*x5*
f3*f5^4+4*x2^2*x3*x6*f5^2*f4^2*f1+12*x1^3*x7*f5^2*f1^2*f4-32*x1^3*x7*f2*f6^2*
f1^2+32*x3^2*x6*x7*f4^2*f6*f3-20*x3^2*x6*x7*f5^2*f3*f4+16*x3^2*x6*x7*f7*f2*f4^
2-80*x3^2*x6*x7*f0*f6*f7*f4+40*x3^2*x7^2*f4*f6^2*f2+88*x3^3*x4*f7*f2^2*f5^2*f6
+64*x3^3*x4*f0*f6^2*f5*f3*f7+48*x3^3*x4*f1*f6*f7^2*f3^2+144*x3^2*x4^2*f3^2*f5^
2*f6^2-8*x3^2*x1*x6*f1^2*f7^2*f3-4*x2^2*x3*x4*f7*f2^2*f5^2*f4+12*x1*x6*x3^2*f3
^2*f5*f7*f1-24*x1*x6*x3^2*f0*f5^2*f2*f7-4*x2^3*x3*f1*f5^4*f2-4*x2^2*x4^2*f7*f4
^3*f1*f6+2*x2^4*f5*f7^2*f1^3+60*x3*x4*x7*x8*f7^2*f2*f4-4*x2^4*f0*f6*f4^4-72*x2
^2*x3*x4*f5^3*f6*f3*f1+32*x2^2*x3*x4*f0*f7^3*f3*f1+24*x2^2*x3*x4*f4^5*f5-16*x1
^4*f0*f6*f4^2*f2^2-456*x4^3*x6*f6*f5^2*f1*f7+8*x1^4*f6*f5*f4*f1^3+64*x1^4*f0*
f3*f2*f1*f7*f5+48*x1*x3^3*f4*f6*f0*f7*f2*f5-2*x2^4*f5*f4^4*f1+40*x4^2*x2*x5*f7
*f4^2*f5*f1+16*x1^3*x7*f6*f7*f1^3+24*x2^2*x1*x7*f0*f7^2*f2^2-32*x2^2*x1*x7*f0^
2*f7^2*f4+16*x2^2*x1*x3*f7*f2*f3*f1*f4*f5+72*x4^3*x8*f7^3*f4*f1+16*x1*x7^2*x4*
f7*f2*f3*f5+2*x3^2*x7^2*f3*f5^3+x1^4*f2^4*f5^2+2*x1^2*x2^2*f1^2*f5^3*f3+4*x1^2
*x2^2*f1*f5^3*f2^2-8*x1^2*x2^2*f0*f4*f3^3*f7+48*x2^2*x3*x4*f4^2*f6*f1*f5^2-18*
x1^4*f7*f3^2*f1*f2^2-8*x2^2*x1*x7*f0*f4^2*f5^2+4*x2^2*x1*x7*f5*f4^3*f1-20*x1^2
*x3*x4*f7*f2*f3^2*f4^2-48*x1*x3*x2*x7*f0*f3^2*f7*f6+12*x1^2*x3*x4*f5^3*f1*f4*
f3-64*x1^2*x3*x7*f1*f6^2*f0*f5-36*x2^2*x4^2*f5^2*f4^2*f6*f2+16*x3^4*f0*f5^3*f4
*f7+48*x1^2*x3*x7*f1*f5^2*f0*f7+6*x1^4*f1^2*f4^2*f3*f5-16*x1^2*x2*x5*f1*f4*f3*
f0*f7-6*x1^2*x2^2*f7*f2^2*f3^3-112*x4^2*x1*x5*f0*f5*f4^2*f7-132*x4^2*x5^2*f1*
f7*f3*f5-64*x1^2*x2*x4*f7^3*f1*f0^2+32*x1^2*x2*x3*f0*f5*f4*f7*f2*f3+44*x1^4*f2
*f7*f3*f1^2*f4+4*x2*x7^2*x3*f5^3*f2-8*x1^3*x7*f1^2*f6*f4^2-48*x1*x2*x3*x4*f7*
f2^3*f5*f6-72*x1*x2*x3*x4*f2*f6*f7^2*f1^2-32*x1*x2*x4*x7*f7*f1*f6*f2*f4-24*x1^
4*f0*f2*f7^2*f1^2+24*x1^4*f0*f4*f3^3*f5-96*x1*x2*x3*x4*f7*f0*f6*f3^2*f5-8*x1^2
*x2*x7*f2^3*f5*f6+4*x1^2*x2*x7*f3*f5*f4^2*f1+4*x1^2*x2^2*f2^2*f4^4+12*x1^2*x6^
2*f1^2*f5^2+4*x1^2*x6^2*f2^2*f4^2+18*x1^2*x4^2*f7^3*f1^3+12*x1^2*x3^2*f1^2*f5^
4+8*x1^2*x3^2*f7^2*f2^4-64*x1^4*f6^3*f0^3+8*x1^4*f7^2*f1^4-2*x1^4*f1^3*f5^3-2*
x1^4*f4^3*f2^3+x1^4*f1^2*f4^4-32*x1^3*x7*f0*f6*f5*f2*f3-40*x1*x3*x2*x7*f0*f5^3
*f4+4*x1*x3*x2*x7*f3*f5^3*f1-24*x2*x3^2*x7*f3*f7*f1*f4*f6-24*x1^2*x3*x4*f7*f3^
3*f1*f6+104*x1*x2*x4*x7*f7*f2^2*f5*f4-108*x1*x2*x4*x7*f7*f1*f5^2*f2+8*x1*x2*x6
^2*f6*f1^2*f5+48*x2^2*x1*x7*f7*f2*f3*f1*f5-48*x2^2*x1*x7*f1*f6*f0*f7*f4+96*x4^
2*x2*x8*f7*f5^3*f2-24*x1^2*x4^2*f0*f6*f4^2*f3*f7-32*x1^2*x4^2*f1^2*f6^2*f7*f3-\
48*x1*x4*x3*x6*f2*f5^3*f3-72*x1^2*x4^2*f5^3*f2*f1*f6+108*x1^2*x4^2*f0*f4*f7^2*
f3^2-8*x2^3*x3*f1^2*f4*f7*f5^2+16*x1^4*f0*f3^3*f7*f2-16*x1^4*f0*f6^2*f2^3+16*
x2*x4^2*x3*f7^2*f3^2*f1*f6-48*x1^2*x4^2*f1^2*f5*f7*f4*f6-192*x4*x6*x3^2*f0*f6*
f5*f7*f4+64*x2*x7*x3^2*f0^2*f7^3+112*x1*x3*x4^2*f0*f6*f3^2*f7^2-48*x1*x3*x4^2*
f0*f5^2*f2*f7^2-16*x2^2*x3*x7*f0*f5^4+40*x3^2*x1*x6*f1*f5^2*f6*f2-4*x1*x6*x5*
x8*f7*f2*f1+24*x3^2*x5^2*f1^2*f6^2-2*x1^2*x3^2*f4^5*f2-64*x1^2*x3*x4*f6^2*f0^2
*f7*f4+48*x2*x3*x4*x5*f5*f4^3*f3+40*x3^3*x4*f1*f7^2*f5^2*f2-4*x3^3*x4*f1*f7^2*
f4^3+32*x1*x7^2*x2*f6*f7*f1^2-64*x3^2*x4*x5*f0^2*f7^3-64*x1*x3^3*f6^2*f0^2*f7*
f5+16*x3^2*x5*x6*f3*f5*f1*f6+24*x3^2*x5*x6*f4*f5^2*f1+12*x4*x5^2*x6*f1*f4*f5+4
*x4*x5^2*x8*f7*f1*f4+16*x2^2*x6*x7*f0*f5^3+384*x1*x2*x3*x4*f6^2*f0^2*f7*f5-16*
x1*x2*x3*x4*f0*f7^3*f2*f1-148*x1*x2*x4*x7*f7*f1*f5*f3*f4+32*x1*x3*x2*x6*f1*f4^
2*f3*f6+32*x2*x3*x5*x6*f2^2*f4*f6+16*x3^3*x4*f0*f5^4*f7+16*x1^2*x3*x5*f0*f3^2*
f6*f4+8*x2^2*x3^2*f1*f4^2*f7*f2*f6-64*x2*x4*x3*x6*f0*f6*f4^2*f7-96*x1^2*x4*x7*
f3*f5*f1*f4*f6-72*x1*x4^2*x5*f2*f5^3*f3+32*x1*x2*x3*x4*f6^2*f1*f0*f7*f4+12*x1^
2*x2*x4*f3^4*f5^2-4*x3*x5*x2*x8*f7*f2*f3*f4+6*x1^4*f2^2*f5^2*f3*f1+24*x4^3*x8*
f7^3*f2*f3-552*x4^3*x8*f7^3*f0*f5+32*x1^3*x7*f1*f4*f6*f2*f3+72*x2*x4*x7^2*f5^2
*f6*f2+28*x2*x4*x7^2*f7*f3^2*f5+76*x1^2*x4^2*f5*f4^2*f1*f3*f7-32*x3^2*x4^2*f0*
f6^3*f7*f3-16*x1*x2^2*x7*f7*f3*f4*f2^2+24*x1*x5*x2*x7*f1*f5*f0*f7+4*x2*x5*x3*
x7*f3^2*f7*f2-40*x3*x4*x5*x7*f3^2*f4*f7+32*x3*x4*x5*x7*f7*f2*f4^2-96*x3*x4*x5*
x7*f5^2*f6*f1+120*x3*x4*x5*x7*f3*f5^2*f4+12*x3^2*x4*x7*f3*f5^4-4*x2^3*x3*f4^3*
f7*f2^2-24*x3*x4*x7^2*f7^2*f2*f3+24*x3*x4*x7^2*f7^2*f1*f4+4*x1^2*x4*x6*f7*f2^3
*f5-4*x2^2*x3^2*f0*f4*f7^2*f3^2-48*x1^2*x3^2*f3^2*f6*f4*f1*f5+228*x4^2*x2*x5*
f1*f7*f3*f5^2-144*x4^2*x2*x5*f1*f5^2*f4*f6-8*x2^3*x6*f4^4*f2+32*x2^3*x3*f0*f6*
f5*f1*f7*f4-4*x2^3*x3*f7^2*f2*f3^2*f1+8*x2^3*x3*f0*f5^2*f2*f7*f4+8*x2^3*x3*f0*
f5*f7^2*f2^2+32*x4^2*x7*x3*f4*f6^2*f1*f7-16*x1*x4*x3*x6*f7*f2*f1*f4*f6-12*x1^2
*x4*x5*f3^4*f5-8*x2*x4*x6*x7*f2*f7^2*f1+48*x2*x4*x6*x7*f2*f5*f4*f6-48*x2*x4*x6
*x7*f5*f4^3-16*x1^2*x7^2*f0*f6^2*f2-12*x1^2*x7^2*f0*f5^2*f4-64*x1*x3^2*x2*f5*
f0^2*f7^2*f4+108*x4^3*x7*f5^5-192*x1*x3*x4^2*f7*f2*f6*f5^2*f1+112*x1*x3*x4^2*
f7*f3*f5^2*f2*f4-16*x2*x3*x4*x5*f0*f4*f2*f7^2+40*x1^2*x3^2*f0*f6*f4^2*f1*f7+40
*x3^3*x4*f5*f4^2*f7*f1*f6+216*x1*x2*x4*x7*f7*f6*f1^2*f5+48*x1*x2*x4*x5*f0*f3^2
*f7*f5+4*x1*x2*x6^2*f2^2*f5*f4+128*x1^4*f6*f0^3*f7*f5-40*x3*x4*x6^2*f1*f4*f7*
f5-24*x3*x4*x6^2*f0*f7*f5^2+64*x2*x4*x7^2*f0*f7^2*f4-16*x2*x4*x7^2*f1*f7^2*f3+
40*x2*x4*x7^2*f7*f5^2*f1-24*x2^3*x3*f5^2*f2*f1*f4*f6+16*x2^3*x3*f6*f2^2*f5*f4^
2+4*x2^3*x3*f5*f4^4*f2-8*x3^3*x4*f7*f2*f4^3*f6+16*x3^2*x5*x7*f0*f7^2*f2-4*x2*
x5^2*x6*f4*f3*f1+16*x1*x5*x2*x6*f0*f4^3-4*x2^2*x1*x5*f4^3*f2^2+8*x3*x4*x5*x7*
f2*f7^2*f1-80*x3*x4*x5*x7*f0*f7*f5^2-18*x1^2*x4^2*f5^4*f2^2+4*x2^3*x6*f1^2*f7^
2*f2-8*x2^3*x6*f0*f7^2*f2^2+8*x2^3*x6*f5*f4^3*f1+24*x3^2*x1*x6*f7*f2*f6*f1*f3-\
4*x2^3*x7*f3*f5*f7*f2^2-32*x1^2*x6^2*f6^2*f0^2-12*x2*x6^2*x4*f3^2*f5^2-12*x2*
x6^2*x4*f2*f5^2*f4+4*x2^3*x3*f7*f2*f3*f1*f5^2-12*x1^4*f2^3*f5*f3*f4+12*x1^4*f2
^2*f5*f1*f4^2-64*x3^2*x5*x6*f0*f6*f5*f4+32*x3^2*x5*x6*f3*f4*f2*f6+32*x3^2*x5*
x6*f2^2*f6*f5-4*x3^2*x5*x6*f4^2*f5*f2-12*x1^4*f1*f4^3*f2*f3+16*x3^2*x6^2*f0*f6
^2*f4-12*x3^2*x6^2*f4^2*f6*f2-8*x3^2*x6^2*f3^2*f6*f4+12*x4*x6^2*x7*f3*f5^2+16*
x1*x6*f0^2*f7^2*x3^2*f5-16*x2^2*x3*x7*f0*f6*f5^2*f4+32*x1*x3^2*x2*f7*f1*f5*f2^
2*f6-16*x1^2*x3*x5*f7*f5*f1^2*f2-24*x2^2*x3*x4*f1^2*f7^2*f6*f3+96*x1^2*x4*x5*
f0*f6*f5*f3^2-48*x1*x3^2*x2*f0*f4^2*f6*f2*f7+4*f7^2*x4*x8^2*x6*f2+12*f7*x4*x8^
2*x6*f4*f5+96*x1^2*x2*x4*f1*f5^2*f2*f3*f6-24*x1*x2*x4*x5*f2^2*f4*f5^2+96*x1*x2
*x3*x4*f0*f6*f7^2*f2^2+24*x3^2*x4*x8*f7^2*f2*f4^2-24*x2*x4*x6*x7*f5^3*f2-16*x2
^3*x7*f0*f4*f7^2*f1+4*x2^3*x7*f4^2*f1*f3*f7-72*x4^4*f0*f6*f7^3*f3+136*x3*x4*x7
*x8*f7*f6*f2*f5-12*x1^2*x4*x7*f2^2*f5^3-568*x4^4*f1*f7^3*f3*f5+152*x4^4*f1*f7^
2*f6*f4*f5-4*x2^2*x3*x7*f7*f3^2*f5*f2+8*x2^2*x3*x7*f1*f7*f2*f4*f6-8*x3^2*x5*x6
*f3^2*f4*f5-12*x3^2*x5*x6*f2*f5^2*f3-44*x1*x2*x3*x6*f3*f5*f4^2*f2-36*x1^2*x2*
x4*f3^2*f5^3*f1-32*x1^2*x2*x3*f2^3*f4*f5*f6+16*x3^2*x6*x7*f0*f5^2*f7+12*x3^2*
x6*x7*f7*f2*f3*f5+56*x3^2*x6*x7*f1*f7*f4*f5+8*x3^3*x4*f0*f5*f1*f7^3-16*x3^3*x4
*f7^2*f2*f5*f3^2-8*x2^3*x3*f7*f1^2*f5*f6*f3-32*x1*x4^2*x3*f6^2*f2^2*f7*f3+32*
x3^2*x5*x6*f0*f4^2*f7+24*x1^4*f2*f6*f1*f3^3-16*x3^2*x4*x5*f0*f6*f1*f7^2+84*x3^
2*x4*x5*f5^2*f4^2*f3-12*x3^2*x4*x5*f2*f5^3*f4+160*x3^2*x4*x5*f7*f2*f1*f5*f6+32
*x1^2*x2*x5*f1*f5^2*f0*f4+8*x2^3*x3*f0*f5^3*f4^2+4*x2^2*x3*x7*f7^2*f2*f3*f1+16
*x3^2*x4*x6*f1*f7*f4^2*f6-16*x3*x5*x6^2*f2^2*f6+32*x1^3*x7*f0*f7*f3*f5*f1-8*x2
^3*x6*f2^2*f4*f5^2+16*x2^3*x6*f0*f6*f4^3+4*x2^3*x6*f1*f5^3*f2-24*x3^4*f5*f4^3*
f3*f6-8*x2^2*x1*x7*f4^2*f6*f2^2+32*x1^4*f0^2*f7^2*f3*f1-32*x1^3*x7*f1*f6*f0*f4
*f5-8*x1^3*x7*f0*f3^2*f5^2+16*x2*x6^2*x7*f0*f5*f6+312*x4^3*x8*f7^2*f5^2*f2-4*
x4^2*x6*x8*f7^2*f2*f4-48*x3^2*x5*x6*f1*f6^2*f2-8*x3^2*x2*x6*f2^3*f7^2-24*x3^2*
x6^2*f3*f5*f6*f2-18*x3^2*x6^2*f1*f7*f4^2-144*x3^3*x4*f3*f6^2*f1*f4*f7+132*x3^2
*x4*x7*f5^3*f4^2-8*x2^2*x3*x7*f7*f4^2*f2*f3+12*x2^2*x4*x5*f3^2*f4^2*f5-4*x2^2*
x3*x6*f3^2*f5*f4^2-24*x1*x2^2*x4*f1*f5^2*f2*f4*f6-48*x1*x2*x4*x5*f1^2*f5^2*f6+
24*x4^3*x6*f7*f2*f4*f5*f6+228*x4^3*x6*f7*f3*f4*f5^2+80*x4^3*x6*f7^2*f0*f5^2-24
*x1*x3*x4*x6*f0*f4^2*f7*f5-48*x1*x3^2*x4*f0*f5^2*f1*f7^2+24*x1*x3*x5*x7*f0*f5^
2*f4+64*x1^4*f6^2*f2*f0^2*f4-96*x1*x5*x2*x7*f6*f0^2*f7+24*x1*x5*x2*x7*f0*f3^2*
f7+36*x4*x5*x7^2*f3*f5^2+32*x1^3*x7*f0*f7*f2*f4*f3+16*x1*x2^2*x4*f0*f6*f7*f3*
f5*f2+32*x1^4*f6^2*f1*f0^2*f5-16*x1^2*x2*x6*f2^2*f5*f3*f4-48*x1^2*x2*x6*f0*f6*
f2*f4^2+8*x1*x7^2*x4*f7*f1*f4*f5+8*x3^2*x5^2*f2*f3*f5*f4+8*x2^3*x3*f1^2*f5^3*
f6+256*x2*x3*x4^2*f0*f6^2*f5*f3*f7-64*x1*x3*x2*x5*f0*f6*f7*f2^2-8*x2^3*x5*f2^2
*f4^2*f5+80*x3^2*x4*x7*f3^2*f7*f6*f4-4*x1*x5*x2*x8*f5*f1^2*f7+24*x1*x5^2*x4*f0
*f5*f4^2+8*x2*x5^2*x6*f0*f4^2+4*x1*x5*x6*x7*f7*f1^2-64*x1*x5*x4*x6*f7^2*f0^2+
144*x3^2*x4*x5*f0*f6*f5^3-4*x4*x5*f3*f7*f1*f5^2*x3^2+32*x1^3*x6*f0*f4*f7*f3*f1
+8*x1^2*x2*x6*f0*f5^2*f3^2-12*x1^2*x2*x6*f4^3*f3*f1+12*x1*x2*x5*x7*f1*f5*f3*f4
-8*x3^2*x2*x6*f4^5+12*x1*x3*x5*x7*f1^2*f7*f5+288*x2*x3*x4^2*f4*f5^2*f6^2*f1-32
*x1*x3*x5*x7*f0*f4^2*f6-48*x1*x4^2*x2*f7*f2*f5^2*f3^2+24*x1^2*x4*x6*f0*f5^2*f4
^2+48*x1*x4^2*x2*f0*f4^2*f3*f7^2+6*x3^2*x4^2*f5*f4^4*f7+32*x1^2*x2*x3*f0*f4^3*
f2*f7-4*x1^2*x2*x6*f3^2*f4^2*f2+32*x1^2*x2*x4*f0*f3^2*f7*f5*f4+22*x3^2*x7^2*f5
^2*f4^2+24*x3^3*x7*f5^2*f4^3+60*x1^2*x4*x5*f2*f5^2*f1*f4-28*x1^2*x4*x5*f7^2*f1
^3+8*x1^2*x2*x6*f0*f4^4+108*x4^3*x2*f4^2*f5^4+224*x1*x2*x3*x4*f7*f2*f5*f1*f6*
f3-4*x1^2*x2^2*f0*f4^5+4*x2*x7*f7*f3^3*x3*x6-36*x1*x4^2*x5*f4*f5^3*f1+72*x1*x4
^2*x5*f2^2*f5^2*f6-48*x1^3*x6*f0*f5*f7*f2*f1-16*x6^2*f7*f3*f1*x3^2*f5+80*x3^2*
x2*x4*f0*f4*f1*f7^3-468*x2*x3*x4^2*f7*f5^2*f4^2*f2+32*x2*x3*x4^2*f7^3*f2*f1*f3
-2*x1^2*x3^2*f3^4*f5^2-24*x2^2*x3*x7*f2^2*f7*f5*f4+4*x3^4*f4^3*f6*f7*f1-8*x2*
x5*x7^2*f3^2*f5-4*x1^4*f5*f7*f2^2*f1^2+16*x1^2*x2*x6*f0*f3*f4^2*f5-8*x1*x3^2*
x6*f7*f2^3*f6+48*x1^2*x3*x5*f1*f6*f5*f0*f4+36*x1^2*x2*x6*f1^2*f4*f7*f3-8*x1^2*
x2*x6*f2^2*f4^3-8*x2^2*x1*x3*f1^2*f4^2*f7*f5-24*x2*x3*x4*x7*f7*f3^3*f6+96*x2*
x3*x4*x7*f0*f6^2*f3*f7+96*x2*x3*x4*x7*f3^2*f5^2*f6-40*x1^4*f0*f5^2*f3^2*f2+18*
x1^2*x2^2*f1^2*f4^2*f5^2-40*x3^3*x4*f7*f2*f5^3*f3-20*x3^2*x5^2*f0*f5^2*f4-8*x1
^4*f0*f5*f4^3*f1+16*x2^2*x3*x7*f4^2*f6*f1*f5+32*x1^2*x6*x7*f0*f1*f6^2-52*x3*x4
*x6*x8*f7^2*f1*f4-8*x1*x4^2*x6*f7*f2^2*f4*f6-12*x1^2*x4*x6*f4*f5^2*f2^2+24*x2*
x5*x7*x8*f7*f0*f5-12*x2*x5*x7*x8*f7*f1*f4+48*x4*x6^2*x7*f7*f0*f6-24*x4*x6^2*x7
*f6*f2*f5-4*x1^2*x6^2*f0*f4^3+64*x1*x3^2*x2*f6^2*f0^2*f7*f4+10*x1^2*x2^2*f2^4*
f5*f7-80*x1^2*x2^2*f0*f6*f4*f7*f2*f1+20*x2^2*x6*x7*f7*f4*f2^2-8*x2*x6*x1*x7*f4
^2*f1*f5-16*x2*x6*x1*x7*f0*f4*f3*f7+104*x3^3*x4*f0*f5*f4^2*f7^2-56*x3^3*x4*f4*
f5^3*f7*f1+4*x5^3*x3*f5*f1*f2+4*x5^3*x3*f1*f4*f3-24*x2^2*x3*x7*f3*f5^2*f6*f1+
48*x1*x3*x2*x5*f1^2*f6*f7*f2+224*x1*x3*x4^2*f0*f6*f7*f4^2*f5-32*x1^2*x3^2*f7*
f2*f3^2*f1*f6-20*x3*x4*x6^2*f7*f2*f4^2+24*x3*x4*x6^2*f2*f7^2*f1-8*x2^3*x3*f0*
f7^3*f1^2+16*x2*x6*x4*x7*f3*f7*f1*f6-32*x1^3*x7*f0*f6*f7*f2*f1+32*x1^3*x2*f0*
f6*f5^2*f2*f1+16*x2*x3*x7^2*f2*f6*f4*f5-16*x3^4*f0*f6*f5*f1*f7^2+4*x3*x6^2*x5*
f4^2*f2-8*x3*x6^2*x5*f3*f1*f6+12*x7^3*x4*f5^3+2*x2^4*f3*f5^2*f4^2*f1-304*x1*x2
*x3*x4*f0*f6*f4*f2*f7*f5+24*x1*x2*x4*x5*f2*f4*f5*f1*f6+16*x1^2*x2^2*f5^4*f0^2-\
8*x3^3*x4*f7^2*f2^2*f6*f3-104*x3^3*x4*f5^2*f4^2*f2*f7+60*x3^3*x4*f7^2*f2^2*f4*
f5+16*x3^3*x4*f0*f5^2*f3*f7^2-8*x2^2*x1*x5*f0*f4^4-16*x3^2*x4*x5*f7*f3^2*f4^2-\
32*x1^3*x6*f0*f6*f3*f5*f1-4*x2^4*f1*f5^3*f2*f4-80*x1^3*x2*f0*f5^2*f4*f2*f3-32*
x3^4*f3*f6^3*f4*f1-16*x2^2*x3*x6*f1*f6*f5*f0*f7-96*x2*x3*x4^2*f7^2*f0*f5^2*f3-\
24*x1^2*x3*x7*f1*f6*f4^2*f3+224*x4^2*x7*x8*f7^2*f2*f5-4*x2^3*x3*f2*f7*f5*f1*f4
^2+16*x3^2*x6*x7*f3^2*f5*f6-4*x3^2*x6*x7*f2*f7^2*f1-4*x3^2*x6*x7*f7*f3^2*f4+4*
x5*x6^2*x7*f3^2+8*x2*x4^2*x5*f7*f2*f4^3-16*x5^2*x7^2*f0*f6+8*x1*x2*x5*x7*f1*f6
*f2*f4+8*x1*x2*x5*x7*f1*f5^2*f2-8*x1*x2*x5*x7*f2^2*f5*f4-24*x3^2*x5^2*f2*f1*f5
*f6+48*x1*x5*x2*x6*f5*f0^2*f7+4*x2*x5^3*f1*f2*f4+4*x5^2*x7^2*f3^2+4*x3^2*x7^2*
f5^2*f6*f2-4*x2^2*x7*x8*f5*f7*f2*f3+16*x2^2*x6*x7*f1*f0*f7^2+2*x2^2*x6^2*f1*f5
^2*f3-16*x2*x6^2*x4*f7*f6*f0*f3+48*x2*x6^2*x4*f0*f6*f5^2+48*x1^2*x2^2*f0*f5*f4
*f3*f1*f7-4*x1*x2^2*x6*f7*f1*f3^3-48*x3^2*x6*x7*f4*f6^2*f1-24*x3^2*x6*x7*f5^2*
f6*f1+16*x3^2*x6*x7*f2*f5*f4*f6-96*x1^2*x3^2*f0*f6^2*f5*f1*f4-96*x1^2*x3^2*f0*
f6^2*f5*f3*f2+20*x1*x3*x6^2*f3*f5*f2*f4+16*x2^2*x7^2*f5*f4*f1*f6-36*x1*x2*x3*
x4*f3^2*f5*f7*f2*f4+48*x1^2*x2*x3*f0*f6*f4^3*f3-4*x1*x3^2*x5*f4^3*f1*f5+208*x1
^2*x3*x4*f0*f5^2*f2*f7*f4+8*x2*x3*x1*x7*f0*f4^3*f7+640*x2*x3*x4^2*f7*f0*f6*f5^
2*f4+16*x2*x3*x5*x6*f2^2*f5^2+8*x1*x5*x2*x6*f1*f7*f2^2+16*x1*x5*x2*x6*f1^2*f7*
f3+16*x1*x5*x2*x6*f1^2*f4*f6-16*x1*x5*x2*x6*f3*f4^2*f1+4*x5^2*x6^2*f2^2+72*x1*
x3*x4*x5*f2*f6*f5^2*f1-4*x2*x3*x7^2*f7*f3*f5*f2+48*x3*x4*x6^2*f3*f5^2*f4-20*x3
*x4*x6^2*f7*f2*f5*f3+36*x3^2*x4^2*f6*f2*f5^4+48*x3*x4*x1*x6*f0*f6*f4*f5^2-16*
x2^3*x4*f0*f5*f4*f1*f7^2+48*x1^2*x2*x6*f1^2*f5*f7*f2+16*x1^2*x3*x6*f7*f2^2*f3^
2+40*x1*x3*x4*x6*f7*f1*f3^2*f6+144*x2*x3*x4^2*f6*f2*f5^3*f4-144*x2*x3*x4^2*f4^
2*f3*f5^2*f6-128*x1*x3^2*x4*f6^3*f0^2*f7+12*x1*x2*x4*x5*f7*f2*f4^2*f1+24*x1^2*
x2*x3*f1*f5^2*f2^2*f6+36*x1*x2*x4*x5*f1^2*f7^2*f2-8*x2^2*x1*x3*f3*f5^2*f4^2*f1
-20*x2^2*x1*x3*f7*f2^3*f5*f4-16*x3^2*x4^2*f7^2*f2*f4^3+36*x4^3*x6*f7*f2*f5^3-\
12*x4^3*x6*f5*f4^3*f7-576*x3^2*x4^2*f0*f6^3*f5^2-16*x1*x7*f0*f6*f7*f2*x3*x6-10
*x1^4*f5^2*f4*f2*f1^2+24*x1^2*x2^2*f0*f5*f4*f2^2*f7-48*x1^2*x2^2*f0*f6*f5*f7*
f1^2-32*x1^4*f0*f6^2*f1^2*f4+6*x1^2*x3^2*f2^2*f5^2*f4^2-28*x1^2*x2^2*f2^2*f5*
f1*f3*f7-36*x1^2*x2*x6*f1*f4*f7*f2^2+8*x1^4*f0*f5^3*f2*f1-2*f7*x7^2*x8^2*f5+28
*x1^2*x2^2*f7*f3^2*f1*f2*f4+40*x1^2*x2^2*f0*f5^2*f7*f2*f1-48*x1^2*x4*x6*f3^2*
f5^2*f2-12*x2^2*x4*x5*f5^2*f4^2*f1+32*x1^3*x6*f2*f3*f4*f1*f5+52*x1^2*x3^2*f7^2
*f1^3*f5-20*x1^2*x2*x6*f7*f3^2*f1*f2-292*x4^3*x6*f7^2*f3*f2*f5+48*x4^3*x6*f7^2
*f1*f6*f3-96*x4^3*x6*f7^2*f0*f6*f4-36*x1^2*x2^2*f2*f5*f4*f7*f1^2+96*x1^2*x4*x7
*f0*f4*f1*f7^2+12*x2^2*x4*x8*f7^2*f3*f4*f1+96*x1^2*x4*x7*f6^2*f1^2*f5+56*x1*x4
^2*x3*f7^2*f3^2*f5*f1-48*x1^2*x4*x6*f0*f6*f5*f4*f3-56*x1^2*x4*x6*f0*f5*f2*f7*
f4+24*x1*x4*x2*x6*f5*f4^3*f2+16*x2^2*x1*x3*f4*f7^2*f1^2*f2+24*x2^2*x1*x3*f5*f4
^3*f2*f3-8*x2^2*x1*x3*f7*f2*f3^3*f4+24*x1^2*x4^2*f1*f4*f6*f7*f3^2+36*x2*x4*x6^
2*f5^3*f1+x6^4*f3^2+76*x4^3*x6*f7^2*f1*f4*f5+60*x4^3*x6*f7^3*f2*f1-16*x1^4*f6*
f2*f7*f1^3+188*x3^2*x4^2*f7^2*f2^2*f5^2-16*x2^2*x5*x7*f0*f6*f4^2-4*x2^2*x5*x7*
f1*f5*f4^2+8*x2^2*x5*x6*f1*f5*f0*f7-16*x1*x3*x4*x5*f0*f5^2*f2*f7+8*x2^2*x1*x3*
f1*f5^2*f7*f2^2-16*x2^2*x1*x3*f0*f6*f7^2*f1^2-20*x2*x3*x7^2*f1*f4*f7*f5-4*x2^2
*x3*x6*f3*f5^3*f1+24*x2^2*x3*x6*f4^3*f1*f6+36*x1^2*x2*x6*f1*f4^2*f5*f2+32*x1^2
*x2^2*f6*f4*f3*f0^2*f7+8*x2^2*x3*x7*f2*f5^3*f3+24*x1^2*x3^2*f2^2*f4^3*f6+36*x1
*x2*x4*x5*f1*f5^2*f3*f4+8*x1*x2*x3*x6*f7*f2*f3^3-36*x2^2*x3*x7*f1*f4^3*f7+16*
x2^3*x4*f0*f6*f7^2*f3*f1+64*x1^3*x2*f6*f1*f0^2*f7*f5-40*x1^3*x2*f3*f5*f7*f2*f1
^2-12*x2^3*x3*f3*f7*f4*f2^2*f5-8*x3^4*f0^2*f7^3*f5+8*x1*x2^2*x6*f7*f2^2*f3^2+4
*x3^3*x1*f7*f2*f4^3*f3-16*x3^3*x1*f0*f5^4*f4+16*x2^3*x4*f5*f4^2*f1*f3*f7+16*x2
^3*x4*f0*f5*f3*f2*f7^2+20*x2^2*x3*x7*f1^2*f7^2*f4+36*x4^2*x7^2*f7^2*f3^2-40*x1
^2*x2*x6*f0*f5*f7*f2^2+12*x3^3*x1*f3*f5^3*f2*f4-24*x2*x3*x5^2*f2*f4*f1*f6-8*x4
^2*x5*f3^3*f7*x3*f6-8*x1^3*x6*f2^2*f5^2*f1-32*x3^2*x6*x7*f2*f3*f6^2+96*x3^2*x2
*x4*f3*f5^3*f6*f2-32*x1^3*x2*f0*f5*f6^2*f1^2+120*x1^2*x3^2*f0*f6*f5*f4^2*f3+52
*x2*x3*x6*x7*f7*f4^2*f1-16*x2*x3*x6*x7*f4*f6*f1*f5+4*x1*x3^2*x5*f4^4*f2-4*x3^2
*x5*x7*f1^2*f7^2-36*x3^2*x4*x5*f5^4*f1-24*x1^2*x2*x6*f0*f5*f7*f1*f3-24*x3^2*x4
^2*f2^2*f7^3*f3-32*x4*x5*f0*f6*f7*f3*x3^2*f5+32*x2^2*x3*x7*f3*f5*f2*f4*f6-8*x2
*x3*x5*x6*f3*f5*f2*f4-8*x2*x3*x5*x6*f4^3*f2+16*x2*x3*x5*x6*f1*f4^2*f5+16*x1^2*
x5^2*f5^2*f0^2-20*x2^3*x4*f1*f5^2*f7*f2*f4-12*x2^3*x4*f7*f3^2*f2*f4*f5-4*x5^3*
x6*f2*f1+46*x3^2*x4^2*f7^3*f3^2*f1-4*x1*x2*x5*x7*f3*f4^2*f2-16*x1*x2*x5*x7*f6*
f1^2*f5+9*x3^4*f5^2*f4^4+32*x2^2*x3*x7*f0*f4^2*f7*f5+8*x2^2*x3*x7*f0*f5^2*f3*
f7-64*x1^2*x3^2*f5^3*f0^2*f7-64*x2*x3*x4^2*f7^3*f6*f0^2+12*x2*x3*x4^2*f7^3*f1^
2*f4+32*x1*x3*x2*x4*f0*f6*f4^2*f3*f7-16*x1*x3*x2*x5*f7*f5*f1*f2^2-24*x1*x3*x2*
x7*f7*f2^3*f6+12*x3^2*x6^2*f4*f5^2*f2+8*x1^2*x2^2*f0*f4*f1^2*f7^2-304*x1^2*x4^
2*f6*f0^2*f7^2*f4+8*x1^3*x2*f3^2*f1^2*f5*f6-8*x1^3*x6*f4^2*f1^2*f5+96*x3^3*x4*
f5*f6^2*f2*f4^2+96*x3^3*x4*f1^2*f7*f6^3-12*x1^3*x6*f2^2*f3*f4^2-16*x1^2*x2*x5*
f1^2*f4*f6*f3+16*x1*x2^2*x6*f0*f6*f7*f1*f3-8*x1*x2*x3*x6*f7*f3*f4*f2^2-32*x1^3
*x2*f0*f2^3*f7*f6+16*x3^2*x7*f2^2*f6^2*f7*x4+144*x3^3*x4*f4*f6^2*f1*f5^2+128*
x3^3*x4*f0*f6^2*f4^2*f7-24*x3^3*x4*f3^2*f5^3*f6+8*x2*x7^2*x5*f7*f2^2+48*x1^3*
x2*f6*f3*f7*f1^3-12*x2*x3*x6^2*f2*f5^2*f3+16*x1*x3*x4*x6*f0*f5^2*f3*f7+12*x1^2
*x2*x7*f2^2*f5*f4^2-12*x1*x2*x4*x5*f3*f5*f4^2*f2-8*x1^2*x2*x5*f2*f4*f3*f1*f5+
168*x1^2*x4^2*f0*f4^2*f2*f7^2-24*x1*x4*x3*x6*f4*f5^3*f1-16*x1*x3*x2*x6*f1*f7*
f2^2*f6+4*x1*x2^2*x6*f1^2*f7*f4^2-120*x1*x2*x4^2*f7^2*f0*f3^2*f5+16*x1*x2*x4^2
*f7^2*f1^2*f5*f4-24*x1*x2*x4^2*f7^2*f3^2*f4*f1+20*x1^2*x2*x7*f1^2*f7*f3*f5-32*
x1*x2*x4^2*f7^3*f0*f1*f3+36*x1*x2*x4^2*f7^2*f3*f4*f2^2+16*x1^2*x2*x6*f0*f5^3*
f1+16*x3^4*f1^2*f6^4-24*x3^3*x4*f7^2*f2*f4*f1*f6+16*x3^3*x4*f6^2*f4*f7*f2^2+28
*x3^2*x2*x7*f5*f4^4+16*x3^4*f3^2*f6^2*f4^2-16*x2^3*x5*f7*f5*f1*f0*f4-4*x2^3*x5
*f7^2*f1^3-4*x2*x6^2*x7*f2*f4*f5-4*x2^2*x1*x3*f7*f3^2*f2^2*f5-4*x1^2*x3^2*f1^2
*f3^2*f7^2-16*x2^2*x1*x3*f3*f6*f4^3*f1-4*x1^2*x2*x4*f7*f3^5+32*x2*x3*x6*x7*f0*
f5^2*f6-16*x1*x3*x6^2*f3*f6*f4*f1+108*x1*x3*x2*x4*f3*f5^3*f2*f4-16*x1^2*x3*x7*
f2^3*f6^2+16*x1*x3^3*f0*f5^3*f2*f7+16*x2*x3^2*x4*f6^2*f2^2*f7*f3-4*x3*x5*x2*x6
*f3*f7*f2^2-4*x1*x5^2*x3*f1^2*f7*f3-48*x1*x3^2*x6*f0*f6*f7*f4*f2-2*x2^4*f7^2*
f2^2*f1*f3-16*x1^2*x6*x7*f1^2*f6*f5+4*x1^2*x6*x7*f4^2*f2*f3-16*x1^2*x6*x7*f3^2
*f5*f2-4*x1^2*x6*x7*f2^2*f5*f4+16*x1*x2*x3*x6*f1*f4*f0*f7*f6+16*x1^2*x2*x3*f7*
f1*f4*f3^3+6*x1^2*x2^2*f4^4*f3*f1+8*x1^2*x3^2*f3*f5^2*f4^2*f1-4*x5*x7*f7*f2^2*
x3^2*f5-12*x3^2*x5*x7*f1*f5^3-56*x2^2*x1*x4*f0*f3^2*f5^2*f7-16*x1^3*x2*f1*f5*
f7*f2^3+12*x2^3*x5*f1*f5^2*f2*f4-4*x2^3*x5*f3*f5*f4^2*f1+100*x4^2*x3*x5*f7*f2*
f5*f4^2+124*x4^2*x3*x5*f7^2*f2*f1*f5+24*x1^3*x2*f2^2*f5*f3^2*f4+32*x1^3*x2*f0*
f6*f4^3*f1-16*x2^2*x3*x6*f0*f5*f3*f7*f4-2*x1^2*x2^2*f4^2*f3^4-48*x1*x4*x2*x7*
f0*f5^4+96*x2*x3*x4^2*f7*f2*f5^3*f3-24*x1^3*x2*f4*f5*f7*f1^3+8*x1*x3^3*f2^3*f6
*f7*f5-32*x2^2*x3*x6*f2^2*f5*f4*f6-8*x2^2*x3*x6*f0*f5^2*f2*f7+4*x1^3*x3*f2^2*
f4^4-96*x3^2*x4*x5*f5*f4*f6*f3^2-144*x3^2*x4*x5*f1^2*f7*f6^2-64*x1^2*x2*x3*f0*
f3*f2^2*f7^2-96*x1^2*x2*x3*f5^2*f0^2*f7*f4+24*x1^2*x2*x3*f1^2*f5^2*f6*f3+12*x2
^2*x1*x3*f7*f3^2*f1*f4^2+32*x1^3*x2*f0*f4^3*f5*f2+16*x1*x3*x2*x5*f7^2*f0*f1*f2
+52*x1*x3*x4*x6*f7*f2*f5^2*f1-72*x4^3*x1*f5^2*f4^2*f7*f2+96*x1*x4^3*f2^3*f7^3-\
20*x3^2*x4^2*f7*f3^2*f5^3+8*x3^2*x4^2*f3^3*f6^2*f7+8*x3*x4*x2*x8*f7*f4^2*f6*f2
+12*x2^2*x4*x7*f2*f5^3*f4-24*x2^2*x4*x7*f2*f5*f4^2*f6+8*x1*x2^3*f0*f5^2*f7*f2^
2-64*x1^3*x2*f5^2*f2*f0^2*f7-52*x2*x3*x4*x5*f7*f4^2*f2*f3+96*x2*x3*x4*x5*f0*f5
^4+16*x1^2*x2*x6*f1^2*f6*f4^2-16*x1^2*x2^2*f0*f4^2*f3*f2*f7+8*x1^2*x2^2*f6*f1*
f4*f2^2*f5-34*x1^2*x2^2*f1^2*f4^2*f3*f7+44*x1^2*x2^2*f4*f7*f6*f1^3-6*x1^2*x2^2
*f3^2*f1^2*f5*f7-32*x1^2*x3*x5*f1*f4^2*f0*f7+8*x2*x3^2*x6*f7*f2*f1*f4*f6-16*x2
*x3^2*x6*f0*f6*f5*f2*f7-96*x2*x3*x4*x7*f3*f4^2*f5*f6+22*x1^2*x2^2*f4^2*f1*f7*
f2^2-8*x2^2*x4*x8*f7^2*f6*f1^2-48*x1^2*x4*x6*f1*f4*f6*f0*f7+24*x1^2*x4*x7*f4*
f5^2*f2*f3-144*x3*x4*x5*x6*f7*f2*f1*f6+2*x3^4*f4*f5^4*f2+96*x3^2*x1*x4*f4*f0^2
*f7^3+64*x1^2*x2*x6*f6^2*f0^2*f4+8*x1^2*x2*x6*f2^3*f4*f6+24*x1*x2*x4*x5*f2*f5^
3*f1+4*x1^2*x2*x7*f3^4*f5-20*x1^2*x2^2*f4^3*f5*f1*f2+4*x1*x2*x3*x4*f1^2*f7^2*
f4^2-12*x1*x2*x3*x4*f7^2*f1*f3^3-12*x5^2*x2*x7*f3*f1*f5+8*x5^2*x2*x7*f2*f3*f4+
48*x3^2*x5*x7*f6^2*f1*f3-40*x1*x6*x3^2*f2*f5*f1*f4*f7+24*x3^2*x1*x6*f3*f4*f1*
f5*f6-8*x3^2*x1*x6*f4^2*f6*f2*f3+36*x1*x2*x3*x4*f1^2*f5^3*f7+16*x1*x2*x3*x4*f7
^2*f2^2*f3^2+96*x1*x2*x3*x4*f1^2*f5^2*f6^2-616*x2*x3*x4^2*f7*f3*f5^2*f1*f6+192
*x2*x3*x4*x7*f1*f5*f6^2*f4-32*x1*x3^2*x6*f6^2*f1^2*f5+32*x1^3*x3*f5^4*f0^2-8*
x1^3*x3*f0*f4^5+48*x3*x4*x5*x6*f1*f5*f4*f6-24*x3*x4*x5*x6*f3^2*f5^2-4*x3*x4*x5
*x6*f1*f5*f7*f3+96*x3*x4*x5*x6*f2*f3*f5*f6+24*x2^2*x3*x6*f2*f6*f5^2*f1-16*x1*
x3*x2*x5*f7*f3*f1^2*f5-64*x2*x3*x4^2*f7*f3^3*f5*f6+296*x2*x3*x4^2*f7*f3*f5*f4*
f6*f2-144*x4^2*x3*x5*f5^3*f6*f1-156*x2*x5*x4^2*f7^2*f1^2*f5-16*x1^2*x2^2*f0*f6
*f5*f4*f3*f2+16*x1^2*x2*x7*f0*f7*f3^2*f4+4*x1^2*x2^2*f6*f3*f7*f2*f1^2-24*x1*x6
*x3^2*f0*f4*f3*f7*f5-144*x1^2*x4^2*f0*f6^2*f5^2*f2+48*x1*x4*x3*x6*f2^2*f5^2*f6
+20*x2^2*x3*x7*f5^3*f4*f1-4*x2^2*x3*x7*f2*f5^2*f4^2-16*x2^3*x4*f4^2*f7^2*f0*f2
-48*x1^3*x2*f1^2*f4^2*f6*f3+64*x1^3*x2*f0*f6*f5*f3*f4*f1-160*x1^3*x2*f0*f3*f2*
f1*f7*f6+36*x4^2*x6^2*f5^2*f4^2-8*x3^2*x1*x7*f0*f5^4+16*x1^3*x3*f2^4*f6^2+48*
x1^3*x2*f0*f7^2*f2^2*f1-16*x1^2*x2^2*f0*f6*f3^2*f1*f7+32*x1^2*x2^2*f0*f5*f3^2*
f2*f7+24*x1^3*x2*f0*f5*f4^2*f3^2+40*x2^2*x7^2*f0*f7*f5*f4-4*x2^2*x7^2*f3*f5*f7
*f1-4*x4^2*x6^2*f1*f6*f7*f4-8*x2^2*x6*x7*f4*f7*f3*f1+8*x2*x6*x1*x7*f4^3*f2+28*
x1^2*x2*x7*f7*f1*f5*f2^2-64*x1^2*x2*x7*f2*f6*f7*f1^2-12*x1^2*x2^2*f2^3*f3*f4*
f7-52*x2*x3*x4^2*f7^2*f4^3*f1-8*x2*x3^2*x4*f1^2*f7^2*f4*f6+192*x1*x3*x2*x7*f6^
2*f0^2*f7+8*x1^3*x2*f3^2*f1*f5^2*f2+64*x3*x4*x2^2*f6*f5*f0^2*f7^2-16*x2*x3*x6*
x7*f4^4-2*x4^2*x6^2*f3*f7^2*f1-24*x1*x3^2*x4*f7*f3^2*f5^2*f2+x4^4*f7^2*f4^4+8*
x1*x3*x2*x6*f4^4*f2-32*x1^3*x6*f0*f6*f2*f4*f3-216*x4^3*x1*f7*f2^2*f5^2*f6+144*
x4^3*x1*f7*f2*f5^3*f3+24*x1^2*x4^2*f7^2*f2^2*f3^2+32*x3^2*x1*x7*f1^2*f7^2*f4-\
32*x2*x4^2*x3*f3*f6^2*f7*f1*f4-16*x2*x4*x1*x5*f0*f4^2*f3*f7+72*x3*x4*x5*x6*f7*
f2^2*f5-28*x3^2*x4^2*f2*f7^3*f1*f4-8*x2^2*x1*x6*f0*f3^2*f7*f4+18*x2^2*x4^2*f4*
f5^4*f2+96*x3^3*x4*f5*f4*f6^2*f3^2-108*x4^2*x3*x5*f7*f2*f3*f5^2-16*x4^2*x3*x5*
f7^2*f2^2*f4+16*x2*x5*x4^2*f7^2*f0*f5*f2+160*x2*x5*x4^2*f7^2*f2*f1*f4+8*x3^4*
f7^2*f2^2*f4^2+18*x1^2*x3^2*f7*f3^2*f1*f4^2+12*x3^4*f0*f6*f5^4+48*x1*x5*x2*x7*
f0*f4*f2*f7-8*x1*x5*x2*x7*f1^2*f7*f4+48*x3*x5^2*x4*f0*f5*f6*f4+4*x2^2*x1*x6*f1
*f4^2*f3*f5+4*x2^2*x4*x8*f7*f4^2*f5*f2-224*x3^2*x2*x4*f1*f5^2*f7*f6*f2-80*x1^2
*x4*x5*f0*f6*f7*f2^2+16*x3^4*f6^2*f2^2*f5^2+2*x1^2*x2^2*f3^2*f4^3*f2+24*x1^2*
x2*x5*f2*f6*f1^2*f5+24*x1^3*x2*f0*f5^2*f1^2*f7+96*x3^2*x1*x7*f6*f0^2*f7^2+64*
x3^2*x1*x4*f0*f2^2*f7^3-112*x1*x4*x3^2*f1^2*f5^2*f7*f6-20*x1*x4*x3^2*f5*f4^3*
f1*f7-8*x1*x4*x3^2*f1*f5^3*f7*f2-24*x1^2*x3^2*f0*f4^3*f3*f7-24*x1*x3*x2*x5*f7*
f3*f1*f2*f4-24*x2*x3^2*x6*f1^2*f7*f6*f5-48*x1^2*x2*x3*f6^2*f5*f2*f1^2-128*x1^2
*x2*x3*f6*f0^2*f7*f4^2-8*x1^2*x5^2*f1*f5*f0*f4-48*x2*x5*x4*x7*f0*f6*f3*f7-4*x2
^2*x6*x7*f1*f5*f7*f2-2*x2^2*x6^2*f3*f7*f2^2-4*x1^2*x2*x6*f2*f5*f3^3-36*x1*x2*
x4*x6*f7^2*f1*f2^2-48*x1*x2*x4*x6*f7^2*f1^2*f3+6*x3^2*x6^2*f5^2*f3^2+16*x1^3*
x2*f2*f3^2*f4*f1*f6-64*x2^2*x3*x4*f0*f3*f4^2*f7^2+64*x1^2*x2*x3*f5*f2*f0^2*f7^
2+16*x1^2*x2^2*f3*f5*f1^2*f6*f4+32*x1^2*x2*x7*f2*f5*f1*f6*f3+32*x1^3*x2*f6*f7*
f2^2*f1^2+8*x6^2*x3*x7*f4^3+16*x2^2*x1*x3*f0*f4*f5*f7*f3^2-8*x2^2*x1*x3*f0*f5^
2*f7*f3*f2-24*x1^3*x2*f3^2*f7*f1^2*f4-4*x2^3*x3*f2*f5*f7^2*f1^2+4*x2^3*x3*f1^2
*f4*f7^2*f3-4*x1*x3*x6^2*f4^3*f2-4*f7*x5*x8^2*x7*f3+112*x1^2*x4*x5*f0*f7^2*f2*
f1-64*x1^3*x2*f0*f4^2*f2^2*f7+360*x2*x3*x4^2*f7^2*f1^2*f6*f5+8*x1*x3^2*x2*f7*
f2^2*f3^2*f6+32*x1*x3^2*x2*f0*f6^2*f7*f3*f1+8*x7^3*x2*f6*f2*f5-8*x7^3*x2*f7*f2
*f4+4*x7^3*x2*f7*f1*f5-4*x7^3*x2*f3*f5^2+4*x7^3*x2*f5*f4^2-20*x3^3*x4*f7^3*f2*
f1*f3-8*x3^2*x5*x6*f3*f4^3+24*x1^2*x3*x5*f4^2*f2*f5*f1-384*x2*x3*x4*x7*f0*f6^2
*f5^2-8*x1^2*x2*x3*f4^2*f3*f2^2*f6+32*x1*x2*x3*x6*f0*f7^2*f1*f3-4*x1*x2*x3*x5*
f2*f4^3*f3+24*x1^3*x2*f1*f4*f5^2*f2^2-44*x2^2*x4*x5*f1^2*f7*f5^2+44*x1^3*x2*f1
^2*f4*f5^2*f3+64*x4^2*x3*x5*f0*f5^3*f7-80*x4^2*x3*x5*f1*f0*f7^3-16*x1^3*x2*f3^
3*f5*f1*f4+120*x3^2*x1*x4*f3*f5^2*f6*f2*f4-8*x2^3*x7*f0*f5^3*f4+32*x1^3*x2*f2*
f1^2*f4^2*f7-16*x1^3*x2*f0*f5^3*f3*f1+24*x1^3*x2*f1*f3^3*f7*f2-64*x1^3*x2*f0^2
*f7^2*f4*f1-144*x4^3*x1*f0*f5^4*f7-16*x3*x6*f0*f6*f7*f3*x4*x5+48*x4*x5*x3*x6*
f0*f5*f7*f4-16*x4^2*x5*x7*f4*f6*f1*f7-48*x2*x3*x4*x6*f1*f4*f6*f5^2+96*x2*x3*x4
*x6*f6*f2*f5*f4^2-16*x1^3*x2*f2^3*f3*f4*f6-2*x1^2*x7^2*f4^3*f2+16*x1^2*x7^2*f6
^2*f1^2-48*x1^2*x3*x5*f0*f3*f4*f7*f2-12*x3^4*f4*f5^2*f7*f2*f3-12*x3^4*f4^2*f6*
f7*f2*f3-8*x1*x2^3*f2*f4^3*f6*f1+64*x1^3*x2*f6*f0^2*f7*f3^2-36*x2^2*x1*x4*f1*
f4^3*f7*f3+16*x1^3*x2*f1*f4^2*f2^2*f6-48*x4^2*x5*x6*f4*f5*f7*f1+168*x4^2*x5*x6
*f7*f2*f3*f5+144*x4^2*x5*x6*f6*f5^2*f1-8*x1^2*x3*x5*f1^3*f7*f6+28*x1^2*x3*x6*
f1^2*f4^2*f7+48*x2^2*x3*x4*f0*f5^3*f3*f7+12*x1^2*x2*x7*f1^2*f5^3-64*x1^3*x2*f0
^2*f7^2*f2*f3+4*x1^2*x2*x7*f4^4*f1+x2^4*f1^2*f3^2*f7^2+4*x3^2*x6*x8*f7^2*f3*f1
+8*x1^2*x3^2*f6*f2*f5*f3^3+16*x1^2*x3^2*f7*f3^3*f1*f5-32*x1^2*x3^2*f0*f6*f5^3*
f1-16*x1^2*x4*x5*f1*f0*f7*f4*f5+8*x1^2*x4^2*f7*f1^2*f5^3+4*x1^2*x3*x6*f7*f1*f5
*f2^2+96*x1^2*x3^2*f6^2*f5^2*f0^2-80*x1*x3*x4*x5*f0*f6*f7*f4*f2-12*x3*x5^2*x4*
f4*f1*f5^2-12*x3*x5^2*x4*f4^2*f2*f5-48*x1^2*x3*x6*f7^2*f1^3+96*x2*x3*x4*x7*f2*
f5^2*f4*f6+28*x1^2*x3*x5*f3^2*f4*f1*f5-320*x2*x3*x4^2*f7^2*f2*f1*f4*f6+16*x2*
x4^2*x5*f3*f6*f4*f1*f7+28*x2*x4*x7*x8*f7^2*f1*f4-4*x2^3*x3*f3*f5^2*f2*f4^2-100
*x2^2*x1*x4*f2*f5*f7^2*f1^2+28*x2^2*x1*x4*f1^2*f4*f7*f5^2-16*x2*x3^2*x7*f7*f2*
f5*f1*f6-4*x2*x3^2*x7*f3^2*f5^3-18*x1^2*x4^2*f3^3*f5^3+16*x1*x2*x3*x6*f7*f0*f6
*f2*f3-64*x1^2*x2^2*f6*f0^3*f7^2-16*x1^2*x2*x3*f0*f4^2*f3^2*f7-24*x2^3*x4*f0*
f5^2*f3*f7*f4+16*x2*x6*x3*x7*f0*f7*f4*f5-16*x3*x6^2*x7*f2*f4*f6+12*x2^2*x3^2*
f1^2*f4^2*f7^2-24*x5^2*x3*x7*f3*f1*f6+8*x5^2*x3*x7*f2*f3*f5+6*x2^2*x3^2*f7^2*
f3^2*f2^2+8*x2^2*x3^2*f5*f4^2*f2*f3*f6-8*x2^2*x3^2*f0*f6*f4^2*f5^2-112*x4^2*x6
*x8*f7^2*f1*f5-8*x1^2*x7^2*f0*f6*f7*f1+2*x2^4*f4^5*f2+4*f7^2*x3^2*x8^2*f1*f5-8
*f7^2*x3^2*x8^2*f0*f6+8*f7*x3^2*x8^2*f3*f6*f4-32*x1^2*x2*x7*f0*f6*f4*f2*f5-48*
x1^2*x2^2*f0*f3*f2*f1*f7^2+4*x2*x3^2*x4*f7^2*f3^4+16*x2^2*x3^2*f0*f6*f5*f2*f7*
f4+32*x1^2*x3^2*f0*f5*f4^2*f7*f2-32*x3*x4^2*x5*f7*f4*f5^2*f1+48*x1*x4*x3*x6*f0
*f5^4+4*x1*x2^3*f7*f1*f4*f3^3+8*x1*x2^3*f1^2*f5*f6*f4^2-4*x1*x2^3*f4^3*f3*f1*
f5+16*x2^2*x3*x4*f0*f6*f4^3*f7-24*x2^2*x3*x4*f1*f5^2*f3*f7*f4-96*x5^2*x4*x7*f0
*f5*f6-44*x5^2*x4*x7*f7*f3*f1+88*x5^2*x4*x7*f7*f0*f4-8*x1*x5^2*x7*f1*f4*f3-4*
x1*x5^2*x7*f2*f5*f1+4*x1*x5*x4*x6*f7*f2*f1*f4+12*x1*x5^2*x4*f5*f2^2*f4+2*x3^4*
f5^3*f7*f2^2+160*x1*x6*x4^2*f7^3*f0^2-48*x1*x2*x3*x4*f6*f2^2*f5^2*f4-32*x1*x2*
x3*x4*f5^2*f2^2*f7*f3-48*x1^2*x3*x5*f1*f6*f3*f4*f2+8*x2*x3*x6^2*f1^2*f7*f6+120
*x2^2*x3*x4*f0*f5^2*f4^2*f7-104*x2^2*x3*x4*f1*f5*f7*f4^3-18*x1^2*x4^2*f7^2*f1^
2*f4^2-4*x1*x2^3*f1*f5^2*f2*f4^2+16*x1*x2^3*f0*f5*f4*f7*f2*f3-26*x4^2*f3^3*f7^
2*x3^2*f5-2*x3^2*x4^2*f5^4*f1*f7+24*x2*x3*x4*x6*f7*f2*f3^2*f6+48*x2*x3*x4*x6*
f7^2*f0*f4*f3+76*x1^2*x3*x6*f1^2*f7*f3*f5-16*x1^2*x3*x6*f7*f2^3*f4-8*x3^4*f7*
f3*f4*f1*f5*f6-120*x1^2*x3*x6*f1*f0*f7*f4*f5+16*x1^2*x3*x6*f0*f6*f7*f2^2-56*x2
^2*x3*x4*f0*f5^2*f1*f7^2-4*x1*x2*x3*x4*f1*f5*f7^2*f2^2+12*x1*x2*x3*x4*f7*f2*f4
^3*f3+8*x1^2*x2*x5*f2^3*f4*f5+32*x2^2*x3*x6*f0^2*f7^2*f5-4*x2^2*x3*x6*f1^2*f7*
f5^2+32*x1^3*x5*f0*f5*f2*f4*f3+328*x4^2*x5*x8*f7^2*f0*f5-36*x4^2*x5*x8*f7^2*f1
*f4-48*x1*x2*x4*x5*f0*f7^2*f2^2-12*x1*x2^2*x4*f1*f5^4*f2+8*x1*x2^2*x4*f7^2*f2^
3*f3+8*x2^2*x3*x7*f4^5+8*x5^2*x3*x7*f3^2*f4-8*x3^4*f0*f6*f4*f2*f7^2-72*x1*x2*
x3*x4*f6*f2*f5^3*f1-32*x1*x3*x4*x5*f0*f6*f3^2*f7+48*x2*x3^2*x4*f3^2*f5^2*f6*f4
+4*x4^2*x6^2*f0*f4*f7^2-16*x1^2*x6^2*f2*f5*f4*f1-16*x1^2*x2*x7*f0*f4^3*f5-96*
x3^3*x4*f3*f6^3*f1*f5-92*x4^2*x5*x6*f2*f7^2*f1-72*x4^2*x5*x6*f3*f4*f5^2+4*x1*
x2^3*f4^4*f3*f2+4*x1^2*x2*x7*f2^2*f5^2*f3-28*x3*x4*x5*x6*f7*f1*f4^2-48*x3*x4*
x5*x6*f3*f5*f4^2+72*x3*x4*x5*x6*f5^3*f1+26*x1^2*x4^2*f7^2*f2^3*f4+16*x1*x2*x4*
x5*f1^2*f6*f7*f3-48*x1^2*x2*x7*f0*f7^2*f2*f1+24*x1*x3*x5*x7*f1*f6*f2*f5-20*x1*
x3*x5*x7*f3*f5*f2*f4+12*x2*x3*x4*x5*f1^2*f7^2*f4-32*x2*x3*x4*x5*f0*f6*f5*f2*f7
+16*x1^2*x2*x7*f0*f6*f7*f1*f3-96*x2*x3*x4*x5*f3*f5*f4*f6*f2+8*x2*x3*x4*x6*f7*
f3^2*f4^2-36*x2*x3*x4*x6*f7^2*f1^2*f5+48*x1*x4*x2*x6*f2^2*f5*f4*f6-8*x1*x2^3*
f7*f2^2*f3^2*f4+4*x1*x2^3*f7*f2^3*f3*f5+48*x1^3*x2*f0*f3*f7^2*f1^2+8*x2*x3*x4*
x6*f7*f3*f1*f4*f6-48*x2*x3*x4*x6*f7^2*f1*f4*f2+40*x2*x3*x4*x6*f7*f2*f3*f5*f4-\
48*x2*x3*x4*x5*f2*f5^3*f3-96*x1^3*x2*f6*f5*f0^2*f4^2-48*x1^3*x2*f0*f5^2*f4^2*
f1+8*x4*x5*x6^2*f7*f0*f4+4*x1^2*x5^2*f0*f4*f3^2+288*x3^2*x4^2*f6^2*f5^3*f1-8*
x2^3*x5*f7*f5*f0*f3*f2+12*x2*x5*x4*x7*f3^3*f7+8*x3*x5*x7^2*f7*f2*f3-36*x2^2*x4
*x5*f7*f4^2*f2^2-96*x3*x5*x4*x6*f0*f6*f5^2-8*x1*x5*x2*x7*f0*f5*f4^2+64*x3^2*x4
^2*f0*f6*f5^3*f7+16*x1*x5*x3*x7*f0*f4*f3*f7+36*x1^2*x2*x4*f1^2*f5^4-32*x1^3*x5
*f1^2*f0*f7*f5-46*x4^2*x7^2*f4*f7^2*f2-8*x2^3*x4*f0*f3^2*f7^2*f4+16*x7^3*x3*f6
^2*f2+8*x7^3*x3*f4*f5^2+8*x7^3*x3*f7*f1*f6-8*x7^3*x3*f3*f5*f6-8*x7^3*x3*f7*f2*
f5+12*x7^3*x4*f1*f7^2+176*x1*x4^2*x2*f0*f5^3*f3*f7+112*x1*x4^2*x2*f0*f5^2*f4^2
*f7+28*x1*x2*x4*x6*f7*f2^2*f3*f5+8*x1^2*x3*x5*f3^3*f1*f6+16*x1^2*x2*x6*f0*f7*
f2*f3*f4-8*x1*x2^2*x4*f7*f2*f4*f1*f6*f3+12*x1*x2*x6^2*f3*f4^2*f2-60*x1*x3*x4*
x5*f3*f5^2*f2*f4+24*x2*x3*x7^2*f1*f7^2*f2+16*x2*x3*x6^2*f2^2*f6*f5+28*x2*x4*x6
^2*f1^2*f7^2+24*x3^3*x4*f1^2*f7^2*f5*f6+12*x3^2*x4*x5*f2*f7^2*f1*f4+16*x3^2*x4
*x5*f0*f4*f3*f7^2+48*x1*x4*x2*x7*f2*f5^3*f3-24*x1*x4*x2*x7*f5^2*f4^2*f2+4*x5*
x7*f7*f3*f1*x3^2*f5-24*x1^2*x2*x7*f7*f2^3*f4+24*x2^2*x4*x5*f0*f5^3*f4-96*x3*x4
*x5*x7*f2*f5*f4*f6-8*x3*x4*x5*x7*f7*f2*f5*f3-48*x2*x7*x3^2*f4^2*f1*f7*f5+48*x2
*x7*x3^2*f1*f4*f7^2*f2+8*x2*x4^2*x6*f1*f7*f4^2*f6-40*x1^2*x4*x5*f0*f4*f3^2*f7-\
16*x1^3*x2*f3^2*f7*f2^3+68*x2*x4*x7*x8*f7*f5^2*f2-12*x2*x4*x1*x6*f3*f5^3*f1-\
112*x1^2*x4*x7*f1*f6*f5*f0*f7+32*x1^2*x2^2*f5*f1*f0^2*f7^2-56*x1^2*x3*x6*f0*f7
*f5*f2*f3-4*x2^3*x5*f1^2*f5^3-24*x3*x6^2*x7*f7*f0*f5+4*x3*x6^2*x5*f3^2*f4-80*
x2*x4^3*f1*f7^2*f3*f6*f4+504*x2*x4^3*f6*f5^2*f7*f1*f4+16*x3^4*f0*f6*f5^2*f3*f7
-4*x3^2*x4*x5*f1^2*f7^2*f5-32*x2*x4^3*f7^2*f2*f4^3+188*x2*x4^3*f1^2*f7^3*f5-16
*x2^2*x1*x6*f0*f4^2*f2*f7+32*x2^2*x1*x6*f6*f0^2*f7*f4+16*x3^4*f6^2*f0^2*f7^2-\
448*x1^2*x4^2*f7^2*f0^2*f5^2+24*x1*x6*x4*x8*f7^2*f2*f1-16*x1*x4^2*x6*f7*f4^2*
f5*f1-8*x1^3*x5*f3*f4*f5*f1^2+8*x4*x5*f3^3*f7*x3^2*f5+32*x1^2*x2*x4*f7^2*f2^4-\
8*x1*x3^2*x2*f7*f3^3*f1*f6-40*x1*x3*x4*x5*f7*f2*f5*f1*f4+8*x1^3*x2*f2^4*f5*f6-\
24*x1*x2*x3^2*f0*f7^2*f3*f5*f1-80*x1^2*x2*x3*f0*f6*f5^2*f2*f3+2*x2^2*x4^2*f7*
f4^4*f3+12*x1^3*x2*f2^2*f3*f4^3+16*x2^3*x5*f5^2*f0^2*f7+48*x4^2*x6^2*f2^2*f7^2
-112*x3^2*x4^2*f0*f5*f2*f7^3-280*x3^2*x4^2*f1*f7^2*f3*f6*f4+232*x3^2*x4^2*f7^2
*f1^2*f6^2+56*x1*x6*x4^2*f7^2*f3^2*f1-20*x1*x6*x4^2*f7^2*f3*f2^2-8*x1*x7*x4^2*
f7^2*f1*f5*f2+8*x1*x7*x4^2*f7^2*f4*f3*f1+128*x2^2*x4*x7*f0^2*f7^3+16*x1^3*x5*
f0*f5^2*f3*f1+124*x4^2*x7^2*f1*f7^2*f5-16*x1^3*x5*f2^2*f5*f1*f4-144*x4^2*x7^2*
f0*f6*f7^2+80*x1*x2*x4*x6*f7^2*f0*f2*f3+144*x3^2*x4*x5*f3*f6^2*f1*f5-16*x3^2*
x4*x5*f7*f2^2*f4*f6+112*x2*x4^3*f0*f6*f4^2*f7^2-144*x2*x4^3*f7*f3*f5^2*f6*f2-\
208*x2*x4^3*f0*f5*f2*f7^3-32*x1^2*x3^2*f0*f5^3*f3*f4-4*x1^2*x3*x5*f3^4*f4-232*
x4^2*x3*x5*f1^2*f7^2*f6-528*x4^2*x3*x5*f0*f6*f5*f4*f7+128*x1^2*x3^2*f0*f5^2*f1
*f7*f4+4*x2^3*x5*f4^3*f2*f3-12*x2*x4*x6*x7*f7*f2*f3*f5-8*x2*x4*x5*x7*f1^2*f7^2
-96*x4^2*x5*x8*f7*f5^2*f2-32*x1*x7*x4^2*f7^3*f0*f1+8*x1*x7*x4^2*f7^2*f6*f1^2+
16*x1^3*x5*f0*f4^2*f1*f5-8*x1^3*x5*f2^4*f6+80*x1^2*x3*x7*f0*f6*f7*f3*f2+16*x2*
x3*x7^2*f1*f5^2*f6-32*x1^3*x5*f2*f6*f1*f0*f5-48*x1^2*x3^2*f0*f5*f6*f7*f2^2+32*
x1^2*x2*x6*f2*f4*f1*f6*f3-16*x1*x2*x3*x5*f2^2*f5*f4^2-8*x1*x2^2*x5*f7*f0*f3*f5
*f1+8*x1*x4*x3*x7*f2^2*f3*f7^2+28*x1*x4*x3*x7*f1*f7^2*f3^2-120*x3^2*x4*x5*f0*
f5^2*f4*f7+12*x3^2*x4*x5*f7*f2*f4^3+16*x3^2*x4*x5*f7*f4^2*f5*f1-32*x1^2*x2*x3*
f0*f6^2*f4^2*f1-64*x1^2*x2*x3*f0*f3^2*f1*f7^2-32*x1^3*x5*f1*f6*f4*f3*f0+8*x2^2
*x3^2*f0*f4^3*f5*f7+24*x2^2*x1*x6*f1*f6*f4^2*f2+4*x1*x4*x2*x5*f7*f3^2*f1*f4+12
*x1*x4^2*x2*f5*f4^3*f1*f7-20*x1*x4*x6^2*f7*f3*f4*f1+360*x3^2*x4^2*f4*f6^2*f2*
f5^2+12*x1*x2^2*x4*f4*f5^3*f2^2+24*x1*x2^2*x4*f1^2*f5^3*f6-72*x1*x2*x4*x6*f7*
f1^2*f6*f4+56*x1*x2*x4*x6*f7*f1*f4^2*f3-32*x1^2*x2*x6*f6*f5^2*f0^2+8*x1^3*x5*
f1*f4^2*f2*f3+4*x1^3*x5*f2^3*f4^2-32*x2*x4^2*x5*f0*f6*f4^2*f7-50*x1^2*x4^2*f7^
2*f3^3*f1-108*x1^2*x4^2*f0*f5^4*f4+144*x1^2*x4^2*f6^2*f1^2*f5^2+62*x4^2*x5^2*
f1^2*f7^2+8*x2^3*x3*f4^2*f3*f1*f5*f6+16*x1^3*x5*f1*f3*f2^2*f6-32*x1^2*x3*x5*f6
^2*f0*f3*f1-4*x2*x3^2*x5*f3*f5^3*f1+264*x4^3*x2*f7*f3^2*f5^3-128*x2*x4^3*f0*f4
*f3*f7^3-32*x3^2*x1*x5*f4*f0^2*f7^2-8*x1^3*x5*f3^2*f1*f5*f2-32*x2*x3*x7^2*f7*
f4^2*f2-96*x1*x3^2*x4*f1*f4*f6^2*f3*f5+24*x2*x3^2*x4*f7*f3^2*f5*f4^2+4*x3*x6*
x2*x8*f7*f4^2*f2-16*x3*x6*x2*x8*f7*f0*f6*f4-4*x3^2*x5*x7*f5^2*f2*f4-32*x3^2*x5
*x7*f3*f5*f6*f2-48*x1^2*x3^2*f0*f5*f7^2*f2*f1-8*x1^2*x6*x7*f3^2*f1*f6+32*x1^2*
x6*x7*f6*f0^2*f7+128*x1^3*x2*f0^3*f7^2*f5+28*x1*x2*x3*x5*f3*f5*f4^2*f1+24*x2*
x6*x4*x7*f3*f5^2*f4+4*x3^4*f3^3*f5^2*f7+12*x3^2*x5*x7*f7*f2*f3*f4+28*x3^2*x5*
x7*f5*f4^2*f3+80*x1^2*x3^2*f0*f5^2*f7*f2*f3+4*x1*x3^2*x6*f7*f3*f5*f2^2+12*x1^2
*x3^2*f7*f2^3*f3*f6+16*x1^2*x3^2*f0*f6*f3^3*f7+56*x3^2*x4^2*f0*f6*f1*f7^3-360*
x3^2*x4^2*f6*f5^3*f3*f4-280*x3^2*x4^2*f7*f2*f5^3*f4-8*x1*x3*x4*x7*f7*f3*f5^2*
f1-24*x2*x3*x6*x7*f1*f5^3-28*x1^2*x2*x7*f2*f5^2*f1*f4-144*x4^2*x3*x5*f3^2*f6*
f5^2+576*x4^2*x3*x5*f0*f6^2*f5^2+180*x4^2*x3*x5*f4*f5^3*f3-128*x1^3*x4*f7^3*f0
^3+8*x3^2*x4*x5*f0*f5*f2*f7^2-96*x3^2*x4*x5*f3*f5^2*f6*f2-224*x3^2*x4*x5*f0*f6
*f4^2*f7+4*x1^2*x5^2*f1*f2^2*f5+36*x4^2*x5*x6*f5^3*f2+168*x4^2*f0*f6*f7^2*f3*
x3^2*f5-208*x3^2*x4^2*f5^2*f4^2*f7*f3+12*x3^4*f3*f5*f7^2*f2^2+16*x3^4*f4^2*f6^
2*f1*f5+8*x3^4*f6*f4*f5*f7*f2^2+12*x2^2*x6^2*f4^3*f2+48*x2^3*x4*f0*f6*f5^2*f4^
2-16*x2^3*x4*f0*f4^3*f5*f7+48*x2^2*x3*x4*f0*f7^3*f2^2+24*x7^3*x4*f7*f2*f6-12*
x7^3*x4*f7*f3*f5-8*x7^3*x5*f2*f6-4*x7^3*x5*f7*f1+4*x7^3*x5*f3*f5-8*x7^2*x2*x8*
f0*f7^2+20*x1^2*x3^2*f3*f5*f4*f7*f2*f1+16*x3*x5^2*x4*f0*f7^2*f1+8*x1*x3^2*x6*
f1^2*f7*f4*f6+40*x2*x3*x4*x6*f7*f4^3*f2-8*x2*x3*x4*x6*f7^2*f2^2*f3+40*x1*x3*x4
*x7*f7^2*f1*f2*f4+4*x1^2*x3*x5*f2^3*f5^2+32*x2^3*x4*f6*f0^2*f7^2*f4-8*x2^3*x3*
f4^3*f3*f2*f6-16*x2*x7*x3^2*f4*f6*f7*f2^2+64*x3^3*x4*f6*f0^2*f7^3+8*x3^2*x1*x5
*f2*f7^2*f1^2+392*x3^2*x4^2*f0*f6*f4^2*f7^2-48*x3*x6^2*x4*f4*f5*f2*f6-16*x1^2*
x6^2*f0*f4*f5*f3-16*x1^2*x6^2*f2*f1*f6*f3+20*x2^2*x7^2*f1^2*f7^2-768*x2*x4^3*
f0*f6*f5^3*f7+452*x2*x4^3*f7^2*f2*f3*f5*f4-20*x1*x5*x4*x6*f7*f1*f3^2-4*x3*x5^2
*x7*f1*f4*f5-4*x2*x5*x6^2*f7*f1^2-48*x1*x4*x2*x6*f7*f2^2*f4^2-36*x3*x4^2*x5*f2
*f5^4+32*x1^3*x3*f3^2*f0^2*f7^2-16*x2*x3*x4*x5*f0*f3^2*f7^2-48*x2*x3*x4*x5*f4*
f5^3*f1-128*x1*x3*x2*x4*f5^2*f0^2*f7^2-32*x1^3*x3*f0*f6*f3^2*f1*f7+16*x1^3*x2*
f1*f4^3*f3^2-48*x3^3*x4*f0*f6*f5*f7^2*f2+32*x3^3*x4*f6*f4^2*f3^2*f7-24*x3^2*x1
*x4*f0*f5^5-12*x1^3*x2*f2^3*f5*f4^2+64*x1^3*x3*f2*f5*f4*f7*f1^2+96*x1^3*x3*f0*
f6*f5*f7*f1^2+16*x2^3*x4*f0*f6*f7^2*f2^2-32*x1^3*x3*f0*f6*f5*f4^2*f1+18*x3^2*
x4^2*f3*f5^5+64*x1^3*x3*f1*f4*f6*f2^2*f5-36*x1^2*x4*x5*f1^2*f5^3-96*x1*x4*x3*
x7*f2^2*f6^2*f5-64*x1*x2*x3^2*f0*f6*f4*f1*f7*f5+16*x1^3*x2*f7*f2^4*f4-12*x1^3*
x2*f5^3*f2*f1^2-32*x1^2*x2*x7*f0*f7*f5*f2*f3-44*x3^2*x4*x5*f7*f2^2*f5^2+16*x1^
2*x2*x7*f1*f3*f7*f2*f4+32*x1^3*x2*f4^3*f0^2*f7+32*x1^3*x2*f6^2*f4*f1^3-10*x2^2
*x3^2*f7^3*f1^3+4*x5*x6^2*x7*f2*f4-16*x5*x6^2*x7*f0*f6-12*x4*x6^2*x7*f7*f3^2+8
*x3^2*x6^2*f0*f7^2*f2-4*x1^2*x4*x5*f1^2*f7*f3*f5-4*x1*x3*x4*x6*f7*f4^2*f2*f3+
20*x1*x3*x4*x6*f7^2*f2*f3*f1-8*x1^2*x3*x5*f4^3*f2^2-16*x2^2*x3*x5*f4^2*f6*f2^2
-8*x4*x7^2*f7^2*f2^2*x2-8*x2*x4^2*x6*f7*f3*f4*f2*f6-8*x3^4*f7^2*f3*f4^2*f1-8*
x3^4*f1*f7^2*f2*f4*f5-64*x2*x7*x3^2*f0*f7^2*f3*f4-12*x1^2*x2*x5*f7*f2^4+36*x2^
2*x4^2*f4^4*f5^2+36*x2^2*x4^2*f3^2*f5^4-16*x2*x5*x3*x7*f1*f4^2*f6-16*x3*x5*x7^
2*f2*f4*f6-8*x2^2*x3*x6*f1*f7^2*f2^2-16*x2^2*x3*x6*f5*f4^3*f2-4*x2^2*x3*x6*f7^
2*f1^2*f3+6*x3^4*f4^2*f5^3*f3+16*x5*x6*x7^2*f1*f6+16*x1*x7*x4^2*f7^2*f0*f4^2+
20*x1*x7*x4^2*f7^2*f4*f2^2-8*x1*x7*x4^2*f7^2*f3^2*f2-16*x2^2*x3*x4*f5*f2^3*f7^
2-240*x1*x2*x4^2*f7*f1*f5^2*f3*f4+16*x1^2*x2*x3*f2*f4*f5*f1*f6*f3+32*x2*x3*x6*
x7*f4^2*f2*f6-16*x2*x3*x6*x7*f5*f4^2*f3+128*x2*x3*x4*x6*f7*f4^2*f5*f1-12*x2*x3
*x4*x6*f7*f2^2*f5^2-24*x2^2*x3*x5*f1^2*f5^2*f6+24*x2^2*x1*x6*f0*f7^2*f1*f2-16*
x3^3*x4*f6*f4*f5*f7*f2*f3+4*x4^3*x2*f7^2*f3^2*f4^2+8*x4^3*x2*f7^2*f3^2*f2*f6-\
80*x4^3*x2*f0*f6*f1*f7^3-16*x2^2*x3*x6*f5*f4*f6*f1*f3+12*x4^3*x2*f7*f4^4*f5+32
*x4^3*x2*f1^2*f6^2*f7^2-312*x4^3*x2*f4*f5^3*f7*f2+16*x1^2*x5^2*f0*f6*f2^2+64*
x1^2*x2*x4*f7^2*f6*f2*f0^2+48*x1^2*x2*x4*f0*f6*f5*f3*f4^2-36*x1^2*x3^2*f4*f7^2
*f2*f1^2+48*x1^2*x3^2*f4*f6*f1^2*f5^2-8*x1^2*x6*x7*f0*f3^2*f7-16*x1*x7*x3^2*f3
^2*f5*f7*f2-16*x3^2*x1*x7*f6^2*f4*f2^2+8*x1^2*x5*x7*f0*f4^3-4*x3^2*x2*x5*f4*f5
^2*f2*f3-36*x2*x4^2*x6*f5^4*f2+8*x2^2*x3*x6*f7*f2^2*f5*f3-4*x2*x3^2*x6*f7*f3^3
*f4-16*x1*x3*x4*x5*f7*f4^2*f2^2-8*x2^2*x3*x6*f2^2*f5^3-80*x1^2*x3^2*f0*f6*f7^2
*f1^2-110*x4^2*x7^2*f7*f5^2*f3-24*x1^2*x3^2*f2*f5^3*f4*f1+4*x3^4*f0*f3*f7^3*f2
+4*x1^2*x3^2*f1*f3*f7^2*f2^2+24*x6^2*x4*x7*f5*f4^2-28*x6^2*x4*x7*f7*f1*f5-16*
x6^2*x4*x7*f7*f2*f4-16*x1*x2*x4*x6*f7*f2*f3^2*f4-4*x7^2*x3*x8*f1*f7^2+24*x7^2*
x3*x8*f7*f2*f6+40*x7^2*x4*x8*f7^2*f2-64*x2*x3*x4*x7*f2*f6*f0*f7^2+16*x2^2*x5*
x7*f0*f4*f3*f7+8*x2^2*x5*x7*f0*f5^2*f4+24*x3*x5^2*x6*f2*f1*f6-8*x3*x5*x1*x6*f1
*f6*f2*f4-16*x1^3*x3*f3*f1^2*f5*f4*f6-16*x1*x3^2*x4*f0*f5*f3^2*f7^2-40*x1^3*x3
*f2*f3*f4*f1*f5^2+64*x1^2*x2*x7*f0*f6*f7*f2^2+16*x2^3*x3*f0*f6*f5*f7*f3*f2+32*
x1^3*x3*f3^2*f1*f5*f2*f6+28*x3^3*x4*f1^2*f7^3*f4+156*x4^2*x3*x5*f7^2*f3*f4*f1-\
144*x4^2*x3*x5*f4*f5^2*f6*f2+48*x4^3*x5*f0*f6*f7^2*f3-8*x2^3*x4*f2*f6*f7^2*f1^
2-2*f7^2*x3^2*x8^2*f3^2-2*f7^2*x3^2*x8^2*f2*f4-2*f7*x3^2*x8^2*f3*f5^2-6*f7*x3^
2*x8^2*f5*f4^2-124*x4^2*x3*x5*f7*f3^2*f4*f5+8*x1*x2*x4*x6*f7*f2*f6*f3*f1-16*x4
^3*x2*f7^2*f2*f5*f1*f6+216*x4^3*x2*f6*f2*f5^4+16*x4^3*x2*f7^2*f2^2*f6*f4-240*
x4^3*x2*f5^2*f4^2*f7*f3-12*x2^2*x3*x6*f4^4*f3+52*x1*x2*x4^2*f7*f3*f5*f4^2*f2+
76*x1*x2*x4*x6*f7*f2*f4*f1*f5-96*x1^3*x3*f0*f3*f2*f1*f7^2+2*x1^2*x5^2*f1^2*f3*
f5-32*x1*x5*x3*x7*f0^2*f7^2+8*x1^3*x3*f1*f4^4*f3-168*x3^3*x4*f5^2*f4^2*f3*f6+
16*x3^3*x4*f0*f3^2*f7^3+4*x3^2*x2*x7*f2*f5^3*f4-24*x2^2*x3*x6*f0*f5^3*f4-24*x2
^3*x4*f4^3*f1*f5*f6+32*x1^2*x2*x3*f6^2*f4*f1^2*f3-64*x1^2*x2*x4*f0^2*f7^2*f4^2
+192*x1^2*x2*x4*f5^2*f6^2*f0^2-76*x1^2*x4^2*f7*f2*f3^2*f4*f5+136*x1^2*x4^2*f1*
f6*f0*f7^2*f3-4*x3*x7^2*x5*f5^2*f2+36*x2^2*x3*x6*f7*f2*f5*f1*f4+48*x4^2*x1*x7*
f4*f5^2*f1*f7-144*x4^2*x1*x7*f7*f2^2*f6*f5-48*x4^2*x1*x7*f7*f2*f5*f4^2+64*x1*
x7*x4^2*f7^2*f0*f6*f2-8*x3^2*x1*x5*f1^2*f5^2*f6-8*x3^2*x1*x5*f4^2*f6*f2^2+8*x2
*x5*x3*x7*f4^2*f2*f5+24*x2^2*x4*x7*f4^4*f5-100*x4^3*x2*f7^2*f3^3*f5+32*x1^2*x2
*x4*f7*f0*f3^3*f6-64*x1^2*x2*x3*f6*f5*f3*f0^2*f7+32*x1*x5*x4*x6*f7*f0*f4*f3-16
*x3^2*x5*x6*f0*f7^2*f1+64*x3*x5*x7*x8*f7*f0*f6-40*x3^2*x4^2*f7*f2*f5*f4^2*f6-\
16*x1*x3^2*x6*f0*f6*f3^2*f7-8*x1*x3*x4*x7*f7*f4^2*f1*f5-80*x1^2*x2*x3*f0*f6*f5
^2*f1*f4-32*x1^2*x2*x3*f0*f6^2*f4*f2*f3+8*x1*x2*x3*x5*f2*f6*f1*f4^2+16*x1^2*x3
^2*f0*f4*f7^2*f2^2+16*x3^2*x1*x5*f0*f4^2*f3*f7+32*x3^2*x1*x5*f1*f6*f4^2*f3+4*
x2*x4*x6^2*f7*f5*f1*f3-108*x4^3*x6*f4*f5^4+56*x1*x2*x3^2*f7*f2*f4*f1*f6*f3-16*
x1^2*x2*x5*f0*f5*f4^2*f2+40*x3^2*x4^2*f7^2*f2^2*f4*f6-4*x3^3*x2*f3*f5^4*f2+8*
x3^3*x2*f0*f5^5+416*x3^2*x4^2*f6*f5^2*f7*f1*f4-464*x3^2*x4^2*f3*f5*f6^2*f7*f1-\
60*x3^2*x4^2*f7^2*f4^2*f5*f1+16*x2^2*x3^2*f0*f4^3*f6^2+32*x1*x3*x2*x7*f7*f4^2*
f2^2-48*x1*x2*x3^2*f0*f6*f7*f3*f5*f2-28*x1*x2*x3^2*f1^2*f5^2*f4*f7+16*x5*x6*x7
^2*f7*f0-16*x2^2*x4*x5*f7*f3*f4^2*f1+4*x2^3*x5*f7*f3*f1^2*f5+8*x2^3*x5*f7^2*f0
*f1*f2+8*x1*x4*x2*x7*f1^2*f7^2*f4+24*x1^2*x4*x5*f0*f5*f4^3-16*x1^2*x5^2*f4*f0^
2*f6-48*x2^2*x4*x5*f0*f6*f5*f4^2+20*x2*x7*f7^3*f1^2*x4^2-32*x3^3*x1*f0*f6*f4^2
*f3*f7+24*x3^3*x1*f3*f6*f4^2*f2*f5-16*x3^3*x1*f0*f4^2*f2*f7^2-108*x4^2*x2*x7*
f3*f5^4-24*x4^3*x2*f5*f4^2*f7*f2*f6+132*x4^3*x2*f1*f7*f5^4+120*x3*x4*x6*x7*f7*
f4*f2*f5-24*x3*x4*x6*x7*f7^2*f2^2-120*x3*x4*x6*x7*f4^2*f5^2+48*x3*x4*x1*x6*f1*
f6^2*f2*f5-10*x1^2*x3^2*f1*f5^2*f7*f2^2-108*x4^2*x6*x7*f5^3*f4-132*x4^3*x5*f5^
3*f7*f1+17*x3^4*f1^2*f7^2*f5^2-12*x4*x6^2*x8*f7*f2*f5-58*x1^2*x3^2*f4^2*f7*f1^
2*f5-16*x1^4*f6*f4^3*f0^2+8*x1*x2*x3^2*f3^2*f5*f4*f7*f1+64*x3^2*x4^2*f0^2*f7^4
+16*x3^3*x1*f7^2*f2*f4*f1*f3-20*x3^2*x4*x6*f7^2*f2^2*f4-80*x3^2*x4*x6*f0*f4^2*
f7^2-4*x1^2*x3*x7*f4^4*f2-48*x1*x4*x2*x7*f2^2*f5^2*f6+24*x1*x4*x2*x7*f4*f5^3*
f1+32*x3^2*x2*x4*f0*f4^3*f7^2-48*x2*x3^2*x4*f7*f2*f3^2*f5*f6-4*x2^2*x3^2*f5^3*
f2*f3*f4+16*x1^4*f6^2*f2^2*f1^2+32*x1^4*f6^2*f1^3*f3-8*x3^3*x4*f7^2*f3^3*f4+96
*x3^3*x4*f6^2*f2*f3*f5^2+64*x1*x2*x3^2*f0*f5^2*f2*f7*f4+24*x1^2*x2*x4*f5^2*f2*
f3^2*f4+160*x3^2*x4^2*f7*f3*f5^2*f6*f2-108*x3^2*x4^2*f7^2*f3*f5^2*f1+520*x3^2*
x4^2*f0*f5^2*f4*f7^2+8*x3^2*x4^2*f0*f4*f3*f7^3-48*x1^2*x3^2*f0*f6^2*f4^2*f2+8*
x1^2*x3*x5*f0*f4^4-28*x3^2*x4^2*f7^2*f2*f3*f5*f4-204*x4^2*x2*x5*f7*f3*f4*f2*f5
-128*x4^2*x2*x5*f0*f6*f5*f3*f7+288*x4^2*x2*x5*f0*f6*f5^3+32*x4^2*x2*x5*f7*f3^3
*f5-16*x2^3*x4*f0*f6*f4^2*f3*f7-8*x5*x6*x7^2*f3*f4+4*x3^2*x6*x8*f7*f1*f5^2+32*
x2*x3*x4^2*f7^3*f0*f3^2+32*x1*x3^2*x4*f0*f6^2*f7*f3^2+24*x1^2*x3*x6*f3^2*f1*f4
*f6-4*x2^2*x4^2*f7^2*f2^3*f6-24*x3*x4*x6*x8*f7^2*f2*f3-16*x3*x4*x5*x8*f7^2*f2^
2+248*x3^2*x4^2*f7*f3^2*f5*f6*f4+36*x3^2*x2*x4*f5^5*f1-12*x1^2*x2*x4*f4^3*f5*
f3*f2+8*x1*x2*x3*x6*f1*f5^2*f0*f7-96*x3*x4*x6*x7*f3*f7*f2*f6+24*x3*x4*x5^2*f3^
2*f5*f4+64*x1^2*x4*x6*f6*f5*f0^2*f7-16*x4^2*x5*f0*f7^2*f2*x3*f6+80*x3*x4*x5^2*
f0*f4^2*f7-8*x1*x2*x3^2*f7*f2*f5*f3^3+40*x1*x2*x3^2*f5*f7^2*f2*f1^2-4*x6^3*x7*
f3*f4+8*x6^3*x7*f1*f6+8*x1*x2^2*x6*f1*f5^2*f2*f4-16*x1^2*x2*x3*f0*f5^3*f2*f4+
48*x3^2*x1*x4*f5^2*f4^2*f1*f6-64*x3^2*x1*x4*f1^2*f6*f7^2*f3-48*x1^3*x3*f0*f5*
f4*f2^2*f7+8*x3^3*x2*f7^2*f3*f4*f2^2+96*x1^2*x4*x6*f0*f5*f6^2*f1-56*x1^2*x3^2*
f4^2*f6*f1*f5*f2+24*x2^2*x4*x5*f0*f4^3*f7-16*x1*x7*x4^2*f7^2*f0*f5*f3+216*x4^2
*x7^2*f7*f5*f2*f6-8*x2*x7*x3*x8*f7*f2*f3*f6-24*x1*x7*x4*x8*f7^2*f2^2+16*x1^3*
x3*f2*f6*f3*f7*f1^2+32*x2*x5*x6*x7*f0*f6*f4-8*x2*x5*x6*x7*f2*f4^2-8*x2*x5*x6*
x7*f3^2*f4+16*x2*x5*x6*x7*f2*f3*f5+16*x1*x2*x3*x5*f1*f5^2*f2*f4-96*x1^2*x2*x4*
f0*f6^2*f4*f1*f5+38*x1^2*x4^2*f7*f3^4*f5+96*x1^2*x4*x7*f1*f7*f2*f3*f6-2*x1^2*
x4^2*f7*f4^2*f3^3+120*x2*x3*x4*x7*f5^2*f4^3-64*x1^2*x3*x4*f7^2*f0^2*f3*f6+96*
x2*x3*x4*x7*f5^3*f1*f6+32*x1^2*x2*x3*f0*f6*f3^2*f2*f7-16*x1*x2^2*x4*f1^2*f5*f7
*f6*f3+44*x1*x3*x4*x5*f1^2*f7*f5^2-12*x1*x3*x4*x5*f1*f7^2*f2^2+2*x2^2*x3^2*f4^
2*f5^2*f3^2-32*x2*x7*x4*x8*f7^2*f2*f3+16*x1*x7^2*x2*f7*f4*f2^2+16*x1*x7^2*x2*
f0*f7*f4^2+16*x1*x7^2*x2*f0*f7*f5*f3-32*x1*x7^2*x2*f0*f6*f7*f2-16*x3^3*x1*f6*
f2*f5^3*f1-16*x3^3*x1*f0*f2*f1*f7^3+32*x3^3*x1*f6^3*f1^2*f4+16*x3^3*x1*f3^2*f6
*f4*f1*f7-12*x1*x5^2*x4*f1^2*f7*f4-8*x2^2*x5^2*f7*f0^2*f5+56*x4^2*x2*x8*f7^3*
f2*f1+92*x2*x8*f7^2*x4^2*f1*f4*f5-216*x2*x8*f7^2*x4^2*f0*f5^2+48*x2*x7*f0*f6*
f7*f3*x3^2*f5+16*x1*x7*f0*f6*f7*f2*x3^2*f5-48*x3^2*x1*x7*f0*f6*f5^2*f4-48*x1^2
*x2*x4*f3*f6*f4*f2^2*f5+32*x1^3*x5*f1*f4*f2*f0*f7+16*x2*x5*x6*x7*f1*f4*f5+8*x1
^2*x5^2*f0*f4^2*f2-12*x1^2*x5^2*f2*f1^2*f6+8*x2*x5^2*x7*f0*f4*f5+12*x1^2*x2*x4
*f4^4*f1*f5-12*x1^2*x2*x4*f4^2*f3^3*f5-8*x2^2*x3*x5*f1*f5*f7*f2*f3-18*x1^2*x3^
2*f2^2*f5*f3^2*f7+80*x3^2*x1*x4*f0*f4^3*f6*f7+8*x3^2*x1*x4*f4^2*f6*f7*f2^2-72*
x3^2*x1*x4*f1*f6*f7*f4^2*f3-40*x3^2*x1*x4*f2*f7^3*f1^2-32*x3^3*x2*f4*f6^3*f2*
f1-48*x3*x4*x5^2*f0*f5^3-32*x3^2*x1*x4*f0*f6*f4*f1*f7^2-144*x3^2*x1*x4*f0*f6*
f5^3*f4-4*x3^2*x1*x4*f7*f2*f4^4+24*x3^2*x1*x4*f7^2*f3^2*f1*f4-228*x4^3*x5*f7*
f3^2*f5^2-48*x3^2*x1*x7*f0*f4*f7^2*f2+8*x1*x7*f2*f5^2*f7*f1*x3^2-24*x3^2*x1*x4
*f7^2*f3*f4*f2^2-48*x3^2*x1*x4*f6^2*f2^2*f4*f5+48*x3^2*x1*x4*f6^2*f7*f1^2*f4+
32*x1^2*x2*x5*f0*f5^2*f3*f2+20*x1*x2*x3*x6*f1^2*f5*f7*f4+8*x1*x2*x3*x6*f7*f2^3
*f5-4*x3^2*x1*x5*f2^2*f5^2*f4-8*x3^2*x1*x5*f7*f3^2*f1*f4-32*x3^2*x1*x5*f0*f4^3
*f6-12*x7^2*x5*x8*f7*f2+2*x1^2*x7^2*f5^2*f3*f1-16*x1*x6^2*x2*f0*f5*f4^2+96*x4^
2*x1*x7*f7*f2*f3*f5^2-80*x1*x6*x4^2*f7^2*f0*f4*f3+12*x1*x3^2*x2*f4^3*f7*f2^2-\
48*x1*x3^2*x2*f0*f5^3*f4^2-24*x3^2*x1*x4*f6*f2^2*f5^3+12*x4^3*x5*f7*f3*f4^2*f5
-216*x4^3*x5*f6*f5^3*f2+96*x3^2*x2*x4*f3*f5*f6^2*f2*f4-78*x1^2*x3^2*f3*f5^2*f7
*f1^2-24*x1^3*x4*f0*f5*f4^4-4*x3^3*x4*f7^2*f3*f4^2*f2-84*x3^3*x4*f7^2*f3*f5*f1
*f4-32*x1*x5^2*x4*f6*f0^2*f7+16*x1*x5^2*x4*f0*f4*f2*f7+36*x4^2*x5^2*f3^2*f5^2-\
32*x3*x5*x6*x7*f0*f5*f6+48*x3*x5*x6*x7*f7*f0*f4-8*x3*x5*x6*x7*f7*f3*f1+32*x1^2
*x5*x7*f2*f4*f6*f0-4*x1*x2*x3*x6*f7*f2*f4^2*f1+52*x1^2*x2*x3*f2^2*f5*f7*f4*f1+
8*x2^3*x3*f0*f5^3*f1*f7+168*x4^3*x5*f4*f5^2*f2*f7+72*x1*x4*x3^2*f7^2*f2*f5*f3*
f1+8*x1*x4*x3^2*f4*f5^2*f1*f3*f7-16*x3^3*x1*f7^2*f2^3*f4+12*x1^2*x2*x3*f3^2*f5
*f7*f2*f1+4*x5*x7^2*x6*f2*f5+32*x4^2*x5*x6*f0*f6*f7*f4-8*x3*x5^2*x6*f2*f3*f4+
24*x3*x5^2*x6*f0*f5*f4-4*x3*x5^2*x6*f3*f1*f5+16*x3*x5*x6*x7*f1*f4*f6-8*x4^2*x5
^2*f0*f6*f7*f3-64*x4^2*x6*x3*f0*f6^2*f7*f4+32*x4^2*x6*x3*f1*f6^2*f7*f3-12*x2^2
*x4*x8*f7*f2*f5^2*f3+32*x2^2*x4*x8*f7*f5^2*f4*f1-12*x3*x6*f3^3*f7^2*x4^2+24*x1
*x7*x3^2*f0*f5*f7*f4^2-56*x1*x7*x3^2*f0*f7^2*f5*f1-4*x3^2*x1*x7*f5^2*f4^2*f2-\
16*x3^2*x1*x7*f2*f6*f4^3-256*x3^2*x4^2*f7^2*f2*f1*f5*f6+40*x1^2*x3^2*f6*f7*f1^
2*f5*f2+48*x3^2*x1*x4*f4^2*f2*f7^2*f1+16*x3^3*x1*f4^2*f6*f2*f7*f1-32*x4^3*x2*
f7^3*f3*f2^2-536*x2*x4^3*f7^2*f3*f5^2*f1+672*x2*x4^3*f0*f5^2*f4*f7^2-12*x2^2*
x5^2*f2*f5*f1*f4+198*x3^2*x4^2*f4^2*f5^4+4*x2*x3^3*f7^2*f2*f5*f3*f1-56*x1^2*x2
*x3*f1*f3*f7*f2^2*f6+16*x1^2*x2*x3*f0*f6*f7*f2^2*f4+24*x3^2*x1*x4*f3*f5^4*f2+8
*x1*x2^2*x7*f1^2*f5^2*f6-4*x1*x2^2*x7*f2*f5^3*f1+4*x1*x2^2*x7*f2^2*f4*f5^2-16*
x2*x3*x4^2*f7^2*f3^3*f4+144*x2*x3*x4^2*f6*f5^4*f1-576*x2*x3*x4^2*f0*f6^2*f5^3+
144*x2*x3*x4^2*f3^2*f5^3*f6-32*x3^2*x1*x5*f6^2*f1^2*f4+4*x3^2*x1*x5*f3*f7*f2^2
*f4+8*x3^2*x1*x5*f0*f5^2*f4^2-48*x3^2*x1*x4*f0*f4^2*f3*f7^2+96*x1*x4*x3^2*f0*
f6*f5^2*f2*f7+24*x3^2*x1*x7*f7^2*f2*f1*f3+20*x1^2*x3^2*f2^3*f5*f4*f7-16*x2*x5*
x6^2*f0*f4*f5-32*x3^2*x4^2*f0*f6^2*f4*f5*f7-4*x3^2*x7^2*f1*f7^2*f3+16*x1^2*x2*
x5*f0*f4*f2^2*f7-72*x1*x2*x3*x6*f0*f4*f2*f7*f5+32*x1^2*x2*x3*f0*f6^2*f5*f1*f3-\
64*x1*x6*x4^2*f7^2*f0*f6*f1-180*x4^2*x3*x6*f4^2*f5^3+12*x1^2*x4*x7*f7*f3^4+16*
x1*x6^2*x2*f0*f4*f2*f7-32*x1^2*x2*x5*f0*f6*f5*f2^2+32*x3^3*x2*f0*f6*f3*f2*f7^2
-16*x3^3*x1*f6*f7^2*f2*f1^2+28*x1*x3^3*f7*f2*f5^2*f1*f4-40*x1*x3^3*f0*f5*f7^2*
f3*f2-4*x3^3*x1*f7*f4^4*f1-8*x1*x6^2*x2*f7*f2*f3*f1-84*x1^2*x2*x3*f3*f4*f5*f7*
f1^2-160*x1^2*x2*x3*f2*f0*f7^2*f4*f1+16*x4^3*x5*f0*f7^3*f2-76*x4^3*x5*f7^2*f2^
2*f5+912*x4^3*x5*f0*f6*f5^2*f7-48*x4^3*x5*f1*f7*f6*f4*f5-16*x2*x3^2*x6*f3*f6^2
*f4*f1+44*x2*x3*x4*x8*f7^3*f1^2-32*x1*x6*f0*f6^2*f7*f1*x3*x4-2*x1^2*x5^2*f2^3*
f4-12*x1^2*x3*x6*f2^2*f5*f4^2+16*x1^2*x2*x3*f3*f4^2*f7*f2*f1+60*x2*x4^3*f7^3*
f3^2*f1-140*x2*x4^3*f2*f7^3*f1*f4-96*x1^3*x4*f1*f5^2*f6*f4*f0+56*x1^4*f0*f6*f4
^2*f3*f1+16*x1*x6*x3*x7*f2*f1*f6^2+16*x1*x6*x3*x7*f7*f2^2*f4+32*x1*x6*x3*x7*f0
*f7^2*f1+8*x1*x6*x3*x7*f3^2*f7*f2-36*x4^2*x6^2*f2*f6*f5^2-44*x1*x4*x6^2*f7*f2*
f5*f1+72*x1*x4^2*x5*f0*f5^4-4*x6^4*f0*f6+8*x1*x7^2*x5*f0*f5^2+48*x3^2*x2*x7*f4
^2*f6^2*f1-32*x3^2*x2*x7*f3*f4^3*f6-8*x2*x7*f7*f3^3*x3^2*f5+12*x3^2*x2*x7*f5^4
*f1-172*x4^3*x5*f1^2*f7^3+124*x2*x4*x6*x7*f1*f7*f4*f5+192*x2*x4*x5*x7*f0*f5^2*
f6+12*x2*x4*x5*x7*f1*f7*f4^2-80*x2^2*x4*x7*f2*f5*f0*f7^2+4*x3^3*x2*f7^2*f3^3*
f2-64*x2*x3^3*f6*f5*f0^2*f7^2-16*x4*x7*x3^2*f3*f5*f2*f6*f7+192*x4*x7*x3^2*f4*
f6*f1*f5*f7-68*x3^2*x4*x7*f5*f4^2*f7*f3-384*x3^2*x4*x7*f0*f6^3*f5+12*x3^2*x1*
x4*f4*f5^4*f1-8*x1^3*x4*f7*f3^4*f2-8*x5^2*x3*x8*f0*f4*f7-16*x5^2*x7*x8*f7*f0-\
96*x1^3*x4*f0*f6*f5^2*f2*f3+96*x1^2*x2*x3*f0*f5*f1*f7*f4^2-4*x1^2*x2*x5*f2*f4*
f3^3-12*x4^3*x5*f3^3*f7^2-72*x2*x4^3*f7^2*f4^2*f5*f1-56*x4^3*x2*f7^2*f2^2*f5^2
-72*x4^2*x2*x6*f5^2*f4^3+40*x3^2*x1*x7*f3*f5*f6*f2*f4+16*x3^2*x1*x7*f5*f4^2*f1
*f6-32*x4^2*x3*x6*f1^2*f7^3-20*x3*x5*x7*x8*f7*f2*f4-16*x3*x5*x7*x8*f7*f1*f5-16
*x3^2*x5*x7*f4*f5*f1*f6+32*x3^2*x5*x7*f0*f6^2*f4-16*x1^3*x4*f7^2*f4*f1^3-16*x2
^2*x4*x7*f7*f4^3*f2+96*x2^2*x4*x7*f7^2*f1^2*f5+24*x1^2*x3^2*f4^3*f7*f1*f2-24*
x2*x3^3*f4*f5^2*f1*f3*f7-8*x2*x3^3*f0*f5*f2*f7^2*f4-12*x2*x3^3*f2*f5*f7*f4^2*
f3-32*x2*x3^2*x6*f0*f6^2*f4^2+32*x2*x3^2*x6*f6*f0^2*f7^2-32*x1*x3^2*x2*f0*f6*
f7^2*f1*f2+2*x2^2*x3^2*f5*f7^2*f3*f1^2+24*x2*x3*x4*x6*f3^2*f5^3-8*x1^2*x3*x7*
f3*f6*f2^2*f5+256*x1*x3*x4^2*f7^3*f0^2*f5+8*x1^2*x3^2*f3^2*f5^3*f1+40*x1^2*x3*
x7*f6*f1^2*f5^2+24*x2^2*x3*x6*f0*f4^3*f7-16*x1*x7^2*x2*f1*f5*f7*f2+8*x1*x2^2*
x7*f7*f2*f4^2*f1-32*x1*x2^2*x7*f1^2*f7^2*f2-64*x1^2*x2*x4*f7*f0^2*f6^2*f3+8*x3
^2*x7^2*f7^2*f2^2-72*x4^2*x2*x5*f3^2*f5^3-16*x1*x2^2*x6*f1^2*f5*f4*f6+184*x2*
x3*x4*x6*f7*f2*f5*f1*f6+12*x1*x3*x6^2*f1*f7*f2*f4+52*x4^3*x5*f1*f7^2*f4^2+476*
x4^3*x5*f1*f7^2*f3*f5-1000*x4^3*x5*f0*f5*f7^2*f4+40*x1^4*f0*f5*f1^2*f7*f4-40*
x3*x4*x5*x8*f7*f1*f5^2+24*x2^3*x4*f7*f3^2*f1*f5^2-8*x2^3*x4*f3*f5^2*f7*f2^2+12
*x3^2*x2*x4*f4*f5^4*f2-72*x1*x3^3*f0*f5*f1*f7^2*f4+16*x3^3*x1*f0*f6*f3*f1*f7^2
+16*x3^3*x1*f0*f5*f4^3*f7-8*x3^3*x1*f2*f4^4*f6-24*x3^3*x2*f7*f3^2*f2*f4*f6+24*
x2*x4*x1*x6*f1*f5^2*f6*f2-8*x1*x7*x3*x4*f3^2*f7*f2*f6-88*x2*x4*x7*x8*f7^2*f0*
f5-16*x3^3*x2*f1*f6*f7^2*f2^2+4*x1*x7*x5*x8*f7*f2^2+8*x2^3*x4*f0*f5^3*f2*f7-4*
x3^2*x2*x8*f7^2*f2^2*f4-40*x4^2*x2*x7*f7^2*f2^2*f5+172*x4^2*x2*x7*f7*f3^2*f5^2
+128*x4^2*x2*x7*f5^3*f7*f1-48*x1^3*x4*f3*f4*f5*f7*f1^2+56*x6^2*x3*x4*f7*f2^2*
f6-8*x6^2*x3*x4*f7*f1*f3*f6+48*x6^2*x3*x4*f0*f6*f7*f4-24*x4*x6*x2*x8*f7^2*f0*
f4-8*x1*x6*x4*x7*f7*f2*f3*f4+4*x2*x6^2*x4*f7*f3^3+8*x3^2*x6^2*f3*f6^2*f1-4*x2^
4*f0*f6*f7^2*f1^2+200*x2^2*x4*x7*f0*f5^2*f4*f7-96*x2^2*x4*x7*f0*f5^3*f6+96*x2^
2*x4*x7*f1*f6*f4*f5^2+18*x4^4*f3^3*f7^3+4*x4^2*x6^2*f2*f6*f7*f3+10*x4^2*x6^2*
f1*f5^2*f7-38*x4^2*x6^2*f5*f7*f3^2+144*x4^2*x6^2*f0*f6*f7*f5+2*x4^2*x6^2*f7*f4
^2*f3-32*x3*x6*x7^2*f6^2*f1+36*x2*x4*x7^2*f5^2*f4^2-16*x1^2*x2*x5*f0*f4^3*f3-4
*x1^2*x2*x5*f2^2*f3*f4^2+16*x1^2*x2*x5*f3^2*f1*f4^2+40*x3^2*x1*x6*f0*f5^3*f4-4
*x1*x7^2*x3*f1*f7*f4^2-8*x1*x2^2*x3*f1*f3^2*f7*f2*f6+64*x1*x2*x3*x6*f6*f0^2*f7
*f5-8*x1*x2^2*x3*f1^2*f3*f7*f4*f6+48*x1^2*x2*x4*f0*f5^3*f4*f3-24*x1^2*x3*x4*f3
*f5^2*f2^2*f6-12*x2*x3*x6^2*f5^2*f1*f4+96*x1^2*x3*x7*f0*f6*f5*f3*f4+16*x3^3*x2
*f0*f3*f1*f7^3-16*x3^3*x2*f6*f2*f5*f4^3+12*x3^3*x2*f5*f4^5+32*x1^2*x3^2*f4^2*
f0^2*f7^2-12*x1^2*x3^2*f6*f2^3*f5^2+32*x1*x3^2*x7*f0*f6^2*f4^2-128*x1^3*x3*f6*
f0^3*f7^2-8*x1^2*x2*x5*f1*f4*f2^2*f6-40*x1*x2*x3*x6*f0*f3^2*f7*f5+216*x4^2*x2*
x7*f6*f5^3*f2-8*x1^2*x2*x5*f1*f5^2*f2^2-4*x1^2*x2*x5*f1^2*f5^2*f3-4*x1^2*x2*x5
*f1^2*f5*f4^2+4*x1^2*x2*x5*f2*f4^3*f1+8*x1^2*x3^2*f3^4*f6*f4-32*x1^2*x3^2*f0^2
*f7^3*f1+64*x1^2*x3^2*f6^3*f0^2*f4-72*x1*x2*x3*x4*f3*f6*f4*f1*f5^2-24*x3^2*x4*
x7*f7^2*f2*f3*f4-60*x4*x7*x3^2*f3*f5*f1*f7^2+192*x4*x7*x3^2*f0*f5*f7^2*f4+224*
x4*x7*x3^2*f0*f6*f5^2*f7-4*x1^2*x6^2*f2^3*f6-40*x1*x4*x2*x6*f0*f4^3*f7+4*x2^2*
x4*x6*f2^3*f7^2-32*x1^2*x3^2*f2^2*f3*f4^2*f7-240*x4^2*x2*x5*f0*f5^2*f4*f7+32*
x4^2*x2*x5*f0*f6*f1*f7^2+4*x2*x7*x5*x8*f7*f2*f3+24*x2^2*x1*x4*f4^3*f7*f2^2+8*
x1^2*x6*x7*f2*f1*f5^2+18*x4^2*x6^2*f3*f5^3-4*x2*x3^2*x7*f7*f1*f5^2*f3+4*x2*x3^
2*x7*f7*f3^2*f4^2+12*x3^2*x4*x5*f3^2*f5^3+8*x1^2*x6*x7*f0*f5*f4^2-4*x1*x5*f2^3
*f7*x3^2*f5+16*x3^2*x1*x5*f1^2*f6*f7*f3-16*x3^2*x1*x5*f0*f2^2*f7^2+8*x6^2*f7*
f0*f4*x3^2*f5+12*x4*x6^2*x5*f2*f4*f5-48*x4*x6^2*x5*f0*f5*f6+16*x1*x3^3*f0*f5^2
*f3*f7*f4-8*x1*x3^3*f7*f3^2*f2*f5*f4-28*x1*x3^3*f5^3*f7*f1^2-152*x4^2*x2*x7*f7
*f3*f4^2*f5-284*x4^2*x2*x7*f4*f5^2*f2*f7+144*x4^2*x2*x7*f0*f6*f7^2*f3+108*x4^2
*x2*x7*f4^2*f5^3-8*x3*x6^2*x7*f6*f3^2-24*x2*x6*x7^2*f7*f0*f5+28*x2*x6*x7^2*f7*
f1*f4-16*x2*x6*x7^2*f6*f1*f5+4*x2*x6*x7^2*f3*f5*f4-44*x4*x6*x7*x8*f1*f7^2+16*
x2^2*x3^2*f0*f7^3*f1*f2+4*x1*x2^2*x5*f7*f2*f3^2*f1+32*x1^2*x2*x5*f4^2*f0^2*f7+
4*x1^2*x2*x5*f3^3*f1*f5+18*x1^2*x4^2*f3*f5^4*f1+36*x1^2*x4^2*f4^2*f5^3*f1+12*
x2^2*x1*x4*f5^2*f4^3*f1-88*x2^2*x1*x4*f0*f5^2*f2*f7*f4+72*x3*x4*x7^2*f4*f5^3-\
40*x1*x5*x2*x7*f1*f7*f2*f3-24*x2^2*x3^2*f6*f2*f5^3*f1+32*x2^2*x3^2*f4*f5^2*f6*
f2^2+4*x1^2*x2^2*f1*f5^2*f2*f3*f4-56*x1^4*f0*f4*f3^2*f7*f1-12*x1*x5^2*x4*f2*f5
^2*f1+8*x1*x5^2*x7*f1^2*f6+8*x1*x5^2*x7*f0*f4^2+64*x3*x5*x7^2*f0*f6^2-12*x1^4*
f2*f3^2*f4*f1*f5-6*x1^2*x3^2*f3^3*f5*f4^2-24*x1^2*x3^2*f2^3*f6^2*f4+8*x1^2*x3^
2*f6^2*f4^2*f1^2-8*x1^2*x3^2*f0*f5^4*f2+209*x4^4*f1^2*f7^4+24*x2^2*x4*x7*f3^2*
f5^3-64*x2^2*x4*x6*f6*f0^2*f7^2+12*x2^2*x3*x5*f2*f7^2*f1^2+28*x3*x4*x5*x8*f7^2
*f3*f1-60*x3*x4*x5*x8*f7*f2*f4*f5-18*x1^2*x4^2*f5^2*f4^3*f2-16*x3*x4*x5*x8*f7*
f1*f4*f6-144*x4^2*x5^2*f0*f6*f5^2-44*x1*x5*x4^2*f7^2*f2^3-32*x1*x3^2*x7*f0*f6*
f4*f3*f7+16*x1*x3^2*x7*f1*f7*f2*f4*f6+6*x1^2*x3^2*f3*f5^3*f2^2+8*x1^2*x3^2*f5*
f4^4*f1+80*x4^2*x6*x3*f0*f6*f7^2*f3+76*x3*x4^2*x6*f1*f5*f7^2*f3-56*x3*x4^2*x6*
f7^2*f2*f3*f4+8*x3*x4*x1*x6*f7*f2^2*f4*f5-96*x1*x4*x3*x7*f0*f6*f5^3+320*x3*x4^
3*f7^2*f0*f5^3-16*x3^3*x1*f0*f6*f5^2*f4^2-496*x2*x7*x4^2*f0*f6*f5^2*f7+140*x2*
x7*x4^2*f3*f7^2*f2*f4+416*x2*x7*x4^2*f0*f5*f7^2*f4-36*x4^2*x2*x7*f7^2*f3^3-44*
x1^2*x2*x4*f3^2*f1*f4^2*f7-4*x1*x2*x3^2*f1*f5^4*f2+16*x3^2*x7^2*f3^2*f6^2-8*x1
^3*x3*f4^3*f6*f1^2+32*x1^3*x3*f6^2*f5*f1^3+16*x2^2*x1*x6*f0*f5*f1*f7*f4-8*x1*
x5^2*x4*f1*f7*f2*f3-2*x2^2*x5^2*f7*f1^2*f3-44*x2^2*x4*x6*f7^2*f1^2*f4+8*x1*x3*
x4*x6*f7*f1^2*f6*f5+16*x2^2*x3^2*f1*f6*f5^2*f0*f7-56*x2*x3*x4^2*f2^3*f7^3+48*
x3^3*x2*f0*f4^3*f6*f7-64*x3^2*x4*x7*f0*f7^3*f2-128*x2*x4*x5*x7*f0*f5*f7*f4+48*
x1^3*x3*f3*f7^2*f1^3-28*x1^3*x3*f5^2*f7*f1^3-24*x3*x5*x6^2*f0*f5^2+8*x1*x2*x3*
x4*f3*f6*f4*f7*f2^2-4*x1*x2^2*x5*f7*f2^3*f3+36*x2*x6*x3^2*f4*f5*f7*f3*f1-12*x3
^3*x6*f5*f4^4+32*x1^2*x3^2*f6*f0^2*f7^2*f2-48*x1^2*x3*x4*f3^2*f5^2*f1*f6+4*x2^
2*x5*x7*f2*f4^3-16*x1^2*x2*x3*f2^3*f4^2*f7+16*x3^2*x1*x6*f1*f6^2*f2*f4-48*x1*
x6*f0*f6*f7*f1*x3^2*f5+24*x1^2*x2*x3*f7*f2^4*f6-28*x3^2*x1*x6*f4*f5^2*f2*f3+12
*x2^2*x3*x5*f1*f5^3*f2+52*x1*x6*x3^2*f5^2*f7*f1^2-56*x1*x5*x4^2*f7^2*f0*f3^2+
56*x1*x5*x4^2*f7^2*f1^2*f4+224*x1*x5*x4^2*f7^2*f6*f0^2-52*x4^2*x6^2*f7*f2*f4*
f5+44*x1^2*x2*x3*f1^2*f4*f5^3+16*x1^2*x6*x7*f0*f5^2*f3-80*x1^2*x2*x4*f0*f5*f7^
2*f2*f1-48*x1^2*x2*x4*f7^2*f3^2*f0*f2+24*x2^2*x3*x6*f3*f6*f4^2*f2+20*x1^2*x2*
x3*f5*f4^3*f2^2-48*x1*x3*x4*x7*f1*f7*f6*f3*f4+64*x1*x3*x4*x7*f1^2*f7*f6^2-12*
x3^2*x2*x8*f7^2*f2*f1*f5+4*x2^2*x3*x8*f7*f3*f5*f2*f4-8*x1*x3*x2*x4*f1*f4*f6*f7
*f3^2-28*x1^2*x2*x3*f7*f4^3*f1^2+24*x1^2*x6^2*f0*f6*f4*f2+16*x1^2*x6*x7*f1^2*
f4*f7+32*x3*x6^2*x7*f0*f6^2+16*x1^2*x6*x7*f3*f2^2*f6-8*x2*x6*x7^2*f4^3-32*x3^3
*x2*f3*f6^2*f4*f1*f5+32*x3^3*x2*f6^2*f2*f4^2*f3+48*x1^2*x2*x3*f7^2*f4*f1^3+16*
x2^2*x1*x4*f1*f4*f7*f3^2*f5+120*x2^2*x1*x4*f7*f2*f3*f1*f5^2-28*x2^2*x1*x4*f2^3
*f7*f5^2+20*x1^2*x2*x3*f3*f5^2*f4*f2^2+12*x1^2*x2*x3*f4^2*f3^2*f2*f5-8*x2^2*x3
^2*f1^2*f6^2*f7*f3+6*x2^2*x3^2*f5*f4^4*f3-16*x2^2*x3*x5*f7*f0*f6*f3*f2+16*x3*
x5^2*x7*f0*f6*f4-4*x3*x5^2*x7*f4^2*f2+8*x3^2*x2*x4*f7*f2^2*f5^3+4*x1*x2*x4*x5*
f7*f2*f3^3+456*x4^3*x3*f7*f3^2*f6*f5^2-8*x3^2*x1*x6*f0*f4^3*f7+4*x2^4*f0*f5^2*
f7*f3*f2+96*x3^2*x4*x7*f3^2*f6^2*f5+32*x1^2*x3*x7*f0*f7^2*f2^2-16*x2*x3*x7^2*
f7*f3*f6*f1-16*x2*x3*x7^2*f5^2*f3*f4+16*x2*x3*x7^2*f3^2*f6*f5+32*x2*x3*x7^2*f1
*f6^2*f4-24*x1^2*x3^2*f0*f4^3*f5^2+12*x1^2*x3*x4*f3*f5^2*f2*f4^2+4*x1^4*f2*f6*
f1^2*f4^2+40*x3*x4*x5*x6*f7*f2*f3*f4+16*x1^2*x2*x3*f1*f6^2*f4*f2^2+8*x1^2*x2*
x3*f2*f4*f6*f3^3-8*x1^2*x2*x3*f6*f1*f5*f3^3+12*x5^3*x4*f3*f1*f5+64*x2*x4^2*x6*
f0*f5^3*f7+16*x1*x6*x3*x7*f0*f6*f4*f5-12*x1*x6*x3*x7*f7*f3*f1*f4-8*x1*x6*x3*x7
*f3*f5*f1*f6-12*x1^2*x2*x7*f1*f5^2*f3^2+40*x1*x4*x3^2*f7*f2*f5*f1*f4*f6+16*x1*
x4*x3^2*f1^2*f7^2*f4*f5-8*x1*x4*x3^2*f7*f4*f5^2*f2^2-4*x2*x5^3*f1^2*f5+64*x1*
x4*x3^2*f0*f5^2*f4^2*f7+8*x2*x6^2*x3*f3*f6*f1*f5+4*x3^2*x5*x6*f7*f4*f2^2+4*x3^
2*x5*x6*f1*f5*f7*f2-8*x2*x5*x6^2*f2^2*f5-24*x1*x4*x2*x6*f0*f5^2*f2*f7-60*x1*x4
*x2*x6*f4*f5^2*f2*f3+136*x3*x4*x7^2*f7*f6*f1*f5+24*x3*x4*x7^2*f7*f2*f4*f6-64*
x3*x4*x7^2*f7*f5^2*f2+96*x4*x5*x6*x7*f6*f1*f5-8*x1^3*x3*f3^3*f1*f5^2+36*x1^3*
x3*f5^3*f3*f1^2-16*x1^3*x3*f7^2*f2^3*f0-40*x3*x4*x5^2*f7*f2*f1*f5-72*x3*x4*x5^
2*f3*f6*f1*f5+24*x3*x4*x5^2*f2*f5^2*f3+16*x1^3*x3*f1^2*f6^2*f3^2+16*x2^2*x3^2*
f6*f0^2*f7^2*f4+128*x1^2*x3*x5*f5*f0^2*f4*f7+112*x1^2*x3^2*f0*f6*f4*f7*f3*f2+8
*x1^2*x3*x7*f6*f3^4-8*x3^2*x2*x6*f1^2*f7^2*f4-8*x1^2*x2*x3*f1^2*f3^2*f7*f6-20*
x1^2*x2*x3*f2^3*f5*f7*f3-64*x1^2*x2*x3*f5^2*f1*f4^2*f2-96*x1^2*x2*x3*f0*f6^2*
f7*f1^2-4*x2^2*x3^2*f4^3*f7*f2*f3-96*x2*x7*x4^2*f3*f6*f7*f2*f5-228*x2*x7*x4^2*
f3*f7^2*f1*f5-40*x1^2*x2*x3*f2*f5^2*f7*f1^2-8*x2^3*x4*f4^3*f7*f2*f3-24*x1*x3*
x4*x5*f5^2*f4^2*f1+4*f7^2*x4*x8^2*x5*f1-12*f7*x4*x8^2*x5*f3*f5-24*x1^2*x3*x5*
f1^2*f5*f6*f3-2*x1^2*x3^2*f7*f3^5+16*x3^2*x4*x6*f1*f0*f7^3+16*x3^2*x4*x6*f7^2*
f3^2*f2+8*x1*x3*x2*x8*f7*f1^2*f6*f5-8*x2*x3*x6*x8*f7*f3*f1*f6-20*x3^2*x2*x6*f5
^2*f4^2*f2+4*x1^2*x2*x3*f2^2*f4*f7*f3^2+112*x3^2*x2*x7*f0*f6*f4^2*f7-16*x1*x2*
x3^2*f0*f7^3*f1^2-8*x2^2*x3*x5*f0*f2^2*f7^2+24*f7*x3*x8^2*x4*f3*f5*f6+8*f7^2*
x3*x8^2*x4*f3*f4-16*f7^3*x3*x8^2*x4*f0+76*x3*x4^2*x6*f7*f3^2*f5^2-32*x4^2*x1*
x6*f1*f7*f3*f5^2-32*x3*x6*x7^2*f7*f0*f6+16*x3*x6*x7^2*f3*f6*f4+24*x3*x6*x7^2*
f7*f1*f5+56*x1^2*x2*x3*f6*f5*f7*f1^3-40*x1^4*f6*f1^2*f3^2*f4+8*x1^2*x3^2*f6^2*
f7*f1^3+216*x4^3*x3*f4*f5^5-8*x1*x3*x2*x8*f7*f1*f5^2*f2-8*x2^2*x3*x7*f3^2*f4^2
*f6+4*x3^2*x5^2*f2^2*f5^2+16*x1^3*x3*f7^2*f2^2*f1^2-24*x1*x4*x2*x6*f5^2*f4^2*
f1-48*x3*x4*x6*x7*f1*f7*f4*f6-2*x1^2*x5^2*f1^2*f4^2+32*x3^3*x2*f1^2*f6^3*f5+8*
x2*x3^3*f6*f5^2*f7*f1^2-8*x2*x4^2*x7*f2*f7*f4^2*f6-64*x2^2*x1*x4*f0*f4*f7^2*f3
*f2-4*x3^3*x6*f5^3*f3^2-12*x2^2*x1*x4*f2*f7*f5*f1*f4^2-16*x2^2*x1*x4*f0*f4^2*
f6*f2*f7-48*x2^2*x1*x4*f3*f7*f4*f2^2*f5+32*x1^2*x2*x3*f1^2*f0*f7^2*f5+20*x2*x3
*x7*x8*f7*f5*f2*f4+16*x2*x3*x7*x8*f7*f5^2*f1+8*x1^2*x3*x5*f7*f2*f3^2*f1+24*x1^
2*x3*x4*f3^4*f5*f6+96*x1^2*x2*x4*f0*f5*f6*f7*f1*f3-16*x1^2*x2*x4*f7*f0*f6*f2*
f3*f4+32*x2*x3*x4*x5*f7*f3*f4*f1*f5-16*x1*x3*x5*x7*f1*f7*f2*f4+8*x1*x3*x5*x7*
f4^3*f2-4*x2^2*x3*x4*f7^2*f3^2*f1*f4+32*x1*x2*x3*x4*f0*f6^2*f2*f3*f7+96*x1*x3*
x4*x5*f1*f4*f6*f3*f5-28*x2*x3*x4^2*f7^2*f2*f3^2*f5+32*x1^2*x2*x3*f2^2*f5^2*f0*
f7+18*x1^2*x3^2*f3^2*f5^2*f2*f4+36*x1^2*x3*x7*f1*f4*f7*f3^2-856*x3*x4^3*f7^2*
f1*f3*f5*f6-8*x3*x4^3*f7^3*f2*f3^2+312*x3*x4^3*f1^2*f7^3*f6+1200*x3*x4^3*f7^2*
f0*f6*f4*f5+8*x1*x2*x3^2*f1^2*f5^3*f6-8*x1*x2*x3*x7*f2^2*f3*f7*f5-16*x2^2*x3*
x5*f2^2*f4*f5^2-24*x2^2*x4*x5*f7*f3^2*f1*f5-32*x3*x4^2*x5*f0*f7^2*f5*f3-32*x3^
3*x1*f1*f6^2*f4^2*f3+32*x3^3*x1*f0*f6*f2^2*f7^2-20*x3^2*x7^2*f7*f2*f3*f6-2*x1^
2*x5^2*f1*f3^3-48*x5^2*x4*x8*f7*f0*f5-32*x1^2*x2*x3*f6*f7*f2*f4*f1^2+32*x3^2*
x5^2*f0*f4^2*f6-4*x2*x3^2*x5*f3*f7*f1*f4^2-16*x1*x3*x2*x5*f7*f6*f0*f3*f1-192*
x1^2*x3*x4*f5*f0^2*f7^2*f4+40*x1^2*x3*x6*f2*f5^2*f1*f4+384*x1^2*x3*x4*f6^3*f0^
2*f5-8*x2^2*x3*x8*f7^2*f1*f4*f2-48*x1^2*x3*x4*f2^3*f5*f6^2-24*x1^2*x3*x4*f4*f5
^2*f3^3-144*x2^2*x1*x4*f0*f6*f5*f1*f7*f4+4*x5*x7*f7*f2^2*x3*x6-16*x2*x3^2*x6*
f0*f5^2*f3*f7+4*x2^2*x3*x5*f4^4*f2-16*x1*x7^2*x3*f0*f7^2*f2-8*x1*x7^2*x3*f4^2*
f6*f2+128*x2*x4^3*f0^2*f7^4-32*x3^3*x2*f0*f4^2*f3*f7^2-8*x1*x6*x3*x7*f0*f7*f3*
f5-8*x1*x6*x3*x7*f3*f4*f2*f6+80*x1^2*x3^2*f1*f6^2*f4*f3*f2+8*x2*x5*x7^2*f4^2*
f3-16*x1*x7^2*x3*f0*f6*f5^2-16*x4*x6*x1*x7*f7^2*f0*f2+16*x2*x3^2*x6*f0*f6*f5^2
*f4-8*x2^2*x3^2*f0*f4^2*f2*f7^2+8*x1*x6*x4^2*f7^2*f1^2*f5+80*x4^2*x1*x6*f7*f2*
f5*f1*f6-28*x4^2*x1*x6*f7*f3*f4*f2*f5-12*x1^3*x3*f3^3*f7*f2^2+40*x3^2*x2*x7*f6
*f5^2*f1*f4-16*x2*x7*f3*f7*f2*f4*x3^2*f5-48*x2*x4*x5*x7*f3^2*f5^2+44*x2*x4*x5*
x7*f7*f2^2*f5+8*x3^2*x4*x7*f7^2*f1*f4^2-2*x6^4*f1*f5-4*x1^2*x6^2*f1^2*f3*f7+2*
x5^2*x6^2*f3*f1-4*x5^2*x6^2*f0*f4-4*x2*x5^2*x7*f1*f4^2-32*x3*x5*x4*x7*f7*f1*f4
*f5-12*x2*x5*x4*x6*f7*f3^2*f2-32*x3^2*x2*x6*f2^2*f5^2*f6+16*x1^3*x3*f2^2*f5^2*
f3^2+12*x3^3*x5*f4^3*f5*f3+8*x1^3*x3*f2^2*f5^3*f1-16*x2^2*x4*x7*f1*f7*f6*f3*f4
+4*x2^2*x5^2*f7*f0*f4*f1+8*x1*x5^2*x4*f0*f3^2*f7-2*x3^2*x5^2*f1^2*f7*f5+16*x1*
x5^2*x4*f1*f5*f0*f7-12*x3^2*x1*x4*f5^3*f4^2*f2-8*x3^3*x2*f1*f6*f7*f4^2*f3+4*x3
^3*x2*f7*f3^2*f4^3-36*x1^3*x3*f1^2*f4^2*f3*f7+16*x1*x4*x3^2*f0*f5^3*f3*f7+104*
x3*x4^3*f7^2*f2*f5^2*f3+4*x1^2*x3*x7*f5*f4^2*f2*f3-96*x1*x3*x4*x5*f0*f6*f5*f4^
2+8*x2^2*x3*x5*f7*f1^2*f6*f3-16*x2*x3^2*x6*f7^2*f2*f1*f3+4*x2^2*x3*x5*f3^2*f4^
3+32*x1*x5*f6*f0^2*f7*x3^2*f5-8*x1*x5*f7*f3^2*f0*x3^2*f5+32*x2^2*x4*x7*f7^2*f3
^2*f1+24*x3^2*x2*x8*f7*f1*f4^2*f6-4*x2^2*x4*x7*f3^2*f7*f4^2-36*x2^2*x4*x7*f3*
f5^2*f4^2-96*x1^2*x4*x7*f0*f5*f6^2*f2+4*x1^2*x3*x6*f3*f4^3*f2+x3^4*f7^2*f3^4+
16*x3*x6*x7^2*f7*f2*f4-8*x5*x6^2*x8*f7*f0+8*x3*x6^3*f1*f5^2-96*x4*x7*x3*x6*f0*
f6*f5*f7+8*x1*x5^2*x3*f1^2*f4*f6+16*x1*x5*x3*x6*f1*f5*f0*f7-8*x1*x5^2*x3*f3*f4
^2*f1-8*x1*x5*x6^2*f1^2*f6+8*x2*x3*x6^2*f7*f2^2*f4-32*x2*x4*x3*x6*f0*f6*f1*f7^
2+144*x1^2*x4^2*f0*f5^3*f2*f7-128*x2*x7*x4^2*f0*f7^3*f2-24*x2*x7*x4^2*f4^2*f1*
f7^2+216*x4^2*x3*x7*f4*f5^4-12*x1^2*x4^2*f7^2*f2*f6*f1^2+4*x1^2*x2*x6*f3^4*f4+
312*x2*x7*x4^2*f4*f6*f1*f5*f7+200*x2*x4^2*x3*f5*f4^2*f7*f1*f6-24*x2*x4*x1*x5*
f0*f5^2*f4^2+4*x3^2*x2*x6*f7*f3*f4^2*f2+8*x3^2*x2*x6*f2^2*f6*f7*f3+16*x2^2*x3*
x6*f3*f5^2*f2*f4-24*x2^2*x4*x6*f2*f5^3*f3-20*x1^2*x4^2*f7^2*f1*f5*f2^2-12*x1^2
*x3*x6*f3*f5^2*f2^2-4*x2*x3*x1*x5*f1^3*f7^2-16*x1*x5*f0*f7*f2*f4*x3^2*f5+48*x1
^3*x4*f0*f4^2*f1*f7*f5-12*x1*x3*x4*x5*f3*f5^3*f1-4*x1^2*x3*x6*f7*f3^3*f1+16*x1
^2*x3*x6*f6*f2^3*f5+8*x3^3*x1*f1*f6*f4^3*f5-8*x1^2*x3*x6*f3^3*f2*f6+16*x1^2*x3
*x6*f0*f4^3*f5-32*x1^2*x3*x6*f1^2*f3*f6^2-16*x1^2*x3*x6*f2^2*f1*f6^2+32*x3^2*
x2*x6*f7*f4^3*f1+96*x4^2*x1*x6*f0*f5^2*f4*f7-48*x1*x6*x4^2*f7^2*f0*f5*f2-12*x1
*x6*x4^2*f7^2*f2*f1*f4-24*x1^2*x3*x6*f1^2*f5^3+4*x3^2*x4*x6*f7*f3^2*f4*f5-36*
x1^4*f5*f7*f1^3*f3-12*x2^2*x1*x4*f5*f4^4*f2-16*x1^2*x3*x6*f3^2*f1*f5^2+16*x1*
x3^2*x8*f7*f1^2*f6^2+4*x1^2*x3*x7*f1*f4*f3*f5^2+4*x3^2*x5^2*f3^2*f4^2-32*x1^4*
f6*f5^2*f2*f0^2-4*x1^4*f0*f6*f5^2*f1^2-4*x2^2*x7^2*f3*f7*f2*f4+72*x4^2*x2*x5*
f5^2*f4^2*f3+16*x1^2*x3^2*f7^2*f3*f0*f4*f1+4*x2*x3*x6*x7*f3*f7*f5*f1-32*x1*x3*
x6^2*f1*f6*f2*f5-96*x2*x3*x4*x6*f3*f5^2*f6*f2+20*x4*x5*x7^2*f7*f2*f4+32*x2*x7*
f0*f5^2*f7*f4*x3^2+32*x1^3*x4*f2^2*f5*f7*f4*f1-64*x1^3*x3*f0*f6^3*f1^2+12*x3^2
*x4*x5*f7^2*f2^2*f3-4*x3*x4^2*x6*f7*f4^4-36*x3*x4^2*x6*f3*f5^4-24*x1^2*x4*x6*
f3^2*f6*f1*f5-8*x3^3*x8*f7^2*f2^2*f5-20*x1*x2*x3*x7*f2*f3^2*f7*f4-96*x1^2*x2*
x4*f0*f6*f5^2*f2*f4-36*x2*x5*x4*x8*f7*f1*f4*f5-16*x2*x5*x7^2*f7*f0*f4+28*x4*x6
*x7^2*f7*f2*f5+24*x4*x6*x7^2*f7*f3*f4-48*x4*x6*x7^2*f7*f1*f6+4*x5^2*x6*x7*f1*
f4+96*x2*x3*x4^2*f7^2*f3*f4^2*f2-4*x1^2*x3*x5*f3*f4^3*f1+16*x3^3*x2*f2*f6^2*f7
*f1*f3+16*x1^2*x2*x5*f0*f4*f6*f2*f3+64*x1*x2*x3^2*f1^2*f5*f6^2*f4+104*x1*x2*x3
*x7*f2*f6*f7*f3*f1+48*x2^2*x4*x6*f0*f5^4+16*x1*x5*x3*x6*f0*f4*f2*f7-4*x1*x5*x3
*x6*f1^2*f7*f4-96*x2*x4*x5*x7*f4*f6*f1*f5+40*x3^2*x1*x6*f0*f4*f1*f7^2-8*x2*x7*
x3^2*f5^2*f7*f2^2+8*x2^2*x3*x6*f7*f3^2*f1*f5+72*x2^2*x4*x6*f1*f5*f4^2*f6-8*x1^
3*x4*f3^2*f5*f7*f2*f1-64*x1^2*x3*x7*f0*f6^2*f3^2+8*x1^2*x3*x7*f7*f2^3*f5-16*x1
^2*x2*x5*f1*f6*f5*f3*f0-20*x1*x2*x3^2*f7^2*f1^2*f4*f3+8*x1*x2*x3^2*f4^2*f6*f2^
2*f5+8*x1*x2*x3^2*f3*f5^3*f1*f4-4*x1*x2*x3^2*f7^2*f2*f3^2*f1-32*x1^3*x3*f2*f6^
2*f4*f1^2+8*x1^2*x3*x5*f1^2*f4*f7*f3-16*x1^2*x3*x7*f0*f7^2*f3*f1+304*x2*x3*x4^
2*f7^2*f0*f5*f4^2-68*x1*x3*x4^2*f7^3*f1^2*f3-32*x2^2*x3^2*f6^2*f0^2*f7*f5+48*
x1^3*x3*f0*f4^3*f1*f7+24*x1*x4*x3*x6*f5^2*f4^2*f2-16*x1^3*x3*f2^2*f5*f1*f3*f7+
8*x2^2*x3^2*f0*f6*f7^2*f2^2+16*x1^3*x3*f4*f7*f6*f1^3-32*x1^3*x3*f2^3*f5*f3*f6-\
20*x1^3*x3*f4^2*f1*f7*f2^2+4*x1*x2^2*x3*f7*f2*f4^3*f1-16*x3^2*x2*x6*f3*f5^2*f6
*f1+16*x2*x8*f7*x3^2*f1*f4*f5^2+8*x2*x8*f7*x3^2*f2*f5^2*f3-8*x2*x8*f7*x3^2*f0*
f5^3+16*x3^2*x2*x8*f7^2*f6*f1^2-48*x1^3*x3*f0*f5^3*f3*f2-8*x3^2*x2*x8*f7*f3*f1
*f5*f6+8*x3^2*x2*x8*f7*f3*f6*f2*f4+4*x2^2*x3*x6*f7*f1*f4^2*f3-64*x1^3*x3*f3*f5
^2*f0^2*f7+8*x2^2*x3*x5*f7*f3*f4*f2^2+8*x1^3*x3*f4^2*f5*f1*f3^2-108*x4^3*x2*f3
*f5^5-32*x1*x5*x3*x6*f6*f0^2*f7-24*x1^3*x3*f4^3*f5*f1*f2-24*f7*x3*x8^2*x4*f4*
f5^2-8*f7^2*x2*x8^2*x6*f0-8*x2*x3^3*f3*f5*f6*f7*f2^2+16*x2*x3^3*f0*f6*f5^2*f2*
f7+24*x1*x2*x3*x4*f4^2*f5*f6*f2*f3-24*x1*x2*x6^2*f1*f6*f2*f4-16*x2^2*x3*x6*f1*
f0*f7^2*f4-24*x3*x7*x4^2*f7^3*f2*f1-52*x3*x7*x4^2*f7^2*f3*f2*f5-48*x4*x5*x6*x7
*f3*f5*f4+24*x4*x5*x6*x7*f5^2*f2+52*x4*x5*x6*x7*f7*f2*f3+4*x2*x5*x6*x8*f7*f3*
f1-20*x4*x5*x6*x7*f7*f1*f4-8*x4*x5*x6*x7*f7*f0*f5+190*x4^2*x2^2*f1^2*f5^2*f7^2
+12*x2^3*x4*f7^3*f1^3-8*x3^2*x2*x7*f2*f5*f4^2*f6+32*x3^2*x2*x7*f3*f5^2*f6*f2+
442*x4^4*f5^3*f7^2*f1-48*x3^2*x1*x4*f6*f2*f5*f4^3-40*x1^3*x3*f3^2*f1^2*f5*f7+4
*f7*x2*x8^2*x6*f3*f4-240*x1^2*x4^2*f0*f6*f5*f2*f7*f4-10*x6^2*x7^2*f1*f7+16*x1^
3*x3*f0*f6*f3^2*f4^2+16*x2*x3^2*x7*f3^2*f5*f6*f4-16*x2*x3^2*x7*f0*f5*f2*f7^2-\
32*x1^3*x3*f0*f5^3*f4*f1-8*x1^4*f3^4*f2*f4-112*x2^2*x4*x7*f7*f4^2*f1*f5-4*x1^2
*x2*x7*f2*f4^3*f3-64*x2*x3^2*x4*f6^2*f0^2*f7^2+32*x2*x3^2*x4*f0*f5*f6^2*f2*f7+
80*x1^2*x3*x4*f0*f5^3*f1*f7+16*x1^3*x3*f0*f5^2*f4^2*f2-12*x1^2*x4*x5*f3*f5^2*
f2^2-72*x2^2*x4^2*f7^2*f0*f6*f4*f2-60*x1^2*x4*x7*f7*f2^2*f5*f3+28*x1^2*x4*x7*
f3*f7*f1*f4^2+32*x2^2*x4*x7*f7^2*f1*f2*f4-56*x2^2*x4*x7*f7*f3*f5^2*f1+24*x2^2*
x4*x7*f7*f3*f5*f2*f4+16*x3^3*x8*f7*f2*f6*f5*f3+16*x3^3*x8*f7^2*f2*f1*f6+48*x2^
2*x1*x4*f0*f5*f4^2*f3*f7+32*x1^2*x3*x7*f1*f4^2*f7*f2-12*x1^2*x4*x7*f1*f7^2*f2^
2-32*x1^2*x4*x7*f1^2*f7^2*f3-60*x1^2*x3*x7*f1^2*f4*f7*f5-40*x1^2*x3*x7*f7*f2^2
*f3*f4+48*x2^2*x3*x5*f4*f1*f6*f2*f5+272*x4^2*x5^2*f0*f5*f7*f4+120*x2*x3^2*x4*
f6*f5^3*f1*f4+4*x2*x3*x5*x8*f7*f1*f3*f5-16*x2*x3*x5*x8*f7^2*f1^2-8*f7^2*x3*x8^
2*x4*f2*f5+8*x1*x2*x3^2*f4^3*f2*f3*f6-64*x3^2*x7^2*f0*f6^3+36*x1*x3*x4^2*f7^3*
f1*f2^2+40*x1*x3*x2*x5*f7*f5*f1*f0*f4+8*x2*x3^2*x6*f0*f3^2*f7^2+32*x1^2*x3*x5*
f0*f6*f7*f2*f1-48*x1^3*x4*f1*f3*f7*f2^2*f6-342*x4^4*f7*f3*f5^4-56*x1^3*x3*f2*
f6*f5^2*f1^2+8*x1^3*x3*f4*f6*f2^2*f3^2+8*x4^2*x6*x7*f7*f2*f4*f6+20*x1^3*x3*f4^
2*f5*f2^2*f3+64*x1^3*x3*f0*f5*f3^2*f2*f7-8*x1^2*x5^2*f1*f0*f7*f2-16*x1^2*x5^2*
f0*f5*f3*f2-80*x2^2*x4*x7*f0*f4*f3*f7^2+48*x2^2*x4*x7*f0*f7*f4^2*f6+160*x2*x3^
2*x4*f0*f6*f5^2*f3*f7-24*x4*x5*x1*x6*f5*f6*f1*f2+12*x4*x5*x1*x6*f3*f5*f2*f4+16
*x1*x6*f0*f6*f7*f1*x4*x5+16*x2*x7*x3^2*f3^2*f7^2*f1+32*x3^2*x2*x7*f3*f6^2*f2*
f4+48*x1^3*x3*f0*f6*f5^2*f2^2+64*x1^3*x3*f5*f1*f0^2*f7^2-16*x2*x3^2*x4*f6*f7*
f3^3*f4-4*x1*x5*x6^2*f2^2*f4+32*x1^3*x3*f0*f4*f6^2*f2^2-90*x4^4*f1*f7^3*f4^2-\
16*x1^3*x3*f1*f4*f6*f3^3+x2^4*f7^2*f2^4+16*x3^2*x5*x6*f0*f5*f3*f7+16*x1*x3^3*
f0*f6*f3^2*f7*f5+4*x1*x2*x3^2*f7^2*f2^3*f3+36*x1^2*x4*x5*f3^2*f5^2*f1-8*x2*x3*
x6*x8*f7*f2*f3*f5-8*x2*x3*x6*x8*f7*f1*f4*f5+72*x1*x3*x4*x5*f0*f5^3*f4-32*x3^2*
x2*x6*f2^2*f4*f6^2+144*x2*x3*x4*x5*f3*f5^2*f1*f6+8*x1^2*x7^2*f4*f6*f2^2-64*x1^
3*x3*f0*f5*f6*f4*f3*f2+18*x4^4*f4^2*f5^3*f7+64*x1^3*x3*f0*f5*f4*f7*f3*f1-8*x2^
3*x1*f1^2*f4*f7*f3*f5-16*x2^3*x1*f0*f4*f2*f1*f7^2-24*x3^2*x5^2*f1*f4*f3*f6+48*
x1^2*x3*x4*f3^2*f5^3*f2-32*x1*x3*x4*x6*f7^2*f0*f4*f2+8*x1^2*x3*x4*f4*f7*f3^4+
16*x2*x3*x4*x5*f7^2*f2^3-24*x1*x3*x4*x6*f1*f7^2*f0*f5+24*x1^2*x4*x7*f3^2*f6*f2
*f5+8*x1*x2*x3^2*f6*f7*f1^2*f4^2-12*x1*x2*x3^2*f7^2*f1*f4*f2^2-96*x1^3*x3*f0*
f6*f4*f7*f2*f1-48*x3^2*x2*x7*f3*f6^2*f1*f5-16*x2*x7*x3^2*f5*f7^2*f1^2-36*x2*x7
*x3^2*f4^3*f7*f2-80*x1^3*x3*f0*f4*f1^2*f7^2-20*x3^2*x2*x6*f4^3*f5*f3+12*x3^2*
x2*x6*f3*f5^3*f2+16*x3^2*x2*x6*f3*f5*f6*f2*f4-16*x1*x2*x3^2*f2*f4^2*f6^2*f1+24
*x1*x2^2*x3*f1^2*f5^2*f4*f6+40*x1*x2*x3^2*f4^2*f3*f5^2*f2-48*x1^2*x3*x4*f0*f5^
4*f3-144*x2*x3*x4^2*f5^4*f3*f4+288*x1^2*x3*x4*f0*f6*f5^2*f3*f4+4*x2^2*x3^2*f0*
f5^4*f4-72*x1*x3*x4^2*f7^2*f6*f1^2*f4-88*x1*x4*x3^2*f0*f5*f2*f7^2*f4+28*x1*x4*
x3^2*f2*f5*f7*f4^2*f3+46*x1^2*x4^2*f7*f2^2*f5*f4^2-10*x1^4*f3^4*f1*f5-46*x1^2*
x4^2*f7^2*f1^2*f3*f5+24*x1^3*x3*f2^3*f3*f4*f7-32*x1^3*x3*f1*f6^2*f3*f2^2+12*x2
^4*f0*f5^2*f1*f7*f4+48*x1^2*x4^2*f7^2*f0*f6*f2^2-8*x3^2*x7*f2^2*f6*f7*x6-12*x1
*x6*x4*x7*f7*f3*f1*f5-168*x1^2*x4^2*f7^3*f0*f2*f1-16*x1^3*x3*f0*f4*f3^3*f7+8*
x1^2*x7^2*f1*f4*f7*f2-16*x1^2*x7^2*f4*f6*f1*f3+8*x1^2*x7^2*f0*f6*f5*f3+16*x1^2
*x7^2*f0^2*f7^2-72*x1^2*x4^2*f7*f2^3*f5*f6-24*x2*x4*x3*x8*f7*f3*f5*f6*f2-12*x1
^2*x4*x7*f5*f4^3*f2+x5^4*f1^2+4*x1*x3*x4*x6*f7*f1*f4*f3*f5+8*x2*x3*x5*x6*f1*f5
^2*f3-128*x3*x4^3*f7^3*f1*f2*f5+4*x1*x3^2*x5*f4*f3*f5^2*f1-16*x1^2*x3*x7*f1^2*
f7*f6*f3+20*x2*x3*x6*x8*f7^2*f2*f1+36*x1^2*x3*x4*f5^2*f4^3*f1-12*x1^2*x3*x4*f5
*f4^4*f2-4*x1*x3*x4*x5*f7*f3^2*f4*f2+8*x1^3*x3*f0*f5^2*f3^2*f4+8*x2*x6*x3*x7*
f2*f4*f3*f7+8*x2*x6*x3*x7*f7*f2*f1*f6+64*x1^3*x3*f4*f2*f0^2*f7^2+28*x4^3*x6*f7
^2*f2*f4^2+48*x4^3*x6*f7^3*f0*f3-8*f7*x3*x8^2*x7*f4*f5+8*f7*x3*x8^2*x7*f3*f6-2
*f7^2*x2^2*x8^2*f2^2+32*x1^3*x3*f6*f5^2*f4*f0^2-16*x2*x3*x4^2*f7*f0*f5^4+36*x1
*x3*x4*x5*f7*f1*f4^2*f3-32*x1^2*x3*x4*f0*f7*f4^4-96*x1^2*x3*x4*f0*f5^3*f4^2-32
*x2*x4*x5*x6*f0*f4^2*f7+48*x2*x4*x5*x6*f2*f5^2*f3-32*x1*x4*x5*x7*f1^2*f7*f6+48
*x1*x4*x5*x7*f2^2*f6*f5+32*x1^3*x3*f0*f6*f4^3*f2-12*x1*x2*x3^2*f7*f3^2*f4^2*f2
-48*x4^2*x2*x6*f1^2*f7^2*f6+28*x2*x6*x4^2*f7^2*f3^2*f2+100*x4^2*x2*x6*f4*f5^2*
f1*f7+32*x2*x6*x4^2*f7^2*f0*f4^2-64*x1^3*x3*f4^2*f5*f0^2*f7-32*x3^3*x1*f4*f6^2
*f2*f1*f5+8*x2^2*x6*x7*f3^2*f5*f4-8*x2^2*x6*x7*f3*f5^2*f2+32*x2^2*x6*x7*f0*f7*
f4^2-8*x5^2*x3*x6*f2^2*f5+72*x1*x3*x4*x8*f7^2*f6*f1^2-16*x1^2*x3*x7*f3^2*f5*f1
*f6-8*x1^3*x2*f2^3*f5^2*f3+64*x1^2*x2*x4*f5^3*f0^2*f7+24*x3^2*x1*x5*f1*f5*f2*
f4*f6-16*x3^2*x2*x5*f5^2*f4^2*f1+12*x3^2*x2*x5*f1*f7^2*f2^2-48*x1*x3*x4*x8*f7^
2*f2*f5*f1-8*x5^2*x2*x6*f2^2*f4+8*x2^2*x4*x6*f7*f1*f4^3+32*x2^2*x4^2*f7^2*f1*
f6*f3*f2+104*x2^2*x1*x4*f0*f5*f7^2*f2^2+40*x2^2*x1*x4*f1^2*f4*f7^2*f3+16*x1*x4
*x2*x7*f7*f2^2*f3*f6-24*x2*x4*x6^2*f7*f2*f3*f4-72*x2*x4*x6^2*f4*f6*f1*f5-12*x1
*x3^2*x5*f4^2*f3*f5*f2+80*x1^2*x2*x4*f7^2*f1^3*f5-16*x2*x3*x1*x6*f0*f4^2*f7*f3
-12*x5^3*x4*f7*f1^2-32*x1*x3*x4^2*f7^3*f1*f0*f4-176*x1*x3*x4^2*f7^2*f0*f5*f3*
f4-208*x1*x3*x4^2*f7^2*f1*f6*f3*f2+224*x1*x3*x4^2*f7^2*f0*f6*f1*f5+4*x3^2*x6^2
*f3^3*f7+24*x1*x6*x4*x7*f7*f2*f1*f6+32*x1*x6*x4*x7*f7*f0*f4*f5+24*x3*x4*x2*x5*
f0*f5*f1*f7^2-4*x2^2*x5*x7*f1*f7*f2*f4-16*x2^2*x5*x7*f3*f5*f2*f4+8*x1*x3*x5*x8
*f7*f1*f2*f5-32*x1*x3*x2*x6*f1^2*f4*f6^2+64*x1^2*x3*x7*f6^2*f2*f3*f1-24*x1^2*
x3*x4*f5^4*f2*f1+32*x1^2*x3*x7*f1^2*f4*f6^2-16*x1^2*x3^2*f6*f2*f5^2*f3*f1-4*x1
^2*x2*x7*f7*f1*f3^3+4*x3^2*x1*x5*f1*f5^3*f2-28*x1^2*x4*x7*f7*f2*f3^2*f4+32*x1*
x3^3*f0*f6*f5^2*f7*f1-20*x1^2*x3^2*f1*f4*f7*f2^2*f6-12*x1*x3*x4*x7*f7*f4^3*f2+
28*x1*x3*x4*x7*f7^2*f1^2*f5+8*x1^3*x2*f0*f5^3*f2^2-8*x5^3*x3*f0*f4^2-48*x2*x3*
x7*x8*f7*f0*f5*f6+24*x2*x3*x7*x8*f7*f1*f4*f6-8*x1^2*x3*x7*f7*f2^2*f1*f6+64*x1^
3*x2*f4*f5^3*f0^2-48*x3^2*x2*x7*f0*f6*f5^3+16*x1^2*x2*x4*f1^2*f3^2*f7^2+80*x1^
2*x3*x5*f0*f6*f3*f5*f2+16*x2*x3^2*x6*f3^2*f6*f7*f1+16*x1^2*x3*x5*f4*f6*f2^3-6*
x1^4*f4^2*f7*f1^3-8*x5^3*x3*f6*f1^2+36*x1^2*x2*x4*f2^2*f5^2*f4^2+16*x1*x3*x2*
x7*f0*f6*f4^2*f5-8*x1^2*x3^2*f3*f6*f4^3*f1-288*x1^2*x3*x4*f0*f6^2*f5*f2*f4+8*
x2^2*x3*x8*f7*f3*f4*f1*f6+192*x1^2*x3*x4*f6^2*f1*f5*f2*f3-32*x2^2*x4^2*f7^2*f0
*f6*f1*f5-16*x1*x5*x3^2*f0*f5^2*f1*f7+16*x1^2*x3*x4*f7^2*f0*f3^3+64*x1^2*x3*x4
*f7^3*f0^2*f2+8*x1^2*x3*x4*f2^3*f7*f5^2+8*x3^3*x5*f1^2*f7*f5*f6+16*x3^3*x5*f0*
f5*f7^2*f1+4*x3^3*x5*f3*f5^3*f2+24*x1*x3*x4*x5*f5*f4^3*f2-16*x1*x3^2*x8*f7*f1*
f6*f2*f5-16*x1^3*x3*f0*f6*f3*f2^2*f7-112*x1*x4*x2*x7*f0*f4*f2*f7^2-168*x4^2*x6
*x3*f1*f6*f5*f7*f4-4*x2^3*x1*f7*f2*f3^2*f1*f5+8*x2^3*x1*f0*f5^2*f3*f1*f7-188*
x3*x4^3*f7^3*f1*f3*f4-1824*x3*x4^3*f7*f0*f6^2*f5^2-528*x4^3*x3*f4*f5^3*f3*f7-\
40*x1^2*x4*x7*f0*f4^3*f7+12*x1^2*x4*x7*f3*f5^3*f1+4*x1^3*x4*f7*f4^3*f1^2+24*x3
^2*x2*x4*f7^2*f2^2*f4^2-16*x2*x3*x4*x7*f7^2*f3*f4*f1-64*x1^2*x3*x5*f0*f6^2*f2^
2-96*x1^2*x3*x7*f0*f6^2*f2*f4+32*x1^2*x3*x6*f0^2*f7*f5^2-56*x1^2*x3*x7*f6*f2*
f5*f1*f4+32*x1^2*x3*x7*f2^2*f4^2*f6+36*x1^3*x4*f1^2*f4*f5^3+94*x4^2*x2^2*f7^2*
f2^2*f4^2+8*x2^2*x4*x5*f1*f7^2*f2^2-80*x2^2*x3*x4*f0*f5*f2*f7^2*f4+48*x2*x5*x3
^2*f0^2*f7^2*f5+112*x1*x4^3*f7^3*f1*f5*f0-4*x6^3*x2*f3^2*f4+208*x1^2*x4^2*f7^2
*f0*f5*f2*f3-8*x1^3*x4*f2^3*f4^2*f7-64*x1*x3*x4^2*f7^2*f1^2*f5^2-12*x2*x3*x4*
x5*f7^2*f2*f1*f3-32*x2*x3*x4*x5*f0*f6*f4*f3*f7-16*x1^2*x3^2*f1^2*f4*f7*f6*f3+
40*x1^2*x3*x4*f6*f7^2*f1^3-16*x2*x3*x7^2*f4^2*f6*f3+64*x2*x3*x7^2*f0*f7*f6*f4-\
64*x2*x3*x7^2*f0*f6^2*f5+8*x1*x4^2*x2*f7*f2^2*f4^2*f6-24*x1*x4*x6^2*f0*f5^3+24
*x5^2*x4*x7*f3^2*f5-84*x1^2*x4^2*f7^2*f1*f3*f2*f4+64*x1^2*x3*x4*f7^2*f2^3*f3-\
36*x2^2*x4*x6*f5*f4^3*f3+24*x2^2*x4*x6*f2*f5^2*f4^2+24*x2^2*x4*x6*f3^2*f5^2*f4
-8*x1^3*x2*f0*f3^4*f7-20*x2^2*x6*x7*f5^2*f4*f1+8*x2^2*x6*x7*f4^2*f2*f5+24*x2^2
*x6*x7*f1*f6*f4^2-4*x3^3*x1*f7^2*f3^3*f1-32*x1^2*x3*x5*f7*f3*f1*f0*f5-176*x1^2
*x3*x4*f0*f7^3*f1^2+25*x1^4*f3^2*f1^2*f5^2+32*x1^2*x5*x7*f0*f6*f3^2+12*x1^2*x5
*x7*f3^2*f1*f5-4*x1^2*x5*x7*f2^2*f5*f3+4*x1^2*x5*x7*f1*f7*f2^2-4*x1^2*x5*x7*f3
^4+64*x1^2*x3*x7*f0^2*f7^2*f4-4*x1^2*x3*x7*f7*f2*f3^3-8*x1^2*x3*x7*f2*f5^3*f1-\
16*x5^2*x3*x7*f0*f5^2-8*x1^3*x2*f3^3*f2*f4^2+120*x1^2*x3*x4*f1^2*f6*f5^3+4*f7*
x3*x8^2*x6*f4^2+4*f7*x3*x8^2*x6*f3*f5-4*f7^2*x3*x8^2*x6*f1+48*x1*x4^3*f7^2*f2*
f1*f4*f6-96*x1*x4^3*f7^2*f0*f5^2*f3-8*x1*x4^3*f7^2*f3*f4^2*f2+160*x1*x4^3*f7^3
*f0*f4*f2-2*x1^2*x2^2*f1*f5^2*f3^3+16*x1^2*x2^2*f0*f6*f5^2*f2^2-16*x2*x3^2*x4*
f0*f6*f4*f2*f7^2+64*x2*x3^2*x4*f0*f6^2*f4*f3*f7+40*x2*x3*x4^2*f7^2*f2^2*f3*f6+
128*x4^2*x2^2*f5*f0^2*f7^3-8*x3^3*x7*f3^2*f5^2*f6+32*x3^3*x7*f2*f6^2*f4^2+48*
x5^2*x4*x6*f0*f5^2+4*x2*x4^2*x3*f7*f4^5+76*x2*x4*x5*x7*f7*f5*f1*f3-16*x1^2*x2*
x3*f0*f5^4*f1+96*x1^2*x2*x3*f6*f5^3*f0^2+4*x1^2*x2*x3*f4^5*f1+12*x1^2*x3*x4*f7
*f2^2*f4^3+8*x2*x3^2*x8*f5*f7*f4^2*f2+32*x1^2*x2*x4*f7*f2^2*f1*f4*f6-24*x1^2*
x2*x3*f0*f5*f4^4-8*x1^2*x2*x3*f0*f5^3*f3^2+4*x2^2*x7^2*f3^2*f5^2+48*x4^2*x2*x6
*f0*f6*f2*f7^2+112*x4^2*x2*x6*f7*f2*f5*f4^2-84*x4^2*x2*x6*f7*f2*f3*f5^2-144*x2
*x6*x4^2*f7^2*f4*f2^2+52*x4^2*x2*x6*f7*f3^2*f4*f5+224*x1*x4^3*f7^2*f0*f6*f5*f2
+96*x1*x4^3*f7^2*f0*f5*f4^2-4*x2*x5*x3^2*f5^2*f7*f1^2+24*x3^2*x5*x6*f0*f5^3+48
*x3^2*x2*x6*f1*f6^2*f2*f5+4*x1^2*x2*x3*f5^2*f2*f3^3+8*x1^2*x2*x3*f7^2*f2^3*f1-\
8*x1^2*x2*x3*f7*f2*f3^4+8*x3^2*x2*x5*f3*f4^4+16*x1^2*x3*x6*f0*f5^3*f2+40*x3^2*
x4^2*f6^2*f2^2*f7*f5+128*x1^2*x4*x7*f0*f3*f2*f7^2-32*x1^4*f0*f4*f3*f7*f2^2-12*
x2*x7*x3*x8*f7^2*f3*f1-4*f7*x3*x8^2*x5*f3*f4+8*f7^2*x3*x8^2*x5*f0-120*x1*x3*x2
*x4*f5*f4^2*f7*f3*f1+16*x1^2*x6^2*f0*f6*f3^2+24*x1^2*x6^2*f5*f0^2*f7+2*x1^2*x6
^2*f3^2*f2*f4+16*x3*x6*x1*x7*f0*f5^3-32*x2^2*x6*x7*f0*f6*f5*f4+8*x1^2*x2*x3*f1
^2*f5*f6*f4^2-52*x1*x2*x4*x6*f7*f1^2*f5^2+16*x1^2*x2*x3*f0*f3^3*f5*f7+48*x1*x3
^2*x2*f0*f6*f5*f4^3-12*x2*x3*x5^2*f2*f5^2*f1+8*x2*x3*x5^2*f2^2*f5*f4+8*x2*x3*
x5^2*f4^2*f2*f3-4*x1*x3*x6*x7*f1*f7*f2*f5+4*x1^2*x7^2*f4^2*f1*f5-4*x3*x7^2*x6*
f3*f5^2+16*x5^2*x6*x7*f0*f5-12*x1^2*x7^2*f3*f7*f2^2-16*x3^3*x8*f7*f3*f1*f6^2-8
*x6^3*x2*f0*f5^2-40*x6^2*f7*f0*f4*x2*x4*f5-48*x3^2*x4*x5*f1*f5^2*f4*f6-8*x6^3*
x2*f4^2*f2-4*x2*x6^2*x4*f7*f1*f4^2+4*x1^2*x6*x7*f3^3*f4-1184*x4^2*x3*x7*f0*f6^
2*f5*f7+600*x4^2*x3*x7*f6*f5^2*f1*f7-344*x4^2*x3*x7*f7*f3*f4*f5^2-36*x1^3*x6*
f3*f5^2*f1^2-4*x1^3*x6*f1^2*f3^2*f7+8*x3^3*x7*f3*f5^3*f4-8*x2*x6*x3^2*f0*f5*f7
*f4^2+12*x3^3*x6*f7*f2*f3*f5*f4+128*x1*x4^2*x3*f0*f5*f6^2*f2*f7+64*x1^2*x5*x7*
f5*f0^2*f7+8*x1^2*x5*x7*f3^2*f4*f2-4*x1^2*x5*x7*f3*f4^2*f1-264*x4^2*x3*x7*f7^2
*f3*f1*f6+296*x4^2*x3*x7*f7*f3^2*f5*f6+8*x1^3*x6*f2^3*f5*f4-4*f7*x2*x8^2*x7*f4
^2+4*f7*x2*x8^2*x7*f3*f5-12*x1^2*x3*x7*f3*f1*f5*f2*f7-32*x1^2*x3*x7*f2*f7^2*f1
^2+24*x1^3*x4*f7*f2^4*f6+96*x1^3*x4*f6*f5^3*f0^2-320*x4^2*x2*x6*f0*f6*f5*f4*f7
+64*x4^2*x2*x6*f3*f5*f6*f1*f7+16*x2*x6*x4^2*f7^3*f0*f1-32*x1^2*x3*x7*f0*f4^2*
f5^2-96*x1*x3*x4*x5*f6^2*f1^2*f5+176*x1*x3*x2*x4*f0*f5^2*f3*f7*f4-8*x4^2*x5^2*
f4^2*f1*f7-60*x2^2*x4*x6*f5^3*f4*f1-4*x1^2*x5*x6*f2^3*f5+72*x2*x4^2*x6*f2*f5^2
*f4*f6-80*x1^2*x4*x5*f0*f4^2*f7*f2+16*x2*x4*x6*x7*f3^2*f7*f4+4*x1^2*x7^2*f4*f5
*f2*f3-2*x1^2*x7^2*f3^3*f5+16*x1^2*x7^2*f0*f5*f7*f2-2*x1^2*x7^2*f5^2*f2^2-8*x1
^2*x7^2*f2*f6*f5*f1+x8^4*f7^2-24*x5^3*x4*f0*f5*f4-28*x3^3*x7*f2*f5*f4^2*f7+16*
x3^3*x7*f1*f7*f4^2*f6-6*x2^2*x7^2*f3*f5*f4^2-56*x1^3*x4*f3*f4^2*f7*f2*f1+4*x2^
2*x7^2*f4^4+32*x1^3*x4*f7*f0*f6*f3^2*f2+216*x4^3*x3*f4*f5^2*f2*f6*f7+96*x3*x4^
3*f0*f5*f7^3*f3+792*x4^3*x3*f5^3*f6*f1*f7+24*x4^3*x3*f5^2*f4^3*f7+232*x1^2*x4^
2*f7^2*f1*f0*f4*f5+56*x1^2*x4*x5*f2*f6*f7*f1^2-96*x1^2*x3*x5*f6*f5^2*f0^2+8*x1
^2*x3*x5*f0*f5^2*f3^2+16*x1^3*x4*f6*f7*f2*f4*f1^2+16*x2*x3*x4*x7*f7^2*f1^2*f6-\
112*x2*x3*x4*x7*f7^2*f3*f0*f5-448*x1*x3*x4^2*f6^2*f0^2*f7^2+20*x1*x3^3*f1*f7^2
*f5*f2^2-16*x1^3*x4*f0*f6*f7*f2^2*f4-64*x1^4*f6*f0^2*f7*f2*f3+16*x3^3*x8*f7*f4
^2*f2*f6-12*x1^2*x4*x5*f7*f1*f5*f2^2-8*x5^3*x7*f0*f4-168*x4^2*x3*x7*f7*f2*f5^3
+432*x4^2*x3*x7*f6^2*f2*f5^2-4*x6^3*x3*f3^2*f5-4*x2^3*x7*f3^2*f5*f4^2-20*x3*x6
*x7^2*f5*f4^2-12*x1^4*f6*f2^3*f3^2-32*x1^4*f6*f1*f0^2*f7*f4-88*x1^2*x4^2*f7*f2
*f5^2*f1*f4-8*x3^3*x1*f3*f6*f4*f1*f5^2-24*x1^3*x4*f0*f5^3*f3^2-96*x1^4*f0*f3*
f2*f1*f6^2+12*x1^3*x4*f5*f4^3*f2^2+64*x1*x3^2*x2*f0*f6^2*f7*f2^2-96*x2*x3^2*x4
*f0*f6^2*f5^2*f4+2*x2^2*x3^2*f3^3*f7*f4^2+24*x1^3*x4*f3^3*f5^2*f2-4*x1*x5*x3*
x6*f1*f7*f2*f3+8*x1^2*x5^2*f1*f3*f0*f6+8*x1*x5*x3*x6*f0*f3^2*f7-74*x1^2*x4^2*
f7*f3*f5^2*f2^2+56*x1^4*f0*f6*f5*f3*f2^2+4*x3^3*x6*f2*f7^2*f1*f4+4*x5^3*x7*f3*
f1-48*x2^2*x4*x5*f3*f5^2*f2*f4-12*x2*x6*f7*f4*f2^2*x3^2*f5+16*x1^4*f0*f4*f6*f3
^2*f2+12*x2*x4*x5*x8*f7*f2*f3*f5-20*x2*x4*x5*x8*f7^2*f2*f1+4*x2^2*x6^2*f2^2*f5
^2-8*x1^2*x3*x6*f2*f6*f7*f1^2-4*x2*x5^2*x3*f1*f4^3-72*x4*x5*x7^2*f6*f2*f5-40*
x4*x5*x7^2*f7*f1*f5-18*x4^2*x5^2*f4*f5^2*f2+10*x4^2*x5^2*f5*f7*f2^2-24*x2*x5*
x3^2*f0*f4*f3*f7*f5+4*x2*x5*x3^2*f2*f5*f1*f4*f7-32*x3^2*x2*x5*f6*f4*f5*f2^2-8*
x3^2*x2*x5*f2^2*f5^3-32*x1*x3^3*f5*f6*f7*f4*f1^2-48*x2^2*x3*x4*f0*f5^5-4*x1*x2
*x3^2*f7*f2^3*f5^2-4*x1^2*x2*x3*f4^4*f3*f2-4*x1^2*x2*x3*f4^3*f3^3+32*x2*x6*x3^
2*f1*f7*f5^2*f2-24*x2*x6*x3^2*f0*f7^2*f5*f1-8*x5^2*x6*x7*f2*f3-24*x2*x3*x6^2*
f1*f6*f4^2+12*x1^2*x3*x7*f5*f4^3*f1-16*x1^2*x3*x7*f0*f5^3*f3+54*x4^2*x7^2*f5^4
+32*x1^3*x5*f0*f6^2*f1^2-32*x3^3*x8*f7*f4*f6^2*f0+24*x1^2*x4*x7*f5^2*f4^2*f1+
240*x3^2*x4*x7*f6^2*f2*f5*f4+8*x1^3*x5*f2^3*f5*f3+8*x1*x6*x2*x7*f7*f2*f1*f4+64
*x2^2*x4^2*f6^2*f0^2*f7^2+8*x1^3*x5*f3^3*f1*f4+16*x1*x2^2*x3*f5*f7^2*f1^3+12*
x1*x2^2*x3*f5^2*f2^2*f4^2+32*x1*x2*x4*x5*f1*f5^2*f0*f7+8*x1^2*x3*x6*f1*f6*f4^2
*f2-80*x1^2*x4*x5*f1*f6*f0*f7*f3-2*x3^2*x5^2*f4^3*f2+16*x1^2*x3*x7*f1*f6*f0*f7
*f4-12*x1^4*f0*f4^3*f3^2-16*x2^3*x1*f0*f5*f1^2*f7^2-16*x2^2*x4^2*f3^3*f5^2*f7-\
8*x3*x5*x6*x7*f3^2*f5-16*x3*x5*x6*x7*f4^2*f3+24*x3*x5*x6*x7*f1*f5^2+32*x3*x5*
x6*x7*f2*f3*f6+4*x3*x5^2*x6*f1*f4^2+48*x1^4*f6^2*f0^2*f3^2-64*x1^3*x3*f6^2*f0^
2*f4^2-12*x3^3*x7*f7^2*f3*f4*f1+32*x3^2*x7^2*f6^2*f1*f5+6*x2^2*x6^2*f3^2*f4^2-\
128*x1^3*x2*f6^2*f0^3*f7-56*x2*x6*x4*x7*f7*f0*f5^2+10*x1^2*x7^2*f3^2*f7*f1+24*
x1^2*x2*x4*f3^2*f6*f4*f1*f5-40*x1*x2*x3^2*f0*f5*f7^2*f2^2+4*x1*x2*x3^2*f4*f5^3
*f2^2-64*x1*x4*x2*x7*f0*f3^2*f7^2+72*x3*x4*x5^2*f1^2*f7*f6+64*x2*x4^2*x3*f0*f6
^2*f4^2*f7-36*x1*x4^2*x2*f5^3*f4^2*f2+72*x1*x4^2*x2*f3*f5^4*f2+4*x2^2*x3^2*f4^
6+24*x3*x4*x6*x7*f3^2*f7*f5+32*x3*x4*x6*x7*f3*f7^2*f1-192*x3*x4*x6*x7*f1*f6^2*
f5+72*x3*x4*x6*x7*f5^2*f7*f1+12*x2^2*x4*x5*f2*f5*f4^3+12*x1^3*x5*f2*f1^2*f5^2+
160*x1^3*x4*f1*f4*f3*f0*f7*f6+36*x1*x3*x2*x7*f3*f5^2*f2*f4+32*x1*x2*x3^2*f0*f5
^2*f7*f3^2-2*f7*x6^2*x8^2*f3+4*f7*x6*x8^2*x7*f4-10*f7^3*x4^2*x8^2*f1+96*x1^3*
x4*f1*f4*f6*f2*f3*f5+36*x4^2*x2*x6*f4*f5^3*f3-144*x4^2*x2*x6*f5^3*f6*f1+16*x3^
3*x2*f1*f6^2*f4^3-8*x1*x4^3*f7^2*f1^2*f6*f5-8*x1*x4^3*f7^2*f4^3*f1-384*x1*x4^3
*f7^3*f6*f0^2-14*x3^2*x7^2*f7*f5^2*f1+176*x2^2*x4^2*f0*f6*f7*f4^2*f5-64*x1^3*
x4*f7*f5*f6*f3*f0^2+16*x3^3*x1*f4^2*f7^2*f1^2+128*x1^2*x3*x7*f6^3*f0^2-16*x1^2
*x3^2*f0*f4*f5*f7*f3^2-52*x2*x3*x4^2*f7^2*f2*f5^2*f1-4*x1^2*x3*x6*f4^4*f1-128*
x1^3*x4*f2*f0*f7^2*f4*f1+48*x1^3*x4*f0*f5^2*f7*f3*f1+64*x2^2*x3*x4*f4*f0^2*f7^
3+16*x3^3*x6*f1*f7*f3*f6*f4-28*x3^3*x6*f1^2*f7^2*f5+56*x1^2*x2*x3*f2*f3*f7^2*
f1^2-24*x1^2*x2*x3*f4^2*f3^2*f1*f6+16*x2*x3^2*x7*f1^2*f7*f6^2+48*x4^2*x3*x7*f7
^2*f3^2*f4+144*x4^2*x3*x7*f7*f2*f4*f5*f6+416*x4^2*x3*x7*f0*f5^2*f7^2-216*x4^2*
x3*x7*f3*f5^3*f6+16*x1^2*x4*x6*f0*f6*f3*f7*f2-128*x3*x4*x6*x7*f0*f7^2*f4+40*x3
*x4*x6*x7*f7*f3*f4^2+96*x1^2*x4*x7*f0*f5^2*f2*f7+120*x2*x6*x4^2*f7^2*f1*f5*f2-\
4*x2*x6*x4^2*f7^2*f4*f3*f1+416*x2*x4*x3^2*f0*f6*f5*f4^2*f7-8*x4^2*x5*x8*f7^2*
f2*f3-12*x1^4*f0*f6*f3^4-12*x2^2*x3^2*f4^4*f2*f6+96*x1*x3^2*x4*f0*f6^2*f2*f7*
f4-144*x2^2*x4^2*f0*f6*f5^4+32*x3^2*x2*x5*f3*f4*f1*f5*f6+16*x3^2*x2*x5*f0*f5^3
*f4+8*x3^3*x6*f5^4*f1-88*x2*x4*x3*x7*f7*f2^2*f6*f5+24*x2*x4*x3*x7*f5^4*f2-8*x1
^3*x5*f0*f3^2*f4^2+32*x1^3*x5*f4^2*f6*f0^2+80*x1^2*x3*x6*f0*f7^2*f2*f1-8*x3^3*
x5*f3*f5^2*f6*f1+32*x3^3*x8*f7*f1*f6*f4*f5-88*x1*x2*x4*x5*f7*f2*f5*f1*f3-12*x1
^2*x2*x3*f1*f5^2*f3^2*f4+12*x4^2*x2*x8*f7^2*f2*f4^2+8*x1^3*x7*f7*f2^3*f3-256*
x1^2*x2*x4*f6*f0^2*f7*f5*f4-12*x1*x2^2*x3*f1*f5^3*f2*f4+8*x1*x2^2*x3*f7*f2^3*
f3*f6-64*x1*x2*x3^2*f1*f5^2*f2*f4*f6+32*x2^2*x4*x6*f7*f2*f5^2*f1+32*x1^3*x7*f6
*f0^2*f5^2-8*x2^2*x4*x6*f7*f3^3*f4-40*x2^2*x1*x3*f0*f5^2*f1*f7*f4-4*x6^3*x3*f4
^2*f3+56*x3*x7*x4^2*f7^2*f6*f2^2-60*x3*x7*x4^2*f7^2*f2*f4^2+48*x3*x7*x4^2*f7^3
*f0*f3-22*x2^2*x7^2*f7*f1*f4^2-16*x3^3*x6*f3*f5^2*f4^2+32*x3^2*x5*x8*f7*f0*f6*
f4-72*x1^2*x4*x7*f0*f5^3*f4+144*x1^2*x4^2*f0*f6*f4^2*f5^2-32*x1^2*x4^2*f7^3*f3
*f0^2-36*x1*x4*x5*x8*f7^2*f1^2+8*x1*x3^2*x4*f3^2*f6*f4*f7*f2+16*x1^3*x2*f0*f5*
f1*f7*f3^2-70*x2^2*x4^2*f7^3*f1^2*f3+24*x3^2*x4*x8*f7^3*f2*f1+272*x3^3*x4*f0*
f6*f5^2*f4*f7+336*x4^2*x3*x7*f0*f6*f7^2*f4+104*x4^2*x3*x7*f4*f5*f7^2*f1+8*x3^2
*x6*x8*f7^2*f2^2+16*x3^3*x6*f2*f5*f4^2*f6+16*x1*x4^2*x5*f0*f5^2*f3*f7-160*x3*
x4*x5*x7*f0*f6*f7*f4-40*x1*x4*x3*x5*f0*f4^3*f7-152*x1*x2*x3*x4*f1*f5^2*f7*f2*
f4-16*x1*x2*x3*x6*f1^2*f5^2*f6+32*x1^3*x7*f0*f6^2*f2^2+8*x1^3*x7*f1*f4^3*f3-76
*x1*x4^3*f7^3*f1^2*f4+16*x3^3*x6*f0*f6*f1*f7^2+24*x3^3*x6*f3*f5^2*f6*f2+24*x2*
x5^2*x4*f0*f5^2*f4+8*x1*x5*x6^2*f1*f4*f3+4*x1*x5*x6^2*f2*f5*f1-72*x1*x4^2*x2*
f5^3*f6*f2^2-4*x1*x4^2*x2*f7*f4^4*f2-48*x3*x4^2*x8*f7^3*f3*f1+60*x2^2*x3*x4*f4
*f5^4*f1-8*x1*x2*x4^2*f7^2*f2*f3^3-8*x2*x3*x5^2*f1*f4*f3*f5-48*x1^2*x3*x5*f0*
f5*f4^2*f3-24*x1*x3^2*x2*f2^3*f6*f7*f4-12*x1^2*x2*x5*f7*f1^2*f3^2+36*x2^2*x4*
x5*f3*f5^3*f1-16*x3^2*x2*x5*f0*f4^3*f7-48*x1*x3*x2*x4*f4^2*f7^2*f0*f2+80*x1*x3
*x2*x4*f0*f4^3*f5*f7+48*x1*x3*x2*x4*f0*f6*f5^2*f4^2+152*x4^3*x3*f7^2*f3^2*f4*
f5-64*x3*x4^3*f7^2*f4^2*f6*f1-96*x3*x4^3*f0*f6^2*f7^2*f3+112*x3*x4^3*f7^4*f0*
f1+32*x1^2*x3*x6*f0*f6^2*f2*f3+32*x1^2*x3*x6*f6*f1*f5^2*f0-32*x1*x3*x2*x6*f0*
f6*f4^3-12*x1*x5*x3*x6*f1*f4*f5*f3+12*x2*x5*x6^2*f2*f3*f4-16*x1*x3*x5*x8*f7*f1
^2*f6-16*x1*x3^2*x5*f4^2*f1*f7*f2+16*x2^2*x3*x7*f3^2*f6*f7*f1-4*x3^3*x1*f3*f5^
2*f7*f2^2+32*x3^3*x1*f0*f6^2*f4^3-2*x3^4*f5^5*f1-16*x1^2*x4*x7*f1^2*f7*f4*f6+
32*x4^2*x5*f0*f6^2*f7*f3*x3+16*x1*x4^2*x5*f7*f2^2*f3*f6-8*x1^2*x3*x5*f7*f2^3*
f3+32*x1^2*x3*x5*f1^2*f0*f7^2-54*x2^2*x4^2*f4^2*f3*f5^3-16*x2^2*x3*x4*f0*f5*f3
^2*f7^2-8*x2^2*x3^2*f3^2*f6*f4^3-16*x3^3*x8*f7*f0*f6*f5^2-192*x3^2*x4*x8*f7*f5
*f6^2*f0+8*x1*x7^2*x5*f2^2*f6-64*x2^2*x4^2*f5*f4*f6*f1*f3*f7+64*x2^2*x4^2*f0*
f6*f5^2*f3*f7-144*x1^2*x4^2*f4*f5^2*f1*f6*f3+64*x2*x4*x5*x6*f7*f2^2*f4-24*x2*
x4*x5*x6*f3^2*f4*f5+48*x2*x4*x5*x6*f4*f5^2*f1-24*x2*x4*x5*x6*f4^2*f5*f2-104*x2
*x4*x3^2*f5^2*f4^2*f1*f7-160*x2*x4*x3^2*f7*f2*f5*f4^3-40*x3*x4^2*x5*f7*f2^2*f6
*f5-8*x3^3*x6*f7*f2*f1*f5*f6+32*x3^3*x6*f0*f6^2*f4*f5-48*x3^3*x6*f0*f6*f4^2*f7
+16*x1*x7^2*x3*f5*f6*f2*f3+16*x1*x7^2*x3*f0*f7*f4*f5-4*x1*x7^2*x3*f3*f7*f1*f5-\
912*x4^3*x7*f0*f6*f5*f7^2-12*x4^3*x7*f4^2*f7^2*f3-336*x4^3*x7*f7*f5^3*f3+412*
x4^3*x7*f7^2*f5^2*f1+228*x4^3*x7*f7^2*f5*f3^2+4*x1^4*f7*f2^4*f3-64*x1^2*x2*x4*
f0*f5^2*f1*f7*f4+16*x1^2*x3*x7*f0*f5*f3^2*f7+64*x1*x3^2*x4*f0*f6^2*f1*f7*f5-24
*x1^2*x4*x5*f2^2*f5*f4^2+8*x3^3*x7*f2^2*f6*f7*f5-8*x2^2*x6*x8*f7*f4*f0*f5-8*x3
*x6^2*x4*f3^2*f7*f4+32*x2*x3*x5*x7*f0*f5^3+48*x2*x3*x5*x7*f5*f1*f6*f3+12*x2*x3
*x6^2*f3*f4^3-24*x2*x3*x6^2*f3*f6*f2*f4-24*x2*x3*x6^2*f7*f2*f5*f1+4*x1*x3*x2*
x5*f7*f3^3*f1-4*x1*x3*x2*x5*f7*f3^2*f2^2+80*x1^2*x2*x4*f0*f7^2*f1*f3*f4-56*x4^
4*f0*f7^4*f2-268*x4^3*x7*f7^2*f2*f4*f5+648*x4^3*x7*f7*f2*f5^2*f6+360*x4^3*x7*
f0*f4*f7^3+48*x4^3*x7*f4*f6*f1*f7^2+48*x4^3*x7*f2^2*f7^3+32*x1*x3*x2*x4*f6*f0^
2*f7^2*f4+16*x2*x3*x5*x7*f3*f4^3+24*x1^2*x3^2*f0*f6*f5^2*f2*f4-24*x1*x2*x3*x7*
f3*f5*f1*f4*f6+8*x1*x2*x3*x6*f2*f5^3*f1+12*x2*x5*x3*x6*f1^2*f5*f7-32*x2*x5*x3*
x6*f0^2*f7^2+64*x1^2*x3*x6*f6*f0^2*f7*f4+32*x2^2*x3*x7*f0*f6^2*f4^2-8*x1*x3*x2
*x6*f5*f4^3*f1+x3^4*f5^4*f3^2+4*x1*x6^2*x4*f7*f3^2*f2-16*x2*x7^2*x3*f0*f7^2*f3
+16*x1^2*x7^2*f0*f6*f4^2+4*x1^2*x7^2*f3^2*f6*f2-12*x1^2*x7^2*f1^2*f5*f7-4*x1^2
*x5*x6*f2*f1*f4^2+4*x3*x6*f3^3*f7*x4*x5+96*x4*x5*x7^2*f7*f0*f6+4*x4*x5*x1*x7*
f3^2*f7*f2-16*x2^2*x7^2*f0*f6*f5^2+160*x3*x4*x5*x7*f7*f6*f3*f1+256*x1*x4*x2*x7
*f6*f0^2*f7^2-20*x1*x4*x2*x7*f7*f2*f3^2*f5+96*x1^2*x4*x5*f0^2*f7*f5^2+24*x3*x4
^3*f3^3*f6*f7^2+432*x4^3*x3*f6^2*f2*f5^3-8*x1^2*x6^2*f1^2*f4*f6+12*x4*x6^2*x5*
f3^2*f5+8*x1^2*x6^2*f3^2*f5*f1-20*x1^2*x3*x5*f4*f1^2*f5^2-8*x1^2*x4*x7*f7*f2*
f5*f4*f1-16*x1^3*x7*f2^3*f6*f4+88*x3*x4*x2^2*f6*f5^2*f7*f1^2-48*x3*x4*x2^2*f0*
f6*f5*f4*f3*f7+64*x1*x3*x2*x7*f0*f5*f3*f7*f4-64*x1*x3^2*x4*f0*f6*f5*f3*f7*f4+8
*x1^2*x5*x6*f1*f6*f2^2-32*x1^2*x4*x7*f7*f1^2*f5^2+8*x3^3*x2*f7^2*f2^3*f5-32*x3
^3*x6*f0*f6*f5^3-32*x3^3*x6*f6^2*f2^2*f5+16*x2^2*x4*x6*f0*f3^2*f7^2+16*x1^2*x4
*x7*f7*f2^2*f4^2-4*x4*x6*x1*x7*f7*f1*f4^2-12*x1^2*x4*x6*f5*f4^3*f1+128*x1*x4*
x3*x7*f0^2*f7^3+24*x2*x4*x3*x5*f5^2*f4^2*f2-8*x1^3*x7*f6*f2^2*f3^2-68*x1*x2*x4
^2*f7^2*f2^3*f5-30*x2^2*x4^2*f7^3*f1*f2^2-16*x3^3*x4*f0*f4*f7^3*f2+24*x3^3*x4*
f3*f5^4*f4-24*x3^3*x4*f5*f4^3*f3*f7+48*x2^2*x4*x6*f0*f4^2*f7*f5+8*x2*x7^2*x6*
f2*f4*f6-16*x2^2*x3*x7*f4^3*f6*f2-8*x1*x5*x6^2*f0*f4^2-16*x1*x7^2*x4*f7*f0*f5^
2-12*x1*x6^2*x3*f3^2*f7*f1-32*x1*x6^2*x3*f0^2*f7^2+96*x1^2*x4*x5*f0*f6*f5*f4*
f2+16*x3^3*x7*f6*f5^3*f1-4*x1^2*x5*x6*f1^2*f2*f7+16*x2*x5*x3*x8*f7*f0*f5*f4-16
*x1^2*x5*x6*f3^2*f4*f1-32*x1^2*x5*x7*f1*f6*f2*f3+4*x5^2*x7*f7*f2^2*x4-12*x4*x5
^2*x7*f2*f4*f5-4*x1^2*x4*x5*f7*f2^2*f3^2+361*x4^4*f7^2*f3^2*f5^2+16*x1^2*x4*x5
*f1^2*f4^2*f7-48*x1^2*x2*x5*f7*f0*f5*f2*f1-256*x1^2*x3^2*f6*f5*f0^2*f7*f4-32*
x2*x3*x5*x7*f3*f6*f2*f4-24*x2*x3^2*x4*f5^3*f4^2*f3+16*x1*x3^2*x2*f0*f4^2*f1*f7
^2+8*x3^3*x2*f5^3*f4^2*f2+4*x3^3*x2*f5^2*f4^3*f3-32*x2*x5*x6*x7*f0*f5^2-8*x3^2
*x5*x8*f7*f2*f4^2+8*x2*x5^2*x4*f0*f5*f2*f7+8*x3^3*x7*f7*f3^2*f4*f5-32*x3^3*x7*
f0*f6^2*f5^2-8*x2*x6^2*x3*f4*f7*f3*f1+16*x2*x6^2*x3*f0*f7^2*f1+16*x1*x6^2*x3*
f0*f4*f3*f7-16*x1^3*x7*f0*f7^2*f1^2+16*x1*x6^2*x4*f7^2*f0*f1+4*x1*x6*x2*x8*f2*
f5*f1*f7-8*x1^2*x6^2*f0*f5^2*f2+6*x1^2*x6^2*f3*f1*f4^2+6*x1^2*x6^2*f3*f5*f2^2+
16*x3*x6*x1*x7*f5*f6*f2^2-4*x1*x2*x3*x4*f7^3*f1^3-12*x3^3*x2*f7*f2*f4^4+18*x3^
2*x4^2*f7^2*f3^2*f4^2+272*x1*x3*x4^2*f7^2*f0*f6*f4*f2-208*x2*x3*x4*x5*f1^2*f7*
f6*f5+24*x2*x3*x4*x5*f7*f2*f3^2*f5+164*x1*x3*x4^2*f7^2*f2*f5*f1*f4-192*x1*x2*
x4*x5*f6*f0^2*f7*f5+144*x1*x2*x3*x4*f7*f2^2*f5*f4^2+4*x1^2*x4*x5*f7*f2^3*f4-\
144*x1^2*x2*x4*f0*f5^2*f7*f2*f3+20*x2^3*x4*f7^2*f2*f3*f1*f4+48*x3^2*x2*x5*f1*
f6^2*f4*f2-48*x3^2*x2*x5*f1^2*f6^2*f5+48*x1^2*x2*x4*f1^2*f3*f7*f4*f6-28*x1*x2*
x3*x7*f1*f7^2*f2^2+36*x1*x2*x3*x6*f7*f2*f5*f1*f3-16*x3^2*x2*x4*f7*f4^4*f3-8*x3
^3*x7*f7*f3*f5*f1*f6-32*x3^3*x7*f7*f3*f4*f2*f6-32*x3^3*x7*f4*f5^2*f1*f7+32*x3^
3*x7*f6^2*f2*f3*f5-16*x1*x2*x3*x4*f1^2*f5*f7^2*f3-8*x1*x2*x3*x4*f2*f6*f3^3*f7+
4*x1*x2*x6^2*f1*f5*f3*f4+32*x1^2*x3^2*f7*f3*f0*f6*f1*f5-8*x1*x7^2*x2*f0*f5^3+2
*x2^2*x7^2*f7*f3^3+4*x6*x7*x2*x8*f7*f2*f4+16*x1*x4^3*f7^2*f2*f3^2*f5-8*x1*x5*
x3*x6*f2*f5^2*f1-8*x1*x7*x3*x8*f6*f7*f2^2+2*x2^2*x7^2*f4*f5^2*f2-16*x1^2*x7^2*
f0*f4*f3*f7-8*x2^2*x7^2*f0*f6*f7*f3-8*x2*x5*x3^2*f0*f5^2*f2*f7+32*x2^2*x4*x6*
f7^2*f0*f4*f2-28*x2^2*x4*x6*f7^2*f2*f3*f1+16*x1*x6^2*x3*f0*f6*f1*f7-240*x1^2*
x2*x4*f6*f7*f1^2*f5*f2-216*x4^3*x3*f5^4*f6*f3-144*x4^3*x3*f7*f2*f5^4-24*x4^3*
x3*f6*f4^2*f7*f5*f3-8*x4^3*x3*f7^2*f3*f4^3+4*x3*x5^2*x4*f7*f4*f2^2-8*x1*x4^2*
x3*f4^3*f6*f1*f7+48*x1*x2*x3*x6*f0*f7^2*f2^2-44*x1*x2*x3*x6*f1^2*f7^2*f2+64*x2
^2*x3*x7*f6*f0^2*f7^2+96*x2*x3*x4^2*f7*f3^2*f5^2*f4-28*x4^2*x5*x7*f2^2*f7^2-40
*x2^2*x1*x3*f6*f2*f5*f1*f4^2+48*x2^2*x1*x3*f0*f6*f2^2*f7*f5+4*x2^3*x1*f4^3*f2^
2*f5-24*x1*x5*x2*x6*f1*f4*f0*f7-4*x4*x5*x2*x8*f7*f4^2*f2-64*x1^2*x5*x7*f6^2*f0
^2-80*x2*x8*f7^2*x4^2*f5*f2*f3+24*x2^2*x4*x5*f0*f5*f3*f7*f4+48*x3^2*x2*x5*f1*
f5^2*f6*f2+10*x6^2*f7*f2^2*x3^2*f5-32*x3^3*x5*f3*f5*f6*f2*f4+4*x3^2*x5*x7*f7*
f3^3-96*x1^2*x4*x5*f2*f5*f1*f6*f3+48*x1^2*x4*x5*f1*f6*f5^2*f0+32*x2^2*x4*x6*f6
*f0*f4*f3*f7-4*x2^2*x4*x6*f7*f2^2*f5*f4+8*x3*x6*x1*x7*f4^2*f2*f5-16*x3*x6*x1*
x7*f5^2*f2*f3-8*x3*x6*x1*x7*f5^2*f1*f4-8*x1^3*x5*f0*f5^2*f2^2+32*x1^2*x3*x6*f6
*f2*f5*f3*f1+64*x1^2*x3*x7*f0*f5*f2*f7*f4-96*x2^2*x4*x6*f0*f6*f5^2*f4+48*x2^2*
x4*x6*f1*f7^2*f0*f5-24*x2^2*x4*x6*f0*f5^2*f3*f7+4*x3^2*x6^2*f4^4+176*x1^2*x2*
x4*f7*f0*f5*f2*f4^2-56*x1*x2*x3^2*f3*f5*f6*f1*f4^2+32*x1*x2*x3^2*f0*f7^2*f2*f3
*f4+92*x2^2*x4*x5*f7*f2*f5*f1*f4-4*x2^3*x6*f3^2*f4^3-8*x1*x2*x3*x6*f2^2*f4*f5^
2-24*x1*x2*x3^2*f1*f5^2*f7*f2*f3+16*x1*x2*x3*x4*f7^2*f6*f0*f1*f3+36*x1*x4^2*x2
*f4*f5^4*f1-24*x3^2*x2*x5*f0*f3*f7^2*f2-24*x3^2*x2*x6*f0*f5^4-184*x3*x4*x2^2*
f6*f2*f5*f1*f4*f7+8*x1*x7^2*x2*f5^2*f2*f3-4*x1*x7^2*x2*f4^2*f2*f5+4*x1*x7^2*x2
*f4*f1*f5^2+4*x1*x3^2*x7*f7*f4^2*f2*f3+8*x1^2*x3*x5*f2*f3^2*f4^2+16*x2*x3^2*x6
*f3^2*f4^2*f6-96*x1*x4^2*x2*f4*f0^2*f7^3-16*x3^2*x6*f0*f7^2*f2*x4*f6+32*x3*x4*
x1*x5*f0*f5*f4*f3*f7-24*x2^2*x4*x7*f7*f2^2*f5^2-8*x1^2*x4^2*f2*f7*f3^3*f6+36*
x1^2*x4^2*f3^2*f5^2*f6*f2-16*x1*x3^2*x4*f0*f6*f7^2*f3*f2+4*x1^2*x3*x6*f4^2*f3^
3+56*x1*x3*x2*x6*f4^2*f0*f5^2+72*x3*x4*x2^2*f7*f2^2*f4^2*f6-32*x1^3*x5*f5^2*f0
^2*f4-4*x1^2*x2*x7*f4^2*f3^3+16*x3^2*x2*x5*f1^2*f7^2*f3+2*x3^2*x5^2*f1*f5^2*f3
-8*x1*x5*x3*x7*f7*f1*f3^2-8*x2*x3^2*x7*f4^2*f5^2*f3-16*x1^2*x3*x6*f1^2*f4*f6*
f5-32*x2*x3*x1*x5*f4*f0^2*f7*f6-48*x1^2*x3*x6*f0*f6*f5*f2*f4-192*x1^2*x3*x7*f6
*f5*f0^2*f7+32*x1^4*f3*f5^3*f0^2+32*x1*x3*x2*x4*f0*f5^3*f2*f7-32*x1^2*x2*x4*f1
*f3^2*f7*f2*f6+32*x1^2*x2*x3*f0*f5^2*f7*f1*f3+16*x1^2*x2*x4*f0*f6*f1*f7*f4^2-\
32*x1*x2*x3*x5*f1^2*f5*f4*f6-16*x3^3*x2*f3*f6*f4^4-16*x1^2*x3*x6*f7*f6*f0*f3*
f1+16*x2*x4*x3*x6*f7^2*f3^2*f1+36*x2*x4*x3*x8*f7^2*f1*f4^2-48*x2*x4*x3*x8*f7^2
*f0*f5*f4-14*x1^2*x4^2*f7*f3^2*f5^2*f1+8*x3*x4^2*x7*f7*f5*f4^3-32*x2^2*x1*x3*
f7^2*f3*f0*f4*f1-24*x2^2*x1*x3*f6*f5*f7*f1^2*f2-48*x2^2*x1*x3*f0*f5*f7^2*f1*f2
+16*x2^2*x1*x3*f0*f5*f4^2*f7*f2-16*x1^3*x5*f0*f4^3*f2-16*x4*x5*x3*x7*f0*f7^2*
f3+4*x1*x5^2*x4*f7*f2^3+128*x3^3*x7*f0*f6*f5*f4*f7+48*x3^3*x7*f1*f5*f6^2*f4-56
*x3^3*x7*f3*f5*f4^2*f6+8*x3^3*x7*f1^2*f7^2*f6-4*x2*x4^2*x6*f7*f4^3*f3+72*x4^3*
x1*f4*f5^3*f1*f7+138*x4^4*f7^3*f2^2*f5-96*x1*x3*x2*x7*f0*f6*f1*f7*f5-8*x1^3*x5
*f1^2*f3^2*f6+60*x1*x4^3*f7^2*f2^2*f5*f4-48*x1*x4^3*f7^2*f2^2*f3*f6-24*x1*x4^3
*f7^2*f2*f5^2*f1+96*x1*x4^3*f7^3*f0*f3^2-12*x2*x3^3*f1*f5^3*f7*f2-32*x1^3*x4*
f2*f6*f1*f0*f7*f5+8*x3^3*x2*f3*f5^2*f6*f2*f4+8*x3^3*x2*f3*f5^3*f6*f1-8*x1^3*x5
*f2^2*f3^2*f4+4*x2^2*x5^2*f7*f0*f2*f3+2*x2^2*x5^2*f3*f4^2*f1-124*x2*x3*x4^2*f5
*f4^3*f7*f3+8*x2*x3*x1*x5*f0*f4*f3^2*f7-64*x1*x3*x2*x5*f5^2*f0^2*f7+48*x2^2*x3
*x4*f7*f3^2*f5*f1*f6-4*f7^2*x2*x8^2*x3*f2*f3-16*x4^2*x5*x6*f3*f6*f1*f7-16*x4^2
*x5*x6*f0*f7^2*f3-16*x3^3*x6*f3*f5*f6^2*f1-16*x3^3*x6*f4^2*f6^2*f1+4*f7^2*x2^2
*x8^2*f0*f4+2*f7^2*x2^2*x8^2*f3*f1-2*f7*x2^2*x8^2*f4^2*f3-4*f7*x2*x8^2*x3*f4^3
+8*f7^2*x2*x8^2*x3*f0*f5-24*x3^2*x2*x4*f1^2*f7^3*f3-4*x2*x6*x5*x7*f7*f2*f1+8*
x4*x6*x2*x8*f7^2*f2^2+x7^4*f5^2+544*x1^2*x4^2*f6^2*f0^2*f7*f5+72*x1^2*x4^2*f0*
f6*f5^3*f3-44*x3*x4*x5^2*f1*f7*f3*f4+16*x3^2*x4^2*f0*f6^2*f7^2*f2-20*x2^2*x4*
x6*f7*f1*f4*f3*f5+256*x1^2*x2*x4*f0*f5*f6*f7*f2^2-28*x1^2*x2*x4*f4^3*f7*f1*f2-\
112*x1^2*x2*x4*f0*f4*f7^2*f2^2+16*x1^4*f0^2*f7^2*f2^2+12*x2^2*x4*x6*f7*f3^2*f5
*f2-24*x1*x7^2*x2*f4*f7*f3*f1-16*x1*x7^2*x3*f2^2*f6^2+112*x1*x4*x2*x7*f0*f5^2*
f3*f7+12*x2^2*x5*x7*f3*f5^2*f1-64*x1^2*x3*x4*f3*f5^2*f7*f2*f1+32*x1^2*x2*x4*f4
*f7^2*f2*f1^2-84*x1^2*x2*x4*f2^3*f5*f4*f7+16*x1^2*x3*x7*f3^2*f5^2*f2-12*x2*x3^
2*x4*f3^2*f5^4+8*x2*x3*x6^2*f3^2*f5*f4+12*x1*x3*x2*x5*f7*f2^3*f4+44*x1*x4^2*x3
*f7^2*f2^2*f5*f3-72*x1*x4^2*x3*f4^2*f5^2*f2*f6-40*x2*x4*x6*x8*f7*f1*f5^2-96*x2
*x4*x5*x6*f0*f5^3-168*x1^2*x3*x4*f2*f6*f5^2*f1*f4+36*x1^2*x2*x4*f3*f5^2*f7*f1^
2+24*x2*x3*x4*x7*f7^2*f2^2*f4+80*x3^2*x2*x4*f4^2*f6*f7*f2*f3-4*x3^3*x8*f7^3*f1
^2+4*x2^3*x3*f4^5*f3-12*x1*x3^3*f4^2*f7*f2^2*f5-48*x4*x8*f7^2*x3^2*f0*f5^2-24*
x3^3*x6*f0*f5^2*f7*f4-24*x1*x2*x3*x7*f1^2*f7^2*f3+32*x1*x2*x3*x7*f1^2*f6^2*f5+
20*x1*x2*x3*x7*f1^2*f5^2*f7+12*x3^2*x2*x5*f7*f3^2*f2*f4-32*x3^2*x2*x5*f4^2*f6*
f2*f3+8*x3^2*x2*x5*f2*f5*f4^3-8*x2^2*x3*x7*f7*f2^2*f3*f6-16*x2^2*x3*x7*f0*f4*
f2*f7^2+16*x1^2*x3*x7*f0*f4^3*f6-8*x2*x3^3*f7*f2*f5^2*f3^2-32*x2*x3^3*f5*f4^3*
f1*f7+98*x3^2*x4^2*f1^2*f7^3*f5+24*x2^2*x4*x6*f7*f4^2*f2*f3-4*x3^2*x4^2*f7^2*
f3^2*f6*f2-12*x1^2*x4*x7*f3^3*f5^2+16*x3^3*x7*f7^2*f2^2*f4-4*x6^2*x7^2*f2*f6+2
*x6^2*x7^2*f3*f5-2*x5^2*x7^2*f2*f4-8*x3^3*x6*f0*f7^2*f2*f5+32*x3^3*x6*f2*f6^3*
f1+100*x1^2*x2*x4*f1*f5^2*f7*f2^2-40*x1^2*x2*x4*f4^2*f7*f1^2*f5-24*x2*x4^2*x3*
f6*f4^3*f7*f2-128*x2*x4^2*x3*f7*f2^2*f5^2*f6+16*x1*x5*x3*x6*f1^2*f6*f5+8*x4*x5
*x1*x6*f0*f5*f7*f2-16*x2^2*x1*x3*f0*f6*f4^2*f1*f7-4*x2^3*x1*f1^2*f4^3*f7-248*
x2*x3*x4*x7*f7*f5*f1*f6*f3-96*x2*x3*x4*x7*f3*f5^3*f4+2*x3^2*x7^2*f5*f7*f3^2-12
*x1^2*x5*x7*f1^2*f5^2-144*x1*x3*x2*x7*f0*f6*f7*f4*f2-8*x2^2*x3*x5*f7*f0*f5*f2*
f4+32*x3^3*x2*f4*f0^2*f7^3+16*x1^3*x3*f0*f4^2*f3*f2*f7-96*x1^2*x4*x7*f0*f6*f3^
2*f7+96*x1^2*x4*x7*f0*f6*f5*f4^2+48*x1^2*x4*x7*f0*f6*f5^2*f3-16*x1^2*x4*x6*f0*
f4^2*f7*f3-24*x3*x4*x5*x7*f2*f5^3-8*x1^2*x5*x7*f2^2*f4^2+48*x3^2*x5*x7*f0*f5^2
*f6-4*x6^3*x1*f2*f3*f4-4*x6^3*x1*f3*f1*f5+8*x6^3*x1*f0*f5*f4+4*x6^3*x2*f7*f2*
f1+120*x3^2*x4*x8*f7*f4*f5*f6*f2+16*x3^2*x4*x8*f7^2*f2^2*f6+20*x1*x3^2*x5*f4*
f1^2*f7*f5-12*x2^2*x1*x7*f7*f2^3*f5+16*x2^2*x1*x3*f7*f3*f0*f6*f1*f5+28*x4*x8*
f7^2*x3^2*f2*f3*f5+52*x4*x8*f7^2*x3^2*f1*f4*f5+40*x1^2*x3*x4*f1*f5*f6*f7*f2^2-\
8*x4^2*x5*x6*f4^2*f2*f7-24*x1*x5^2*x4*f1*f4*f5*f3+40*x4*x5*x6*x8*f1*f5*f7-16*
x2*x7^2*x3*f2^2*f6*f7-16*x2*x3*x5*x7*f5^2*f1*f4-16*x2*x3*x5*x7*f2*f5^2*f3+16*
x1^2*x3*x4*f0*f3^2*f5^2*f7+28*x2^2*x4*x5*f7^2*f1^2*f3-28*x4*x5*x6^2*f7*f2^2-8*
x1^3*x3*f2^3*f5^2*f4+36*x2*x4^2*x3*f5^5*f2+24*x1*x4*x6^2*f7*f2^2*f4-16*x4^2*x6
*f0*f7^2*f3*x2*f5-8*x1^2*x2*x4*f2^2*f5*f3^2*f7+8*x1*x5*x3*x6*f0*f5*f4^2+8*x1*
x5*x3*x6*f5*f2^2*f4-16*x3^2*x2*x5*f2*f6*f7*f3*f1-8*x3^3*x5*f0*f5^4-128*x1^2*x2
*x4*f0*f6*f7^2*f1^2-16*x3^3*x1*f6^2*f7*f1^2*f3+64*x3^3*x1*f4*f6*f0^2*f7^2+16*
x3^3*x1*f6^2*f5^2*f1^2+8*x3^4*f6^2*f4^3*f2+48*x1^2*x2*x4*f1^2*f5^2*f4*f6-96*x1
^2*x2*x4*f0*f6*f5^2*f3^2+128*x1^2*x3*x4*f0*f4^2*f1*f7^2-40*x1*x3*x4*x6*f7^2*f2
^3-48*x2*x3*x4*x6*f4^2*f5^2*f3-656*x3*x8*f7^2*x4^2*f0*f6*f5+72*x3*x8*f7^2*x4^2
*f4*f6*f1+24*x3^2*x6^2*f0*f6*f5^2-8*x1*x6^2*x4*f7*f0*f5*f3-16*x3^2*x6^2*f0*f6*
f7*f3-56*x3^2*x4*x8*f7^2*f6*f1*f3+80*x3^2*x4*x8*f7*f5^2*f6*f1+32*x1^2*x2*x4*f2
^2*f3*f4^2*f7-4*f7^2*x2*x8^2*x4*f3^2-84*x1^2*x2*x4*f2*f5^3*f4*f1-32*x1^2*x2*x4
*f1*f3*f7^2*f2^2-16*x3*x4*x1*x5*f1*f7*f3^2*f5+2*x6^4*f2*f4-128*x1^2*x3*x4*f0*
f6*f7^2*f2*f1-8*x3^2*x2*x5*f0*f4*f1*f7^2-4*x3^3*x1*f5^2*f4^3*f2+20*x1^2*x3*x4*
f1*f4^3*f7*f3-32*x1*x3^2*x7*f6^2*f2*f5*f1+48*x2*x3*x4*x6*f3^2*f5*f6*f4+4*x3^3*
x5*f3^2*f4*f5^2+64*x3^3*x5*f0*f6*f5^2*f4-16*x3^3*x5*f0*f5^2*f3*f7+32*x1^3*x6*
f7*f1^3*f5-12*x3^3*x5*f1*f5^3*f4+14*x3^2*x6^2*f5*f4^2*f3+6*x1^2*x6^2*f1*f7*f2^
2-2*x3^2*x2^2*f5*f4^2*f7*f2^2-48*x1^2*x3^2*f0*f6^2*f3^2*f4+48*x1*x3*x4*x5*f1*
f6*f7*f3*f2+128*x1*x3*x4*x5*f6^2*f0^2*f7+16*x2*x6*x4*x7*f0*f7^2*f3+16*x2^2*x5*
x6*f2^2*f5*f4+8*x2^2*x5*x6*f3*f5*f1*f4-4*x3^2*x2^2*f7*f3^2*f1*f5^2+304*x3*x4^3
*f7^3*f0*f4^2+36*x1^2*x4^2*f5^3*f2*f3*f4+48*x2*x4*x5*x7*f5*f4^2*f3-64*x2*x4*x5
*x7*f7*f2*f3*f4+48*x1^2*x3*x6*f0*f5^2*f3*f4+144*x1^2*x3*x4*f0*f4*f7^2*f3*f2+48
*x2*x4*x7^2*f4*f7*f1*f6+72*x1*x4^2*x3*f6*f5^3*f1*f4+8*x6^3*x2*f1*f4*f5+4*x2^2*
x5*x7*f3^2*f4^2-4*x2^2*x1*x3*f4^5*f2-24*x2^2*x1*x7*f1*f5^2*f0*f7-16*x2^2*x4*x5
*f0*f5^2*f2*f7-8*x2^2*x6^2*f1*f7*f2*f4-2*x2^2*x3^2*f7^2*f3^3*f1+20*x2*x3*x6^2*
f2*f5*f4^2+6*x2^2*x5^2*f1^2*f5^2-12*x2^2*x6^2*f3*f5*f2*f4-112*x1^2*x3*x4*f2*f6
^2*f7*f1^2-24*x1^2*x3*x4*f6*f7*f2^2*f3^2+16*x1^2*x3*x5*f1*f4*f7*f2^2-32*x1^2*
x5*x7*f0*f5*f4*f3-8*x1^2*x5*x6*f0*f5*f3^2+4*x1^2*x5*x6*f4*f2^2*f3-16*x1^2*x5*
x6*f0*f5^2*f1-32*x1^2*x5*x6*f0^2*f7*f4-32*x1^3*x6*f1*f0*f6*f4^2-48*x1^2*x3*x4*
f6*f7*f1^2*f4^2-16*x1^3*x6*f2*f5*f0*f4^2-16*x1*x7*f1*f0*f7^2*x3*x4*f6-8*x3*x4*
x1*x7*f7*f2^2*f5^2-4*x3^3*x6*f7*f3^2*f4^2-384*x1^2*x3*x4*f6*f0^2*f7*f5^2+20*x1
^2*x2*x4*f7*f2*f4*f3^3+96*x3^2*x4*x5*f0*f6^2*f5*f4-8*x3^2*x4*x5*f3*f7*f2*f4*f5
-24*x3^2*x4*x5*f2*f5*f4^2*f6+4*x4*x5*x6*x8*f7*f2*f4-4*x2*x5*x3*x7*f7*f3*f1*f4-\
24*x1*x5*x2*x6*f0*f3*f2*f7-48*x1*x3*x2*x4*f5^2*f4^3*f2-72*x1^2*x3*x4*f5*f4^2*
f1*f6*f3+12*x2*x7^2*x8*f7*f2*f5-8*x2^2*x7^2*f0*f7^2*f2+12*x3^3*x5*f7^2*f2*f1*
f3-8*x2*x3^2*x4*f7*f3*f5^3*f1-12*x1*x3*x4^2*f7^2*f4^2*f2^2+88*x1*x3*x4^2*f7^2*
f2^3*f6-12*x1^2*x3^2*f3^2*f6*f4^2*f2+48*x1^2*x2*x3*f0*f6*f5*f2*f4^2+48*x1*x2*
x3*x7*f0*f7^2*f2*f3-24*x1^2*x3*x4*f2^3*f6*f7*f4+40*x1*x4*x3*x5*f1^2*f7^2*f3+16
*x1^2*x2^2*f0*f4^3*f1*f7+20*x1^2*x2^2*f3*f7^2*f1^3-32*x1*x2*x3*x4*f1^2*f6^2*f3
*f7+128*x1^2*x2*x3*f4*f3*f0^2*f7^2-8*x1*x5*x2*x6*f2*f5*f4*f1-184*x4^2*x5*x6*f0
*f5^2*f7-16*x1^2*x3*x6*f7*f2*f3*f1*f4-32*x1*x2*x3*x7*f7*f2*f4*f1*f5-208*x1*x2*
x4^2*f7^2*f1*f5^2*f0-16*x1*x2*x3*x7*f5*f4*f2^2*f6-8*x1^2*x2*x6*f1*f6*f2^2*f5+
32*x1^2*x2^2*f4*f2*f0^2*f7^2-16*x1^2*x2*x6*f1^2*f5*f6*f3-48*x2^2*x3^2*f6^2*f2*
f5*f1*f4-32*x3^2*x6*x8*f7*f1*f4*f6-64*x3^2*x7*x8*f6^2*f7*f0+8*x3^2*x5*x8*f7*f0
*f5^2-16*x2^2*x3^2*f7*f2^2*f3*f4*f6+16*x3^2*x5*x8*f7*f1*f3*f6-56*x1^2*x3*x4*f3
*f6*f5*f7*f1^2-208*x3*x4^3*f7^2*f2*f5*f4^2+20*x3*x4^3*f7^3*f2^2*f4-8*x1^3*x2*
f1*f4^4*f2-4*x3^2*x7*x8*f7^2*f2*f3-4*x3^2*x7*x8*f7^2*f1*f4-76*x1^2*x3*x4*f3*f5
*f7*f2^2*f4+48*x1^2*x4*x6*f3*f5*f2^2*f6+28*x1^2*x4*x7*f7*f3^2*f5*f1+48*x1^2*x4
*x7*f2^2*f5*f4*f6-48*x2*x4*x3*x5*f5*f4^2*f1*f6-32*x1^2*x2*x6*f0*f7^2*f1^2+24*
x1*x4*x5*x7*f2*f5*f4^2-32*x1*x4*x5*x7*f0*f7*f4^2-8*x3^3*x7*f7*f3^3*f6+16*x3^3*
x7*f1*f0*f7^3+4*x3^3*x7*f7^2*f3^2*f2+12*x1^2*x2*x4*f3*f5^2*f4^2*f1+480*x1*x2*
x4^2*f7^2*f6*f0^2*f5-16*x2^3*x1*f0*f6*f4*f3*f1*f7-8*x2^3*x1*f1*f4*f7*f2^2*f5+
16*x2^3*x1*f4*f7^2*f1^3-136*x4^2*x6*x7*f0*f5*f7^2+32*x2*x6*x1*x7*f0^2*f7^2-16*
x3^3*x5*f2^2*f5^2*f6+24*x1*x6*x2*x7*f0*f5^2*f4-24*x3^3*x6*f6*f5^2*f1*f4+144*x4
^2*x3*x6*f3*f5^2*f6*f4+8*x1^3*x2*f1^2*f4^3*f5+8*x1*x6^2*x3*f0*f5*f2*f7-8*x3^4*
f5^3*f7*f3*f1-32*x2^2*x5*x7*f0^2*f7^2+4*x3^3*x5*f1*f7*f3*f5*f4-40*x3^3*x5*f0*
f5*f4^2*f7-92*x2*x4*x5*x6*f7*f2*f1*f5+32*x1^2*x4^2*f0*f6^2*f1*f7*f4+32*x3^2*x6
*f0*f6^2*f7*f3*x4+32*x1*x4^2*x2*f3*f5*f6*f7*f2^2+72*x1^2*x4^2*f4*f5^2*f2^2*f6+
192*x1^2*x4*x7*f6^2*f0^2*f7-32*x1^3*x6*f4*f7*f2*f1^2+16*x2*x6*x1*x7*f4*f6*f2^2
-4*x4^2*x6*x7*f7*f4^3+16*x3^3*x6*f7*f3^2*f2*f6-4*x2*x6^2*x5*f3*f1*f5-108*x1^2*
x3*x4*f5^2*f7*f1^2*f4-16*x1^2*x3*x4*f4*f7^2*f3*f1^2+96*x1^2*x3*x4*f2^2*f5*f6*
f4^2-12*x3^2*x6^2*f5^3*f1-80*x1^2*x3*x4*f7^2*f3^2*f1*f2+16*x3*x5*x6*x8*f7*f1*
f4+8*x3*x5*x6*x8*f7*f2*f3-4*x3*x5^2*x8*f7*f3*f1+4*x1^2*x5*x6*f2*f3^3+8*x1^3*x7
*f3^3*f2*f5-32*x3^3*x7*f1*f6^3*f3-8*x2*x3^3*f7*f2*f5*f1*f4*f6-2*f7^2*x4^2*x8^2
*f4^2-18*f7*x4^2*x8^2*f5^3-16*x2^2*x1*x3*f0*f4^3*f5^2+8*x1*x7^2*x3*f4*f5*f1*f6
+40*x1^2*x3*x4*f1^2*f5*f7^2*f2+32*x2^2*x1*x3*f5^3*f0^2*f7-8*x3^2*x5*x6*f4*f7*
f3*f1+4*x3^2*x5*x7*f3^2*f5^2+4*x2^2*x5^2*f2^2*f4^2-64*x1^2*x3*x4*f1*f4*f7^2*f2
^2-144*x2*x3*x4*x8*f7*f0*f6*f5^2+40*x2*x3*x4*x8*f7*f1*f5^3-40*x2*x3*x4*x8*f7^2
*f3*f5*f1+60*x2*x3*x4*x8*f7*f2*f5^2*f4-8*x3*x4*x2^2*f6*f2^2*f5*f7*f3-24*x3*x4*
x2^2*f3^2*f6*f4*f7*f2-192*x1^2*x3*x4*f0*f6^2*f3^2*f5-48*x1^2*x4*x6*f1^2*f5^2*
f6-64*x1^2*x3*x4*f0*f5*f7^2*f2^2+8*x1^3*x3*f3^4*f1*f7+20*x1^3*x3*f1^2*f4^2*f5^
2-24*x2^2*x3*x4*f4^2*f3^2*f5*f6+24*x2*x3^2*x6*f4^3*f6*f2-4*x2*x3^2*x6*f3^2*f5^
2*f4+48*x1^2*x4*x6*f7^2*f0*f2^2-36*x1^2*x4*x6*f7^2*f2*f1^2+12*x5^2*x2*x6*f1*f5
*f2+20*x1^2*x2*x6*f7*f2^3*f3+40*x3^2*x7*x8*f6*f7*f2*f4-8*x2^2*x1*x6*f0*f5*f7*
f3*f2+184*x4^2*x3*x6*f7^2*f2*f1*f6+16*x1^2*x5*x7*f0*f6*f5*f1-16*x1^2*x5*x7*f1*
f4*f0*f7+4*x1*x5^2*x8*f7*f1^2-32*x1^2*x5*x7*f0*f3*f2*f7+8*x1^2*x5*x6*f1^2*f4*
f5-8*x1^3*x3*f2*f4^3*f3^2-32*x3^3*x6*f6^2*f2*f3*f4-8*x3^3*x6*f7*f5^2*f2^2+4*x2
^2*x4*x5*f7*f3*f5*f2^2-32*x2^2*x4*x5*f1*f0*f7^2*f4-24*x1^2*x3*x5*f1*f5*f2^2*f6
+80*x3*x4*x2^2*f0*f6*f4*f1*f7^2+64*x3*x4*x2^2*f0*f6*f3*f2*f7^2-16*x1^2*x4*x6*
f0*f3*f1*f7^2-8*x3*x4^2*x7*f7*f3*f4^2*f6-8*x1^2*x3*x7*f5*f4*f3^3-112*x2*x3*x4^
2*f7^2*f0*f6*f5*f2-32*x2*x3^2*x8*f7*f0*f6*f5*f4+20*x2^2*x6^2*f0*f5^2*f4-48*x2^
2*x4*x5*f0*f7^2*f3*f2+12*x2^2*x4*x5*f7*f3^2*f4*f2-24*x1*x3*x6^2*f1^2*f7*f5+12*
x2*x3*x6*x7*f7^2*f1^2-64*x1*x3*x4*x5*f0*f6*f1*f7*f5+24*x2*x3*x6^2*f0*f5^3-32*
x1^2*x2*x6*f5^2*f1^2*f4+72*x1*x2*x3*x6*f2*f4*f5*f1*f6-40*x1*x2*x4^2*f7^2*f2*f4
^2*f1+40*x1*x2*x3*x7*f1^2*f7*f6*f4-48*x1^2*x2*x6*f6*f7*f1^3-16*x1^3*x6*f0*f3^2
*f4*f5-12*x2^2*x5*x6*f3*f4^2*f2-12*x2^2*x5*x6*f2*f5^2*f1+40*x4*x8*f7^2*x3*x6*
f0*f5-8*x2^2*x3*x4*f5*f4^2*f7*f2*f3+52*x2^2*x3*x4*f7^2*f2*f3*f1*f5+96*x2^2*x3*
x4*f3*f5^2*f4*f6*f2+48*x1*x3*x2*x4*f4^2*f5^3*f1-8*x2*x3*x5*x7*f3^2*f5*f4+12*x1
*x3*x2*x4*f5^4*f3*f1+32*x1*x3*x4*x7*f0*f5^2*f4*f7+20*x1^2*x5*x7*f2*f5*f4*f1+16
*x1*x3*x2*x7*f1*f0*f7^2*f4+32*x1*x3^2*x4*f7*f3^2*f5*f1*f6-24*x1^3*x3*f4^2*f6*
f2^3-192*x2*x3*x4*x6*f0*f6^2*f4*f5+32*x1^2*x3^2*f3*f0^2*f5*f7^2-8*x1^2*x3*x5*
f3*f2^2*f5*f4-32*x1^2*x3^2*f6^2*f0^2*f3*f7+180*x2*x3*x4^2*f5^3*f4^3+128*x2*x3*
x4^2*f7^3*f1*f5*f0-152*x2*x3*x4^2*f7^2*f3*f4*f1*f5+12*x1*x4*x2*x8*f5*f7^2*f1^2
-64*x1^2*x4*x6*f0*f5^2*f1*f7+16*x1^2*x4*x6*f7*f1^2*f4*f5-12*x2^2*x3^2*f2*f6*f7
^2*f1^2-24*x2^2*x4*x8*f7*f0*f5^3+32*x3*x4*x2^2*f0*f6*f5^2*f2*f7-40*x1^2*x4*x6*
f7*f2^2*f3*f4+8*x3^2*x2^2*f0*f5^3*f2*f7-68*x4*x5*x7*x8*f7*f2*f5+8*x1*x5*x2*x6*
f4^2*f2^2+24*x3*x4*x6^2*f4^3*f5+48*x1*x4*x3*x7*f4*f5^2*f1*f6+4*x2^2*x5*x7*f3*
f7*f2^2+104*x4*x5*x7*x8*f7^2*f0+144*x4^2*x2^2*f0*f3*f2*f7^3-8*x1^2*x2*x4*f7*f1
*f3^3*f5-4*f7^2*x4^2*x8^2*f2*f6+38*f7^2*x4^2*x8^2*f3*f5-32*x2*x4^2*x5*f0^2*f7^
3+288*x1^2*x4^2*f7*f2*f5*f3*f1*f6+32*x3^3*x7*f0*f6^2*f3*f7+32*x3^3*x7*f3^2*f6^
2*f4-8*x1^2*x3*x7*f3^2*f6*f4*f2-32*x1^2*x3^2*f0*f6^2*f7*f2*f1+16*x1*x3*x6^2*f1
^2*f6^2+8*x5*x6*x2*x8*f7*f0*f4+144*x3^2*x4*x6*f1*f7*f6^2*f2+32*x3^2*x7*x8*f7*
f6*f1*f5-16*x2^2*x1*x6*f5^2*f0^2*f7+4*x2^2*x1*x6*f2^3*f7*f4-96*x2*x4*x6*x7*f5^
2*f6*f1-160*x1*x3*x4^2*f5*f4*f6*f1*f3*f7+64*x1*x3*x4*x7*f0*f7*f4^2*f6-4*x2^2*
x6*x8*f7*f1*f3*f5-24*x3*x4*x1*x6*f3*f5^2*f6*f1+4*x2*x7^2*x6*f7*f2*f3-4*x2*x7^2
*x6*f5^2*f2-32*x3^3*x5*f1^2*f6^3+4*x2^2*x1*x3*f5*f4^4*f1+152*x3*x4^3*f7^2*f2^2
*f6*f5+96*x3*x4^3*f7*f6^2*f4*f1*f5+12*x1*x4*x6^2*f5^2*f1*f4-128*x2*x3*x4*x6*f7
*f2^2*f4*f6+4*x1*x3*x6^2*f4^2*f1*f5+12*x1*x3*x6^2*f3*f5^2*f1+8*x2^3*x1*f7*f3*
f4^2*f1*f2+24*x2^2*x3^2*f1^2*f5^2*f6^2+160*x1^2*x3*x4*f0*f6^2*f7*f2^2+12*x2*x3
^3*f1^2*f7^2*f4*f5+16*x2*x3^3*f0*f5^3*f3*f7-16*x1*x3*x4*x5*f7*f2^3*f6+16*x2^2*
x1*x3*f0*f6*f4^4-64*x3^3*x7*f0*f6^3*f4-32*x3^3*x7*f0*f6*f2*f7^2-48*x3^2*x2^2*
f5^2*f0^2*f7^2-24*x4*x5*x7^2*f7*f3^2+120*x1*x4*x2*x7*f7^2*f2*f1*f3-4*x1^2*x4*
x6*f2*f7*f3^3+2*x3^2*x2^2*f1^2*f5^3*f7-20*x1*x6*x2*x7*f3*f5*f2*f4+8*x1*x6*x2*
x7*f2*f5*f1*f6-32*x2^2*x3*x7*f0*f6*f4*f3*f7-8*x2^2*x3*x6*f1^2*f7*f4*f6-64*x1^3
*x4*f7^2*f1*f3^2*f0+16*x3^3*x2*f4^2*f2*f7^2*f1+24*x1^3*x4*f4^3*f5*f1*f3+24*x1^
3*x4*f3*f5^2*f2^2*f4+28*x1^2*x4*x6*f7*f1*f4^2*f2+96*x2^2*x3*x4*f0*f6^2*f5*f4^2
-16*x1^2*x6*x7*f0*f6*f4*f3+16*x1^2*x6*x7*f7*f2*f3*f1-4*x1^2*x6*x7*f4^3*f1-16*
x1^2*x6*x7*f0*f4*f2*f7-4*x1^2*x6*x7*f7*f2^3-40*x1^2*x6*x7*f1*f5*f0*f7-8*x3^3*
x7*f7^2*f3*f0*f5-12*x3^3*x7*f3*f5^2*f7*f2+648*x4^4*f7*f2*f5^3*f6-388*x4^4*f4*
f5^2*f2*f7^2-1444*x4^4*f0*f6*f5^2*f7^2-4*x4^4*f2*f7^2*f4^2*f6-4*x1*x6*x2*x7*f3
*f5^2*f1-24*x1^3*x4*f3^2*f4*f5^2*f1+48*x1^3*x4*f3*f6*f5^2*f1^2+48*x1^3*x4*f0*
f5^2*f3*f4^2+96*x1*x4*x3*x7*f3*f5^2*f6*f2-48*x1*x4*x3*x7*f2*f4^2*f6*f5-24*x1^2
*x3^2*f0*f3^2*f7^2*f2-16*x2^2*x3*x7*f1*f5*f0*f7^2-8*x2*x3^2*x7*f7*f2*f3^2*f6-\
24*x1^2*x4*x6*f1*f7*f2^2*f6-24*x1*x4*x3*x8*f6*f7*f2^2*f5+28*x1^2*x4*x6*f7*f3^2
*f1*f4-4*x6^2*x7*x8*f7*f2-4*x3^2*x5*x7*f1*f7*f4^2-8*x3^2*x5*x6*f3^2*f7*f2-272*
x3*x4^2*x5*f0*f4^2*f7^2+496*x3*x4^2*x5*f1*f7*f3*f5*f6-32*x1*x3^2*x7*f1*f4*f6^2
*f3+4*x1^2*x3^2*f7*f2*f3^3*f4+16*x1*x3^2*x7*f1*f3^2*f7*f6+32*x1*x3^2*x7*f1^2*
f6^3+40*x1^2*x3^2*f6^2*f5*f3*f1^2-4*x1*x2*x6^2*f1*f5^2*f2-48*x1^2*x2*x4*f0*f6*
f5^3*f1-130*x2^2*x4^2*f7*f5^2*f4^2*f1-16*x2*x5*x4*x6*f7^2*f0*f1+8*x1*x5^2*x3*
f0*f4^3+4*x1*x5^2*x3*f4^2*f2^2+144*x3*x4^3*f7^2*f4*f5^2*f1+4*x4^4*f7^3*f3*f4*
f2+24*x2*x5*x4*x6*f7*f0*f5*f3+16*x1^3*x4*f7*f0*f5*f3^3+72*x1*x4*x2*x6*f0*f5^3*
f4+16*x2*x3*x4*x6*f7*f1*f5^2*f3-48*x2*x3*x4*x6*f5*f4^4+16*x1*x3*x4^2*f7*f5^2*
f4^2*f1-40*x1*x3*x4^2*f7*f5*f4^3*f2+40*x2^2*x4^2*f7^2*f6*f1^2*f4+32*x2*x4*x6*
x7*f7*f2*f4^2-96*x2*x4*x6*x7*f0*f6*f7*f4+8*x6^3*x7*f7*f0-12*x6^2*x5*x7*f1*f5+8
*x1*x2*x3*x7*f2*f6*f4^2*f3-16*x1*x2*x3*x7*f2*f6^2*f1*f4-24*x1*x2*x3*x7*f2*f5^2
*f6*f1-180*x4^3*x7*f3*f7^3*f1+4*x6*x7*x3*x8*f7*f2*f5+8*x6*x7*x3*x8*f0*f7^2+8*
x2^2*x1*x6*f0*f4^3*f5-48*x2*x4*x5^2*f2*f7*f1*f4+24*x2*x4*x5^2*f2*f3*f5*f4-16*
x3^2*x5*x7*f0*f6*f3*f7+16*x3^2*x8*f7*x4*f6^2*f1*f4+16*x6^3*x2*f0*f6*f4+4*x6^3*
x2*f2*f3*f5+8*x6^3*x3*f2*f3*f6-40*x2^2*x4^2*f0*f4^3*f7^2-16*x1^2*x4*x6*f0*f5*
f3^2*f7+1208*x4^4*f0*f5*f7^3*f4+16*x1^3*x7*f1^2*f5*f7*f2+16*x1^3*x7*f1*f5*f6*
f2^2+8*x3^4*f7^2*f6*f0*f3^2-4*x2^2*x5*x8*f7*f4*f3*f1+16*x1^2*x5*x6*f1^2*f6*f3+
32*x1^2*x5*x6*f6*f5*f0^2+48*x4*x5*x3*x8*f7^2*f0*f4-8*x1^3*x4*f2^3*f5*f7*f3-8*
x1^3*x4*f1^2*f3^2*f7*f6-24*x1^3*x4*f3*f5^3*f2*f1-96*x1^3*x4*f5*f6^2*f2*f1^2+4*
x2^2*x5*x6*f1^2*f7*f4+8*x2^2*x5*x6*f0*f5*f4^2+32*x2*x4^2*x5*f0*f4*f3*f7^2-12*
x3^2*x4*x7*f7^2*f3^3-16*x3^2*x6*x8*f7*f2*f3*f6-16*x1*x3^2*x6*f1*f7^2*f2^2+128*
x1^2*x3*x4*f7*f2*f3*f1*f4*f6-24*x2*x3*x4*x5*f3^2*f5^2*f4+112*x2*x3*x4*x5*f7*f2
*f5^2*f1+12*x4^3*x7*f7*f5^2*f4^2+108*x4^2*x5*x7*f5^3*f3-12*x1^2*x3*x6*f1*f4^2*
f3*f5+28*x1^2*x2*x4*f3*f5*f4*f7*f2*f1-128*x1^3*x4*f6*f0^2*f7*f4^2+64*x1^3*x4*
f2*f4^3*f0*f7-24*x1^3*x4*f1^2*f4^2*f6*f5-16*x1^2*x3*x6*f0*f5*f3^2*f6-8*x2^2*x5
*x7*f3^2*f7*f1-8*x3^2*x5*x7*f4^2*f6*f2-8*x3^3*x2*f0*f5*f3^2*f7^2+48*x2*x3^3*f0
*f6*f5*f4*f3*f7-8*x2^2*x3*x5*f3*f1*f4^2*f6-96*x1*x3*x2*x7*f0^2*f7^2*f5+16*x4*
x5*x1*x7*f1*f0*f7^2-16*x1*x7*f0*f6*f7*f2*x4*x5+4*x2^2*x1*x6*f1^2*f7*f3*f5+144*
x1*x4^2*x3*f5^3*f6*f2*f3+60*x1*x4^2*x6*f7*f2^2*f5^2+48*x1^3*x4*f1*f6*f5^2*f2^2
-18*x2^2*x3^2*f7*f4^4*f1-16*x1^2*x4*x6*f1^2*f7*f6*f3-12*x1*x4*x2*x8*f5^2*f7*f2
^2+12*x1^2*x4*x6*f5*f4^2*f2*f3+8*x2*x4*x6*x8*f7*f2*f4*f5+6*x2^2*x3^2*f2^3*f7^2
*f4-132*x2^2*x4^2*f7*f3*f5^3*f1+16*x1*x4*x2*x6*f0*f6*f4*f2*f7+144*x1*x4*x2*x6*
f1*f6*f5*f0*f7-4*x3^3*x5*f1^2*f7^2*f4-32*x3^3*x5*f6^2*f0*f4^2+8*x2*x3*x5*x7*f7
*f2^2*f4+32*x1^2*x3^2*f1*f6^2*f5*f2^2+232*x2*x3*x4^2*f7^2*f2^2*f5*f4-48*x1^2*
x3^2*f6^3*f2*f1^2+4*x2^3*x8*f7*f1*f4*f3*f5+12*f7^2*x4*x8^2*x7*f3-12*f7*x4*x8^2
*x7*f5^2+16*f7^2*x2*x8^2*x4*f0*f6-8*f7^2*x2*x8^2*x4*f2*f4-8*x1^3*x7*f1*f4*f5*
f3^2+4*x3^3*x2*f4*f5^4*f1-4*x2^2*x5^2*f4^3*f0+64*x1^3*x3*f6*f4*f3*f0^2*f7+32*
x2*x3^3*f0*f5^2*f4^2*f7+4*x2*x3^3*f7*f4*f5^2*f2^2+16*x3^3*x2*f6*f2^2*f5^3-48*
x1^3*x4*f5^2*f1*f4^2*f2+16*x3^3*x6*f3^2*f5*f6*f4-32*x1*x6^2*x2*f6*f0^2*f7+16*
x5*x6*x7*x8*f7*f1-96*x1^3*x4*f0*f6^2*f7*f1^2+156*x4^2*x5*x7*f3*f7^2*f1-20*x1^2
*x3*x6*f2*f3^2*f5*f4-128*x4^2*x5*x7*f7*f5^2*f1-312*x4^2*x5*x7*f0*f4*f7^2+16*x2
*x3*x4*x7*f7*f2*f5^2*f3-64*x2*x3*x4*x7*f7*f5^2*f1*f4+32*x1^2*x2*x4*f0*f4^3*f3*
f7-32*x1*x2*x4^2*f7^2*f1^2*f6*f3-16*x2*x7^2*x4*f3*f6*f2*f7-192*x3^2*x2*x4*f1*
f7*f6^2*f4*f2+128*x1^3*x4*f7^2*f4*f3*f0^2+4*x2^2*x4^2*f7^2*f3^4+64*x1^3*x4*f1^
2*f0*f7^2*f5+16*x3^3*x6*f3*f4^3*f6-8*x3^3*x6*f2*f5^3*f4+16*x1*x4*x6^2*f0*f7*f4
^2+64*x1^3*x3*f0*f6^2*f4*f3*f1+64*x1*x3^2*x6*f6^2*f0^2*f7-4*x2^2*x3*x5*f2*f3*
f5*f4^2-12*x2^2*x1*x6*f3*f4^3*f2-16*x2^3*x6*f4^2*f0*f5^2+60*x4^2*x6*x7*f7*f5^2
*f2+40*x4^2*x6*x7*f4*f7^2*f1+72*x2*x5*x4*x8*f7*f0*f5^2+4*x1^3*x7*f2^2*f4^3+20*
x1^2*x3*x4*f2*f7*f5*f1*f4^2-64*x1*x3*x4*x7*f7*f1*f6*f2*f5-16*x3^3*x2*f1^2*f6*
f7^2*f3+8*x2*x3^3*f0*f5^2*f1*f7^2-8*x1*x7^2*x2*f5*f6*f2^2+64*x1^2*x3^2*f0*f6^3
*f2^2+16*x1*x3^2*x7*f0*f5^2*f3*f7+12*x1*x3*x4^2*f7^2*f3^2*f4*f2+8*x2*x3*x6*x7*
f3^2*f5^2+8*x6^3*x3*f1*f4*f6+4*x6^3*x3*f7*f3*f1+32*x1*x3^2*x2*f0*f5*f4^2*f3*f7
+40*x1*x3*x2*x5*f7*f5*f0*f3*f2+4*x2*x3^2*x5*f7*f2^2*f5*f3-32*x1*x4^2*x3*f0*f6*
f5^2*f3*f7-4*x3^4*f5^2*f4^2*f6*f2-16*x3^4*f7^2*f2*f6*f1*f3+64*x3^4*f0*f6*f5*f4
^2*f7-36*x2*x4*x5^2*f3*f5^2*f1+52*x2*x4*x5^2*f1^2*f7*f5-48*x3*x6*f0*f6*f7*f3*
x2*x4*f5+32*x3^4*f3*f6^2*f2*f4*f5-4*x2*x4*x6*x8*f7^2*f3*f1-32*x2*x4^3*f6^2*f2*
f0*f7^2+4*x2*x5^2*x7*f7*f1^2+4*x4^2*x5*x7*f4^2*f7*f3-48*x1^2*x3*x6*f0*f6*f4^2*
f3+32*x2*x3*x7^2*f5^2*f7*f0-8*x1^2*x3^2*f3^3*f1*f6^2-16*x2*x3*x5*x7*f1^2*f7*f6
-32*x2*x3*x5*x7*f0*f7*f4^2+8*x2*x3*x5*x7*f7*f2*f5*f1+2*x2^2*x3^2*f3*f5^4*f1-48
*x1*x4*x5*x7*f2*f5^2*f3-24*x1*x4*x5*x7*f5^2*f1*f4-12*x1*x4*x6^2*f2*f5*f4^2-16*
x3^2*x7*f1*f7^2*f2*x4*f6+16*x2*x3*x1*x5*f0*f4^2*f7*f2-8*x1^3*x7*f0*f4^4+4*x3^3
*x5*f7*f3^3*f4+96*x3*x6^2*x4*f0*f6^2*f5-16*x4*x6^2*x3*f0*f7^2*f3-8*x1*x6^2*x2*
f1*f5*f0*f7-48*x4*x6*x7^2*f0*f7^2+4*x1*x7^2*x5*f4^2*f2-16*x1^3*x4*f2^2*f5^2*f0
*f7-96*x1^3*x4*f5^2*f0^2*f4*f7+64*x4*x7*x3^2*f5*f7^2*f2^2+64*x1^3*x4*f7^2*f5*
f2*f0^2-16*x1*x4*x3*x6*f0*f3^2*f7^2+20*x1^2*x4*x5*f7*f3^3*f1+48*x1*x2*x3*x4*f2
*f7^2*f4*f3*f1+64*x1*x2*x4^2*f7^2*f1*f4*f0*f6-176*x1*x2*x4^2*f7*f2*f5^3*f1-8*
x3^2*x5*x8*f7*f2*f3*f5-16*x3^2*x5*x8*f7*f1*f4*f5-20*x1*x3*x2*x4*f2^3*f7^2*f4-\
120*x1*x3*x2*x4*f0*f5^4*f4+4*x3^3*x6*f7*f2*f4^3-4*x2^3*x8*f7^2*f1^2*f4+24*x1*
x5^2*x4*f1^2*f6*f5+8*x1*x6^2*x2*f0*f3^2*f7-48*x2*x3*x4*x5*f7*f2^2*f5*f4+96*x1^
2*x3*x4*f0*f6^2*f7*f3*f1+2*x4^2*x5^2*f3^3*f7-4*x6*x7^3*f4*f5+4*x6*x7^3*f2*f7+
192*x3^2*x4*x7*f5^2*f6^2*f1-240*x3^2*x4*x7*f6*f5^2*f3*f4-144*x3^2*x2*x4*f0*f6*
f5^4-12*x2*x4*f5^2*f7^2*f1^2*x3^2-16*x2*x4*f3^3*f7*f5^2*x3^2-24*x1*x7^2*x4*f7*
f2^2*f6-8*x1*x7^2*x4*f7*f4^2*f2+32*x1^2*x4^2*f0*f6^2*f2*f7*f3-192*x1^2*x4*x5*
f0^2*f6^2*f5+144*x1^2*x4^2*f0*f5^2*f3*f7*f4-112*x1^2*x4^2*f0*f4^3*f5*f7+24*x1^
2*x4*x5*f2^3*f6*f5+4*x1*x4^2*x5*f4^3*f7*f1-176*x1*x4*x2*x7*f0*f6*f5*f2*f7+64*
x2*x4*x3*x7*f1*f7*f4^2*f6-56*x1*x4*x2*x6*f0*f5*f4*f3*f7-112*x1*x4*x2*x7*f1*f5*
f0*f7^2+4*x6^2*f7*f2^2*x2*x4*f5-40*x3^2*x2*x4*f1*f7^3*f2^2+84*x3^2*x2*x4*f5^2*
f4^4-144*x3^2*x4*x6*f7*f2^2*f6*f5-44*x3^2*x4*x7*f5^3*f7*f1-32*x3^2*x4*x7*f0*f6
^2*f4*f7-8*x3^2*x4*x7*f2*f7*f4^2*f6-176*x3^2*x4*x7*f4*f5^2*f2*f7+4*x1*x7^2*x6*
f7*f2^2-144*x3^2*x4*x6*f1*f5*f6^2*f4+48*x3^2*x4*x6*f2*f5^2*f4*f6-12*x3^3*x6*f2
^2*f7^2*f3-96*x3^2*x4*x6*f3*f6^2*f2*f5-16*x1^3*x7*f0*f5*f7*f2^2-60*x2^2*x4^2*
f7*f5*f4^3*f2+8*x2^2*x3^2*f4^2*f5^3*f1-48*x3^3*x2*f6^2*f2*f1*f5^2-32*x3^3*x2*
f0*f6*f5^3*f4+4*x3^4*f1^2*f7^3*f3+76*x1^2*x4*x6*f7*f3*f1*f5*f2+384*x3*x4*x5*x7
*f0*f6^2*f5-16*x5*x7*f7*f2^2*x3*x4*f6-40*x1*x4*x2*x7*f7^2*f2^3+16*x1*x4*x3*x6*
f7*f2^2*f3*f6+16*x2^2*x3^2*f4^2*f6^2*f2^2-12*x2^2*x1*x5*f1^2*f4*f7*f3+4*x2^2*
x1*x7*f1*f4*f7*f3^2+16*x2^2*x1*x7*f0*f4^2*f3*f7+16*x2^2*x1*x7*f1^2*f4*f7*f5-\
320*x4^2*x3*x6*f3*f5*f6*f2*f7-8*x4^2*x3*x6*f5^3*f7*f1-288*x4^2*x3*x6*f1*f5^2*
f6^2+4*x2*x3*x4^2*f7*f4*f5^3*f1+8*x2*x3*x4*x5*f7*f3^3*f4-4*x1*x7*x2*x8*f7*f5*
f2^2+8*x1^3*x3*f7*f3^2*f1*f2*f4-8*x3^3*x6*f7*f2^2*f4*f6+20*x3^3*x6*f7*f3*f5^2*
f1-8*x3^3*x6*f7*f3^3*f5-8*x1^3*x7*f2*f3^2*f4^2+12*x2^2*x7*x8*f7*f5*f1*f4+16*x2
*x7*x3*x6*f7*f5*f2^2-24*x1*x6*x2*x7*f1^2*f5*f7+8*x1*x6*x2*x7*f3*f7*f2^2+48*x1*
x6*x2*x7*f0*f6*f1*f7-4*x1*x6*x2*x7*f3^2*f7*f1-168*x1*x4^3*f7^3*f2*f1*f3-24*x2^
2*x1*x4*f6*f2^2*f5*f4^2-48*x2^2*x1*x4*f0*f5^3*f1*f7+32*x1^2*x3*x6*f1*f6^2*f0*
f4-4*x1*x3*x4*x6*f7*f3^2*f5*f2+192*x1*x3*x4*x6*f6*f0^2*f7^2+36*x1*x3*x4*x7*f7*
f3*f5*f2*f4-16*x1^2*x3*x4*f0*f3^2*f6*f7*f4+16*x1^4*f5^2*f4^2*f0^2+160*x1^2*x4*
x5*f4*f0^2*f7*f6+96*x3*x4*x7^2*f0*f7^2*f5-72*x3*x4*x7^2*f3*f6*f5^2+16*x3^2*x5^
2*f0^2*f7^2-8*x2*x5*x3*x7*f0*f7*f3*f5+4*x2^2*x3^2*f5^4*f2^2+40*x3^3*x6*f7*f4^2
*f5*f1+4*x3^3*x6*f7^2*f3^2*f1-2*x1^2*x6^2*f3^4+80*x2^2*x3*x4*f1^2*f4*f7^2*f5+
24*x6^3*x4*f6*f1*f5-12*x6^3*x4*f3*f5*f4-8*x6^3*x3*f2*f4*f5+8*x6^3*x4*f7*f2*f3+
8*x6^3*x4*f7*f0*f5-48*x2^2*x3*x4*f4^3*f6*f2*f5-12*x3^2*x5*x8*f7^2*f2*f1+16*x2^
2*x3^2*f6*f2*f5*f7*f3*f1+8*x3^4*f1*f5^2*f7*f6*f2-8*x3^4*f7^2*f3^2*f1*f5-32*x3^
4*f6^3*f2*f1*f5+6*x3^4*f7*f3^2*f4^2*f5-84*x4^2*x6*x7*f3*f7^2*f2-296*x4^2*x6*x7
*f7*f5*f1*f6+148*x4^2*x6*x7*f7*f5*f3*f4-48*x1^3*x4*f2^3*f5*f4*f6+32*x3^3*x2*f6
^2*f2^2*f4*f5+44*x1^3*x4*f2^2*f4*f7*f3^2-24*x1*x3*x4^2*f7^2*f1*f4^2*f3-16*x1*
x3*x4^2*f7^3*f0*f3*f2+32*x1^2*x3^2*f0*f6^3*f3*f1+4*x1^2*x3*x6*f3^4*f5+64*x2*x4
^2*x5*f7*f2^2*f5^2-64*x1*x4*x3*x7*f0*f5*f2*f7^2+144*x2^2*x4^2*f4*f5^3*f6*f1-96
*x4^2*x2^2*f0*f5^2*f2*f7^2+12*x4^2*x2^2*f4^2*f7^2*f3*f1+16*x1*x7^2*x3*f7^2*f1^
2+64*x1^3*x4*f7^2*f3*f2*f1^2-8*x2^4*f5^3*f0^2*f7-14*x2^2*x4^2*f3^2*f5*f7*f4^2+
80*x1*x4*x2*x7*f0*f5*f4^2*f7-96*x3*x4*x5*x7*f3^2*f5*f6+16*x1^3*x3*f0*f5^2*f7*
f2*f1-32*x1*x7*f6*f7*f1^2*x3^2*f5+16*x3^2*x4*x6*f7*f4^3*f3+44*x3^2*x4*x6*f7^2*
f3*f4*f1-64*x1^3*x4*f7^2*f3*f0*f2^2-96*x1*x5*x4^2*f7^2*f0*f4*f2-96*x3^2*x2*x4*
f5*f4^3*f3*f6+80*x3^2*x2*x4*f0*f5^3*f4*f7-16*x3^2*x2*x4*f7^2*f2^3*f6+16*x1^3*
x3*f3*f6*f1*f4^2*f2+12*x3*x5*x6^2*f2*f3*f5-216*x4^2*x5*x7*f5^2*f6*f2-148*x4^2*
x5*x7*f7*f5*f3^2+8*x6^3*x5*f0*f5-48*x2^2*x1*x7*f0*f5*f2*f7*f4-12*x2^2*x6*x7*f4
^3*f3-8*x3^3*x5*f0*f3^2*f7^2-12*x3*x5*x6^2*f1*f4*f5+144*x3^2*x2*x4*f4^2*f6^2*
f1*f5+12*x2^2*x1*x7*f5*f4^2*f2*f3+x2^4*f4^4*f3^2+344*x1*x2*x4^2*f7*f1^2*f5^2*
f6+164*x1*x2*x4^2*f7*f2^2*f4*f5^2+64*x1^2*x2*x4*f7^2*f3*f0^2*f5-16*x1^3*x2*f2*
f1^3*f7^2-4*x6^3*x3*f7*f2^2-64*x1*x5*x4^2*f7^2*f1*f5*f0-8*x1*x2^2*x6*f2^2*f5*
f4^2+80*x2*x3*x4*x7*f7^2*f0*f4^2-248*x2*x3*x4*x7*f7*f2*f5*f4^2+64*x1^3*x4*f6*
f5*f7*f1^3+232*x2^2*x4^2*f0*f5^3*f4*f7-24*x1^3*x4*f3^2*f5*f2*f4^2-24*x1^3*x4*
f2^2*f5*f3^2*f6+96*x1^3*x4*f0*f6^2*f5*f2^2-12*x2*x5*x3*x8*f7*f1*f4^2-4*x3^2*x5
^2*f4^2*f1*f5+16*x4*x5*x3*x6*f0*f7^2*f2+x2^4*f1^2*f5^4-32*x2^2*x4^2*f0*f6*f3^2
*f7^2-24*x3^2*x2*x4*f5^2*f4^2*f6*f2-8*x1^3*x4*f3^3*f1*f4*f7+32*x2*x4*x1*x5*f4*
f0^2*f7^2-24*x1^2*x4*x7*f7*f2^3*f6-160*x1^2*x4*x7*f5*f0^2*f7^2-24*x2^2*x3*x4*
f7*f3^2*f5^2*f2-20*x3^2*x2*x4*f7^2*f3*f4^2*f1+208*x3^2*x2*x4*f7*f1^2*f6^2*f5-\
28*x3^2*x6*x7*f5*f4^3-32*x1^3*x6*f5^3*f0^2-12*x1^2*x4*x5*f4^2*f5*f3*f1+16*x4^2
*x8*f7^2*x3*f3*f6*f2+24*x1*x4*x6^2*f2*f5^2*f3-24*x1^4*f0*f4^2*f2*f1*f7-4*x1^2*
x2^2*f0*f5^2*f4*f3^2+4*x2*x4*x1*x7*f7*f4^3*f1+24*x2*x3*x5^2*f1^2*f5*f6+8*x1^4*
f1^2*f3^3*f7-4*x1^3*x6*f7*f2^4-4*x4*x5*x6^2*f7*f3*f1+40*x4*x6*f3*f6*f1*f7*x3^2
*f5-60*x3^2*x4*x6*f3*f5^3*f4-72*x3^2*x4*x6*f6*f5^3*f1-208*x1*x2*x4^2*f7^2*f0*
f4*f2*f5-12*x1*x2*x3*x7*f7*f1*f4^2*f3+240*x1*x2*x4^2*f7^2*f2*f5*f1*f3+16*x1^2*
x5*x6*f0*f7*f3*f1-8*x1^3*x7*f3*f1*f5^2*f2-16*x1^3*x7*f1*f4^2*f5*f2-16*x1^3*x2*
f0*f4^4*f3+32*x1^3*x7*f1*f0*f7*f4^2+16*x1^3*x7*f0*f5*f3*f4^2+24*x1^2*x2^2*f0*
f6*f4^3*f2-64*x1^3*x7*f0^2*f7*f4*f5+8*x1^3*x7*f2^2*f3*f4*f5-48*x2^2*x3*x4*f0*
f6*f5^3*f4+48*x1^2*x3*x4*f0*f4^2*f6*f2*f7-12*x1*x5^2*x2*f7*f2*f1^2-16*x1^2*x5*
x6*f0*f6*f3*f2+4*x1^2*x5^2*f2*f1*f4*f3-12*x2^2*x3*x4*f7^2*f2^2*f3*f4-16*x1^2*
x2^2*f0*f5^3*f3*f2+16*x1^2*x5*x6*f0*f4^2*f3+16*x1*x5^2*x2*f7*f2^2*f0+4*x6^2*x7
^2*f4^2-64*x1*x4*x3*x7*f0*f4*f3*f7^2+4*x2*x4^2*x7*f7*f4^4-24*x3*x4*x1*x6*f6*f4
*f5*f2*f3-24*x1^3*x7*f1^2*f4*f7*f3-8*x1^3*x7*f7*f3^2*f1*f2-8*x2*x7*x6^2*f7*f2^
2-8*x1^3*x7*f1*f4*f7*f2^2+16*x1^3*x7*f3*f1^2*f5*f6-48*x1^2*x3*x7*f0*f4^2*f3*f7
-24*x2*x3*x1*x4*f0*f4*f7^2*f3^2-8*x3^2*x1*x7*f2^2*f5^2*f6-4*x2^2*x7^2*f5*f7*f2
^2-4*x2^2*x7^2*f4^2*f6*f2+10*x1^2*x2^2*f4^2*f3*f2^2*f5-4*x2^2*x1*x7*f4^4*f2-38
*x4^2*x2^2*f7^2*f3^2*f2*f4+16*x3^3*x5*f0*f6*f4*f3*f7-32*x3^3*x5*f7^2*f6*f0^2-\
144*x3^2*x4*x7*f3*f6^2*f1*f7+96*x4^2*x2^2*f0*f4*f1*f7^3+12*x2^2*x1*x5*f7*f5*f1
^2*f2-24*x2^2*x1*x5*f0*f5*f7*f2^2+8*x2^2*x1*x5*f1^2*f0*f7^2-36*x4*x5*x6^2*f1*
f5^2+8*x1*x3^2*x6*f5*f4^3*f2-8*x1*x3^2*x6*f5^2*f4^2*f1+8*x2*x3^2*x6*f7*f2*f3^2
*f5-12*x2*x5^2*x4*f1*f5*f4^2+4*x2*x5^2*x4*f7*f2^2*f3+16*x2*x3*x6*x7*f3^2*f6*f4
-32*x2*x3*x6*x7*f2*f5*f3*f6-64*x2*x3*x6*x7*f0*f6^2*f4+96*x1^2*x3*x4*f6^2*f5*f4
*f1^2+20*x2*x3*x7^2*f5*f4^3+12*x1*x4*x5*x8*f7*f2^2*f5-72*x1*x4^2*x8*f7^2*f2^2*
f5+592*x4^2*x5*x7*f0*f6*f7*f5+116*x4^2*x5*x7*f7*f2*f4*f5+40*x4^2*x3*x8*f7^3*f2
^2+52*x2^2*x3*x4*f1*f4^2*f7^2*f2-8*x1^2*x2^2*f4^2*f3^2*f1*f5-16*x1^2*x2*x6*f0*
f7*f1*f4^2+16*x1^2*x2^2*f6*f5^2*f4*f0^2-36*x2*x4*x3^2*f4*f5^2*f7*f2*f3-200*x2*
x4*x3^2*f0*f5*f4*f3*f7^2-2*x4^2*x2^2*f3*f5*f2^2*f7^2-64*x1*x4^2*x5*f0*f6*f5*f2
*f7-16*x1*x4^2*x5*f7*f2*f1*f4*f6+96*x2*x3*x4*x7*f7*f0*f5^3-4*x2^4*f1^2*f4^2*f7
*f5-4*x6^3*x5*f2*f3+64*x2*x3*x4*x5*f6*f0^2*f7^2+96*x2*x3*x4*x6*f0*f6*f5^3-28*
x2^3*x4*f5*f7^2*f3*f1^2+88*x2*x3*x4*x7*f7*f3*f6*f2*f4+80*x1^3*x2*f0*f5*f2^2*f7
*f3-32*x1^3*x2*f0*f4*f1^2*f7*f6-32*x1^4*f0*f5^2*f4*f3*f1+128*x1*x3^2*x4*f6*f0^
2*f7^2*f5-104*x2*x3*x4*x5*f0*f5*f4^2*f7+192*x2*x3*x4*x5*f7*f2*f1*f4*f6+24*x1*
x3^2*x4*f1*f7^2*f2^2*f6+32*x4^2*x6*x3*f0*f6*f5^2*f7+72*x1*x4^2*x8*f7^3*f1^2+24
*x4^2*x6*x3*f7*f4^2*f2*f6+20*x2*x3*x4*x5*f4^3*f7*f1-192*x1^2*x3*x4*f0*f6^2*f5^
2*f1+8*x1*x3^2*x7*f3*f5^2*f6*f1+16*x2^2*x3^2*f0*f6^2*f2*f7*f3+120*x2^2*x4^2*f7
*f3*f5^2*f2*f4-32*x1^2*x2^2*f5*f4^2*f0^2*f7+176*x1*x2*x3*x4*f1^2*f5*f7*f4*f6-\
32*x1^2*x2^2*f3*f5^2*f0^2*f7+16*x3^3*x2*f0*f6*f4*f1*f7^2-12*x1*x2^2*x4*f3*f5^3
*f1*f4-24*x1^2*x2*x4*f5^2*f2^3*f6-32*x3*x6*x7*x8*f7*f1*f6+4*x1*x6*x5*x7*f3*f1*
f5+4*x3^2*x1*x7*f1*f5^3*f4-8*x3^2*x1*x7*f7*f4^3*f1-16*x1^2*x2^2*f1*f6*f4^2*f2*
f3-32*x1*x3*x6^2*f0*f5^2*f4-64*x1^3*x2*f4*f3*f0^2*f7*f5-12*x2^2*x3*x4*f4^2*f5^
3*f2+32*x2^3*x4*f5^2*f0^2*f7^2+48*x3*x4*x7^2*f7*f6*f3^2-192*x3*x4*x7^2*f0*f6^2
*f7+32*x1^2*x4*x6*f4*f0^2*f7^2+12*x1^2*x4*x6*f3^3*f4*f5+24*x1^2*x4*x6*f1*f5^3*
f2-36*x4*x6*x7^2*f4*f5^2-24*x1^2*x2^2*f0*f5^3*f4*f1+8*x1^2*x2*x7*f3^2*f5*f2*f4
+12*x2^2*x3*x8*f5*f7*f1*f4^2-4*x1*x7^2*x5*f1*f4*f5-8*x1*x7^2*x5*f2*f3*f5+8*x1^
2*x3*x4*f2*f7*f5*f3^3+400*x2*x3*x4*x7*f7*f0*f5*f4*f6+104*x2*x3*x4*x7*f7^2*f2*
f5*f1-6*x2^2*x3^2*f7*f3*f5^2*f2^2-32*x1^2*x3*x4*f0*f5*f4^2*f3*f7-8*x2^2*x3^2*
f4*f5^2*f1*f6*f3-48*x2*x3*x5*x6*f2*f5*f1*f6+16*x2*x3*x5*x6*f3*f4*f1*f6+16*x1^2
*x2^2*f0*f6*f4^2*f3^2-8*x1^2*x2^2*f0*f2^3*f7^2+16*x1^2*x2^2*f3^2*f0^2*f7^2-12*
x2^3*x4*f3^2*f5^2*f4^2-8*x3^4*f3^2*f5^2*f6*f4-8*x3^4*f1^2*f6^2*f7*f5-8*x3^4*f7
*f2*f5*f4^3+80*x1*x5*x4^2*f7^2*f1*f2*f3+12*x6^2*x2*x7*f1*f5^2+12*x2^3*x4*f4^4*
f3*f5+80*x1^2*x3*x4*f0*f5*f7^2*f3*f1+6*x2^2*x3^2*f5^2*f4^3*f2-48*x2*x3*x4*x5*
f0*f5^2*f3*f7-4*x1*x6^2*x7*f7*f2*f1-24*x1*x2*x3*x4*f7*f2*f6*f1*f4^2+16*x1^2*x2
*x7*f0*f5^2*f4*f3+96*x2*x4*x3^2*f6*f4*f5*f7*f2^2+168*x2*x4*x3^2*f1*f7^2*f2*f4*
f5-16*x3^2*x2*x4*f7^2*f3^2*f2*f4+400*x2*x4^3*f0*f6*f5*f3*f7^2-32*x3*x5*x7^2*f7
*f0*f5-8*x3*x5*x7^2*f7*f1*f4+20*x3*x5*x7^2*f3*f5*f4-16*x3*x5*x7^2*f6*f1*f5+8*
x3^2*x1*x7*f3*f5^3*f2+8*x3^2*x1*x7*f3*f7*f2^2*f6-8*x1^2*x2^2*f0*f6*f3*f2^2*f7+
4*x1^2*x2^2*f2*f4*f5*f3^3+8*x1^2*x2^2*f0*f6*f5^2*f3*f1-32*x2*x3^2*x7*f0*f6^2*
f5*f4-8*x2^2*x3*x5*f0*f5^2*f1*f7+4*x2^2*x3*x5*f3*f5^2*f1*f4-8*x1*x2^2*x4*f7^2*
f2*f3^2*f1-12*x1*x2*x3*x6*f1*f5^2*f3*f4-8*x2^2*x1*x4*f0*f7^3*f1^2+24*x2^2*x1*
x4*f0*f7*f4^4+80*x4^2*x1*x5*f1*f4*f7*f5*f3+56*x4^2*x1*x5*f1*f5^2*f7*f2-80*x4^2
*x1*x5*f1^2*f5*f7*f6-68*x4^2*x1*x5*f7*f2^2*f5*f4-8*x1*x7*f7*f4*f2^2*x3^2*f5-24
*x2^2*x1*x4*f0*f5^3*f4^2+96*x4^2*x2^2*f7^2*f3^2*f1*f5-2*x2^4*f7*f2^2*f3*f4^2+
48*x3^2*x4*x6*f3^2*f5^2*f6-72*x3^2*x4*x6*f7*f3*f4*f2*f6+52*x4*x6*x3^2*f3*f5^2*
f7*f2-12*x1^2*x2^2*f6*f5^2*f2*f1^2-224*x1*x2*x3*x4*f0*f6*f5^2*f1*f7-8*x3^2*x1*
x7*f0*f3^2*f7^2+24*x3^3*x2*f6*f5^2*f1*f4^2+4*x2^2*x4^2*f4^2*f6*f7*f2*f3-38*x2^
2*x4^2*f7*f2^2*f5^3-4*x2^3*x4*f7^2*f3^3*f1-4*x2^2*x3*x5*f1*f4^2*f7*f2+96*x1^2*
x2*x3*f0*f6*f4*f7*f1*f3-48*x1*x2*x3*x4*f6^2*f2*f5*f1*f4+12*x1^2*x2*x4*f3*f5^3*
f2^2-28*x3^2*x2^2*f1*f5^2*f7*f2*f4-12*x3^2*x2^2*f7*f3^2*f2*f4*f5-72*x4^2*x3*x8
*f7^3*f0*f4-8*x2^3*x4*f2^3*f7^2*f4-96*x1*x3^2*x4*f6^2*f2*f5^2*f1+12*x1*x3*x4*
x6*f7^2*f1^2*f4+16*x1*x3^2*x4*f0*f7^3*f3*f1+8*x1^2*x3*x6*f2^2*f3*f4*f6+16*x3^2
*x6^2*f6^2*f2^2-4*x2^3*x4*f7*f4^4*f1+48*x1^2*x3*x5*f2*f1^2*f6^2+8*x1^2*x3*x5*
f4^2*f6*f1^2-16*x2*x3^2*x6*f0*f6*f4*f3*f7-48*x1*x3^2*x2*f6^2*f7*f1^2*f2+12*x1*
x3^2*x2*f5^2*f4^3*f1+24*x2^3*x4*f3*f5^3*f2*f4-32*x2^3*x4*f0*f7^3*f1*f2+4*x2^3*
x4*f7^2*f3^2*f2^2-22*x3^4*f5^2*f4^2*f1*f7-8*x3^4*f3*f5^3*f6*f2-4*x1^2*x3*x5*f2
*f5*f3^3+16*x1^2*x3*x5*f0*f5^3*f1-12*x2^3*x4*f5^2*f4^3*f2-64*x1*x3*x4*x6*f6*f0
*f4*f3*f7+16*x1*x3*x6^2*f0*f6*f4^2+96*x3*x4*x6*x7*f4*f5*f3*f6+24*x2^3*x4*f4^2*
f5^3*f1-12*x2^3*x4*f5^4*f3*f1+8*x3^2*x2^2*f0*f5*f3*f2*f7^2+4*x1*x5*x4*x6*f7*f2
^2*f3+96*x1^2*x2*x6*f0*f6*f7*f2*f1+16*x2^3*x4*f1^2*f4^2*f7^2-84*x3^2*x4*x6*f5^
2*f4^3-24*x2*x3*x1*x5*f0*f5*f4^3-48*x2^2*x3*x4*f2*f7*f5^3*f1-16*x3^2*x6*f7^2*
f1^2*x4*f6-24*x1*x4*x6^2*f2^2*f6*f5+80*x3^2*x7*x4*f0*f6*f7^2*f3-72*x1*x4^2*x2*
f0*f5^5+24*x1*x4*x6^2*f1^2*f7*f6+8*x1*x5*x4*x6*f7*f5*f1^2+4*x1*x5^2*x7*f2^2*f4
-16*x2*x5*x7^2*f1*f4*f6+144*x3*x4*x7^2*f6^2*f2*f5-56*x3*x4*x7^2*f7*f3*f4*f5+32
*x1*x7*f0*f6^2*f7*f2*x3*x4-8*x1*x6*x5*x7*f2*f1*f6+8*x1*x7*x3^2*f4*f5*f7*f3*f1+
8*x2^2*x1*x5*f3*f4^3*f1+72*x3^3*x4*f5^3*f4^3-4*x2*x6^2*x7*f3^2*f5+16*x1^2*x2*
x7*f0*f4^2*f3*f6+64*x1^2*x2*x7*f6^2*f0^2*f5-16*x3^3*x5*f3^2*f6*f4^2-32*x1^3*x6
*f0^2*f7*f4^2+12*x4*x6*x3*x8*f7*f5^2*f2-16*x2*x6*x7*x8*f7*f1*f5+8*x1^3*x6*f3^3
*f4*f2-80*x3*x4*x6*x8*f7*f6*f1*f5-8*x3*x4*x6*x8*f7*f2*f4*f6-120*x4^2*x2^2*f1*
f5*f7^2*f2*f4-4*x3^3*x5*f7*f4*f2^2*f5+48*x3^3*x5*f6^2*f4*f1*f3-32*x2*x7*x6^2*
f7*f0*f4+4*x6^2*x2*x7*f7*f3*f1-24*x6^2*x2*x7*f1*f4*f6+4*x2^3*x4*f1^2*f5^3*f7+8
*x1^3*x6*f4^3*f1*f2+16*x1^2*x3*x5*f0*f5*f7*f2^2-12*x1*x3^2*x2*f5*f4^4*f2+8*x2^
2*x3^2*f0*f6*f3*f1*f7^2-96*x4^2*x1*x7*f0*f5^3*f7-8*x4^2*x2*x8*f7^2*f2^2*f6-24*
x2^3*x4*f0*f5^4*f4+4*x2^3*x4*f3^3*f7*f4^2+16*x3^4*f4*f5^3*f1*f6+12*x3^4*f0*f4*
f1*f7^3+16*x3^4*f6^2*f7*f3^2*f1-16*x2^3*x7*f0*f5*f4*f3*f7-48*x1*x3*x4^2*f0*f5^
3*f4*f7+160*x1*x3*x4^2*f5*f6^2*f7*f1^2+8*x1*x3*x4^2*f7*f3*f5^3*f1-64*x1*x3^2*
x4*f7*f2*f3*f6^2*f1-12*x3^2*x2^2*f5*f4^2*f1*f3*f7+32*x3^2*x2^2*f0*f5^2*f4*f3*
f7+16*x1^2*x2*x7*f1^2*f5*f4*f6-20*x1^2*x2*x7*f1^2*f7*f4^2-32*x1^2*x2*x7*f1*f6^
2*f0*f4-2*x2^4*f5^2*f7*f3*f1^2-32*x1^2*x2*x3*f0*f6*f5*f7*f2*f1+32*x1*x2*x4^2*
f7^2*f0*f6*f2*f3+64*x1^2*x2*x3*f0*f6^2*f5*f2^2-8*x3^4*f7*f3^3*f6*f4+80*x3^2*x2
*x4*f0*f3*f7^3*f2+96*x2*x4*f0^2*f7^3*x3^2*f5+56*x3^2*x2*x4*f2*f6*f7^2*f3*f1-12
*x2^2*x6^2*f4^2*f1*f5-16*x1^2*x2*x7*f0*f6*f5^2*f1-4*f7^2*x2*x8^2*x4*f1*f5-12*
f7*x2*x8^2*x4*f5*f4^2+12*f7*x2*x8^2*x4*f3*f5^2+4*x3^2*x6*x8*f7*f2*f4*f5+96*x4*
x6*x3^2*f1*f5^2*f7*f4-8*x4*x6*x3^2*f7^2*f3*f0*f5-72*x4*x6*x3^2*f1*f7^2*f2*f5+
24*x1*x3^2*x4*f5^3*f6*f3*f1+40*x1^2*x3*x4*f1*f4*f7*f3^2*f5+16*x1*x3^2*x4*f7*f2
^3*f6^2-24*x1^2*x3*x4*f6*f2*f5*f3^2*f4-32*x1^3*x6*f6^2*f1^3-24*x2^2*x6^2*f0*f6
*f4^2+12*x2^3*x7*f2*f7*f4*f1*f5-12*x2^3*x7*f4^2*f7*f2^2+8*x2^3*x7*f3*f5^2*f2*
f4-16*x3^4*f7*f3^2*f6*f2*f5+81*x4^4*f5^6-328*x4^2*x3*x6*f0*f5*f7^2*f4+224*x4^2
*x3*x6*f4*f5^2*f2*f7+24*x2^2*x3*x4*f3*f5^4*f2+20*x3^2*x7^2*f4*f7*f1*f6+4*x2^4*
f0*f4*f2^2*f7^2-4*x2^2*x3*x5*f4^3*f5*f1+4*x2^3*x7*f4^4*f3+12*x6^2*x2*x7*f4^2*
f3+36*x1*x4^2*x5*f5^2*f4^2*f2+24*x1^2*x2*x5*f7*f1*f3*f2^2-2*x2^4*f4*f7^2*f1^2*
f2-20*x2^2*x3*x4*f7*f4^4*f2-32*x2^3*x3*f6*f5^2*f0^2*f7+48*x1^2*x2*x5*f7*f0*f6*
f1^2+2*x3^4*f7^2*f3^2*f2*f4+8*x3^4*f1^2*f6*f7^2*f4+8*x3^4*f3*f6^2*f1*f5^2+32*
x1*x3^3*f5^2*f0^2*f7^2-8*x1*x6*x5*x7*f0*f4*f5+4*x1*x6*x5*x7*f2*f3*f4-24*x6^2*
x3*x7*f7*f1*f4+16*x6^2*x3*x7*f3*f5*f4+16*x4^2*x5*f4^2*f1*f7*x3*f6+4*x3*x4^2*x5
*f2*f7^2*f3^2-24*x3*x4*x6*x7*f5^3*f3+4*x2^2*x6*x8*f7^2*f1^2-16*x2*x3*x4*x5*f7*
f2^2*f3*f6+48*x1^2*x3*x4*f0*f5*f4^3*f6-4*x2^4*f5*f4^3*f2*f3-24*x3*x6^2*x4*f6*
f3^2*f5+4*x1^2*x6^2*f1*f4*f0*f7+8*x2^3*x7*f3^2*f5*f1*f7-24*x2*x4*x3^2*f0*f5^2*
f2*f7^2+36*x2*x4*x3^2*f7^2*f3^2*f1*f5-192*x2*x4*x3^2*f7*f3*f4*f1*f5*f6-28*x3^2
*x7^2*f7*f2*f5*f4+64*x3^2*x7^2*f0*f6*f7*f5-40*x3^2*x7^2*f5*f3*f6*f4+8*x2^2*x3*
x4*f7^2*f2*f3^3-96*x3^3*x4*f0*f6^2*f5^3-56*x2^2*x3*x4*f1^2*f7^3*f2+12*x1*x5*x2
*x7*f7*f2^3-4*x1*x5^2*x3*f2*f5*f4*f1-32*x1^2*x2*x7*f0*f6*f3^2*f5-16*x1*x2*x4*
x5*f7*f0*f6*f2*f3+32*x2*x5*x7^2*f0*f5*f6+4*x3*x5*x1*x6*f4^2*f2*f3-48*x3^4*f0*
f6^2*f5^2*f4-64*x1^2*x2*x7*f0^2*f7*f6*f4-16*x1*x2*x4*x5*f1*f4*f0*f7*f6+12*x2^2
*x4*x8*f7^2*f2*f5*f1+4*x3^3*x1*f5^3*f4^2*f1+4*x3^3*x1*f3*f5^4*f1-8*x2^2*x3*x8*
f5^2*f7*f0*f4+16*x1*x2*x4*x5*f0*f7^2*f1*f3-16*x1^2*x2*x7*f3*f6*f4*f2^2-8*x3^2*
x4^2*f7*f3*f6*f4^3+4*x3*x4^2*x5*f7*f3*f4^3+12*x4*x5*x1*x6*f5^2*f1*f3-24*x4*x5*
x1*x6*f0*f5^2*f4+4*x2*x5^2*x3*f7*f2*f3*f1+24*x1*x4*x5*x7*f7*f3*f4*f1-8*x3^2*x6
*f3^3*f7*x4*f6-144*x1*x4^2*x3*f6^2*f2^2*f5^2+32*x1*x4*x2*x6*f1*f4*f0*f7^2+8*x1
*x3*x6*x7*f7*f6*f1^2-16*x2*x3*x6^2*f0*f7*f4^2-16*x3*x5*x7^2*f6*f3^2+96*x1*x3^2
*x4*f0*f6^2*f5*f4^2+16*x2^2*x3^2*f0*f6^2*f1*f7*f4+2*x1^2*x5^2*f7*f1^3+192*x3*
x4*x5*x8*f7*f0*f5*f6-264*x1^2*x4^2*f1*f6*f5^2*f0*f7-36*x2*x4*x7^2*f5^3*f3+8*x2
^2*x3^2*f4^2*f3*f1*f6^2-8*x2^2*x3^2*f0*f6*f4^2*f3*f7
    where f0 := Coefficient(f, 0) 
    where f1 := Coefficient(f, 1) 
    where f2 := Coefficient(f, 2) 
    where f3 := Coefficient(f, 3)
    where f4 := Coefficient(f, 4) 
    where f5 := Coefficient(f, 5) 
    where f6 := Coefficient(f, 6)
    where f7 := Coefficient(f, 7)
    where x1 := x[1] where x2 := x[2] where x3 := x[3] where x4 := x[4]
    where x5 := x[5] where x6 := x[6] where x7 := x[7] where x8 := x[8]
]>;



intrinsic KummerThreefold(J::JacHyp) -> Sch
{	Construct the Kummer threefold K associated to the Jacobian of a hyperelliptic curve 
with a rational Weierstrass point at infinity. 
K is returned as a scheme in projective space of dimension 7 over the ground field of J.}
    C := Curve(J);
    f, h := HyperellipticPolynomials(C);
    require IsZero(h):
            "Need a simplified model (h=0).";
    require Genus(C) eq 3:
            "The curve must have genus 3";
    require Degree(f) eq 7:
            "f must have Degree 7.";
    
    R := BaseRing(J);
    P7<[x]> := ProjectiveSpace(R, 7);
    x1, x2, x3, x4, x5, x6, x7, x8 := Explode(x);
    f0, f1, f2, f3, f4, f5, f6, f7 := Explode([Coefficient(f, i) : i in [0..7]]);

    return Scheme(P7,	
            [ x1*x8 - 2*f5*x2*x4 - x2*x7 + f5*x3^2 + 2*f6*x3*x4 - x3*x6 + 3*f7*x4^2 - 
    x4*x5,
4*f5*x1^3*x8 - 8*f5^2*x1^2*x2*x4 - 4*f5*x1^2*x2*x7 - 16*f5*f6*x1^2*x3*x4 - 
    8*f6*x1^2*x3*x7 - 24*f5*f7*x1^2*x4^2 + 8*f5*x1^2*x4*x5 - 
    12*f7*x1^2*x4*x7 + 4*x1^2*x5*x7 - x1^2*x6^2 + 4*f5^2*x1*x2^2*x3 + 
    12*f5*f6*x1*x2^2*x4 - 2*f5*x1*x2^2*x6 + 4*f6*x1*x2^2*x7 + 
    8*f5*f6*x1*x2*x3^2 + 16*f5*f7*x1*x2*x3*x4 - 8*f5*x1*x2*x3*x5 - 
    4*f7*x1*x2*x3*x7 - 8*f7*x1*x2*x4*x6 + 2*x1*x2*x5*x6 + (4*f5*f7 + 
    8*f6^2)*x1*x3^3 + 44*f6*f7*x1*x3^2*x4 - 12*f6*x1*x3^2*x5 - 
    2*f7*x1*x3^2*x6 + 48*f7^2*x1*x3*x4^2 - 28*f7*x1*x3*x4*x5 + 4*x1*x3*x5^2 
    - f5^2*x2^4 - 4*f5*f6*x2^3*x3 + 4*f5*f7*x2^3*x4 + 2*f5*x2^3*x5 + 
    4*f7*x2^3*x7 + (-6*f5*f7 - 4*f6^2)*x2^2*x3^2 - 16*f6*f7*x2^2*x3*x4 + 
    4*f6*x2^2*x3*x5 + 4*f7*x2^2*x3*x6 - 16*f7^2*x2^2*x4^2 + 8*f7*x2^2*x4*x5 
    - x2^2*x5^2 - 4*f6*f7*x2*x3^3 - 4*f7^2*x2*x3^2*x4 + 2*f7*x2*x3^2*x5 - 
    f7^2*x3^4,
(-4*f1*f6 + 2*f2*f5)*x1^3*x3 - 6*f1*f7*x1^3*x4 + 2*f1*x1^3*x5 - f2*x1^3*x6 +
    (2*f1*f6 - f2*f5)*x1^2*x2^2 + (-2*f1*f7 + 2*f3*f5)*x1^2*x2*x3 - 
    4*f2*f7*x1^2*x2*x4 + f2*x1^2*x2*x5 - f3*x1^2*x2*x6 + (-f2*f7 + 4*f3*f6 -
    2*f4*f5)*x1^2*x3^2 + (6*f3*f7 - 4*f4*f6 - 4*f5^2)*x1^2*x3*x4 - 
    2*f3*x1^2*x3*x5 + f4*x1^2*x3*x6 - 2*f5*x1^2*x3*x7 - 6*f4*f7*x1^2*x4^2 + 
    2*f4*x1^2*x4*x5 + 2*f5*x1^2*x4*x6 + x1^2*x6*x7 + (2*f1*f7 - 
    f3*f5)*x1*x2^3 + (2*f2*f7 - 2*f3*f6 + 3*f4*f5)*x1*x2^2*x3 + (-4*f3*f7 + 
    2*f4*f6 + 2*f5^2)*x1*x2^2*x4 + f3*x1*x2^2*x5 - f4*x1*x2^2*x6 + 
    f5*x1*x2^2*x7 + (f3*f7 + 4*f4*f6 + 2*f5^2)*x1*x2*x3^2 + 
    8*f4*f7*x1*x2*x3*x4 - 3*f4*x1*x2*x3*x5 - 3*f5*x1*x2*x3*x6 + 
    2*f5*f7*x1*x2*x4^2 - 2*f6*x1*x2*x4*x6 + 4*f7*x1*x2*x4*x7 - x1*x2*x5*x7 +
    x1*x2*x6^2 + (f4*f7 + 4*f5*f6)*x1*x3^3 + 6*f5*f7*x1*x3^2*x4 - 
    2*f5*x1*x3^2*x5 - 4*f6*x1*x3^2*x6 + f7*x1*x3^2*x7 - 16*f6*f7*x1*x3*x4^2 
    + 4*f6*x1*x3*x4*x5 - 5*f7*x1*x3*x4*x6 + 2*x1*x3*x5*x6 - 24*f7^2*x1*x4^3 
    + 14*f7*x1*x4^2*x5 - 2*x1*x4*x5^2 - f4*f5*x2^4 + (-2*f4*f6 - 
    f5^2)*x2^3*x3 - 2*f4*f7*x2^3*x4 + f4*x2^3*x5 + f5*x2^3*x6 + (-f4*f7 - 
    2*f5*f6)*x2^2*x3^2 - 5*f5*f7*x2^2*x3*x4 + f5*x2^2*x3*x5 + 
    2*f6*x2^2*x3*x6 - 2*f7*x2^2*x3*x7 + 2*f7*x2^2*x4*x6 - x2^2*x5*x6 + 
    f5*f7*x2*x3^3 + 6*f6*f7*x2*x3^2*x4 - f7*x2*x3^2*x6 + 8*f7^2*x2*x3*x4^2 -
    3*f7*x2*x3*x4*x5 + f7^2*x3^3*x4,
-f2^2*x1^4 - 2*f2*f3*x1^3*x2 + (-8*f0*f6 + 2*f2*f4)*x1^3*x3 + (-12*f0*f7 + 
    4*f2*f5)*x1^3*x4 + 4*f0*x1^3*x5 + 2*f2*x1^3*x7 + (4*f0*f6 - 2*f2*f4 - 
    f3^2)*x1^2*x2^2 + (-4*f0*f7 - 2*f2*f5 + 2*f3*f4)*x1^2*x2*x3 + (-4*f2*f6 
    + 4*f3*f5)*x1^2*x2*x4 + 2*f2*x1^2*x2*x6 + 2*f3*x1^2*x2*x7 - 
    f4^2*x1^2*x3^2 + (2*f2*f7 - 8*f3*f6 - 4*f4*f5)*x1^2*x3*x4 - 
    2*f4*x1^2*x3*x7 + (-12*f3*f7 - 4*f5^2)*x1^2*x4^2 + 4*f3*x1^2*x4*x5 - 
    4*f5*x1^2*x4*x7 - 2*x1^2*x6*x8 - x1^2*x7^2 + (4*f0*f7 - 2*f3*f4)*x1*x2^3
    + (-2*f3*f5 + 2*f4^2)*x1*x2^2*x3 + (-4*f2*f7 + 4*f4*f5)*x1*x2^2*x4 + 
    2*f3*x1*x2^2*x6 + 2*f4*x1*x2^2*x7 + 2*f4*f5*x1*x2*x3^2 + (-2*f3*f7 - 
    4*f4*f6 + 4*f5^2)*x1*x2*x3*x4 - 2*f4*x1*x2*x3*x6 + 2*f5*x1*x2*x3*x7 + 
    (-12*f4*f7 + 8*f5*f6)*x1*x2*x4^2 + 4*f4*x1*x2*x4*x5 + 4*f6*x1*x2*x4*x7 +
    (-2*f4*f7 - 8*f5*f6)*x1*x3^2*x4 - 2*f5*x1*x3^2*x6 + (-16*f5*f7 - 
    8*f6^2)*x1*x3*x4^2 + 4*f5*x1*x3*x4*x5 + 4*f6*x1*x3*x4*x6 - 
    2*f7*x1*x3*x4*x7 + 2*x1*x3*x6^2 - 12*f6*f7*x1*x4^3 + 4*f6*x1*x4^2*x5 + 
    6*f7*x1*x4^2*x6 - 2*x1*x4*x5*x6 - f4^2*x2^4 - 2*f4*f5*x2^3*x3 + 
    2*f4*x2^3*x6 - f5^2*x2^2*x3^2 + 2*f4*f7*x2^2*x3*x4 + 2*f5*x2^2*x3*x6 + 
    8*f5*f7*x2^2*x4^2 + 4*f7*x2^2*x4*x7 - x2^2*x6^2 - 2*f5*f7*x2*x3^2*x4 - 
    8*f6*f7*x2*x3*x4^2 + 2*f7*x2*x3*x4*x6 - 12*f7^2*x2*x4^3 + 
    4*f7*x2*x4^2*x5 - f7^2*x3^2*x4^2,
-8*f1*f5*x1^3*x3 - 24*f2*f5*x1^3*x4 + 4*f1*x1^3*x6 - 8*f2*x1^3*x7 + 
    4*f1*f5*x1^2*x2^2 + 8*f2*f5*x1^2*x2*x3 + (16*f1*f7 - 
    24*f3*f5)*x1^2*x2*x4 - 4*f1*x1^2*x2*x5 - 8*f3*x1^2*x2*x7 + (4*f1*f7 + 
    8*f2*f6 + 8*f3*f5)*x1^2*x3^2 + (32*f2*f7 + 16*f4*f5)*x1^2*x3*x4 - 
    8*f2*x1^2*x3*x5 - 4*f3*x1^2*x3*x6 + 8*f4*x1^2*x3*x7 + 48*f5^2*x1^2*x4^2 
    + 4*f4*x1^2*x4*x6 + 40*f5*x1^2*x4*x7 + 14*x1^2*x6*x8 + 8*x1^2*x7^2 + 
    (-8*f1*f7 + 4*f3*f5)*x1*x2^2*x3 - 20*f4*f5*x1*x2^2*x4 - 8*f4*x1*x2^2*x7 
    + (-8*f2*f7 + 8*f3*f6)*x1*x2*x3^2 + (16*f3*f7 - 48*f5^2)*x1*x2*x3*x4 - 
    4*f3*x1*x2*x3*x5 - 4*f4*x1*x2*x3*x6 - 16*f5*x1*x2*x3*x7 + (16*f4*f7 - 
    48*f5*f6)*x1*x2*x4^2 - 4*f4*x1*x2*x4*x5 - 16*f6*x1*x2*x4*x7 - 
    4*x1*x2*x5*x8 - 6*x1*x2*x6*x7 + (-4*f3*f7 - 8*f4*f6 + 8*f5^2)*x1*x3^3 + 
    (-28*f4*f7 - 16*f5*f6)*x1*x3^2*x4 + 8*f4*x1*x3^2*x5 + 2*f5*x1*x3^2*x6 - 
    8*f6*x1*x3^2*x7 - 72*f5*f7*x1*x3*x4^2 + 24*f5*x1*x3*x4*x5 + 
    28*f6*x1*x3*x4*x6 - 24*f7*x1*x3*x4*x7 + 8*x1*x3*x5*x7 - 10*x1*x3*x6^2 + 
    58*f7*x1*x4^2*x6 - 18*x1*x4*x5*x6 + 4*f4*f5*x2^3*x3 + 4*f5^2*x2^3*x4 + 
    (8*f4*f6 + 4*f5^2)*x2^2*x3^2 + (8*f4*f7 + 16*f5*f6)*x2^2*x3*x4 - 
    4*f4*x2^2*x3*x5 - 4*f5*x2^2*x3*x6 - 16*f5*f7*x2^2*x4^2 - 
    16*f7*x2^2*x4*x7 + 4*x2^2*x5*x7 + (4*f4*f7 + 8*f5*f6)*x2*x3^3 + 
    (44*f5*f7 + 16*f6^2)*x2*x3^2*x4 - 8*f5*x2*x3^2*x5 - 8*f6*x2*x3^2*x6 + 
    8*f7*x2*x3^2*x7 + 64*f6*f7*x2*x3*x4^2 - 24*f6*x2*x3*x4*x5 - 
    24*f7*x2*x3*x4*x6 + 8*x2*x3*x5*x6 + 64*f7^2*x2*x4^3 - 44*f7*x2*x4^2*x5 +
    8*x2*x4*x5^2 - 4*f5*f7*x3^4 - 8*f6*f7*x3^3*x4 + 4*f7*x3^3*x6 - 
    16*f7^2*x3^2*x4^2 + 4*f7*x3^2*x4*x5,
-2*f1*f2*x1^4 - 2*f1*f3*x1^3*x2 + (-8*f0*f5 + 2*f1*f4 + 2*f2*f3)*x1^3*x3 + 
    (4*f1*f5 - 2*f2*f4)*x1^3*x4 + 4*f0*x1^3*x6 + 2*f1*x1^3*x7 + (4*f0*f5 - 
    2*f1*f4)*x1^2*x2^2 + (2*f1*f5 + 2*f2*f4 + 2*f3^2)*x1^2*x2*x3 + (16*f0*f7
    - 4*f1*f6 + 10*f2*f5 - 2*f3*f4)*x1^2*x2*x4 - 4*f0*x1^2*x2*x5 + 
    4*f2*x1^2*x2*x7 + (4*f0*f7 + 8*f1*f6 - 2*f2*f5 - 2*f3*f4)*x1^2*x3^2 + 
    (14*f1*f7 - 12*f3*f5 + 2*f4^2)*x1^2*x3*x4 - 4*f1*x1^2*x3*x5 - 
    2*f3*x1^2*x3*x7 + (-8*f2*f7 + 4*f4*f5)*x1^2*x4^2 + 2*f2*x1^2*x4*x5 + 
    4*f3*x1^2*x4*x6 + 2*f4*x1^2*x4*x7 - 9*x1^2*x7*x8 - 2*f1*f5*x1*x2^3 + 
    (-8*f0*f7 - 4*f1*f6 - 2*f2*f5 + 4*f3*f4)*x1*x2^2*x3 + (-12*f1*f7 + 
    14*f3*f5 - 2*f4^2)*x1*x2^2*x4 + 2*f1*x1*x2^2*x5 + 4*f3*x1*x2^2*x7 + 
    (2*f1*f7 - 4*f2*f6 - 4*f3*f5 - 2*f4^2)*x1*x2*x3^2 + (-4*f2*f7 + 4*f3*f6 
    - 20*f4*f5)*x1*x2*x3*x4 + 2*f2*x1*x2*x3*x5 - 6*f4*x1*x2*x3*x7 + (8*f3*f7
    - 4*f4*f6 - 20*f5^2)*x1*x2*x4^2 - 2*f3*x1*x2*x4*x5 + 4*f4*x1*x2*x4*x6 - 
    6*x1*x2*x6*x8 + 5*x1*x2*x7^2 + (2*f2*f7 - 8*f3*f6 + 2*f4*f5)*x1*x3^3 + 
    (-10*f3*f7 + 8*f4*f6 + 4*f5^2)*x1*x3^2*x4 + 4*f3*x1*x3^2*x5 - 
    7*f5*x1*x3^2*x7 + (22*f4*f7 + 40*f5*f6)*x1*x3*x4^2 - 6*f4*x1*x3*x4*x5 + 
    4*f5*x1*x3*x4*x6 - 2*f6*x1*x3*x4*x7 + x1*x3*x5*x8 + 9*x1*x3*x6*x7 + 
    88*f5*f7*x1*x4^3 - 28*f5*x1*x4^2*x5 + 4*f6*x1*x4^2*x6 + 5*f7*x1*x4^2*x7 
    - x1*x4*x5*x7 - 2*x1*x4*x6^2 + 2*f4^2*x2^3*x3 + 12*f4*f5*x2^3*x4 + 
    4*f4*x2^3*x7 - 2*f4*f5*x2^2*x3^2 + 14*f5^2*x2^2*x3*x4 + 6*f5*x2^2*x3*x7 
    - 4*f4*f7*x2^2*x4^2 + 2*x2^2*x6*x7 + (-4*f4*f6 - 6*f5^2)*x2*x3^3 + 
    (-4*f4*f7 - 4*f5*f6)*x2*x3^2*x4 + 2*f4*x2*x3^2*x5 + 2*f5*x2*x3^2*x6 + 
    4*f6*x2*x3^2*x7 - 6*f5*f7*x2*x3*x4^2 - 12*f6*x2*x3*x4*x6 + 
    8*f7*x2*x3*x4*x7 - 3*x2*x3*x5*x7 + 4*x2*x3*x6^2 - 14*f7*x2*x4^2*x6 + 
    6*x2*x4*x5*x6 + (-2*f4*f7 - 8*f5*f6)*x3^4 + (-18*f5*f7 - 
    16*f6^2)*x3^3*x4 + 5*f5*x3^3*x5 + 8*f6*x3^3*x6 - 2*f7*x3^3*x7 - 
    52*f6*f7*x3^2*x4^2 + 18*f6*x3^2*x4*x5 + 12*f7*x3^2*x4*x6 - 5*x3^2*x5*x6 
    - 40*f7^2*x3*x4^3 + 29*f7*x3*x4^2*x5 - 5*x3*x4*x5^2,
-8*f1*f5*x1^2*x2*x3 - 24*f2*f5*x1^2*x2*x4 + 4*f1*x1^2*x2*x6 - 
    8*f2*x1^2*x2*x7 + (-16*f1*f6 + 8*f2*f5)*x1^2*x3^2 - 24*f1*f7*x1^2*x3*x4 
    + 8*f1*x1^2*x3*x5 - 4*f2*x1^2*x3*x6 + 20*x1^2*x7*x8 + 4*f1*f5*x1*x2^3 + 
    (8*f1*f6 + 4*f2*f5)*x1*x2^2*x3 + (16*f1*f7 - 24*f3*f5)*x1*x2^2*x4 - 
    4*f1*x1*x2^2*x5 - 8*f3*x1*x2^2*x7 + (-4*f1*f7 + 8*f2*f6 + 
    16*f3*f5)*x1*x2*x3^2 + (16*f2*f7 + 16*f4*f5)*x1*x2*x3*x4 - 
    4*f2*x1*x2*x3*x5 - 8*f3*x1*x2*x3*x6 + 8*f4*x1*x2*x3*x7 + 
    48*f5^2*x1*x2*x4^2 + 4*f4*x1*x2*x4*x6 + 10*x1*x2*x6*x8 - 12*x1*x2*x7^2 +
    (-4*f2*f7 + 16*f3*f6 - 8*f4*f5)*x1*x3^3 + (24*f3*f7 - 16*f4*f6 - 
    32*f5^2)*x1*x3^2*x4 - 8*f3*x1*x3^2*x5 + 4*f4*x1*x3^2*x6 + 
    12*f5*x1*x3^2*x7 + (-24*f4*f7 - 96*f5*f6)*x1*x3*x4^2 + 8*f4*x1*x3*x4*x5 
    + 24*f5*x1*x3*x4*x6 + 8*f6*x1*x3*x4*x7 - 4*x1*x3*x5*x8 - 16*x1*x3*x6*x7 
    - 144*f5*f7*x1*x4^3 + 48*f5*x1*x4^2*x5 + 12*f7*x1*x4^2*x7 - 
    4*x1*x4*x5*x7 - 4*x1*x4*x6^2 - 20*f4*f5*x2^3*x4 - 8*f4*x2^3*x7 + 
    12*f4*f5*x2^2*x3^2 + (8*f4*f6 - 24*f5^2)*x2^2*x3*x4 - 8*f4*x2^2*x3*x6 - 
    12*f5*x2^2*x3*x7 + 16*f4*f7*x2^2*x4^2 - 4*f4*x2^2*x4*x5 - 2*x2^2*x6*x7 +
    (8*f4*f6 + 16*f5^2)*x2*x3^3 + (4*f4*f7 + 16*f5*f6)*x2*x3^2*x4 - 
    4*f4*x2*x3^2*x5 - 14*f5*x2*x3^2*x6 - 8*f6*x2*x3^2*x7 + 12*f6*x2*x3*x4*x6
    - 24*f7*x2*x3*x4*x7 + 8*x2*x3*x5*x7 - 2*x2*x3*x6^2 + 14*f7*x2*x4^2*x6 - 
    6*x2*x4*x5*x6 + (4*f4*f7 + 16*f5*f6)*x3^4 + (40*f5*f7 + 32*f6^2)*x3^3*x4
    - 12*f5*x3^3*x5 - 16*f6*x3^3*x6 + 4*f7*x3^3*x7 + 112*f6*f7*x3^2*x4^2 - 
    40*f6*x3^2*x4*x5 - 28*f7*x3^2*x4*x6 + 12*x3^2*x5*x6 + 96*f7^2*x3*x4^3 - 
    68*f7*x3*x4^2*x5 + 12*x3*x4*x5^2,
-f1^2*x1^4 + 2*f1*f3*x1^3*x3 + (12*f0*f5 - 2*f1*f4)*x1^3*x4 + 4*f0*x1^3*x7 +
    (-4*f0*f5 + 2*f1*f4)*x1^2*x2*x3 - 2*f1*f5*x1^2*x2*x4 + (-4*f0*f6 - 
    2*f1*f5 - f3^2)*x1^2*x3^2 + (-16*f0*f7 - 8*f1*f6 - 8*f2*f5 + 
    2*f3*f4)*x1^2*x3*x4 + 4*f0*x1^2*x3*x5 - 4*f2*x1^2*x3*x7 + (-20*f1*f7 + 
    12*f3*f5 - f4^2)*x1^2*x4^2 + 6*f1*x1^2*x4*x5 - 2*f2*x1^2*x4*x6 + 
    4*f3*x1^2*x4*x7 + 6*f1*f5*x1*x2^2*x3 + (4*f1*f6 + 10*f2*f5)*x1*x2^2*x4 -
    2*f1*x1*x2^2*x6 + 4*f2*x1*x2^2*x7 + (4*f0*f7 + 8*f1*f6 - 
    2*f3*f4)*x1*x2*x3^2 + (20*f1*f7 - 10*f3*f5 + 2*f4^2)*x1*x2*x3*x4 - 
    6*f1*x1*x2*x3*x5 + 2*f2*x1*x2*x3*x6 - 4*f3*x1*x2*x3*x7 + (-8*f2*f7 + 
    10*f4*f5)*x1*x2*x4^2 + 2*f2*x1*x2*x4*x5 - 2*f3*x1*x2*x4*x6 + 
    4*f4*x1*x2*x4*x7 - 9*x1*x2*x7*x8 + (2*f1*f7 + 4*f2*f6 + 2*f3*f5)*x1*x3^3
    + (14*f2*f7 + 4*f3*f6 + 6*f4*f5)*x1*x3^2*x4 - 4*f2*x1*x3^2*x5 + 
    4*f4*x1*x3^2*x7 + (4*f3*f7 - 8*f4*f6 + 28*f5^2)*x1*x3*x4^2 - 
    2*f3*x1*x3*x4*x5 + 2*f4*x1*x3*x4*x6 + 20*f5*x1*x3*x4*x7 - x1*x3*x6*x8 + 
    4*x1*x3*x7^2 + (-20*f4*f7 + 12*f5*f6)*x1*x4^3 + 6*f4*x1*x4^2*x5 - 
    8*f5*x1*x4^2*x6 + 4*f6*x1*x4^2*x7 - 11*x1*x4*x5*x8 - 2*x1*x4*x6*x7 - 
    2*f1*f5*x2^4 + (-4*f1*f6 - 2*f2*f5)*x2^3*x3 + (-4*f1*f7 + 
    10*f3*f5)*x2^3*x4 + 2*f1*x2^3*x5 + 4*f3*x2^3*x7 + 4*f4*x2^3*x8 + 
    (-2*f1*f7 - 4*f2*f6 - 6*f3*f5 - f4^2)*x2^2*x3^2 + (-4*f2*f7 - 4*f3*f6 - 
    14*f4*f5)*x2^2*x3*x4 + 2*f2*x2^2*x3*x5 + 4*f3*x2^2*x3*x6 - 
    8*f4*x2^2*x3*x7 + 6*f5*x2^2*x3*x8 + (-8*f3*f7 + 4*f4*f6 - 
    21*f5^2)*x2^2*x4^2 + 2*f3*x2^2*x4*x5 - 4*f4*x2^2*x4*x6 - 4*x2^2*x6*x8 + 
    5*x2^2*x7^2 + (-2*f2*f7 - 4*f3*f6 + 2*f4*f5)*x2*x3^3 + (-2*f3*f7 + 
    12*f4*f6 - 6*f5^2)*x2*x3^2*x4 + 2*f3*x2*x3^2*x5 - 2*f4*x2*x3^2*x6 - 
    13*f5*x2*x3^2*x7 + 4*f6*x2*x3^2*x8 + (32*f4*f7 + 20*f5*f6)*x2*x3*x4^2 - 
    10*f4*x2*x3*x4*x5 - 10*f6*x2*x3*x4*x7 - 2*x2*x3*x5*x8 + 12*x2*x3*x6*x7 +
    80*f5*f7*x2*x4^3 - 4*f6*x2*x4^2*x6 + 9*f7*x2*x4^2*x7 + 10*x2*x4*x5*x7 + 
    4*x2*x4*x6^2 + (-2*f3*f7 - 4*f4*f6 + 3*f5^2)*x3^4 + (-12*f4*f7 - 
    4*f5*f6)*x3^3*x4 + 4*f4*x3^3*x5 - 5*f5*x3^3*x6 - 4*f6*x3^3*x7 + 
    2*f7*x3^3*x8 + (-32*f5*f7 - 4*f6^2)*x3^2*x4^2 - f5*x3^2*x4*x5 - 
    6*f6*x3^2*x4*x6 - 10*f7*x3^2*x4*x7 + 4*x3^2*x5*x7 + 2*x3^2*x6^2 - 
    48*f6*f7*x3*x4^3 - 10*f6*x3*x4^2*x5 + 3*f7*x3*x4^2*x6 + 12*x3*x4*x5*x6 -
    64*f7^2*x4^4 + 3*f7*x4^3*x5 + 6*x4^2*x5^2,
4*f1*x1^3*x8 - 8*f1*f5*x1^2*x2*x4 - 4*f1*x1^2*x2*x7 - 4*f1*f5*x1^2*x3^2 + 
    (-8*f1*f6 - 16*f2*f5)*x1^2*x3*x4 - 8*f2*x1^2*x3*x7 - 12*f1*f7*x1^2*x4^2 
    + 4*f1*x1^2*x4*x5 - 4*f2*x1^2*x4*x6 + 12*f1*f5*x1*x2^2*x3 + (8*f1*f6 + 
    20*f2*f5)*x1*x2^2*x4 - 4*f1*x1*x2^2*x6 + 8*f2*x1*x2^2*x7 + 
    16*f1*f6*x1*x2*x3^2 + (32*f1*f7 - 16*f3*f5)*x1*x2*x3*x4 - 
    12*f1*x1*x2*x3*x5 + 4*f2*x1*x2*x3*x6 - 8*f3*x1*x2*x3*x7 - 
    16*f2*f7*x1*x2*x4^2 + 4*f2*x1*x2*x4*x5 - 4*f3*x1*x2*x4*x6 - 
    18*x1*x2*x7*x8 + (4*f1*f7 + 8*f2*f6 + 8*f3*f5)*x1*x3^3 + (28*f2*f7 + 
    16*f3*f6 + 8*f4*f5)*x1*x3^2*x4 - 8*f2*x1*x3^2*x5 - 4*f3*x1*x3^2*x6 + 
    8*f4*x1*x3^2*x7 + (24*f3*f7 - 16*f4*f6 + 32*f5^2)*x1*x3*x4^2 - 
    8*f3*x1*x3*x4*x5 + 8*f4*x1*x3*x4*x6 + 32*f5*x1*x3*x4*x7 - 4*x1*x3*x6*x8 
    + 8*x1*x3*x7^2 - 24*f4*f7*x1*x4^3 + 8*f4*x1*x4^2*x5 + 8*f5*x1*x4^2*x6 - 
    24*x1*x4*x5*x8 + 4*x1*x4*x6*x7 - 4*f1*f5*x2^4 + (-8*f1*f6 - 
    4*f2*f5)*x2^3*x3 + (-8*f1*f7 + 20*f3*f5)*x2^3*x4 + 4*f1*x2^3*x5 + 
    8*f3*x2^3*x7 + 8*f4*x2^3*x8 + (-4*f1*f7 - 8*f2*f6 - 12*f3*f5)*x2^2*x3^2 
    + (-8*f2*f7 - 8*f3*f6 - 24*f4*f5)*x2^2*x3*x4 + 4*f2*x2^2*x3*x5 + 
    8*f3*x2^2*x3*x6 - 16*f4*x2^2*x3*x7 + 12*f5*x2^2*x3*x8 + (-16*f3*f7 + 
    8*f4*f6 - 40*f5^2)*x2^2*x4^2 + 4*f3*x2^2*x4*x5 - 8*f4*x2^2*x4*x6 - 
    8*x2^2*x6*x8 + 10*x2^2*x7^2 + (-4*f2*f7 - 8*f3*f6 + 8*f4*f5)*x2*x3^3 + 
    (-4*f3*f7 + 32*f4*f6 - 8*f5^2)*x2*x3^2*x4 + 4*f3*x2*x3^2*x5 - 
    8*f4*x2*x3^2*x6 - 26*f5*x2*x3^2*x7 + 8*f6*x2*x3^2*x8 + (72*f4*f7 + 
    48*f5*f6)*x2*x3*x4^2 - 24*f4*x2*x3*x4*x5 - 20*f6*x2*x3*x4*x7 - 
    4*x2*x3*x5*x8 + 26*x2*x3*x6*x7 + 152*f5*f7*x2*x4^3 - 8*f6*x2*x4^2*x6 + 
    10*f7*x2*x4^2*x7 + 22*x2*x4*x5*x7 + 8*x2*x4*x6^2 + (-4*f3*f7 - 8*f4*f6 +
    8*f5^2)*x3^4 - 24*f4*f7*x3^3*x4 + 8*f4*x3^3*x5 - 16*f5*x3^3*x6 - 
    8*f6*x3^3*x7 + 4*f7*x3^3*x8 - 48*f5*f7*x3^2*x4^2 - 8*f5*x3^2*x4*x5 - 
    24*f6*x3^2*x4*x6 - 20*f7*x3^2*x4*x7 + 8*x3^2*x5*x7 + 8*x3^2*x6^2 - 
    64*f6*f7*x3*x4^3 - 32*f6*x3*x4^2*x5 - 16*f7*x3*x4^2*x6 + 32*x3*x4*x5*x6 
    - 96*f7^2*x4^4 - 16*f7*x4^3*x5 + 16*x4^2*x5^2,
-2*f1*f2*x1^3*x2 - 2*f2^2*x1^3*x3 - 2*f1*f3*x1^2*x2^2 + (-8*f0*f5 + 2*f1*f4 
    - 2*f2*f3)*x1^2*x2*x3 + (4*f1*f5 - 2*f2*f4)*x1^2*x2*x4 + 4*f0*x1^2*x2*x6
    + 2*f1*x1^2*x2*x7 + (-16*f0*f6 + 4*f2*f4)*x1^2*x3^2 + (-24*f0*f7 - 
    8*f1*f6 + 12*f2*f5)*x1^2*x3*x4 + 8*f0*x1^2*x3*x5 + 4*f2*x1^2*x3*x7 - 
    12*f1*f7*x1^2*x4^2 + 4*f1*x1^2*x4*x5 - 2*f2*x1^2*x4*x6 + (4*f0*f5 - 
    2*f1*f4)*x1*x2^3 + (8*f0*f6 - 2*f1*f5 - 2*f2*f4)*x1*x2^2*x3 + (16*f0*f7 
    - 4*f2*f5 - 2*f3*f4)*x1*x2^2*x4 - 4*f0*x1*x2^2*x5 + 2*f1*x1*x2^2*x6 + 
    (-4*f0*f7 - 2*f2*f5 + 2*f3*f4)*x1*x2*x3^2 + (-2*f1*f7 - 8*f2*f6 + 
    2*f4^2)*x1*x2*x3*x4 + 2*f2*x1*x2*x3*x6 + 2*f3*x1*x2*x3*x7 + (-16*f2*f7 +
    4*f4*f5)*x1*x2*x4^2 + 4*f2*x1*x2*x4*x5 + 2*f3*x1*x2*x4*x6 + 
    2*f4*x1*x2*x4*x7 + 2*x1*x2*x7*x8 - 2*f4^2*x1*x3^3 + (2*f2*f7 - 8*f3*f6 -
    12*f4*f5)*x1*x3^2*x4 - 4*f4*x1*x3^2*x7 + (-12*f3*f7 - 8*f4*f6 - 
    16*f5^2)*x1*x3*x4^2 + 4*f3*x1*x3*x4*x5 + 2*f4*x1*x3*x4*x6 - 
    12*f5*x1*x3*x4*x7 + x1*x3*x6*x8 - 2*x1*x3*x7^2 - 12*f4*f7*x1*x4^3 + 
    4*f4*x1*x4^2*x5 + 4*f5*x1*x4^2*x6 - 2*x1*x4*x5*x8 + 2*x1*x4*x6*x7 - 
    2*f4^2*x2^3*x4 + 2*f4^2*x2^2*x3^2 + 2*f4*f5*x2^2*x3*x4 + 2*f4*x2^2*x3*x7
    + 8*f5^2*x2^2*x4^2 + 4*f4*x2^2*x4*x6 - 2*x2^2*x7^2 + 2*f4*f5*x2*x3^3 - 
    2*f4*x2*x3^2*x6 + 4*f5*x2*x3^2*x7 + (2*f4*f7 + 8*f5*f6)*x2*x3*x4^2 + 
    12*f6*x2*x3*x4*x7 - 5*x2*x3*x6*x7 + 20*f5*f7*x2*x4^3 + 22*f7*x2*x4^2*x7 
    - 4*x2*x4*x5*x7 - 2*x2*x4*x6^2 + (-2*f4*f7 - 8*f5*f6)*x3^3*x4 + 
    f5*x3^3*x6 + (-20*f5*f7 - 16*f6^2)*x3^2*x4^2 + 2*f5*x3^2*x4*x5 + 
    10*f6*x3^2*x4*x6 - 2*f7*x3^2*x4*x7 - x3^2*x6^2 - 56*f6*f7*x3*x4^3 + 
    12*f6*x3*x4^2*x5 + 17*f7*x3*x4^2*x6 - 3*x3*x4*x5*x6 - 48*f7^2*x4^4 + 
    22*f7*x4^3*x5 - 2*x4^2*x5^2,
-2*f1^2*x1^3*x2 - 4*f1*f2*x1^3*x3 - 2*f2^2*x1^3*x4 + 8*f0*x1^3*x8 + 
    2*f1*f2*x1^2*x2^2 + 2*f2^2*x1^2*x2*x3 + (8*f0*f5 - 4*f1*f4 - 
    4*f2*f3)*x1^2*x2*x4 + (-8*f0*f5 + 4*f1*f4 + 4*f2*f3)*x1^2*x3^2 + 
    4*f1*f5*x1^2*x3*x4 + 4*f1*x1^2*x3*x7 - 4*f2*f5*x1^2*x4^2 + 
    2*f1*x1^2*x4*x6 + 2*f1*f3*x1*x2^3 + (8*f0*f5 - 2*f1*f4 + 
    2*f2*f3)*x1*x2^2*x3 + (8*f0*f6 - 6*f1*f5 - 2*f2*f4 - 2*f3^2)*x1*x2^2*x4 
    - 4*f0*x1*x2^2*x6 - 2*f1*x1*x2^2*x7 + (8*f0*f6 + 2*f3^2)*x1*x2*x3^2 + 
    (16*f0*f7 - 16*f2*f5 + 4*f3*f4)*x1*x2*x3*x4 - 8*f0*x1*x2*x3*x5 - 
    4*f2*x1*x2*x3*x7 + (4*f1*f7 - 8*f2*f6 + 20*f3*f5 - 2*f4^2)*x1*x2*x4^2 - 
    2*f1*x1*x2*x4*x5 + 6*f2*x1*x2*x4*x6 + 8*f3*x1*x2*x4*x7 - 2*x1*x2*x8^2 + 
    (8*f0*f7 + 4*f2*f5 - 4*f3*f4)*x1*x3^3 + (6*f1*f7 + 4*f2*f6 - 20*f3*f5 + 
    2*f4^2)*x1*x3^2*x4 - 4*f2*x1*x3^2*x6 - 4*f3*x1*x3^2*x7 + (4*f2*f7 - 
    16*f3*f6 + 8*f4*f5)*x1*x3*x4^2 + 6*f3*x1*x3*x4*x6 + 4*f4*x1*x3*x4*x7 + 
    10*x1*x3*x7*x8 + (-24*f3*f7 + 16*f5^2)*x1*x4^3 + 8*f3*x1*x4^2*x5 + 
    2*f4*x1*x4^2*x6 + 12*f5*x1*x4^2*x7 - 11*x1*x4*x6*x8 + 2*x1*x4*x7^2 + 
    (-4*f0*f5 + 2*f1*f4)*x2^4 + (-8*f0*f6 + 2*f1*f5 + 2*f2*f4)*x2^3*x3 + 
    (-8*f0*f7 + 4*f2*f5 - 2*f3*f4)*x2^3*x4 + 4*f0*x2^3*x5 - 2*f1*x2^3*x6 + 
    (-4*f0*f7 + 2*f2*f5 + 2*f3*f4)*x2^2*x3^2 + (-2*f1*f7 + 8*f2*f6 - 2*f3*f5
    + 2*f4^2)*x2^2*x3*x4 - 2*f2*x2^2*x3*x6 - 2*f3*x2^2*x3*x7 - 
    2*f4*x2^2*x3*x8 + (8*f2*f7 + 14*f4*f5)*x2^2*x4^2 - 4*f2*x2^2*x4*x5 + 
    2*f3*x2^2*x4*x6 + 6*f4*x2^2*x4*x7 + 2*x2^2*x7*x8 + (4*f3*f5 - 
    2*f4^2)*x2*x3^3 + (2*f2*f7 + 12*f3*f6 - 4*f4*f5)*x2*x3^2*x4 - 
    4*f3*x2*x3^2*x6 - 4*f5*x2*x3^2*x8 + (16*f3*f7 - 8*f4*f6 + 
    32*f5^2)*x2*x3*x4^2 - 6*f3*x2*x3*x4*x5 - 12*f6*x2*x3*x4*x8 + 
    4*x2*x3*x6*x8 - 8*x2*x3*x7^2 + (-20*f4*f7 + 16*f5*f6)*x2*x4^3 + 
    6*f4*x2*x4^2*x5 + 8*f6*x2*x4^2*x7 - 14*f7*x2*x4^2*x8 + 6*x2*x4*x5*x8 + 
    x2*x4*x6*x7 - 4*f4*f5*x3^4 + (2*f3*f7 - 4*f4*f6 - 20*f5^2)*x3^3*x4 + 
    4*f4*x3^3*x6 + 6*f5*x3^3*x7 + (2*f4*f7 - 40*f5*f6)*x3^2*x4^2 + 
    15*f5*x3^2*x4*x6 + 16*f6*x3^2*x4*x7 - 2*f7*x3^2*x4*x8 - 6*x3^2*x6*x7 + 
    (-36*f5*f7 - 16*f6^2)*x3*x4^3 + 12*f5*x3*x4^2*x5 + 2*f6*x3*x4^2*x6 + 
    30*f7*x3*x4^2*x7 - 10*x3*x4*x5*x7 + 5*x3*x4*x6^2 - 24*f6*f7*x4^4 + 
    8*f6*x4^3*x5 - f7*x4^3*x6 + x4^2*x5*x6,
-2*f1^2*x1^3*x2 + 2*f2^2*x1^3*x4 - 2*f1*f2*x1^2*x2^2 + (4*f1*f3 - 
    2*f2^2)*x1^2*x2*x3 + (24*f0*f5 - 4*f1*f4 + 4*f2*f3)*x1^2*x2*x4 + 
    8*f0*x1^2*x2*x7 + (16*f0*f6 - 4*f1*f5 - 4*f2*f4)*x1^2*x3*x4 + (24*f0*f7 
    - 20*f2*f5)*x1^2*x4^2 - 8*f0*x1^2*x4*x5 + 2*f1*x1^2*x4*x6 - 
    8*f2*x1^2*x4*x7 - 2*f1*f3*x1*x2^3 + (-16*f0*f5 + 6*f1*f4 - 
    2*f2*f3)*x1*x2^2*x3 + (-8*f0*f6 + 2*f1*f5 + 2*f2*f4 + 2*f3^2)*x1*x2^2*x4
    + 4*f0*x1*x2^2*x6 + 2*f1*x1*x2^2*x7 + (-24*f0*f6 + 4*f1*f5 + 4*f2*f4 - 
    2*f3^2)*x1*x2*x3^2 + (-48*f0*f7 - 8*f1*f6 + 20*f2*f5)*x1*x2*x3*x4 + 
    16*f0*x1*x2*x3*x5 - 4*f1*x1*x2*x3*x6 + 4*f2*x1*x2*x3*x7 + (-20*f1*f7 + 
    8*f2*f6 + 4*f3*f5 - 2*f4^2)*x1*x2*x4^2 + 6*f1*x1*x2*x4*x5 - 
    6*f2*x1*x2*x4*x6 + 2*x1*x2*x8^2 + (2*f1*f7 + 4*f2*f6 + 4*f3*f5 + 
    2*f4^2)*x1*x3^2*x4 + (12*f2*f7 + 16*f3*f6 + 16*f4*f5)*x1*x3*x4^2 - 
    4*f2*x1*x3*x4*x5 - 2*f3*x1*x3*x4*x6 + 8*f4*x1*x3*x4*x7 - 8*x1*x3*x7*x8 +
    (24*f3*f7 + 32*f5^2)*x1*x4^3 - 8*f3*x1*x4^2*x5 + 2*f4*x1*x4^2*x6 + 
    28*f5*x1*x4^2*x7 + x1*x4*x6*x8 + 6*x1*x4*x7^2 + (4*f0*f5 - 2*f1*f4)*x2^4
    + (8*f0*f6 - 2*f1*f5 - 2*f2*f4)*x2^3*x3 + (8*f0*f7 - 4*f2*f5 + 
    2*f3*f4)*x2^3*x4 - 4*f0*x2^3*x5 + 2*f1*x2^3*x6 + (4*f0*f7 - 2*f2*f5 - 
    2*f3*f4)*x2^2*x3^2 + (2*f1*f7 - 8*f2*f6 + 2*f3*f5 + 2*f4^2)*x2^2*x3*x4 +
    2*f2*x2^2*x3*x6 + 2*f3*x2^2*x3*x7 + 2*f4*x2^2*x3*x8 + (-8*f2*f7 + 
    6*f4*f5)*x2^2*x4^2 + 4*f2*x2^2*x4*x5 - 2*f3*x2^2*x4*x6 + 2*f4*x2^2*x4*x7
    - 2*x2^2*x7*x8 + (-4*f3*f5 - 2*f4^2)*x2*x3^3 + (-2*f2*f7 - 12*f3*f6 - 
    12*f4*f5)*x2*x3^2*x4 + 4*f3*x2*x3^2*x6 - 4*f4*x2*x3^2*x7 + 
    4*f5*x2*x3^2*x8 + (-16*f3*f7 - 24*f5^2)*x2*x3*x4^2 + 6*f3*x2*x3*x4*x5 + 
    12*f6*x2*x3*x4*x8 - 4*x2*x3*x6*x8 + 6*x2*x3*x7^2 + (4*f4*f7 - 
    16*f5*f6)*x2*x4^3 - 2*f4*x2*x4^2*x5 - 8*f6*x2*x4^2*x7 + 14*f7*x2*x4^2*x8
    - 6*x2*x4*x5*x8 + x2*x4*x6*x7 + (-2*f3*f7 - 4*f4*f6 + 4*f5^2)*x3^3*x4 - 
    8*f5*x3^3*x7 + (-10*f4*f7 + 8*f5*f6)*x3^2*x4^2 + 4*f4*x3^2*x4*x5 - 
    5*f5*x3^2*x4*x6 - 20*f6*x3^2*x4*x7 + 2*f7*x3^2*x4*x8 + 8*x3^2*x6*x7 + 
    (-4*f5*f7 + 16*f6^2)*x3*x4^3 + 4*f5*x3*x4^2*x5 - 14*f6*x3*x4^2*x6 - 
    32*f7*x3*x4^2*x7 + 12*x3*x4*x5*x7 + x3*x4*x6^2 + 24*f6*f7*x4^4 - 
    8*f6*x4^3*x5 - 13*f7*x4^3*x6 + 5*x4^2*x5*x6,
-f1^2*x1^2*x2^2 - 2*f1*f2*x1^2*x2*x3 + 4*f0*x1^2*x2*x8 - f2^2*x1^2*x3^2 + 
    (4*f0*f5 - 2*f1*f4)*x1*x2^2*x4 + (-4*f0*f5 + 2*f1*f4)*x1*x2*x3^2 + 
    (8*f0*f6 - 2*f2*f4)*x1*x2*x3*x4 + 2*f1*x1*x2*x3*x7 + (12*f0*f7 - 
    12*f2*f5)*x1*x2*x4^2 - 4*f0*x1*x2*x4*x5 + 2*f1*x1*x2*x4*x6 - 
    4*f2*x1*x2*x4*x7 + (-8*f0*f6 + 2*f2*f4)*x1*x3^3 + (-12*f0*f7 - 8*f1*f6 +
    8*f2*f5)*x1*x3^2*x4 + 4*f0*x1*x3^2*x5 + 2*f2*x1*x3^2*x7 - 
    12*f1*f7*x1*x3*x4^2 + 4*f1*x1*x3*x4*x5 - 2*f2*x1*x3*x4*x6 + 
    10*x1*x4*x7*x8 - f4^2*x2^2*x4^2 + 2*f4^2*x2*x3^2*x4 + 
    12*f4*f5*x2*x3*x4^2 + 6*f4*x2*x3*x4*x7 + 24*f5^2*x2*x4^3 + 
    2*f4*x2*x4^2*x6 - 6*x2*x4*x7^2 - f4^2*x3^4 - 8*f4*f5*x3^3*x4 - 
    2*f4*x3^3*x7 + (-8*f4*f6 - 16*f5^2)*x3^2*x4^2 + 2*f4*x3^2*x4*x6 + 
    2*f5*x3^2*x4*x7 - x3^2*x7^2 + (-12*f4*f7 - 24*f5*f6)*x3*x4^3 + 
    4*f4*x3*x4^2*x5 + 8*f5*x3*x4^2*x6 + 12*f6*x3*x4^2*x7 - 8*x3*x4*x6*x7 - 
    36*f5*f7*x4^4 + 12*f5*x4^3*x5 + 18*f7*x4^3*x7 - 6*x4^2*x5*x7 - 
    x4^2*x6^2,
-2*f1^2*x1^3*x3 - 2*f1*f2*x1^3*x4 - 2*f1*f2*x1^2*x2*x3 - 2*f1*f3*x1^2*x2*x4 
    + (4*f1*f3 - 2*f2^2)*x1^2*x3^2 + (16*f0*f5 - 2*f1*f4 + 
    2*f2*f3)*x1^2*x3*x4 + 8*f0*x1^2*x3*x7 + (4*f1*f5 - 2*f2*f4)*x1^2*x4^2 + 
    4*f0*x1^2*x4*x6 + 2*f1*x1^2*x4*x7 - 2*f1*f3*x1*x2^2*x3 + (4*f0*f5 - 
    2*f1*f4)*x1*x2^2*x4 + (-16*f0*f5 + 6*f1*f4 - 2*f2*f3)*x1*x2*x3^2 + 
    (-6*f1*f5 + 2*f3^2)*x1*x2*x3*x4 + 4*f0*x1*x2*x3*x6 + 2*f1*x1*x2*x3*x7 + 
    (16*f0*f7 - 4*f1*f6 - 14*f2*f5 - 2*f3*f4)*x1*x2*x4^2 - 4*f0*x1*x2*x4*x5 
    + 4*f1*x1*x2*x4*x6 - 4*f2*x1*x2*x4*x7 + (-24*f0*f6 + 4*f1*f5 + 4*f2*f4 -
    2*f3^2)*x1*x3^3 + (-52*f0*f7 - 16*f1*f6 + 18*f2*f5 + 2*f3*f4)*x1*x3^2*x4
    + 16*f0*x1*x3^2*x5 - 4*f1*x1*x3^2*x6 + 4*f2*x1*x3^2*x7 + (-38*f1*f7 + 
    12*f3*f5)*x1*x3*x4^2 + 12*f1*x1*x3*x4*x5 - 6*f2*x1*x3*x4*x6 + 
    6*f3*x1*x3*x4*x7 - x1*x3*x8^2 + (-8*f2*f7 + 4*f4*f5)*x1*x4^3 + 
    2*f2*x1*x4^2*x5 + 4*f3*x1*x4^2*x6 + 2*f4*x1*x4^2*x7 + 11*x1*x4*x7*x8 + 
    (4*f0*f5 - 2*f1*f4)*x2^3*x3 + 2*f1*f5*x2^3*x4 + (8*f0*f6 - 2*f1*f5 - 
    2*f2*f4)*x2^2*x3^2 + (8*f0*f7 + 4*f1*f6 - 2*f2*f5 + 2*f3*f4)*x2^2*x3*x4 
    - 4*f0*x2^2*x3*x5 + 2*f1*x2^2*x3*x6 + (4*f1*f7 - 10*f3*f5 - 
    2*f4^2)*x2^2*x4^2 - 2*f1*x2^2*x4*x5 - 4*f3*x2^2*x4*x7 - 4*f4*x2^2*x4*x8 
    + (4*f0*f7 - 2*f2*f5 - 2*f3*f4)*x2*x3^3 + (4*f1*f7 - 4*f2*f6 + 8*f3*f5 +
    4*f4^2)*x2*x3^2*x4 + 2*f2*x2*x3^2*x6 + 2*f3*x2*x3^2*x7 + 2*f4*x2*x3^2*x8
    + (-4*f2*f7 + 4*f3*f6 + 20*f4*f5)*x2*x3*x4^2 + 2*f2*x2*x3*x4*x5 - 
    6*f3*x2*x3*x4*x6 + 12*f4*x2*x3*x4*x7 + x2*x3*x7*x8 + (8*f3*f7 - 4*f4*f6 
    + 28*f5^2)*x2*x4^3 - 2*f3*x2*x4^2*x5 + 8*f4*x2*x4^2*x6 + 4*x2*x4*x6*x8 -
    7*x2*x4*x7^2 + (-4*f3*f5 - 2*f4^2)*x3^4 + (-8*f3*f6 - 14*f4*f5)*x3^3*x4 
    + 4*f3*x3^3*x6 - 4*f4*x3^3*x7 + f5*x3^3*x8 + (-14*f3*f7 - 16*f4*f6 - 
    20*f5^2)*x3^2*x4^2 + 4*f3*x3^2*x4*x5 + 2*f4*x3^2*x4*x6 + f5*x3^2*x4*x7 +
    2*f6*x3^2*x4*x8 - x3^2*x6*x8 - 2*x3^2*x7^2 + (-30*f4*f7 - 
    32*f5*f6)*x3*x4^3 + 10*f4*x3*x4^2*x5 + 8*f5*x3*x4^2*x6 + 
    14*f6*x3*x4^2*x7 + 5*f7*x3*x4^2*x8 - x3*x4*x5*x8 - 13*x3*x4*x6*x7 - 
    56*f5*f7*x4^4 + 20*f5*x4^3*x5 + 4*f6*x4^3*x6 + 17*f7*x4^3*x7 - 
    5*x4^2*x5*x7 - 6*x4^2*x6^2,
-f1^2*x1^2*x2*x3 - f1*f2*x1^2*x2*x4 - f1*f2*x1^2*x3^2 - f2^2*x1^2*x3*x4 + 
    4*f0*x1^2*x3*x8 + f1^2*x1*x2^3 + 2*f1*f2*x1*x2^2*x3 - f1*f3*x1*x2^2*x4 +
    (f1*f3 + f2^2)*x1*x2*x3^2 + (-f1*f4 - f2*f3)*x1*x2*x3*x4 + (2*f1*f5 - 
    f2*f4)*x1*x2*x4^2 + 2*f0*x1*x2*x4*x6 + f1*x1*x2*x4*x7 + (f1*f4 + 
    f2*f3)*x1*x3^3 + f2*f4*x1*x3^2*x4 - 2*f0*x1*x3^2*x6 + f1*x1*x3^2*x7 - 
    4*f1*f6*x1*x3*x4^2 + f1*x1*x3*x4*x6 - 6*f1*f7*x1*x4^3 + 2*f1*x1*x4^2*x5 
    - f2*x1*x4^2*x6 - 5*x1*x4*x8^2 + (-10*f0*f5 + f1*f4)*x2^3*x4 - 
    4*f0*x2^3*x7 + (6*f0*f5 - f1*f4)*x2^2*x3^2 + (4*f0*f6 - 2*f1*f5 + 
    f2*f4)*x2^2*x3*x4 - 4*f0*x2^2*x3*x6 - 2*f1*x2^2*x3*x7 + (8*f0*f7 + 
    10*f2*f5 - f3*f4)*x2^2*x4^2 - 2*f0*x2^2*x4*x5 - f1*x2^2*x4*x6 + 
    4*f2*x2^2*x4*x7 + (4*f0*f6 + f1*f5 - f2*f4)*x2*x3^3 + (2*f0*f7 + 6*f1*f6
    - 8*f2*f5 + 2*f3*f4)*x2*x3^2*x4 - 2*f0*x2*x3^2*x5 - f1*x2*x3^2*x6 - 
    2*f2*x2*x3^2*x7 + (7*f1*f7 - 4*f2*f6 + 6*f3*f5)*x2*x3*x4^2 - 
    3*f1*x2*x3*x4*x5 + 3*f2*x2*x3*x4*x6 + 3*f3*x2*x3*x4*x7 - 
    3*f4*x2*x3*x4*x8 + (-8*f2*f7 + 2*f4*f5)*x2*x4^3 + 2*f2*x2*x4^2*x5 + 
    f3*x2*x4^2*x6 + f4*x2*x4^2*x7 + x2*x4*x7*x8 + (2*f0*f7 + f2*f5 - 
    f3*f4)*x3^4 + (2*f1*f7 + 2*f2*f6 - 4*f3*f5)*x3^3*x4 - f2*x3^3*x6 - 
    f3*x3^3*x7 + f4*x3^3*x8 + (5*f2*f7 - 4*f3*f6)*x3^2*x4^2 - f2*x3^2*x4*x5 
    + f3*x3^2*x4*x6 + f4*x3^2*x4*x7 - f5*x3^2*x4*x8 + x3^2*x7*x8 + (-6*f3*f7
    - 4*f4*f6 + 4*f5^2)*x3*x4^3 + 2*f3*x3*x4^2*x5 + 2*f4*x3*x4^2*x6 + 
    4*f5*x3*x4^2*x7 - 6*f6*x3*x4^2*x8 + 4*x3*x4*x6*x8 + x3*x4*x7^2 - 
    6*f4*f7*x4^4 + 2*f4*x4^3*x5 + 2*f5*x4^3*x6 - 7*f7*x4^3*x8 + 3*x4^2*x5*x8
    + x4^2*x6*x7,
-f1^2*x1^2*x3^2 - 2*f1*f2*x1^2*x3*x4 - f2^2*x1^2*x4^2 + 2*f1^2*x1*x2^2*x3 + 
    2*f1*f2*x1*x2^2*x4 + 2*f1*f2*x1*x2*x3^2 + (-2*f1*f3 + 
    2*f2^2)*x1*x2*x3*x4 - 2*f2*f3*x1*x2*x4^2 + 2*f1*f3*x1*x3^3 + (4*f0*f5 + 
    2*f2*f3)*x1*x3^2*x4 + 4*f0*x1*x3^2*x7 + (-8*f0*f6 + 4*f1*f5)*x1*x3*x4^2 
    + 4*f0*x1*x3*x4*x6 + 2*f1*x1*x3*x4*x7 + (-12*f0*f7 + 4*f2*f5)*x1*x4^3 + 
    4*f0*x1*x4^2*x5 + 2*f2*x1*x4^2*x7 - f1^2*x2^4 - 2*f1*f2*x2^3*x3 + 
    2*f1*f3*x2^3*x4 + 4*f0*x2^3*x8 + (-2*f1*f3 - f2^2)*x2^2*x3^2 + 
    (-12*f0*f5 + 2*f2*f3)*x2^2*x3*x4 - 8*f0*x2^2*x3*x7 + 2*f1*x2^2*x3*x8 + 
    (4*f0*f6 - 4*f1*f5 - f3^2)*x2^2*x4^2 - 4*f0*x2^2*x4*x6 - 2*f1*x2^2*x4*x7
    - 4*f2*x2^2*x4*x8 + (4*f0*f5 - 2*f2*f3)*x2*x3^3 + (16*f0*f6 - 4*f1*f5 + 
    2*f3^2)*x2*x3^2*x4 - 4*f0*x2*x3^2*x6 - 2*f1*x2*x3^2*x7 + 2*f2*x2*x3^2*x8
    + (36*f0*f7 + 4*f1*f6 - 4*f2*f5)*x2*x3*x4^2 - 12*f0*x2*x3*x4*x5 - 
    6*f3*x2*x3*x4*x8 + (12*f1*f7 - 4*f2*f6 + 4*f3*f5)*x2*x4^3 - 
    4*f1*x2*x4^2*x5 + 4*f2*x2*x4^2*x6 + 2*f3*x2*x4^2*x7 + 4*x2*x4*x8^2 + 
    (-4*f0*f6 + 2*f1*f5 - f3^2)*x3^4 + (-12*f0*f7 + 2*f2*f5)*x3^3*x4 + 
    4*f0*x3^3*x5 - 2*f1*x3^3*x6 + 2*f3*x3^3*x8 - 6*f1*f7*x3^2*x4^2 + 
    2*f1*x3^2*x4*x5 - 2*f2*x3^2*x4*x6 + 2*f3*x3^2*x4*x7 - x3^2*x8^2 + 
    (-6*f2*f7 - 8*f3*f6)*x3*x4^3 + 2*f2*x3*x4^2*x5 + 4*f3*x3*x4^2*x6 - 
    2*x3*x4*x7*x8 + (-12*f3*f7 - 4*f5^2)*x4^4 + 4*f3*x4^3*x5 - 4*f5*x4^3*x7 
    + 4*f6*x4^3*x8 - 4*x4^2*x6*x8 - x4^2*x7^2,
(3*f1^2*f7 + 8*f1*f2*f6 - f2^2*f5)*x1^4 + (4*f1*f2*f7 + 8*f1*f3*f6 - 
    2*f2*f3*f5)*x1^3*x2 + (24*f0*f5*f6 - 6*f1*f3*f7 - 12*f1*f4*f6 + 
    2*f1*f5^2 + 4*f2^2*f7 - 8*f2*f3*f6 + 4*f2*f4*f5)*x1^3*x3 + (-48*f0*f5*f7
    - 16*f1*f5*f6 + 8*f2*f4*f6 + 10*f2*f5^2)*x1^3*x4 + (4*f0*f5 + 
    2*f1*f4)*x1^3*x5 + (-16*f0*f6 - f1*f5 - f2*f4)*x1^3*x6 + (-12*f0*f7 - 
    8*f1*f6 + 4*f2*f5)*x1^3*x7 + (5*f1*f7 + 12*f2*f6 + 5*f3*f5 + 
    f4^2)*x1^3*x8 + (-12*f0*f5*f6 + 4*f1*f3*f7 + 10*f1*f4*f6 - f1*f5^2 - 
    3*f2*f4*f5 - f3^2*f5)*x1^2*x2^2 + (24*f0*f5*f7 - 12*f1*f4*f7 + 
    16*f1*f5*f6 + 4*f2*f3*f7 - 8*f2*f4*f6 - 6*f2*f5^2 - 8*f3^2*f6 + 
    4*f3*f4*f5)*x1^2*x2*x3 + (-64*f0*f6*f7 - 10*f1*f5*f7 + 16*f1*f6^2 - 
    8*f2*f5*f6 + 8*f3*f4*f6 - 2*f4^2*f5)*x1^2*x2*x4 + (16*f0*f6 - f1*f5 + 
    f2*f4)*x1^2*x2*x5 + (-8*f0*f7 - 10*f1*f6 + 3*f2*f5 - f3*f4)*x1^2*x2*x6 +
    (-9*f1*f7 - 8*f2*f6 - f3*f5 - f4^2)*x1^2*x2*x7 + (-6*f2*f7 + 22*f3*f6 - 
    f4*f5)*x1^2*x2*x8 + (28*f0*f6*f7 + 16*f1*f6^2 - 9*f2*f4*f7 - 6*f2*f5*f6 
    + 3*f3^2*f7 + 12*f3*f4*f6 - f3*f5^2 - 2*f4^2*f5)*x1^2*x3^2 + (96*f0*f7^2
    + 58*f1*f6*f7 - 32*f2*f5*f7 + 24*f2*f6^2 + 26*f3*f5*f6 - 10*f4^2*f6 - 
    12*f4*f5^2)*x1^2*x3*x4 + (-28*f0*f7 - 12*f1*f6 + 4*f2*f5 - 
    2*f3*f4)*x1^2*x3*x5 + (-6*f2*f7 - 6*f4*f5)*x1^2*x3*x7 + (-6*f3*f7 - 
    4*f4*f6 + 8*f5^2)*x1^2*x3*x8 + (87*f1*f7^2 + 68*f2*f6*f7 - 69*f3*f5*f7 -
    16*f4*f5*f6 - 16*f5^3)*x1^2*x4^2 + (-33*f1*f7 - 20*f2*f6 + 11*f3*f5 + 
    f4^2)*x1^2*x4*x5 + (8*f2*f7 - 16*f3*f6 + f4*f5)*x1^2*x4*x6 + (-24*f3*f7 
    - 8*f4*f6 - 14*f5^2)*x1^2*x4*x7 + (-8*f4*f7 - 58*f5*f6)*x1^2*x4*x8 + 
    2*f1*x1^2*x5^2 - f2*x1^2*x5*x6 + 4*f3*x1^2*x5*x7 + 3*f4*x1^2*x5*x8 - 
    f3*x1^2*x6^2 + f4*x1^2*x6*x7 - 5*f5*x1^2*x6*x8 - 3*f5*x1^2*x7^2 - 
    4*f6*x1^2*x7*x8 + 4*f7*x1^2*x8^2 + (-4*f0*f5*f7 + 6*f1*f4*f7 - 
    4*f1*f5*f6 + f2*f5^2 - 3*f3*f4*f5)*x1*x2^3 + (16*f0*f6*f7 + 3*f1*f5*f7 -
    8*f1*f6^2 + 6*f2*f4*f7 - 18*f3*f4*f6 - f3*f5^2 + 5*f4^2*f5)*x1*x2^2*x3 +
    (-32*f0*f7^2 + 12*f2*f5*f7 - 28*f3*f5*f6 + 10*f4^2*f6 + 
    13*f4*f5^2)*x1*x2^2*x4 + (8*f0*f7 + 4*f1*f6 - 2*f2*f5 + 
    f3*f4)*x1*x2^2*x5 + (-2*f1*f7 + f3*f5 - f4^2)*x1*x2^2*x6 + (2*f2*f7 - 
    14*f3*f6 + 6*f4*f5)*x1*x2^2*x7 + 24*f4*f6*x1*x2^2*x8 + (-4*f0*f7^2 - 
    2*f1*f6*f7 + 3*f2*f5*f7 - 4*f2*f6^2 + 3*f3*f4*f7 - 4*f3*f5*f6 + 
    12*f4^2*f6 + f4*f5^2)*x1*x2*x3^2 + (-16*f1*f7^2 - 12*f2*f6*f7 + 
    20*f3*f5*f7 + 28*f3*f6^2 - 2*f4^2*f7 + 22*f4*f5*f6 + 4*f5^3)*x1*x2*x3*x4
    + (3*f1*f7 - 3*f3*f5 - 3*f4^2)*x1*x2*x3*x5 + (-2*f4*f7 + 
    24*f5*f6)*x1*x2*x3*x8 + (30*f2*f7^2 + 34*f3*f6*f7 - 69*f4*f5*f7 + 
    16*f4*f6^2 + 96*f5^2*f6)*x1*x2*x4^2 + (-10*f2*f7 - 14*f3*f6 + 
    10*f4*f5)*x1*x2*x4*x5 + (-8*f3*f7 - 28*f4*f6 - 3*f5^2)*x1*x2*x4*x6 + 
    (-16*f4*f7 + 46*f5*f6)*x1*x2*x4*x7 + (-20*f5*f7 + 8*f6^2)*x1*x2*x4*x8 + 
    f2*x1*x2*x5^2 + f3*x1*x2*x5*x6 + 2*f5*x1*x2*x5*x8 - 8*f6*x1*x2*x6*x8 + 
    (-f1*f7^2 + 2*f2*f6*f7 + 3*f3*f5*f7 - 8*f3*f6^2 + 5*f4^2*f7 + 
    18*f4*f5*f6 + 2*f5^3)*x1*x3^3 + (-8*f2*f7^2 + 12*f3*f6*f7 + 25*f4*f5*f7 
    + 8*f4*f6^2 + 2*f5^2*f6)*x1*x3^2*x4 + (f2*f7 - 3*f4*f5)*x1*x3^2*x5 + 
    (-f3*f7 - 12*f4*f6 - 2*f5^2)*x1*x3^2*x6 + (7*f4*f7 + 6*f5*f6)*x1*x3^2*x7
    + (-2*f5*f7 + 8*f6^2)*x1*x3^2*x8 + (54*f3*f7^2 - 28*f4*f6*f7 - 
    10*f5^2*f7 - 44*f5*f6^2)*x1*x3*x4^2 + (-22*f3*f7 + 10*f4*f6 - 
    2*f5^2)*x1*x3*x4*x5 + (2*f5*f7 + 8*f6^2)*x1*x3*x4*x7 + 
    8*f6*f7*x1*x3*x4*x8 + 2*f3*x1*x3*x5^2 - f5*x1*x3*x6^2 + 2*f7*x1*x3*x7^2 
    + (24*f4*f7^2 - 214*f5*f6*f7)*x1*x4^3 + (3*f4*f7 + 54*f5*f6)*x1*x4^2*x5 
    + (49*f5*f7 - 16*f6^2)*x1*x4^2*x6 - 32*f6*f7*x1*x4^2*x7 - 
    60*f7^2*x1*x4^2*x8 - 3*f4*x1*x4*x5^2 - 8*f5*x1*x4*x5*x6 + 
    4*f6*x1*x4*x5*x7 + 16*f7*x1*x4*x5*x8 + 18*f6*x1*x4*x6^2 + 
    16*f7*x1*x4*x6*x7 - 3*x1*x5*x6*x7 + x1*x6^3 - 2*f4^2*f5*x2^4 + 
    (-10*f4^2*f6 - 3*f4*f5^2)*x2^3*x3 + (2*f4^2*f7 - 36*f4*f5*f6 - 
    3*f5^3)*x2^3*x4 + f4^2*x2^3*x5 + 2*f4*f5*x2^3*x6 + (-16*f4*f6 - 
    f5^2)*x2^3*x7 + (-2*f4^2*f7 - 4*f4*f5*f6)*x2^2*x3^2 + (10*f4*f5*f7 + 
    24*f4*f6^2 - 40*f5^2*f6)*x2^2*x3*x4 + (-2*f4*f7 - 16*f5*f6)*x2^2*x3*x7 +
    (40*f4*f6*f7 + 37*f5^2*f7 - 16*f5*f6^2)*x2^2*x4^2 - 12*f4*f6*x2^2*x4*x5 
    + (-8*f4*f7 + 4*f5*f6)*x2^2*x4*x6 + (16*f5*f7 - 8*f6^2)*x2^2*x4*x7 + 
    (-f4*f5*f7 - 4*f4*f6^2 + 6*f5^2*f6)*x2*x3^3 + (24*f4*f6*f7 - 9*f5^2*f7 +
    12*f5*f6^2)*x2*x3^2*x4 - f5^2*x2*x3^2*x5 + (-f5*f7 - 4*f6^2)*x2*x3^2*x7 
    + (10*f4*f7^2 + 20*f5*f6*f7 + 16*f6^3)*x2*x3*x4^2 + (-10*f4*f7 - 
    8*f5*f6)*x2*x3*x4*x5 + f4*x2*x3*x5^2 + 2*f5*x2*x3*x5*x6 - 
    6*f6*x2*x3*x6^2 + (-28*f5*f7^2 + 24*f6^2*f7)*x2*x4^3 + (4*f5*f7 - 
    8*f6^2)*x2*x4^2*x5 + 8*f6*f7*x2*x4^2*x6 - f5*x2*x4*x5^2 - 
    4*f6*x2*x4*x5*x6 + 6*f7*x2*x4*x6^2 - x2*x5^2*x7 - x2*x5*x6^2 - 
    2*f4*f6*f7*x3^4 + (8*f4*f7^2 + 10*f5*f6*f7)*x3^3*x4 - f4*f7*x3^3*x5 - 
    2*f6*f7*x3^3*x7 + (19*f5*f7^2 + 28*f6^2*f7)*x3^2*x4^2 - 
    9*f5*f7*x3^2*x4*x5 - 16*f6*f7*x3^2*x4*x6 + 6*f7^2*x3^2*x4*x7 + 
    2*f5*x3^2*x5^2 - f7*x3^2*x5*x7 + 48*f6*f7^2*x3*x4^3 - 
    28*f6*f7*x3*x4^2*x5 + 4*f6*x3*x4*x5^2 + 6*f7*x3*x4*x5*x6 - 2*x3*x5^2*x6 
    + 24*f7^3*x4^4 - 28*f7^2*x4^3*x5 + 13*f7*x4^2*x5^2 - 2*x4*x5^3,
(-8*f1^2*f6 + 6*f1*f2*f5 - 4*f2^2*f4)*x1^4 + (-8*f1*f2*f6 + 6*f1*f3*f5 + 
    2*f2^2*f5 - 8*f2*f3*f4)*x1^3*x2 + (-32*f0*f4*f6 + 24*f0*f5^2 + 
    2*f1*f2*f7 + 8*f1*f3*f6 - 10*f1*f4*f5 - 4*f2^2*f6 - 2*f2*f3*f5 + 
    8*f2*f4^2)*x1^3*x3 + (-48*f0*f4*f7 + 96*f0*f5*f6 - 12*f1*f3*f7 - 
    16*f1*f4*f6 - 12*f1*f5^2 + 8*f2^2*f7 + 10*f2*f4*f5)*x1^3*x4 + (16*f0*f4 
    + 4*f1*f3 - 2*f2^2)*x1^3*x5 + (-12*f0*f5 + 2*f1*f4 - 2*f2*f3)*x1^3*x6 + 
    (32*f0*f6 - 6*f1*f5 + 4*f2*f4)*x1^3*x7 + (-4*f0*f7 - 8*f1*f6 + 
    2*f2*f5)*x1^3*x8 + (16*f0*f4*f6 - 12*f0*f5^2 - 4*f1*f2*f7 - 4*f1*f3*f6 +
    8*f1*f4*f5 + 2*f2*f3*f5 - 8*f2*f4^2 - 4*f3^2*f4)*x1^2*x2^2 + 
    (-16*f0*f4*f7 - 48*f0*f5*f6 - 2*f1*f3*f7 + 16*f1*f4*f6 + 10*f1*f5^2 - 
    4*f2^2*f7 - 10*f2*f4*f5 - 2*f3^2*f5 + 8*f3*f4^2)*x1^2*x2*x3 + 
    (-16*f0*f5*f7 - 4*f1*f4*f7 + 28*f1*f5*f6 + 8*f2*f3*f7 - 24*f2*f4*f6 + 
    6*f2*f5^2 + 10*f3*f4*f5)*x1^2*x2*x4 + (4*f0*f5 + 2*f1*f4 - 
    2*f2*f3)*x1^2*x2*x5 + (16*f0*f6 - 8*f1*f5 + 6*f2*f4 - 2*f3^2)*x1^2*x2*x6
    + (4*f0*f7 + 16*f1*f6 - 2*f2*f5 + 4*f3*f4)*x1^2*x2*x7 + (2*f1*f7 + 
    4*f3*f5 - 8*f4^2)*x1^2*x2*x8 + (-8*f0*f5*f7 - 64*f0*f6^2 + 8*f1*f5*f6 - 
    4*f2*f3*f7 + 12*f2*f4*f6 - 4*f2*f5^2 + 6*f3*f4*f5 - 4*f4^3)*x1^2*x3^2 + 
    (-120*f0*f6*f7 - 10*f1*f5*f7 - 48*f1*f6^2 + 10*f2*f4*f7 + 36*f2*f5*f6 + 
    12*f3^2*f7 - 24*f3*f4*f6 + 28*f3*f5^2 - 14*f4^2*f5)*x1^2*x3*x4 + 
    (32*f0*f6 - 4*f3^2)*x1^2*x3*x5 + (-2*f1*f7 + 8*f2*f6 + 2*f3*f5 - 
    4*f4^2)*x1^2*x3*x7 + (8*f2*f7 + 2*f4*f5)*x1^2*x3*x8 + (84*f0*f7^2 - 
    136*f1*f6*f7 - 2*f2*f5*f7 - 60*f3*f4*f7 + 96*f3*f5*f6 - 8*f4^2*f6 - 
    4*f4*f5^2)*x1^2*x4^2 + (-52*f0*f7 + 40*f1*f6 + 20*f3*f4)*x1^2*x4*x5 + 
    (12*f1*f7 - 8*f2*f6 - 8*f3*f5 + 2*f4^2)*x1^2*x4*x6 + (-16*f2*f7 + 
    32*f3*f6 - 2*f4*f5)*x1^2*x4*x7 + (-26*f3*f7 + 28*f4*f6 - 
    48*f5^2)*x1^2*x4*x8 + 8*f0*x1^2*x5^2 - 4*f1*x1^2*x5*x6 + 4*f2*x1^2*x5*x7
    + 2*f3*x1^2*x5*x8 + 2*f2*x1^2*x6^2 + 2*f3*x1^2*x6*x7 - 2*f4*x1^2*x6*x8 -
    2*f5*x1^2*x7*x8 + (16*f0*f4*f7 + 8*f0*f5*f6 - 4*f1*f4*f6 - 2*f1*f5^2 + 
    2*f2*f4*f5 - 8*f3*f4^2)*x1*x2^3 + (12*f0*f5*f7 + 16*f0*f6^2 - 2*f1*f4*f7
    - 8*f1*f5*f6 - 12*f3*f4*f5 + 8*f4^3)*x1*x2^2*x3 + (32*f0*f6*f7 + 
    8*f1*f5*f7 - 12*f2*f4*f7 - 8*f2*f5*f6 - 4*f3*f4*f6 - 6*f3*f5^2 + 
    28*f4^2*f5)*x1*x2^2*x4 + (-8*f0*f6 + 2*f1*f5 - 2*f2*f4)*x1*x2^2*x5 + 
    (8*f0*f7 + 4*f1*f6 - 2*f2*f5 + 4*f3*f4)*x1*x2^2*x6 + (2*f1*f7 - 2*f3*f5 
    + 12*f4^2)*x1*x2^2*x7 + 12*f4*f5*x1*x2^2*x8 + (2*f1*f5*f7 - 4*f2*f5*f6 +
    4*f3*f4*f6 - 8*f3*f5^2 + 4*f4^2*f5)*x1*x2*x3^2 + (-32*f0*f7^2 + 
    16*f1*f6*f7 - 6*f2*f5*f7 - 16*f2*f6^2 + 14*f3*f4*f7 - 20*f3*f5*f6 - 
    16*f4^2*f6 + 16*f4*f5^2)*x1*x2*x3*x4 + (12*f0*f7 - 8*f3*f4)*x1*x2*x3*x5 
    + (-4*f4*f6 + 12*f5^2)*x1*x2*x3*x8 + (-18*f1*f7^2 - 32*f2*f6*f7 + 
    36*f3*f5*f7 - 76*f4^2*f7 + 60*f4*f5*f6 + 68*f5^3)*x1*x2*x4^2 + (6*f1*f7 
    + 8*f2*f6 - 2*f3*f5 + 26*f4^2)*x1*x2*x4*x5 + (-12*f2*f7 + 4*f3*f6 - 
    14*f4*f5)*x1*x2*x4*x6 + (18*f3*f7 + 20*f4*f6 + 34*f5^2)*x1*x2*x4*x7 + 
    (-16*f4*f7 + 32*f5*f6)*x1*x2*x4*x8 + 2*f2*x1*x2*x5*x6 + 2*f4*x1*x2*x5*x8
    + 4*f3*x1*x2*x6^2 - 2*f5*x1*x2*x6*x8 + (-4*f0*f7^2 + 6*f2*f5*f7 + 
    2*f3*f4*f7 - 8*f3*f5*f6 - 8*f4^2*f6 + 12*f4*f5^2)*x1*x3^3 + (-2*f1*f7^2 
    + 16*f2*f6*f7 - 8*f3*f5*f7 - 32*f3*f6^2 - 16*f4^2*f7 - 24*f4*f5*f6 - 
    4*f5^3)*x1*x3^2*x4 + (-2*f3*f5 + 2*f4^2)*x1*x3^2*x5 + (-4*f2*f7 - 
    12*f4*f5)*x1*x3^2*x6 + (4*f3*f7 - 12*f4*f6 + 4*f5^2)*x1*x3^2*x7 + 
    (-2*f4*f7 + 8*f5*f6)*x1*x3^2*x8 + (16*f2*f7^2 - 84*f3*f6*f7 - 
    96*f4*f5*f7 - 8*f4*f6^2 + 24*f5^2*f6)*x1*x3*x4^2 + (-6*f2*f7 + 12*f3*f6 
    + 24*f4*f5)*x1*x3*x4*x5 + (-6*f4*f7 + 12*f5*f6)*x1*x3*x4*x7 + (2*f5*f7 +
    16*f6^2)*x1*x3*x4*x8 + 6*f3*x1*x3*x5*x6 + 2*f4*x1*x3*x6^2 - 
    4*f6*x1*x3*x7^2 - 4*f7*x1*x3*x7*x8 + (-30*f3*f7^2 - 76*f4*f6*f7 - 
    88*f5^2*f7 + 96*f5*f6^2)*x1*x4^3 + (4*f3*f7 + 20*f4*f6 + 
    28*f5^2)*x1*x4^2*x5 + (62*f4*f7 - 92*f5*f6)*x1*x4^2*x6 + (26*f5*f7 + 
    32*f6^2)*x1*x4^2*x7 + 60*f6*f7*x1*x4^2*x8 + 2*f3*x1*x4*x5^2 - 
    20*f4*x1*x4*x5*x6 - 8*f5*x1*x4*x5*x7 - 8*f6*x1*x4*x5*x8 + 
    10*f5*x1*x4*x6^2 - 24*f6*x1*x4*x6*x7 + 12*f7*x1*x4*x6*x8 + 
    8*f7*x1*x4*x7^2 - 3*x1*x5*x6*x8 - 2*x1*x5*x7^2 - 2*x1*x6^2*x7 - 
    4*f4^3*x2^4 - 10*f4^2*f5*x2^3*x3 + (-4*f4^2*f6 - 22*f4*f5^2)*x2^3*x4 + 
    6*f4^2*x2^3*x6 - 10*f4*f5*x2^3*x7 + (4*f4^2*f6 - 2*f4*f5^2)*x2^2*x3^2 + 
    (18*f4^2*f7 + 12*f4*f5*f6 - 22*f5^3)*x2^2*x3*x4 - 4*f4^2*x2^2*x3*x5 + 
    (4*f4*f6 - 8*f5^2)*x2^2*x3*x7 + (76*f4*f5*f7 - 56*f5^2*f6)*x2^2*x4^2 - 
    12*f4*f5*x2^2*x4*x5 + (8*f4*f6 + 4*f5^2)*x2^2*x4*x6 + (20*f4*f7 - 
    24*f5*f6)*x2^2*x4*x7 + (2*f4^2*f7 - 4*f4*f5*f6 + 2*f5^3)*x2*x3^3 + 
    (10*f4*f5*f7 - 16*f4*f6^2 + 4*f5^2*f6)*x2*x3^2*x4 - 4*f4*f5*x2*x3^2*x5 +
    (2*f4*f7 - 4*f5*f6)*x2*x3^2*x7 + (-32*f4*f6*f7 + 18*f5^2*f7 + 
    16*f5*f6^2)*x2*x3*x4^2 - 2*f5^2*x2*x3*x4*x5 + 6*f4*x2*x3*x5*x6 + 
    (-40*f4*f7^2 + 48*f5*f6*f7)*x2*x4^3 + (2*f4*f7 - 8*f5*f6)*x2*x4^2*x5 + 
    2*f5*f7*x2*x4^2*x6 + 4*f6*f7*x2*x4^2*x7 + 4*f4*x2*x4*x5^2 - 
    4*f6*x2*x4*x6^2 + x2*x5*x6*x7 - 2*x2*x6^3 - 2*f4*f5*f7*x3^4 + 
    (-8*f4*f6*f7 - 16*f5*f6^2)*x3^3*x4 - 2*f5*f7*x3^3*x7 + (-12*f4*f7^2 - 
    20*f5*f6*f7 - 32*f6^3)*x3^2*x4^2 + (2*f4*f7 + 8*f5*f6)*x3^2*x4*x5 + 
    (-8*f5*f7 + 16*f6^2)*x3^2*x4*x6 - 8*f6*f7*x3^2*x4*x7 + f5*x3^2*x5*x6 + 
    (-2*f5*f7^2 - 72*f6^2*f7)*x3*x4^3 + 32*f6^2*x3*x4^2*x5 - 
    4*f7^2*x3*x4^2*x7 - 6*f6*x3*x4*x5*x6 + 2*f7*x3*x4*x5*x7 + 
    2*f7*x3*x4*x6^2 - x3*x5*x6^2 - 44*f6*f7^2*x4^4 + 36*f6*f7*x4^3*x5 - 
    12*f7^2*x4^3*x6 - 8*f6*x4^2*x5^2 + 7*f7*x4^2*x5*x6 - x4*x5^2*x6,
-10*f1^2*f6*x1^4 + (f1^2*f7 - 16*f1*f2*f6)*x1^3*x2 + (-f1*f2*f7 + 
    20*f1*f3*f6 + 2*f1*f4*f5 - 16*f2^2*f6)*x1^3*x3 + (120*f0*f5*f6 - 
    20*f1*f4*f6 - 2*f2^2*f7 + 6*f2*f4*f5)*x1^3*x4 - f1*f4*x1^3*x6 + 
    (40*f0*f6 + 2*f2*f4)*x1^3*x7 + (2*f0*f7 - 14*f1*f6 - 2*f2*f5 + 
    f3*f4)*x1^3*x8 + (2*f1*f2*f7 - 16*f1*f3*f6 - f1*f4*f5)*x1^2*x2^2 + 
    (-104*f0*f5*f6 - 3*f1*f3*f7 + 36*f1*f4*f6 - 6*f1*f5^2 + 2*f2^2*f7 - 
    16*f2*f3*f6 - 2*f2*f4*f5)*x1^2*x2*x3 + (-16*f0*f5*f7 - 2*f1*f4*f7 + 
    40*f1*f5*f6 - 4*f2*f3*f7 - 16*f2*f4*f6 - 14*f2*f5^2 + 
    4*f3*f4*f5)*x1^2*x2*x4 + f1*f4*x1^2*x2*x5 + (32*f0*f6 + 
    3*f1*f5)*x1^2*x2*x6 + (-6*f0*f7 + 30*f1*f6 - 4*f2*f5 + f3*f4)*x1^2*x2*x7
    + (4*f1*f7 + 20*f2*f6 - 5*f3*f5 + f4^2)*x1^2*x2*x8 + (-2*f0*f5*f7 - 
    168*f0*f6^2 - 14*f1*f5*f6 + f2*f3*f7 + 30*f2*f4*f6 + 2*f2*f5^2 - 
    10*f3^2*f6 - f3*f4*f5)*x1^2*x3^2 + (-364*f0*f6*f7 - 14*f1*f5*f7 - 
    108*f1*f6^2 - 5*f2*f4*f7 + 64*f2*f5*f6 + 22*f3*f4*f6 - 
    4*f4^2*f5)*x1^2*x3*x4 + (104*f0*f6 + 6*f1*f5 + 2*f2*f4)*x1^2*x3*x5 + 
    (f1*f7 + 20*f2*f6 - 2*f4^2)*x1^2*x3*x7 + (-6*f2*f7 + 4*f3*f6 + 
    10*f4*f5)*x1^2*x3*x8 + (-18*f0*f7^2 - 242*f1*f6*f7 - 10*f2*f5*f7 + 
    3*f3*f4*f7 + 120*f3*f5*f6 - 10*f4^2*f6 - 12*f4*f5^2)*x1^2*x4^2 + 
    (6*f0*f7 + 74*f1*f6 + 8*f2*f5 - f3*f4)*x1^2*x4*x5 + (2*f1*f7 - 20*f2*f6 
    - f4^2)*x1^2*x4*x6 + (40*f3*f6 - 10*f4*f5)*x1^2*x4*x7 + (2*f4*f6 + 
    24*f5^2)*x1^2*x4*x8 - f1*x1^2*x5*x6 + 2*f2*x1^2*x5*x7 + 2*f3*x1^2*x5*x8 
    - 2*f4*x1^2*x6*x8 - 2*f4*x1^2*x7^2 + 6*f5*x1^2*x7*x8 - 4*f6*x1^2*x8^2 + 
    (32*f0*f5*f6 + 2*f1*f3*f7 - 16*f1*f4*f6 + 3*f1*f5^2)*x1*x2^3 + 
    (14*f0*f5*f7 + 64*f0*f6^2 - 3*f1*f4*f7 + 2*f1*f5*f6 + 2*f2*f3*f7 - 
    16*f2*f4*f6 + 4*f2*f5^2 - f3*f4*f5)*x1*x2^2*x3 + (136*f0*f6*f7 + 
    4*f1*f5*f7 + 8*f1*f6^2 - 2*f2*f4*f7 - 52*f2*f5*f6 - 2*f3^2*f7 - 
    16*f3*f4*f6 - 8*f3*f5^2 + 3*f4^2*f5)*x1*x2^2*x4 + (-32*f0*f6 - 
    4*f1*f5)*x1*x2^2*x5 + (-4*f0*f7 + 12*f1*f6)*x1*x2^2*x6 + (-6*f1*f7 - 
    12*f2*f6 - f3*f5 + f4^2)*x1*x2^2*x7 + (-2*f2*f7 + 8*f3*f6 - 
    6*f4*f5)*x1*x2^2*x8 + (28*f0*f6*f7 - 2*f1*f5*f7 + 16*f1*f6^2 - f2*f4*f7 
    + 14*f2*f5*f6 + 2*f3^2*f7 - 6*f3*f4*f6 + 5*f3*f5^2 + f4^2*f5)*x1*x2*x3^2
    + (40*f0*f7^2 + 78*f1*f6*f7 + 9*f2*f5*f7 - 24*f2*f6^2 - 3*f3*f4*f7 - 
    66*f3*f5*f6 + 38*f4^2*f6 + 4*f4*f5^2)*x1*x2*x3*x4 + (-14*f0*f7 - 
    14*f1*f6 - 6*f2*f5 + f3*f4)*x1*x2*x3*x5 + (-6*f3*f7 - 4*f4*f6 - 
    11*f5^2)*x1*x2*x3*x8 + (40*f1*f7^2 - 92*f2*f6*f7 - 31*f3*f5*f7 + 
    140*f4*f5*f6 - 12*f5^3)*x1*x2*x4^2 + (-16*f1*f7 + 16*f2*f6 + 
    7*f3*f5)*x1*x2*x4*x5 + (6*f2*f7 + 12*f3*f6)*x1*x2*x4*x6 + (-4*f3*f7 + 
    58*f4*f6 - 6*f5^2)*x1*x2*x4*x7 + (-4*f4*f7 + 62*f5*f6)*x1*x2*x4*x8 + 
    f1*x1*x2*x5^2 + 2*f4*x1*x2*x5*x8 + 4*f5*x1*x2*x6*x8 + 4*f7*x1*x2*x8^2 + 
    (2*f0*f7^2 + 2*f1*f6*f7 - 5*f2*f5*f7 + 12*f2*f6^2 + 4*f3*f5*f6 - 
    14*f4^2*f6)*x1*x3^3 + (-3*f1*f7^2 + 52*f2*f6*f7 + 10*f3*f5*f7 - 
    80*f3*f6^2 + 6*f4^2*f7 - 66*f4*f5*f6 - 4*f5^3)*x1*x3^2*x4 + (f1*f7 - 
    14*f2*f6 - 4*f3*f5 - 2*f4^2)*x1*x3^2*x5 + (4*f2*f7 + 10*f3*f6 - 
    3*f4*f5)*x1*x3^2*x6 + (-f3*f7 - 26*f4*f6 - 2*f5^2)*x1*x3^2*x7 + (-f4*f7 
    - 14*f5*f6)*x1*x3^2*x8 + (-2*f2*f7^2 - 156*f3*f6*f7 + 2*f4*f5*f7 - 
    76*f4*f6^2 - 24*f5^2*f6)*x1*x3*x4^2 + (-5*f2*f7 + 44*f3*f6 - 
    4*f4*f5)*x1*x3*x4*x5 + (-5*f4*f7 - 56*f5*f6)*x1*x3*x4*x7 + (f5*f7 + 
    56*f6^2)*x1*x3*x4*x8 + 2*f2*x1*x3*x5^2 - f3*x1*x3*x5*x6 - 
    12*f6*x1*x3*x7^2 + (-24*f3*f7^2 - 194*f4*f6*f7 - 92*f5^2*f7 + 
    120*f5*f6^2)*x1*x4^3 + (14*f3*f7 + 58*f4*f6 + 24*f5^2)*x1*x4^2*x5 + 
    (-8*f4*f7 - 80*f5*f6)*x1*x4^2*x6 + (-66*f5*f7 + 40*f6^2)*x1*x4^2*x7 + 
    178*f6*f7*x1*x4^2*x8 - 2*f3*x1*x4*x5^2 + 2*f4*x1*x4*x5*x6 + 
    16*f5*x1*x4*x5*x7 - 40*f6*x1*x4*x5*x8 - 5*f5*x1*x4*x6^2 - 
    20*f6*x1*x4*x6*x7 - 6*f7*x1*x4*x6*x8 - 10*f7*x1*x4*x7^2 - 2*x1*x5*x6*x8 
    + 2*x1*x5*x7^2 - x1*x6^2*x7 + (-4*f0*f5*f7 + 2*f1*f4*f7 - 
    4*f1*f5*f6)*x2^4 + (-8*f0*f6*f7 + f1*f5*f7 - 8*f1*f6^2 + 2*f2*f4*f7 - 
    4*f2*f5*f6 + f3*f5^2 - f4^2*f5)*x2^3*x3 + (-8*f0*f7^2 - 8*f1*f6*f7 + 
    8*f2*f5*f7 - 2*f3*f4*f7 + 4*f3*f5*f6 - 16*f4^2*f6 - 4*f4*f5^2)*x2^3*x4 +
    (4*f0*f7 + 4*f1*f6)*x2^3*x5 - 2*f1*f7*x2^3*x6 + 2*f2*f7*x2^3*x7 + 
    (8*f4*f6 - f5^2)*x2^3*x8 + (-4*f0*f7^2 - 6*f1*f6*f7 - f2*f5*f7 - 
    8*f2*f6^2 + 2*f3*f4*f7 + 4*f4^2*f6 + 3*f4*f5^2)*x2^2*x3^2 + (-4*f1*f7^2 
    - 4*f2*f6*f7 + 11*f3*f5*f7 + 8*f3*f6^2 - 3*f4^2*f7 - 30*f4*f5*f6 + 
    10*f5^3)*x2^2*x3*x4 + (f1*f7 + 4*f2*f6 - 2*f3*f5 + f4^2)*x2^2*x3*x5 + 
    (2*f3*f7 + 4*f4*f6 + 5*f5^2)*x2^2*x3*x7 + 8*f5*f6*x2^2*x3*x8 + 
    (2*f2*f7^2 + 8*f3*f6*f7 - 10*f4*f5*f7 + 8*f4*f6^2 - 
    70*f5^2*f6)*x2^2*x4^2 + (-2*f2*f7 - 4*f3*f6 + 6*f4*f5)*x2^2*x4*x5 + 
    (2*f3*f7 + 24*f4*f6 + 3*f5^2)*x2^2*x4*x6 + (2*f4*f7 - 
    30*f5*f6)*x2^2*x4*x7 - 8*f5*f7*x2^2*x4*x8 + 2*f5*x2^2*x5*x8 - 
    8*f6*x2^2*x6*x8 + (-f1*f7^2 - 6*f2*f6*f7 + f3*f5*f7 - 4*f3*f6^2 + 
    8*f4*f5*f6 - f5^3)*x2*x3^3 + (10*f3*f6*f7 + 10*f4*f5*f7 - 20*f4*f6^2 + 
    28*f5^2*f6)*x2*x3^2*x4 + (f2*f7 - 5*f4*f5)*x2*x3^2*x5 + 
    8*f5*f6*x2*x3^2*x7 + (-f5*f7 + 4*f6^2)*x2*x3^2*x8 + (10*f3*f7^2 + 
    18*f4*f6*f7 - 3*f5^2*f7 + 28*f5*f6^2)*x2*x3*x4^2 + (-7*f3*f7 + 6*f4*f6 +
    f5^2)*x2*x3*x4*x5 - 16*f6*f7*x2*x3*x4*x8 + f3*x2*x3*x5^2 + f5*x2*x3*x6^2
    + (-24*f4*f7^2 + 114*f5*f6*f7)*x2*x4^3 + (14*f4*f7 - 
    14*f5*f6)*x2*x4^2*x5 + (10*f5*f7 - 8*f6^2)*x2*x4^2*x6 + 
    26*f6*f7*x2*x4^2*x7 - 12*f7^2*x2*x4^2*x8 - 2*f4*x2*x4*x5^2 + 
    8*f7*x2*x4*x5*x8 - 8*f6*x2*x4*x6^2 - x2*x5^2*x8 + 2*x2*x5*x6*x7 + 
    (-f2*f7^2 - 2*f3*f6*f7 + 3*f4*f5*f7 - 4*f4*f6^2)*x3^4 + (5*f3*f7^2 - 
    18*f4*f6*f7 + 23*f5^2*f7 - 28*f5*f6^2)*x3^3*x4 + (-f3*f7 + 2*f4*f6 - 
    6*f5^2)*x3^3*x5 + (3*f5*f7 - 4*f6^2)*x3^3*x7 + 2*f6*f7*x3^3*x8 + 
    (30*f4*f7^2 - 26*f5*f6*f7 - 40*f6^3)*x3^2*x4^2 + (-16*f4*f7 - 
    2*f5*f6)*x3^2*x4*x5 + (-19*f5*f7 + 16*f6^2)*x3^2*x4*x6 - 
    16*f6*f7*x3^2*x4*x7 - 6*f7^2*x3^2*x4*x8 + 2*f4*x3^2*x5^2 + 
    5*f5*x3^2*x5*x6 + 2*f6*x3^2*x5*x7 + f7*x3^2*x5*x8 + (99*f5*f7^2 - 
    116*f6^2*f7)*x3*x4^3 + (-65*f5*f7 + 32*f6^2)*x3*x4^2*x5 + 
    24*f7^2*x3*x4^2*x7 + 10*f5*x3*x4*x5^2 - 6*f6*x3*x4*x5*x6 - 
    15*f7*x3*x4*x5*x7 + 5*f7*x3*x4*x6^2 + 2*x3*x5^2*x7 + x3*x5*x6^2 - 
    94*f6*f7^2*x4^4 + 46*f6*f7*x4^3*x5 + 14*f7^2*x4^3*x6 - 6*f6*x4^2*x5^2 - 
    14*f7*x4^2*x5*x6 + 3*x4*x5^2*x6,
(-8*f1^2*f5 - 6*f1*f2*f4)*x1^4 + (-8*f1*f2*f5 - 6*f1*f3*f4)*x1^3*x2 + 
    (-24*f0*f4*f5 + 2*f1^2*f7 + 4*f1*f2*f6 + 14*f1*f3*f5 + 6*f1*f4^2 - 
    10*f2^2*f5 + 6*f2*f3*f4)*x1^3*x3 + (96*f0*f5^2 + 8*f1*f2*f7 - 4*f1*f4*f5
    - 6*f2*f3*f5 - 6*f2*f4^2)*x1^3*x4 - 2*f1*f2*x1^3*x5 + (12*f0*f4 + 
    f1*f3)*x1^3*x6 + (32*f0*f5 + 6*f1*f4 - 2*f2*f3)*x1^3*x7 + (-8*f0*f6 - 
    10*f1*f5 - 4*f2*f4 - f3^2)*x1^3*x8 + (12*f0*f4*f5 - 4*f1^2*f7 - 
    7*f1*f3*f5 - 6*f1*f4^2)*x1^2*x2^2 + (-64*f0*f5^2 - 4*f1*f2*f7 + 
    4*f1*f3*f6 + 18*f1*f4*f5 - 10*f2*f3*f5 + 6*f2*f4^2 + 
    6*f3^2*f4)*x1^2*x2*x3 + (48*f0*f4*f7 + 16*f0*f5*f6 + 12*f1*f3*f7 - 
    12*f1*f4*f6 + 20*f1*f5^2 - 6*f2*f4*f5 - 4*f3^2*f5 - 
    6*f3*f4^2)*x1^2*x2*x4 + (-12*f0*f4 - 3*f1*f3)*x1^2*x2*x5 + (16*f0*f5 + 
    6*f1*f4)*x1^2*x2*x6 + (8*f0*f6 + 18*f1*f5 + 4*f2*f4 - f3^2)*x1^2*x2*x7 +
    (8*f0*f7 - 4*f1*f6 + 8*f2*f5 - 11*f3*f4)*x1^2*x2*x8 + (12*f0*f4*f7 - 
    104*f0*f5*f6 - 3*f1*f3*f7 + 4*f1*f4*f6 + 2*f1*f5^2 - 2*f2*f3*f6 + 
    18*f2*f4*f5 - 7*f3^2*f5 - 6*f3*f4^2)*x1^2*x3^2 + (-240*f0*f5*f7 - 
    16*f0*f6^2 + 14*f1*f4*f7 - 68*f1*f5*f6 - 4*f2*f4*f6 + 48*f2*f5^2 - 
    2*f3^2*f6 - 16*f3*f4*f5 + 6*f4^3)*x1^2*x3*x4 + (64*f0*f5 - 
    2*f1*f4)*x1^2*x3*x5 + (-8*f0*f7 - 4*f1*f6 + 16*f2*f5 - 
    4*f3*f4)*x1^2*x3*x7 + (4*f1*f7 + 4*f3*f5 - 6*f4^2)*x1^2*x3*x8 + 
    (-24*f0*f6*f7 - 170*f1*f5*f7 - 28*f2*f4*f7 - 3*f3^2*f7 + 108*f3*f5^2 + 
    4*f4^2*f5)*x1^2*x4^2 + (8*f0*f6 + 50*f1*f5 + 8*f2*f4 + f3^2)*x1^2*x4*x5 
    + (-16*f0*f7 + 2*f2*f5 + 13*f3*f4)*x1^2*x4*x6 + (-8*f1*f7 + 42*f3*f5 + 
    6*f4^2)*x1^2*x4*x7 + (-8*f2*f7 + 4*f3*f6 + 24*f4*f5)*x1^2*x4*x8 + 
    4*f0*x1^2*x5*x6 + 2*f1*x1^2*x5*x7 - 2*f1*x1^2*x6^2 + 4*f2*x1^2*x6*x7 + 
    6*f3*x1^2*x6*x8 + 2*f3*x1^2*x7^2 + (16*f0*f5^2 - 8*f1*f4*f5)*x1*x2^3 + 
    (-24*f0*f4*f7 + 32*f0*f5*f6 + 2*f1*f3*f7 - 6*f1*f5^2 - 10*f2*f4*f5 - 
    f3^2*f5 + 12*f3*f4^2)*x1*x2^2*x3 + (80*f0*f5*f7 - 12*f1*f4*f7 + 
    12*f1*f5*f6 - 34*f2*f5^2 + 15*f3*f4*f5 - 6*f4^3)*x1*x2^2*x4 + (-12*f0*f5
    - 2*f1*f4)*x1*x2^2*x5 + 6*f1*f5*x1*x2^2*x6 + (8*f0*f7 + 4*f1*f6 - 
    8*f2*f5 + 9*f3*f4)*x1*x2^2*x7 + (f3*f5 - 10*f4^2)*x1*x2^2*x8 + 
    (8*f0*f5*f7 + 4*f1*f4*f7 + 2*f2*f3*f7 - 4*f2*f4*f6 - 2*f3^2*f6 - 
    7*f3*f4*f5 - 6*f4^3)*x1*x2*x3^2 + (-16*f0*f6*f7 + 32*f1*f5*f7 + 
    8*f2*f4*f7 - 20*f2*f5*f6 - 4*f3^2*f7 - 6*f3*f4*f6 - 
    36*f3*f5^2)*x1*x2*x3*x4 + (8*f0*f6 - 4*f1*f5 + f3^2)*x1*x2*x3*x5 + 
    2*f3*f6*x1*x2*x3*x8 + (-40*f0*f7^2 + 4*f1*f6*f7 - 48*f2*f5*f7 + 
    3*f3*f4*f7 - 20*f3*f5*f6 - 12*f4^2*f6 + 60*f4*f5^2)*x1*x2*x4^2 + 
    (24*f0*f7 + 8*f2*f5 + 2*f3*f4)*x1*x2*x4*x5 + (-12*f1*f7 + 13*f3*f5 + 
    18*f4^2)*x1*x2*x4*x6 + (-8*f3*f6 + 22*f4*f5)*x1*x2*x4*x7 + (6*f3*f7 - 
    12*f4*f6 + 48*f5^2)*x1*x2*x4*x8 - 4*f0*x1*x2*x5^2 + 4*f1*x1*x2*x5*x6 + 
    4*f4*x1*x2*x6*x8 + (2*f1*f5*f7 + 2*f2*f4*f7 + f3^2*f7 - 6*f3*f4*f6 - 
    6*f3*f5^2 - 18*f4^2*f5)*x1*x3^3 + (16*f0*f7^2 + 4*f1*f6*f7 + 10*f2*f5*f7
    - 9*f3*f4*f7 - 40*f3*f5*f6 - 8*f4^2*f6 - 32*f4*f5^2)*x1*x3^2*x4 + 
    (-4*f0*f7 - 2*f2*f5 + 4*f3*f4)*x1*x3^2*x5 + (-2*f1*f7 + 9*f3*f5 + 
    10*f4^2)*x1*x3^2*x6 + (2*f3*f6 - 18*f4*f5)*x1*x3^2*x7 + (-f3*f7 + 
    8*f4*f6 + 6*f5^2)*x1*x3^2*x8 + (20*f1*f7^2 - 106*f3*f5*f7 + 8*f3*f6^2 + 
    18*f4^2*f7 + 24*f4*f5*f6 + 40*f5^3)*x1*x3*x4^2 + (-6*f1*f7 - 4*f2*f6 + 
    26*f3*f5 - 2*f4^2)*x1*x3*x4*x5 + (-6*f3*f7 + 12*f4*f6 - 
    8*f5^2)*x1*x3*x4*x7 + 28*f5*f6*x1*x3*x4*x8 + 2*f2*x1*x3*x5*x6 - 
    3*f3*x1*x3*x6^2 - 6*f5*x1*x3*x7^2 + (8*f2*f7^2 + 12*f3*f6*f7 + 
    52*f4*f5*f7 + 96*f5^2*f6)*x1*x4^3 + (-8*f2*f7 - 4*f3*f6 - 
    20*f4*f5)*x1*x4^2*x5 + (6*f3*f7 + 12*f4*f6 - 100*f5^2)*x1*x4^2*x6 + 
    (40*f4*f7 + 32*f5*f6)*x1*x4^2*x7 + (138*f5*f7 + 8*f6^2)*x1*x4^2*x8 + 
    2*f2*x1*x4*x5^2 - 3*f3*x1*x4*x5*x6 - 12*f4*x1*x4*x5*x7 - 
    16*f5*x1*x4*x5*x8 - 12*f4*x1*x4*x6^2 - 42*f5*x1*x4*x6*x7 + 
    8*f6*x1*x4*x6*x8 + 8*f7*x1*x4*x7*x8 - 4*x1*x6*x7^2 + (-f3*f4*f5 + 
    6*f4^3)*x2^3*x3 + (-3*f3*f5^2 + 18*f4^2*f5)*x2^3*x4 + (-f3*f5 + 
    10*f4^2)*x2^3*x7 - 2*f3*f4*f6*x2^2*x3^2 + (-2*f3*f4*f7 - 6*f3*f5*f6 - 
    8*f4^2*f6 - 10*f4*f5^2)*x2^2*x3*x4 + f3*f4*x2^2*x3*x5 + (-2*f3*f6 + 
    6*f4*f5)*x2^2*x3*x7 + (-5*f3*f5*f7 - 14*f4^2*f7 + 4*f4*f5*f6 - 
    68*f5^3)*x2^2*x4^2 + (f3*f5 + 2*f4^2)*x2^2*x4*x5 + 14*f4*f5*x2^2*x4*x6 +
    (-2*f3*f7 + 4*f4*f6 - 30*f5^2)*x2^2*x4*x7 + (-f3*f4*f7 - 4*f4^2*f6 - 
    2*f4*f5^2)*x2*x3^3 + (-3*f3*f5*f7 - 14*f4^2*f7 - 40*f4*f5*f6 + 
    8*f5^3)*x2*x3^2*x4 + (f3*f5 + 4*f4^2)*x2*x3^2*x5 + (-f3*f7 - 4*f4*f6 - 
    2*f5^2)*x2*x3^2*x7 + (2*f3*f6*f7 - 26*f4*f5*f7 - 16*f4*f6^2 + 
    24*f5^2*f6)*x2*x3*x4^2 + (2*f3*f6 + 14*f4*f5)*x2*x3*x4*x5 - 
    f3*x2*x3*x5*x6 + 2*f4*x2*x3*x6^2 + (2*f3*f7^2 - 20*f4*f6*f7 + 16*f5^2*f7
    - 16*f5*f6^2)*x2*x4^3 + (2*f3*f7 + 8*f4*f6 - 12*f5^2)*x2*x4^2*x5 + 
    (-12*f4*f7 + 4*f5*f6)*x2*x4^2*x6 + (-18*f5*f7 - 8*f6^2)*x2*x4^2*x7 - 
    f3*x2*x4*x5^2 + 6*f4*x2*x4*x5*x6 - 20*f5*x2*x4*x6^2 - 4*x2*x6^2*x7 + 
    (-2*f4^2*f7 + 2*f5^3)*x3^4 + (-34*f4*f5*f7 - 16*f5^2*f6)*x3^3*x4 + 
    6*f4*f5*x3^3*x5 - 2*f4*f7*x3^3*x7 + (f3*f7^2 - 40*f4*f6*f7 - 20*f5^2*f7 
    - 32*f5*f6^2)*x3^2*x4^2 + (12*f4*f6 + 14*f5^2)*x3^2*x4*x5 + (18*f4*f7 + 
    28*f5*f6)*x3^2*x4*x6 - 14*f5*f7*x3^2*x4*x7 - 6*f4*x3^2*x5*x6 + 
    2*f5*x3^2*x5*x7 + (-48*f4*f7^2 - 72*f5*f6*f7 + 16*f6^3)*x3*x4^3 + 
    (36*f4*f7 + 52*f5*f6)*x3*x4^2*x5 - 8*f6*f7*x3*x4^2*x7 - 6*f4*x3*x4*x5^2 
    - 18*f5*x3*x4*x5*x6 + 4*f6*x3*x4*x5*x7 + 4*f7*x3*x4*x6*x7 - 
    2*x3*x5*x6*x7 - 2*x3*x6^3 + (-18*f5*f7^2 + 24*f6^2*f7)*x4^4 + (50*f5*f7 
    - 8*f6^2)*x4^3*x5 + 8*f6*f7*x4^3*x6 - 8*f7^2*x4^3*x7 - 16*f5*x4^2*x5^2 -
    4*f6*x4^2*x5*x6 + 8*f7*x4^2*x5*x7 + 8*f7*x4^2*x6^2 - 2*x4*x5^2*x7 - 
    2*x4*x5*x6^2,
(-20*f1^2*f5 - 10*f1*f2*f4)*x1^4 + (-8*f1^2*f6 - 16*f1*f2*f5 - 
    10*f1*f3*f4)*x1^3*x2 + (-40*f0*f4*f5 - 6*f1^2*f7 - 4*f1*f2*f6 + 
    34*f1*f3*f5 + 10*f1*f4^2 - 14*f2^2*f5 + 10*f2*f3*f4)*x1^3*x3 + 
    (240*f0*f5^2 - 12*f1*f2*f7 - 20*f1*f4*f5 + 8*f2^2*f6 - 18*f2*f3*f5 - 
    10*f2*f4^2)*x1^3*x4 + 2*f1*f2*x1^3*x5 + (20*f0*f4 + 3*f1*f3)*x1^3*x6 + 
    (80*f0*f5 + 10*f1*f4 - 6*f2*f3)*x1^3*x7 + (8*f0*f6 - 30*f1*f5 - 24*f2*f4
    - 3*f3^2)*x1^3*x8 + (20*f0*f4*f5 + 4*f1^2*f7 - 8*f1*f2*f6 - 13*f1*f3*f5 
    - 10*f1*f4^2)*x1^2*x2^2 + (-144*f0*f5^2 + 12*f1*f3*f6 + 22*f1*f4*f5 - 
    8*f2^2*f6 - 6*f2*f3*f5 + 10*f2*f4^2 + 10*f3^2*f4)*x1^2*x2*x3 + 
    (80*f0*f4*f7 + 80*f0*f5*f6 - 36*f1*f4*f6 + 52*f1*f5^2 + 16*f2*f3*f6 - 
    50*f2*f4*f5 - 12*f3^2*f5 - 10*f3*f4^2)*x1^2*x2*x4 + (-20*f0*f4 - 
    f1*f3)*x1^2*x2*x5 + (32*f0*f5 + 22*f1*f4)*x1^2*x2*x6 + (24*f0*f6 + 
    46*f1*f5 - 3*f3^2)*x1^2*x2*x7 + (-12*f1*f6 + 12*f2*f5 - 
    49*f3*f4)*x1^2*x2*x8 + (20*f0*f4*f7 - 200*f0*f5*f6 + 15*f1*f3*f7 - 
    52*f1*f4*f6 - 2*f1*f5^2 - 4*f2^2*f7 + 10*f2*f3*f6 + 42*f2*f4*f5 - 
    17*f3^2*f5 - 10*f3*f4^2)*x1^2*x3^2 + (-464*f0*f5*f7 + 80*f0*f6^2 - 
    74*f1*f4*f7 - 188*f1*f5*f6 + 36*f2*f3*f7 - 68*f2*f4*f6 + 80*f2*f5^2 - 
    6*f3^2*f6 - 8*f3*f4*f5 + 10*f4^3)*x1^2*x3*x4 + (144*f0*f5 + 26*f1*f4 - 
    8*f2*f3)*x1^2*x3*x5 + (24*f0*f7 - 12*f1*f6 + 24*f2*f5 - 
    4*f3*f4)*x1^2*x3*x7 + (-8*f1*f7 + 16*f2*f6 - 4*f3*f5 + 
    14*f4^2)*x1^2*x3*x8 + (120*f0*f6*f7 - 406*f1*f5*f7 - 124*f2*f4*f7 - 
    80*f2*f5*f6 - 9*f3^2*f7 + 276*f3*f5^2)*x1^2*x4^2 + (-40*f0*f6 + 
    126*f1*f5 + 36*f2*f4 + 3*f3^2)*x1^2*x4*x5 + (24*f0*f7 + 8*f1*f6 - 
    18*f2*f5 + 23*f3*f4)*x1^2*x4*x6 + (-12*f1*f7 - 32*f2*f6 + 110*f3*f5 + 
    10*f4^2)*x1^2*x4*x7 + (-32*f2*f7 + 12*f3*f6 + 136*f4*f5)*x1^2*x4*x8 - 
    4*f0*x1^2*x5*x6 + 6*f1*x1^2*x5*x7 + 4*f2*x1^2*x5*x8 - 2*f1*x1^2*x6^2 + 
    6*f3*x1^2*x6*x8 + 6*f3*x1^2*x7^2 + 24*f4*x1^2*x7*x8 - 4*f5*x1^2*x8^2 + 
    (32*f0*f5^2 - 8*f1*f3*f6 - 4*f1*f4*f5)*x1*x2^3 + (-40*f0*f4*f7 - 
    14*f1*f3*f7 + 48*f1*f4*f6 - 2*f1*f5^2 - 8*f2*f3*f6 - 2*f2*f4*f5 + 
    5*f3^2*f5 + 20*f3*f4^2)*x1*x2^2*x3 + (104*f0*f5*f7 - 32*f0*f6^2 + 
    24*f1*f4*f7 + 60*f1*f5*f6 + 8*f2*f4*f6 - 46*f2*f5^2 + 8*f3^2*f6 + 
    5*f3*f4*f5 - 10*f4^3)*x1*x2^2*x4 + (-36*f0*f5 - 10*f1*f4)*x1*x2^2*x5 + 
    (16*f0*f6 + 10*f1*f5)*x1*x2^2*x6 + (-16*f0*f7 + 28*f1*f6 - 8*f2*f5 + 
    19*f3*f4)*x1*x2^2*x7 + (12*f1*f7 + 8*f2*f6 - f3*f5 - 46*f4^2)*x1*x2^2*x8
    + (32*f0*f5*f7 - 96*f0*f6^2 - 4*f1*f4*f7 + 16*f1*f5*f6 - 14*f2*f3*f7 + 
    44*f2*f4*f6 + 4*f2*f5^2 + 2*f3^2*f6 - 5*f3*f4*f5 - 10*f4^3)*x1*x2*x3^2 +
    (-160*f0*f6*f7 + 84*f1*f5*f7 - 64*f1*f6^2 + 72*f2*f4*f7 + 12*f2*f5*f6 + 
    24*f3^2*f7 - 82*f3*f4*f6 - 84*f3*f5^2 + 16*f4^2*f5)*x1*x2*x3*x4 + 
    (56*f0*f6 - 12*f1*f5 - 12*f2*f4 - 5*f3^2)*x1*x2*x3*x5 + (12*f2*f7 - 
    2*f3*f6 - 56*f4*f5)*x1*x2*x3*x8 + (96*f0*f7^2 - 140*f1*f6*f7 - 
    72*f2*f5*f7 + 32*f2*f6^2 - 107*f3*f4*f7 - 44*f3*f5*f6 - 28*f4^2*f6 + 
    124*f4*f5^2)*x1*x2*x4^2 + (-40*f0*f7 + 40*f1*f6 + 28*f2*f5 + 
    38*f3*f4)*x1*x2*x4*x5 + (-24*f2*f6 + 23*f3*f5 + 42*f4^2)*x1*x2*x4*x6 + 
    (24*f2*f7 - 24*f3*f6 + 42*f4*f5)*x1*x2*x4*x7 + (-50*f3*f7 + 12*f4*f6 + 
    80*f5^2)*x1*x2*x4*x8 + 4*f0*x1*x2*x5^2 + 4*f3*x1*x2*x5*x8 + 
    24*f4*x1*x2*x6*x8 + (-48*f0*f6*f7 + 10*f1*f5*f7 - 6*f2*f4*f7 + 
    32*f2*f5*f6 - 9*f3^2*f7 + 46*f3*f4*f6 - 26*f3*f5^2 - 38*f4^2*f5)*x1*x3^3
    + (-120*f0*f7^2 - 20*f1*f6*f7 + 50*f2*f5*f7 + 48*f2*f6^2 + 73*f3*f4*f7 -
    88*f3*f5*f6 - 16*f4^2*f6 - 72*f4*f5^2)*x1*x3^2*x4 + (36*f0*f7 - 10*f2*f5
    - 20*f3*f4)*x1*x3^2*x5 + (-6*f1*f7 - 24*f2*f6 + 31*f3*f5 + 
    10*f4^2)*x1*x3^2*x6 + (4*f2*f7 + 6*f3*f6 - 38*f4*f5)*x1*x3^2*x7 + 
    (17*f3*f7 - 48*f4*f6 + 10*f5^2)*x1*x3^2*x8 + (-84*f1*f7^2 + 16*f2*f6*f7 
    - 214*f3*f5*f7 + 88*f3*f6^2 + 14*f4^2*f7 - 56*f4*f5*f6 + 
    136*f5^3)*x1*x3*x4^2 + (26*f1*f7 - 20*f2*f6 + 70*f3*f5 + 
    2*f4^2)*x1*x3*x4*x5 + (18*f3*f7 - 12*f4*f6 + 8*f5^2)*x1*x3*x4*x7 + 
    (-40*f4*f7 + 4*f5*f6)*x1*x3*x4*x8 + 2*f2*x1*x3*x5*x6 - f3*x1*x3*x6^2 - 
    10*f5*x1*x3*x7^2 - 8*f6*x1*x3*x7*x8 - 8*f7*x1*x3*x8^2 + (-144*f2*f7^2 + 
    132*f3*f6*f7 - 188*f4*f5*f7 + 368*f5^2*f6)*x1*x4^3 + (64*f2*f7 - 
    44*f3*f6 + 60*f4*f5)*x1*x4^2*x5 + (54*f3*f7 + 28*f4*f6 - 
    204*f5^2)*x1*x4^2*x6 + (-20*f4*f7 + 192*f5*f6)*x1*x4^2*x7 + (246*f5*f7 -
    40*f6^2)*x1*x4^2*x8 - 6*f2*x1*x4*x5^2 - 13*f3*x1*x4*x5*x6 + 
    12*f4*x1*x4*x5*x7 - 56*f5*x1*x4*x5*x8 - 32*f4*x1*x4*x6^2 - 
    62*f5*x1*x4*x6*x7 + 8*f6*x1*x4*x6*x8 + 24*f6*x1*x4*x7^2 + 
    8*f7*x1*x4*x7*x8 + 4*x1*x6^2*x8 + (16*f0*f5*f6 - 8*f1*f4*f6 - 
    4*f1*f5^2)*x2^4 + (8*f0*f5*f7 + 32*f0*f6^2 - 4*f1*f4*f7 - 16*f1*f5*f6 - 
    8*f2*f4*f6 - 4*f2*f5^2 + 5*f3*f4*f5 + 10*f4^3)*x2^3*x3 + (32*f0*f6*f7 - 
    8*f1*f5*f7 - 32*f2*f5*f6 + 8*f3*f4*f6 + 15*f3*f5^2 + 26*f4^2*f5)*x2^3*x4
    + (-16*f0*f6 + 4*f1*f5)*x2^3*x5 + 8*f1*f6*x2^3*x6 + (-4*f1*f7 - 8*f2*f6 
    + 5*f3*f5 + 22*f4^2)*x2^3*x7 + 4*f4*f5*x2^3*x8 + (32*f0*f6*f7 - 
    4*f1*f5*f7 - 4*f2*f4*f7 - 8*f2*f5*f6 + 2*f3*f4*f6 - 4*f3*f5^2 + 
    8*f4^2*f5)*x2^2*x3^2 + (16*f0*f7^2 + 32*f1*f6*f7 - 16*f2*f5*f7 - 
    16*f2*f6^2 + 14*f3*f4*f7 - 2*f3*f5*f6 - 40*f4^2*f6 + 
    10*f4*f5^2)*x2^2*x3*x4 + (-8*f0*f7 + 4*f2*f5 - 5*f3*f4)*x2^2*x3*x5 + 
    (-4*f2*f7 + 2*f3*f6 + 26*f4*f5)*x2^2*x3*x7 + 8*f5^2*x2^2*x3*x8 + 
    (28*f1*f7^2 - 8*f2*f6*f7 + 17*f3*f5*f7 - 78*f4^2*f7 + 4*f4*f5*f6 - 
    120*f5^3)*x2^2*x4^2 + (-12*f1*f7 + 8*f2*f6 - f3*f5 + 26*f4^2)*x2^2*x4*x5
    + (-8*f3*f6 + 30*f4*f5)*x2^2*x4*x6 + (14*f3*f7 - 4*f4*f6 - 
    50*f5^2)*x2^2*x4*x7 + (-24*f4*f7 + 16*f5*f6)*x2^2*x4*x8 + 
    4*f4*x2^2*x5*x8 - 4*f5*x2^2*x6*x8 + (8*f0*f7^2 - 4*f2*f5*f7 + f3*f4*f7 -
    8*f3*f5*f6 + 20*f4^2*f6 - 14*f4*f5^2)*x2*x3^3 + (12*f1*f7^2 - 5*f3*f5*f7
    - 32*f3*f6^2 + 18*f4^2*f7 - 24*f4*f5*f6 - 16*f5^3)*x2*x3^2*x4 + (-f3*f5 
    - 16*f4^2)*x2*x3^2*x5 + (f3*f7 + 20*f4*f6 - 14*f5^2)*x2*x3^2*x7 + 
    8*f5*f6*x2*x3^2*x8 + (12*f2*f7^2 - 82*f3*f6*f7 - 54*f4*f5*f7 + 
    16*f4*f6^2 + 24*f5^2*f6)*x2*x3*x4^2 + (-4*f2*f7 + 14*f3*f6 + 
    26*f4*f5)*x2*x3*x4*x5 + (-20*f5*f7 + 32*f6^2)*x2*x3*x4*x8 + 
    5*f3*x2*x3*x5*x6 + 14*f4*x2*x3*x6^2 + (-54*f3*f7^2 + 28*f4*f6*f7 + 
    88*f5^2*f7 + 16*f5*f6^2)*x2*x4^3 + (18*f3*f7 - 16*f4*f6 + 
    4*f5^2)*x2*x4^2*x5 + (44*f4*f7 - 12*f5*f6)*x2*x4^2*x6 + (6*f5*f7 + 
    8*f6^2)*x2*x4^2*x7 + 32*f6*f7*x2*x4^2*x8 + f3*x2*x4*x5^2 - 
    10*f4*x2*x4*x5*x6 - 16*f6*x2*x4*x5*x8 - 20*f5*x2*x4*x6^2 + 
    24*f7*x2*x4*x6*x8 - 4*x2*x5*x6*x8 - 4*x2*x5*x7^2 - 4*x2*x6^2*x7 + 
    (-4*f3*f5*f7 + 10*f4^2*f7 - 8*f4*f5*f6 + 6*f5^3)*x3^4 + (4*f2*f7^2 - 
    16*f3*f6*f7 + 30*f4*f5*f7 - 32*f4*f6^2 - 64*f5^2*f6)*x3^3*x4 - 
    14*f4*f5*x3^3*x5 + (10*f4*f7 - 8*f5*f6)*x3^3*x7 + 4*f5*f7*x3^3*x8 + 
    (-21*f3*f7^2 - 24*f4*f6*f7 - 44*f5^2*f7 - 192*f5*f6^2)*x3^2*x4^2 + 
    (4*f3*f7 - 4*f4*f6 + 10*f5^2)*x3^2*x4*x5 + (-42*f4*f7 + 
    76*f5*f6)*x3^2*x4*x6 + (-14*f5*f7 - 32*f6^2)*x3^2*x4*x7 + 
    16*f6*f7*x3^2*x4*x8 + 22*f4*x3^2*x5*x6 + 6*f5*x3^2*x5*x7 + (52*f4*f7^2 -
    376*f5*f6*f7 - 16*f6^3)*x3*x4^3 + (-56*f4*f7 + 140*f5*f6)*x3*x4^2*x5 - 
    64*f6*f7*x3*x4^2*x7 + 24*f7^2*x3*x4^2*x8 + 14*f4*x3*x4*x5^2 - 
    6*f5*x3*x4*x5*x6 + 36*f6*x3*x4*x5*x7 - 4*f7*x3*x4*x5*x8 - 
    24*f7*x3*x4*x6*x7 + 2*x3*x5*x6*x7 - 6*x3*x6^3 + (-170*f5*f7^2 - 
    24*f6^2*f7)*x4^4 + (102*f5*f7 + 8*f6^2)*x4^3*x5 - 16*f6*f7*x4^3*x6 - 
    24*f7^2*x4^3*x7 - 16*f5*x4^2*x5^2 + 12*f6*x4^2*x5*x6 + 28*f7*x4^2*x5*x7 
    - 20*f7*x4^2*x6^2 - 6*x4*x5^2*x7 + 2*x4*x5*x6^2,
(3*f1^2*f4 - f1*f2*f3)*x1^4 + (3*f1^2*f5 + 5*f1*f2*f4 - f1*f3^2)*x1^3*x2 + 
    (-4*f0*f3*f5 + 4*f1^2*f6 - 6*f1*f2*f5 - 5*f1*f3*f4 + 5*f2^2*f4 + 
    f2*f3^2)*x1^3*x3 + (-36*f0*f4*f5 + 6*f1^2*f7 + 2*f1*f3*f5 + 6*f1*f4^2 - 
    13*f2^2*f5 - f2*f3*f4)*x1^3*x4 - 2*f1^2*x1^3*x5 + (2*f0*f3 + 
    3*f1*f2)*x1^3*x6 + (-12*f0*f4 + f1*f3 - 3*f2^2)*x1^3*x7 + (8*f0*f5 + 
    3*f1*f4 - 4*f2*f3)*x1^3*x8 + (2*f0*f3*f5 + 6*f1*f2*f5 + 
    4*f1*f3*f4)*x1^2*x2^2 + (32*f0*f4*f5 + 4*f1^2*f7 + 4*f1*f2*f6 - 
    13*f1*f3*f5 - 11*f1*f4^2 + 6*f2^2*f5 + 6*f2*f3*f4 + f3^3)*x1^2*x2*x3 + 
    (8*f0*f3*f7 - 52*f0*f5^2 + 11*f1*f2*f7 - 2*f1*f3*f6 - 4*f1*f4*f5 - 
    19*f2*f3*f5 + 5*f2*f4^2 - f3^2*f4)*x1^2*x2*x4 + (-2*f0*f3 - 
    2*f1*f2)*x1^2*x2*x5 + (-10*f0*f4 + 4*f1*f3)*x1^2*x2*x6 + (-20*f0*f5 - 
    8*f1*f4 - 2*f2*f3)*x1^2*x2*x7 + (-8*f0*f6 + 9*f1*f5 - 8*f2*f4 - 
    5*f3^2)*x1^2*x2*x8 + (2*f0*f3*f7 + 52*f0*f4*f6 + 4*f1*f2*f7 - 8*f1*f3*f6
    + 3*f1*f4*f5 + 4*f2^2*f6 + 3*f2*f3*f5 - 10*f2*f4^2 + 
    2*f3^2*f4)*x1^2*x3^2 + (108*f0*f4*f7 - 40*f0*f5*f6 - 11*f1*f3*f7 + 
    38*f1*f4*f6 + 10*f1*f5^2 + 11*f2^2*f7 - 8*f2*f3*f6 - 12*f2*f4*f5 - 
    6*f3^2*f5 - 5*f3*f4^2)*x1^2*x3*x4 + (-32*f0*f4 + 4*f1*f3 - 
    2*f2^2)*x1^2*x3*x5 + (-8*f0*f6 + 2*f1*f5 - 4*f2*f4 - f3^2)*x1^2*x3*x7 + 
    (-12*f0*f7 - 4*f1*f6 - 10*f2*f5)*x1^2*x3*x8 + (-60*f0*f5*f7 + 
    81*f1*f4*f7 - 16*f2*f3*f7 + 46*f2*f5^2 - 34*f3*f4*f5 + 3*f4^3)*x1^2*x4^2
    + (20*f0*f5 - 25*f1*f4 + 5*f2*f3)*x1^2*x4*x5 + (-5*f1*f5 + 9*f2*f4 + 
    2*f3^2)*x1^2*x4*x6 + (-12*f0*f7 + 24*f2*f5 - 11*f3*f4)*x1^2*x4*x7 + 
    (-3*f1*f7 + 8*f2*f6 + 21*f3*f5 - 3*f4^2)*x1^2*x4*x8 + 4*f0*x1^2*x5*x7 - 
    2*f0*x1^2*x6^2 - f1*x1^2*x6*x7 + 2*f2*x1^2*x6*x8 + 2*f2*x1^2*x7^2 + 
    2*f3*x1^2*x7*x8 + 2*f4*x1^2*x8^2 + (-10*f0*f4*f5 - 4*f1^2*f7 + 
    6*f1*f3*f5 + 5*f1*f4^2)*x1*x2^3 + (-4*f0*f3*f7 - 20*f0*f4*f6 + 
    32*f0*f5^2 - 8*f1*f2*f7 + 4*f1*f3*f6 - 13*f1*f4*f5 + 6*f2*f3*f5 + 
    5*f2*f4^2 + 2*f3^2*f4)*x1*x2^2*x3 + (-40*f0*f4*f7 + 20*f0*f5*f6 + 
    9*f1*f3*f7 - 2*f1*f4*f6 - 23*f1*f5^2 + 7*f2*f4*f5 - 2*f3^2*f5 + 
    4*f3*f4^2)*x1*x2^2*x4 + (10*f0*f4 - 2*f1*f3)*x1*x2^2*x5 + (-10*f0*f5 - 
    2*f1*f4)*x1*x2^2*x6 + (4*f0*f6 - 13*f1*f5 + 2*f2*f4 + 2*f3^2)*x1*x2^2*x7
    + (12*f0*f7 - 4*f2*f5 - 8*f3*f4)*x1*x2^2*x8 + (-2*f0*f4*f7 + 52*f0*f5*f6
    - 4*f1*f3*f7 - 12*f1*f4*f6 + f1*f5^2 - 4*f2^2*f7 + 4*f2*f3*f6 - 
    9*f2*f4*f5 + 6*f3^2*f5)*x1*x2*x3^2 + (96*f0*f5*f7 - 16*f0*f6^2 - 
    20*f1*f4*f7 + 38*f1*f5*f6 + 13*f2*f3*f7 + 8*f2*f4*f6 - 26*f2*f5^2 - 
    8*f3^2*f6 + 12*f3*f4*f5 - 11*f4^3)*x1*x2*x3*x4 + (-32*f0*f5 + 6*f1*f4 - 
    2*f2*f3)*x1*x2*x3*x5 + (2*f1*f7 - 12*f3*f5 + 2*f4^2)*x1*x2*x3*x8 + 
    (-24*f0*f6*f7 + 63*f1*f5*f7 + 31*f2*f4*f7 - 20*f2*f5*f6 - 11*f3^2*f7 - 
    2*f3*f4*f6 - 30*f3*f5^2 - 31*f4^2*f5)*x1*x2*x4^2 + (8*f0*f6 - 20*f1*f5 -
    5*f2*f4 + 4*f3^2)*x1*x2*x4*x5 + (-14*f0*f7 - 2*f1*f6 + 15*f2*f5 + 
    2*f3*f4)*x1*x2*x4*x6 + (-4*f2*f6 - 12*f3*f5 - 14*f4^2)*x1*x2*x4*x7 + 
    (-9*f2*f7 - 13*f4*f5)*x1*x2*x4*x8 + 2*f0*x1*x2*x5*x6 - f1*x1*x2*x6^2 + 
    2*f3*x1*x2*x6*x8 + (16*f0*f6^2 - 4*f1*f4*f7 - 4*f1*f5*f6 - 4*f2*f3*f7 - 
    8*f2*f4*f6 - 8*f2*f5^2 + 4*f3^2*f6 - f3*f4*f5 + 5*f4^3)*x1*x3^3 + 
    (24*f0*f6*f7 - 4*f1*f5*f7 + 8*f1*f6^2 - 22*f2*f4*f7 - 34*f2*f5*f6 + 
    7*f3^2*f7 + 20*f3*f4*f6 - 3*f3*f5^2 + 16*f4^2*f5)*x1*x3^2*x4 + (-8*f0*f6
    + 4*f2*f4 - 2*f3^2)*x1*x3^2*x5 + (6*f0*f7 + 4*f1*f6 + 9*f2*f5 - 
    2*f3*f4)*x1*x3^2*x6 + (-2*f1*f7 - 4*f2*f6 - f3*f5 + 7*f4^2)*x1*x3^2*x7 +
    (2*f2*f7 + f4*f5)*x1*x3^2*x8 + (18*f1*f6*f7 - 54*f2*f5*f7 + 16*f2*f6^2 +
    41*f3*f4*f7 - 18*f3*f5*f6 + 22*f4^2*f6 - 28*f4*f5^2)*x1*x3*x4^2 + 
    (-4*f1*f6 + 18*f2*f5 - 11*f3*f4)*x1*x3*x4*x5 + (-4*f3*f6 - 
    2*f4*f5)*x1*x3*x4*x7 + (-11*f3*f7 - 28*f4*f6 + 12*f5^2)*x1*x3*x4*x8 - 
    f2*x1*x3*x6^2 + 3*f4*x1*x3*x7^2 + (9*f1*f7^2 + 24*f2*f6*f7 - 13*f3*f5*f7
    + 57*f4^2*f7 - 36*f4*f5*f6 - 40*f5^3)*x1*x4^3 + (-3*f1*f7 - 8*f2*f6 + 
    5*f3*f5 - 17*f4^2)*x1*x4^2*x5 + (13*f2*f7 + 2*f3*f6 + 
    19*f4*f5)*x1*x4^2*x6 + (-2*f3*f7 - 12*f4*f6 - 30*f5^2)*x1*x4^2*x7 + 
    (-52*f4*f7 - 10*f5*f6)*x1*x4^2*x8 - 3*f2*x1*x4*x5*x6 + f3*x1*x4*x5*x7 + 
    11*f4*x1*x4*x5*x8 - 4*f3*x1*x4*x6^2 + 5*f4*x1*x4*x6*x7 - f5*x1*x4*x6*x8 
    - 3*f5*x1*x4*x7^2 - 6*f6*x1*x4*x7*x8 + 4*f7*x1*x4*x8^2 + 2*x1*x5*x8^2 + 
    3*x1*x6*x7*x8 + x1*x7^3 + (-8*f0*f5^2 + 6*f1*f4*f5)*x2^4 + (-16*f0*f5*f6
    + 4*f1*f4*f6 + 4*f1*f5^2 + 6*f2*f4*f5 + f3*f4^2)*x2^3*x3 + (-10*f0*f5*f7
    + f1*f4*f7 + 16*f2*f5^2 - 2*f3*f4*f5 + 5*f4^3)*x2^3*x4 + (8*f0*f5 - 
    2*f1*f4)*x2^3*x5 - 4*f1*f5*x2^3*x6 + (4*f2*f5 + 2*f3*f4)*x2^3*x7 - 
    3*f4^2*x2^3*x8 + (-12*f0*f5*f7 + 4*f1*f4*f7 + 4*f2*f4*f6 + 6*f3*f4*f5 - 
    2*f4^3)*x2^2*x3^2 + (12*f0*f6*f7 - 5*f1*f5*f7 + f2*f4*f7 + 8*f2*f5*f6 - 
    8*f3*f4*f6 + 16*f3*f5^2 + 2*f4^2*f5)*x2^2*x3*x4 - 2*f2*f4*x2^2*x3*x5 + 
    (2*f1*f7 + 6*f3*f5 - f4^2)*x2^2*x3*x7 - 6*f4*f5*x2^2*x3*x8 + (12*f0*f7^2
    - 8*f2*f5*f7 - 7*f3*f4*f7 - 2*f4^2*f6 + 4*f4*f5^2)*x2^2*x4^2 + (-6*f0*f7
    - 4*f2*f5 + 4*f3*f4)*x2^2*x4*x5 + (3*f1*f7 + 4*f3*f5 - 
    6*f4^2)*x2^2*x4*x6 + (-3*f2*f7 + 2*f4*f5)*x2^2*x4*x7 - 6*f5^2*x2^2*x4*x8
    + 2*f4*x2^2*x6*x8 + (-8*f0*f6*f7 + 4*f2*f4*f7 + 4*f3*f4*f6 - f3*f5^2 + 
    3*f4^2*f5)*x2*x3^3 + (-2*f0*f7^2 - 8*f1*f6*f7 + 10*f2*f5*f7 - 5*f3*f4*f7
    + 4*f3*f5*f6 + 17*f4*f5^2)*x2*x3^2*x4 + (4*f0*f7 - 2*f3*f4)*x2*x3^2*x5 +
    (2*f2*f7 + 6*f4*f5)*x2*x3^2*x7 - f5^2*x2*x3^2*x8 + (-7*f1*f7^2 - 
    6*f2*f6*f7 + f3*f5*f7 - 14*f4^2*f7 - 2*f4*f5*f6)*x2*x3*x4^2 + (4*f1*f7 -
    2*f3*f5 + f4^2)*x2*x3*x4*x5 + (9*f4*f7 - 8*f5*f6)*x2*x3*x4*x8 + 
    f3*x2*x3*x6^2 + (-3*f2*f7^2 - 29*f4*f5*f7 - 20*f5^2*f6)*x2*x4^3 + 
    (3*f2*f7 + 4*f4*f5)*x2*x4^2*x5 + (-3*f3*f7 + 7*f5^2)*x2*x4^2*x6 + 
    (-7*f4*f7 - 22*f5*f6)*x2*x4^2*x7 - 2*f5*f7*x2*x4^2*x8 + f4*x2*x4*x6^2 - 
    6*f6*x2*x4*x7^2 - 2*x2*x5*x7*x8 + x2*x6^2*x8 - x2*x6*x7^2 + (-4*f0*f7^2 
    + 4*f3*f4*f7 + 4*f4^2*f6)*x3^4 + (-4*f1*f7^2 + 3*f3*f5*f7 + 11*f4^2*f7 +
    16*f4*f5*f6 + 10*f5^3)*x3^3*x4 - 2*f4^2*x3^3*x5 + (2*f3*f7 + 4*f4*f6 + 
    2*f5^2)*x3^3*x7 + (-2*f4*f7 + 4*f5*f6)*x3^3*x8 + (-5*f2*f7^2 - 
    8*f3*f6*f7 + 30*f4*f5*f7 + 4*f4*f6^2 + 42*f5^2*f6)*x3^2*x4^2 - 
    8*f4*f5*x3^2*x4*x5 + (7*f3*f7 + 4*f4*f6 - 10*f5^2)*x3^2*x4*x6 + (2*f4*f7
    + 16*f5*f6)*x3^2*x4*x7 + (5*f5*f7 + 8*f6^2)*x3^2*x4*x8 - 4*f6*x3^2*x6*x8
    + (-11*f3*f7^2 + 28*f4*f6*f7 + 26*f5^2*f7 + 20*f5*f6^2)*x3*x4^3 + 
    (4*f3*f7 - 6*f4*f6 - 14*f5^2)*x3*x4^2*x5 + (-10*f5*f7 + 
    12*f6^2)*x3*x4^2*x7 + 28*f6*f7*x3*x4^2*x8 - 4*f6*x3*x4*x5*x8 - 
    9*f7*x3*x4*x6*x8 - 7*f7*x3*x4*x7^2 + 2*x3*x5*x7^2 - 2*x3*x6^2*x7 + 
    (36*f4*f7^2 + 30*f5*f6*f7)*x4^4 + (-17*f4*f7 - 10*f5*f6)*x4^3*x5 - 
    f5*f7*x4^3*x6 + 18*f6*f7*x4^3*x7 + 20*f7^2*x4^3*x8 + 2*f4*x4^2*x5^2 - 
    2*f5*x4^2*x5*x6 - 6*f6*x4^2*x5*x7 - 8*f7*x4^2*x5*x8 + 2*f6*x4^2*x6^2 - 
    2*f7*x4^2*x6*x7,
-7*f1^2*f5*x1^3*x2 - 2*f1*f2*f5*x1^3*x3 + 7*f2^2*f5*x1^3*x4 - f1*f2*x1^3*x6 
    + f2^2*x1^3*x7 + (8*f0*f5 + f1*f4 + 2*f2*f3)*x1^3*x8 + (-2*f1^2*f6 - 
    5*f1*f2*f5)*x1^2*x2^2 + (-3*f1^2*f7 - 6*f1*f2*f6 + 14*f1*f3*f5 - 
    5*f2^2*f5)*x1^2*x2*x3 + (68*f0*f5^2 - 7*f1*f2*f7 - 16*f1*f4*f5 + 
    16*f2*f3*f5)*x1^2*x2*x4 + f1*f2*x1^2*x2*x5 - 2*f1*f3*x1^2*x2*x6 + 
    (20*f0*f5 - f1*f4 + 2*f2*f3)*x1^2*x2*x7 + (12*f0*f6 - 10*f1*f5 + 2*f2*f4
    + 3*f3^2)*x1^2*x2*x8 + (-8*f0*f5^2 - 3*f1*f2*f7 + 4*f1*f3*f6 + 
    3*f1*f4*f5 - 4*f2^2*f6 + 2*f2*f3*f5)*x1^2*x3^2 + (24*f0*f5*f6 + 
    6*f1*f3*f7 - 2*f1*f4*f6 - 2*f1*f5^2 - 7*f2^2*f7 + 4*f2*f3*f6 - 
    14*f2*f4*f5)*x1^2*x3*x4 + (-2*f1*f3 + f2^2)*x1^2*x3*x5 + (-8*f0*f6 + 
    6*f1*f5 - 2*f2*f4)*x1^2*x3*x7 + (8*f0*f7 + 6*f1*f6 + 6*f2*f5 - 
    4*f3*f4)*x1^2*x3*x8 + (36*f0*f5*f7 - 3*f1*f4*f7 + 6*f2*f3*f7 - 
    46*f2*f5^2)*x1^2*x4^2 + (-12*f0*f5 + f1*f4 - 2*f2*f3)*x1^2*x4*x5 + 
    (5*f1*f5 - 2*f2*f4)*x1^2*x4*x6 + (-12*f0*f7 - 12*f2*f5)*x1^2*x4*x7 + 
    (8*f1*f7 - 6*f2*f6 - 3*f3*f5 + 2*f4^2)*x1^2*x4*x8 + 4*f0*x1^2*x5*x7 + 
    f1*x1^2*x5*x8 - f1*x1^2*x6*x7 + 2*f2*x1^2*x7^2 + (4*f1^2*f7 - 
    6*f1*f3*f5)*x1*x2^3 + (-36*f0*f5^2 + 8*f1*f2*f7 - 4*f1*f3*f6 + 
    19*f1*f4*f5 - 6*f2*f3*f5)*x1*x2^2*x3 + (-4*f0*f5*f6 - 11*f1*f3*f7 - 
    2*f1*f4*f6 + 19*f1*f5^2 + 10*f2*f4*f5 + 7*f3^2*f5)*x1*x2^2*x4 + 
    2*f1*f3*x1*x2^2*x5 + (8*f0*f5 - 2*f1*f4)*x1*x2^2*x6 + (13*f1*f5 + 
    2*f2*f4)*x1*x2^2*x7 + (-12*f0*f7 + 4*f2*f5 + 6*f3*f4)*x1*x2^2*x8 + 
    (-64*f0*f5*f6 + 4*f1*f3*f7 + 10*f1*f4*f6 + 4*f2^2*f7 - 4*f2*f3*f6 + 
    12*f2*f4*f5 - 6*f3^2*f5)*x1*x2*x3^2 + (-104*f0*f5*f7 + 24*f0*f6^2 + 
    5*f1*f4*f7 - 52*f1*f5*f6 - 11*f2*f3*f7 - 2*f2*f4*f6 + 26*f2*f5^2 + 
    6*f3^2*f6 + 4*f3*f4*f5)*x1*x2*x3*x4 + (32*f0*f5 - 3*f1*f4 + 
    2*f2*f3)*x1*x2*x3*x5 + (-2*f1*f7 + 10*f3*f5 - 2*f4^2)*x1*x2*x3*x8 + 
    (36*f0*f6*f7 - 94*f1*f5*f7 - 5*f2*f4*f7 - 8*f2*f5*f6 + 9*f3^2*f7 + 
    32*f3*f5^2 - 11*f4^2*f5)*x1*x2*x4^2 + (-12*f0*f6 + 23*f1*f5 - 
    3*f3^2)*x1*x2*x4*x5 + (6*f0*f7 + 6*f1*f6 - 12*f2*f5 - 
    3*f3*f4)*x1*x2*x4*x6 + (-9*f1*f7 - 6*f2*f6 + 9*f3*f5 - 
    2*f4^2)*x1*x2*x4*x7 + (9*f2*f7 - 2*f3*f6 - 4*f4*f5)*x1*x2*x4*x8 - 
    2*f3*x1*x2*x6*x8 + (8*f0*f5*f7 - 16*f0*f6^2 + 3*f1*f4*f7 + 2*f1*f5*f6 + 
    4*f2*f3*f7 + 8*f2*f4*f6 + 10*f2*f5^2 - 4*f3^2*f6 - 4*f3*f4*f5)*x1*x3^3 +
    (11*f1*f5*f7 - 12*f1*f6^2 + 10*f2*f4*f7 + 40*f2*f5*f6 - 6*f3^2*f7 - 
    9*f3*f5^2 + 9*f4^2*f5)*x1*x3^2*x4 + (3*f1*f5 - 2*f2*f4 + 
    2*f3^2)*x1*x3^2*x5 + (-4*f0*f7 - 2*f1*f6 - 10*f2*f5 + 
    2*f3*f4)*x1*x3^2*x6 + (f1*f7 + 4*f2*f6 - 4*f3*f5 + f4^2)*x1*x3^2*x7 + 
    (-2*f2*f7 + 4*f4*f5)*x1*x3^2*x8 + (36*f0*f7^2 + 2*f1*f6*f7 + 40*f2*f5*f7
    - 12*f2*f6^2 + 26*f3*f5*f6 + 40*f4*f5^2)*x1*x3*x4^2 + (-24*f0*f7 + 
    4*f1*f6 - 12*f2*f5)*x1*x3*x4*x5 + (-6*f2*f7 + 16*f4*f5)*x1*x3*x4*x7 + 
    (9*f3*f7 + 18*f4*f6 + 2*f5^2)*x1*x3*x4*x8 + 4*f0*x1*x3*x5^2 - 
    3*f1*x1*x3*x5*x6 + 2*f2*x1*x3*x5*x7 - 2*f4*x1*x3*x7^2 + 3*f5*x1*x3*x7*x8
    + (30*f1*f7^2 - 18*f2*f6*f7 + 39*f3*f5*f7 + 64*f5^3)*x1*x4^3 + 
    (-13*f1*f7 + 6*f2*f6 - 13*f3*f5)*x1*x4^2*x5 + (-3*f2*f7 + 
    7*f4*f5)*x1*x4^2*x6 + 38*f5^2*x1*x4^2*x7 + (6*f4*f7 + 
    32*f5*f6)*x1*x4^2*x8 + f1*x1*x4*x5^2 + f3*x1*x4*x6^2 - 10*f5*x1*x4*x6*x8
    - 3*f5*x1*x4*x7^2 + 8*f6*x1*x4*x7*x8 - 4*f7*x1*x4*x8^2 - 2*x1*x5*x8^2 - 
    7*x1*x6*x7*x8 - 3*x1*x7^3 + (8*f0*f5^2 - 6*f1*f4*f5)*x2^4 + (16*f0*f5*f6
    - 4*f1*f4*f6 - 4*f1*f5^2 - 6*f2*f4*f5)*x2^3*x3 + (10*f0*f5*f7 - f1*f4*f7
    - 16*f2*f5^2 + 7*f3*f4*f5)*x2^3*x4 + (-8*f0*f5 + 2*f1*f4)*x2^3*x5 + 
    4*f1*f5*x2^3*x6 - 4*f2*f5*x2^3*x7 + 3*f4^2*x2^3*x8 + (12*f0*f5*f7 - 
    4*f1*f4*f7 - 4*f2*f4*f6 - 6*f3*f4*f5)*x2^2*x3^2 + (-12*f0*f6*f7 + 
    5*f1*f5*f7 - f2*f4*f7 - 8*f2*f5*f6 + 6*f3*f4*f6 - 11*f3*f5^2 + 
    6*f4^2*f5)*x2^2*x3*x4 + 2*f2*f4*x2^2*x3*x5 + (-2*f1*f7 - 4*f3*f5 - 
    2*f4^2)*x2^2*x3*x7 + 6*f4*f5*x2^2*x3*x8 + (-12*f0*f7^2 + 8*f2*f5*f7 + 
    3*f3*f4*f7 + 4*f3*f5*f6 + 35*f4*f5^2)*x2^2*x4^2 + (6*f0*f7 + 4*f2*f5 - 
    3*f3*f4)*x2^2*x4*x5 + (-3*f1*f7 - 5*f3*f5 - 3*f4^2)*x2^2*x4*x6 + 
    (3*f2*f7 + 2*f3*f6 + 14*f4*f5)*x2^2*x4*x7 + 6*f5^2*x2^2*x4*x8 - 
    2*f4*x2^2*x6*x8 + (8*f0*f6*f7 - 4*f2*f4*f7 - 4*f3*f4*f6 - 
    7*f4^2*f5)*x2*x3^3 + (2*f0*f7^2 + 8*f1*f6*f7 - 10*f2*f5*f7 + 4*f3*f4*f7 
    - 8*f3*f5*f6 + 10*f4^2*f6 - 44*f4*f5^2)*x2*x3^2*x4 + (-4*f0*f7 + 
    2*f3*f4)*x2*x3^2*x5 + (-2*f2*f7 - 14*f4*f5)*x2*x3^2*x7 + f5^2*x2*x3^2*x8
    + (7*f1*f7^2 + 6*f2*f6*f7 - 6*f3*f5*f7 - 4*f3*f6^2 + 12*f4^2*f7 - 
    12*f4*f5*f6)*x2*x3*x4^2 + (-4*f1*f7 + 3*f3*f5 - 4*f4^2)*x2*x3*x4*x5 + 
    (-9*f4*f7 + 8*f5*f6)*x2*x3*x4*x8 + (3*f2*f7^2 - 6*f3*f6*f7 - 22*f4*f5*f7
    + 24*f5^2*f6)*x2*x4^3 + (-3*f2*f7 + 2*f3*f6 + 3*f4*f5)*x2*x4^2*x5 + 
    (f3*f7 + 4*f4*f6 - 19*f5^2)*x2*x4^2*x6 + (-3*f4*f7 + 
    36*f5*f6)*x2*x4^2*x7 + 2*f5*f7*x2*x4^2*x8 + f3*x2*x4*x5*x6 + 
    2*f4*x2*x4*x6^2 + 12*f6*x2*x4*x7^2 + 2*x2*x5*x7*x8 - x2*x6^2*x8 + 
    3*x2*x6*x7^2 + (4*f0*f7^2 - 4*f3*f4*f7 - 4*f4^2*f6)*x3^4 + (4*f1*f7^2 - 
    4*f3*f5*f7 - 3*f4^2*f7 - 8*f4*f5*f6 - 20*f5^3)*x3^3*x4 + f4^2*x3^3*x5 + 
    (-2*f3*f7 - 4*f4*f6 - 5*f5^2)*x3^3*x7 + (2*f4*f7 - 4*f5*f6)*x3^3*x8 + 
    (5*f2*f7^2 + 6*f3*f6*f7 + 5*f4*f5*f7 + 12*f4*f6^2 - 
    64*f5^2*f6)*x3^2*x4^2 + 2*f4*f5*x3^2*x4*x5 + (-6*f3*f7 - 12*f4*f6 + 
    19*f5^2)*x3^2*x4*x6 + (8*f4*f7 - 28*f5*f6)*x3^2*x4*x7 + (-5*f5*f7 - 
    8*f6^2)*x3^2*x4*x8 - 2*f4*x3^2*x5*x7 + 4*f6*x3^2*x6*x8 + (9*f3*f7^2 + 
    18*f4*f6*f7 - 40*f5^2*f7 - 24*f5*f6^2)*x3*x4^3 + (-3*f3*f7 - 6*f4*f6 + 
    20*f5^2)*x3*x4^2*x5 + (13*f5*f7 - 24*f6^2)*x3*x4^2*x7 - 
    28*f6*f7*x3*x4^2*x8 - f5*x3*x4*x5*x7 + 4*f6*x3*x4*x5*x8 + 
    9*f7*x3*x4*x6*x8 + 9*f7*x3*x4*x7^2 - 3*x3*x5*x7^2 + 5*x3*x6^2*x7 - 
    36*f5*f6*f7*x4^4 + 12*f5*f6*x4^3*x5 + 12*f5*f7*x4^3*x6 - 
    36*f6*f7*x4^3*x7 - 20*f7^2*x4^3*x8 - f5*x4^2*x5*x6 + 12*f6*x4^2*x5*x7 + 
    8*f7*x4^2*x5*x8 - 4*f6*x4^2*x6^2 - 2*f7*x4^2*x6*x7 + x4*x5*x6*x7 + 
    x4*x6^3,
3*f1^2*f5*x1^3*x2 + 2*f1^2*f6*x1^3*x3 + (3*f1^2*f7 - 4*f2^2*f5)*x1^3*x4 - 
    f1^2*x1^3*x5 + f1*f2*x1^3*x6 - f2^2*x1^3*x7 + (-4*f0*f5 - f1*f4 - 
    f2*f3)*x1^3*x8 + 2*f1*f2*f5*x1^2*x2^2 + (2*f1^2*f7 + 2*f1*f2*f6 - 
    6*f1*f3*f5 + 2*f2^2*f5)*x1^2*x2*x3 + (-28*f0*f5^2 + 5*f1*f2*f7 + 
    8*f1*f4*f5 - 6*f2*f3*f5)*x1^2*x2*x4 - f1*f2*x1^2*x2*x5 + 
    f1*f3*x1^2*x2*x6 + (-8*f0*f5 + f1*f4 - f2*f3)*x1^2*x2*x7 + (-4*f0*f6 + 
    4*f1*f5 - f2*f4 - f3^2)*x1^2*x2*x8 + (4*f0*f5^2 + 2*f1*f2*f7 - 
    4*f1*f3*f6 - f1*f4*f5 + 2*f2^2*f6 - f2*f3*f5)*x1^2*x3^2 + (-16*f0*f5*f6 
    - 6*f1*f3*f7 + 2*f1*f4*f6 + 2*f1*f5^2 + 5*f2^2*f7 - 2*f2*f3*f6 + 
    8*f2*f4*f5)*x1^2*x3*x4 + (2*f1*f3 - f2^2)*x1^2*x3*x5 + (-2*f1*f5 + 
    2*f2*f4)*x1^2*x3*x7 + (-4*f0*f7 - 2*f1*f6 - 2*f2*f5 + 
    2*f3*f4)*x1^2*x3*x8 + (-24*f0*f5*f7 + 3*f1*f4*f7 - 3*f2*f3*f7 + 
    22*f2*f5^2)*x1^2*x4^2 + (8*f0*f5 - f1*f4 + f2*f3)*x1^2*x4*x5 + (-3*f1*f5
    + f2*f4)*x1^2*x4*x6 + 8*f2*f5*x1^2*x4*x7 + (-f1*f7 + 2*f2*f6 - f3*f5 - 
    f4^2)*x1^2*x4*x8 + (-2*f1^2*f7 + 2*f1*f3*f5)*x1*x2^3 + (12*f0*f5^2 - 
    4*f1*f2*f7 + 2*f1*f3*f6 - 8*f1*f4*f5 + 2*f2*f3*f5)*x1*x2^2*x3 + 
    (5*f1*f3*f7 - 7*f1*f5^2 - 4*f2*f4*f5 - 2*f3^2*f5)*x1*x2^2*x4 - 
    f1*f3*x1*x2^2*x5 + (-2*f0*f5 + f1*f4)*x1*x2^2*x6 + (-5*f1*f5 - 
    f2*f4)*x1*x2^2*x7 + (4*f0*f7 - f2*f5 - 2*f3*f4)*x1*x2^2*x8 + 
    (24*f0*f5*f6 - 2*f1*f3*f7 - 6*f1*f4*f6 - 2*f2^2*f7 + 2*f2*f3*f6 - 
    5*f2*f4*f5 + 2*f3^2*f5)*x1*x2*x3^2 + (40*f0*f5*f7 - 8*f0*f6^2 - 
    7*f1*f4*f7 + 20*f1*f5*f6 + 5*f2*f3*f7 - 8*f2*f5^2 - 2*f3^2*f6 - 
    2*f3*f4*f5)*x1*x2*x3*x4 + (-12*f0*f5 + 3*f1*f4 - f2*f3)*x1*x2*x3*x5 + 
    (f1*f7 - 2*f3*f5 + f4^2)*x1*x2*x3*x8 + (-12*f0*f6*f7 + 30*f1*f5*f7 + 
    2*f2*f4*f7 + 4*f2*f5*f6 - 3*f3^2*f7 - 12*f3*f5^2 + 5*f4^2*f5)*x1*x2*x4^2
    + (4*f0*f6 - 9*f1*f5 + f3^2)*x1*x2*x4*x5 + (-2*f0*f7 - 2*f1*f6 + 3*f2*f5
    + f3*f4)*x1*x2*x4*x6 + (2*f2*f6 - 3*f3*f5 + f4^2)*x1*x2*x4*x7 - 
    3*f2*f7*x1*x2*x4*x8 - 2*f5*x1*x2*x8^2 + (-4*f0*f5*f7 + 8*f0*f6^2 - 
    2*f1*f4*f7 - 2*f1*f5*f6 - 2*f2*f3*f7 - 4*f2*f4*f6 - 4*f2*f5^2 + 
    2*f3^2*f6 + 2*f3*f4*f5)*x1*x3^3 + (12*f0*f6*f7 - 6*f1*f5*f7 + 4*f1*f6^2 
    - 8*f2*f4*f7 - 16*f2*f5*f6 + 3*f3^2*f7 + 5*f3*f5^2 - 
    5*f4^2*f5)*x1*x3^2*x4 + (-4*f0*f6 + 2*f2*f4 - f3^2)*x1*x3^2*x5 + 
    (2*f0*f7 + 2*f1*f6 + 4*f2*f5 - f3*f4)*x1*x3^2*x6 + (-f1*f7 - 2*f2*f6 + 
    2*f3*f5 - f4^2)*x1*x3^2*x7 + (f2*f7 - 2*f4*f5)*x1*x3^2*x8 + (8*f1*f6*f7 
    - 20*f2*f5*f7 + 4*f2*f6^2 - 10*f3*f5*f6 - 20*f4*f5^2)*x1*x3*x4^2 + 
    (-2*f1*f6 + 6*f2*f5)*x1*x3*x4*x5 - 10*f4*f5*x1*x3*x4*x7 + (-3*f3*f7 - 
    6*f4*f6 - 6*f5^2)*x1*x3*x4*x8 - 2*f5*x1*x3*x7*x8 + (3*f1*f7^2 + 
    6*f2*f6*f7 - 15*f3*f5*f7 - 28*f5^3)*x1*x4^3 + (-f1*f7 - 2*f2*f6 + 
    5*f3*f5)*x1*x4^2*x5 + (f2*f7 - 3*f4*f5)*x1*x4^2*x6 - 18*f5^2*x1*x4^2*x7 
    + (-2*f4*f7 - 16*f5*f6)*x1*x4^2*x8 + 8*f5*x1*x4*x6*x8 - 4*f6*x1*x4*x7*x8
    + x1*x5*x8^2 + 3*x1*x6*x7*x8 + x1*x7^3 + (-2*f0*f5^2 + 2*f1*f4*f5)*x2^4 
    + (-4*f0*f5*f6 + 2*f1*f4*f6 + f1*f5^2 + 2*f2*f4*f5)*x2^3*x3 + 
    (-2*f0*f5*f7 + f1*f4*f7 + 4*f2*f5^2 - 2*f3*f4*f5)*x2^3*x4 + (2*f0*f5 - 
    f1*f4)*x2^3*x5 - f1*f5*x2^3*x6 + f2*f5*x2^3*x7 - f4^2*x2^3*x8 + 
    (-4*f0*f5*f7 + 2*f1*f4*f7 + 2*f2*f4*f6 + 2*f3*f4*f5)*x2^2*x3^2 + 
    (4*f0*f6*f7 - f1*f5*f7 + f2*f4*f7 + 2*f2*f5*f6 - 2*f3*f4*f6 + 3*f3*f5^2 
    - 2*f4^2*f5)*x2^2*x3*x4 - f2*f4*x2^2*x3*x5 + (f1*f7 + f3*f5 + 
    f4^2)*x2^2*x3*x7 - f4*f5*x2^2*x3*x8 + (4*f0*f7^2 - 3*f2*f5*f7 - f3*f4*f7
    - 13*f4*f5^2)*x2^2*x4^2 + (-2*f0*f7 - f2*f5 + f3*f4)*x2^2*x4*x5 + (f1*f7
    + f3*f5 + f4^2)*x2^2*x4*x6 + (-f2*f7 - 5*f4*f5)*x2^2*x4*x7 + 
    3*f5^2*x2^2*x4*x8 + 2*f5*x2^2*x7*x8 + (-4*f0*f6*f7 + 2*f2*f4*f7 + 
    2*f3*f4*f6 + 3*f4^2*f5)*x2*x3^3 + (-2*f0*f7^2 - 4*f1*f6*f7 + 4*f2*f5*f7 
    - f3*f4*f7 + 2*f3*f5*f6 - 4*f4^2*f6 + 18*f4*f5^2)*x2*x3^2*x4 + (2*f0*f7 
    - f3*f4)*x2*x3^2*x5 + (f2*f7 + 6*f4*f5)*x2*x3^2*x7 - f5^2*x2*x3^2*x8 + 
    (-4*f1*f7^2 - 2*f2*f6*f7 + 2*f3*f5*f7 - 6*f4^2*f7 + 
    4*f4*f5*f6)*x2*x3*x4^2 + (2*f1*f7 - f3*f5 + 2*f4^2)*x2*x3*x4*x5 + 
    (3*f4*f7 - 4*f5*f6)*x2*x3*x4*x8 + (-f2*f7^2 + 8*f4*f5*f7 - 
    8*f5^2*f6)*x2*x4^3 + (f2*f7 - f4*f5)*x2*x4^2*x5 + (-f3*f7 - 2*f4*f6 + 
    7*f5^2)*x2*x4^2*x6 + (f4*f7 - 12*f5*f6)*x2*x4^2*x7 - 4*f5*f7*x2*x4^2*x8 
    - 4*f6*x2*x4*x7^2 - x2*x5*x7*x8 + x2*x6^2*x8 - x2*x6*x7^2 + (-2*f0*f7^2 
    + 2*f3*f4*f7 + 2*f4^2*f6)*x3^4 + (-2*f1*f7^2 + 2*f3*f5*f7 + 3*f4^2*f7 + 
    4*f4*f5*f6 + 8*f5^3)*x3^3*x4 - f4^2*x3^3*x5 + (f3*f7 + 2*f4*f6 + 
    2*f5^2)*x3^3*x7 + (-f4*f7 + 2*f5*f6)*x3^3*x8 + (-2*f2*f7^2 - 2*f3*f6*f7 
    + f4*f5*f7 - 4*f4*f6^2 + 24*f5^2*f6)*x3^2*x4^2 - 2*f4*f5*x3^2*x4*x5 + 
    (2*f3*f7 + 4*f4*f6 - 7*f5^2)*x3^2*x4*x6 + (-f4*f7 + 10*f5*f6)*x3^2*x4*x7
    + (2*f5*f7 + 4*f6^2)*x3^2*x4*x8 - 2*f6*x3^2*x6*x8 + (-3*f3*f7^2 - 
    6*f4*f6*f7 + 16*f5^2*f7 + 8*f5*f6^2)*x3*x4^3 + (f3*f7 + 2*f4*f6 - 
    8*f5^2)*x3*x4^2*x5 + (-4*f5*f7 + 8*f6^2)*x3*x4^2*x7 + 
    12*f6*f7*x3*x4^2*x8 - 2*f6*x3*x4*x5*x8 - 3*f7*x3*x4*x6*x8 - 
    3*f7*x3*x4*x7^2 + x3*x5*x7^2 - 2*x3*x6^2*x7 + 12*f5*f6*f7*x4^4 - 
    4*f5*f6*x4^3*x5 - 6*f5*f7*x4^3*x6 + 12*f6*f7*x4^3*x7 + 8*f7^2*x4^3*x8 + 
    f5*x4^2*x5*x6 - 4*f6*x4^2*x5*x7 - 3*f7*x4^2*x5*x8 + 2*f6*x4^2*x6^2 - 
    x4*x6^3,
4*f1^2*f3*x1^4 + (4*f1^2*f4 + 4*f1*f2*f3)*x1^3*x2 + (-3*f1^2*f5 - 8*f1*f3^2 
    + 4*f2^2*f3)*x1^3*x3 + (-48*f0*f3*f5 - 7*f1*f2*f5 + 8*f1*f3*f4 - 
    4*f2^2*f4)*x1^3*x4 + 2*f1^2*x1^3*x6 + (-16*f0*f3 - 2*f1*f2)*x1^3*x7 + 
    4*f1*f3*x1^3*x8 + (3*f1^2*f5 + 4*f1*f2*f4 + 4*f1*f3^2)*x1^2*x2^2 + 
    (32*f0*f3*f5 + 5*f1*f2*f5 - 20*f1*f3*f4 + 4*f2^2*f4 + 
    4*f2*f3^2)*x1^2*x2*x3 + (-48*f0*f4*f5 + 2*f1^2*f7 - 15*f1*f3*f5 + 
    8*f1*f4^2 - 4*f2*f3*f4)*x1^2*x2*x4 - 8*f0*f3*x1^2*x2*x6 + (-16*f0*f4 - 
    10*f1*f3)*x1^2*x2*x7 + (-2*f0*f5 + 4*f1*f4 - 4*f2*f3)*x1^2*x2*x8 + 
    (48*f0*f3*f6 + 2*f1*f3*f5 + 2*f2^2*f5 - 8*f2*f3*f4 + 4*f3^3)*x1^2*x3^2 +
    (112*f0*f3*f7 - 32*f0*f4*f6 + 8*f0*f5^2 + 2*f1*f2*f7 + 24*f1*f3*f6 + 
    13*f1*f4*f5 - 17*f2*f3*f5 + 8*f2*f4^2 - 8*f3^2*f4)*x1^2*x3*x4 - 
    32*f0*f3*x1^2*x3*x5 + (4*f0*f5 + 2*f1*f4 - 6*f2*f3)*x1^2*x3*x7 + 
    (-7*f1*f5 - 6*f2*f4 - 2*f3^2)*x1^2*x3*x8 + (-48*f0*f4*f7 + 68*f1*f3*f7 +
    14*f1*f5^2 + 45*f2*f4*f5 - 48*f3^2*f5 + 4*f3*f4^2)*x1^2*x4^2 + (16*f0*f4
    - 20*f1*f3)*x1^2*x4*x5 + (-10*f0*f5 - 2*f1*f4 + 4*f2*f3)*x1^2*x4*x6 + 
    (11*f1*f5 + 18*f2*f4 - 16*f3^2)*x1^2*x4*x7 + (28*f0*f7 + 4*f1*f6 - 
    3*f2*f5 + 6*f3*f4)*x1^2*x4*x8 - 4*f0*x1^2*x5*x8 - 4*f0*x1^2*x6*x7 + 
    2*f1*x1^2*x6*x8 + 2*f1*x1^2*x7^2 - 2*f2*x1^2*x7*x8 + (-8*f0*f3*f5 + 
    8*f1*f3*f4)*x1*x2^3 + (-16*f0*f3*f6 + 32*f0*f4*f5 + 3*f1*f3*f5 - 
    12*f1*f4^2 + 8*f2*f3*f4)*x1*x2^2*x3 + (-32*f0*f3*f7 + 16*f0*f4*f6 - 
    18*f0*f5^2 - 15*f1*f4*f5 + 16*f2*f3*f5 - 4*f2*f4^2)*x1*x2^2*x4 + 
    8*f0*f3*x1*x2^2*x5 + (-8*f0*f4 - 4*f1*f3)*x1*x2^2*x6 + (-6*f0*f5 - 
    10*f1*f4 + 4*f2*f3)*x1*x2^2*x7 + (f1*f5 - 4*f2*f4)*x1*x2^2*x8 + 
    (-8*f0*f3*f7 + 48*f0*f4*f6 + 6*f0*f5^2 - 3*f1*f4*f5 - f2*f3*f5 - 
    8*f2*f4^2 + 8*f3^2*f4)*x1*x2*x3^2 + (96*f0*f4*f7 - 4*f0*f5*f6 - 
    14*f1*f3*f7 + 24*f1*f4*f6 + f1*f5^2 + 8*f2*f3*f6 - 20*f2*f4*f5 + 
    19*f3^2*f5 - 12*f3*f4^2)*x1*x2*x3*x4 - 32*f0*f4*x1*x2*x3*x5 + (-8*f0*f7 
    + f2*f5 - 8*f3*f4)*x1*x2*x3*x8 + (-30*f0*f5*f7 + 48*f1*f4*f7 - 
    22*f1*f5*f6 + 20*f2*f3*f7 - 16*f2*f4*f6 + 29*f2*f5^2 - 63*f3*f4*f5 + 
    4*f4^3)*x1*x2*x4^2 + (-4*f0*f5 - 14*f1*f4 - 4*f2*f3)*x1*x2*x4*x5 + 
    (2*f1*f5 + 12*f2*f4 - 4*f3^2)*x1*x2*x4*x6 + (-20*f0*f7 - 8*f1*f6 + 
    15*f2*f5 - 24*f3*f4)*x1*x2*x4*x7 + (-6*f1*f7 - 23*f3*f5 - 
    2*f4^2)*x1*x2*x4*x8 + 2*f2*x1*x2*x7^2 + (4*f0*f5*f6 - f1*f5^2 - 
    10*f2*f4*f5 + 3*f3^2*f5 + 4*f3*f4^2)*x1*x3^3 + (26*f0*f5*f7 - 8*f1*f4*f7
    + 6*f1*f5*f6 - 6*f2*f3*f7 - 24*f2*f4*f6 - 12*f2*f5^2 + 28*f3^2*f6 + 
    9*f3*f4*f5 - 4*f4^3)*x1*x3^2*x4 + (8*f0*f6 - f1*f5 + 6*f2*f4 - 
    4*f3^2)*x1*x3^2*x6 + (4*f0*f7 - 4*f2*f5 + 6*f3*f4)*x1*x3^2*x7 + 
    2*f3*f5*x1*x3^2*x8 + (56*f0*f6*f7 - 14*f1*f5*f7 + 8*f1*f6^2 - 
    56*f2*f4*f7 - 6*f2*f5*f6 + 50*f3^2*f7 - 4*f3*f4*f6 - 22*f3*f5^2 - 
    36*f4^2*f5)*x1*x3*x4^2 + (-8*f0*f6 + 5*f1*f5 + 18*f2*f4 - 
    14*f3^2)*x1*x3*x4*x5 + (-4*f2*f6 + f3*f5 - 18*f4^2)*x1*x3*x4*x7 + 
    (4*f2*f7 - 12*f3*f6 + 14*f4*f5)*x1*x3*x4*x8 - 4*f0*x1*x3*x5*x6 + 
    2*f1*x1*x3*x6^2 + 2*f3*x1*x3*x7^2 + 2*f4*x1*x3*x7*x8 + (84*f0*f7^2 + 
    12*f1*f6*f7 - 25*f2*f5*f7 + 26*f3*f4*f7 - 48*f3*f5*f6 - 
    74*f4*f5^2)*x1*x4^3 + (-40*f0*f7 - 4*f1*f6 + 10*f2*f5 - 
    6*f3*f4)*x1*x4^2*x5 + (20*f1*f7 + 30*f3*f5 - 4*f4^2)*x1*x4^2*x6 + 
    (-10*f2*f7 - 16*f3*f6 - 65*f4*f5)*x1*x4^2*x7 + (-46*f3*f7 + 12*f4*f6 - 
    20*f5^2)*x1*x4^2*x8 + 4*f0*x1*x4*x5^2 - 6*f1*x1*x4*x5*x6 + 
    4*f2*x1*x4*x5*x7 + 6*f3*x1*x4*x5*x8 + 8*f3*x1*x4*x6*x7 - 
    10*f4*x1*x4*x6*x8 - 14*f4*x1*x4*x7^2 - f5*x1*x4*x7*x8 - 4*f6*x1*x4*x8^2 
    + (-8*f0*f4*f5 + 4*f1*f4^2)*x2^4 + (-16*f0*f4*f6 + 2*f0*f5^2 + 
    3*f1*f4*f5 + 4*f2*f4^2)*x2^3*x3 + (-16*f0*f4*f7 - f1*f5^2 + 
    16*f2*f4*f5)*x2^3*x4 + 8*f0*f4*x2^3*x5 - 4*f1*f4*x2^3*x6 + (-f1*f5 + 
    4*f2*f4)*x2^3*x7 + (-8*f0*f4*f7 + 4*f0*f5*f6 - f2*f4*f5 + 
    4*f3*f4^2)*x2^2*x3^2 + (-2*f1*f4*f7 + 4*f1*f5*f6 + 8*f2*f4*f6 - 
    3*f2*f5^2 + 27*f3*f4*f5 - 4*f4^3)*x2^2*x3*x4 - 2*f0*f5*x2^2*x3*x5 + 
    (-f2*f5 + 4*f3*f4)*x2^2*x3*x7 - 2*f4^2*x2^2*x3*x8 + (7*f1*f5*f7 + 
    4*f2*f4*f7 + 35*f3*f5^2 - 2*f4^2*f5)*x2^2*x4^2 + (-2*f1*f5 - 
    4*f2*f4)*x2^2*x4*x5 - 4*f3*f4*x2^2*x4*x6 + (2*f1*f7 + 
    15*f3*f5)*x2^2*x4*x7 - 8*f4*f5*x2^2*x4*x8 + (2*f0*f5*f7 - f3*f4*f5 + 
    4*f4^3)*x2*x3^3 + (-8*f0*f6*f7 + 2*f1*f5*f7 + 6*f2*f4*f7 + 20*f3*f4*f6 -
    7*f3*f5^2 + 16*f4^2*f5)*x2*x3^2*x4 + (-f3*f5 + 6*f4^2)*x2*x3^2*x7 + 
    f4*f5*x2*x3^2*x8 + (-8*f0*f7^2 - 8*f1*f6*f7 + 3*f2*f5*f7 + 10*f3*f4*f7 -
    8*f3*f5*f6 - 4*f4^2*f6 + 2*f4*f5^2)*x2*x3*x4^2 + (4*f0*f7 - 
    10*f3*f4)*x2*x3*x4*x5 + (-12*f4*f6 + f5^2)*x2*x3*x4*x8 + (-10*f1*f7^2 - 
    17*f3*f5*f7 - 20*f4^2*f7 + 18*f4*f5*f6 - 6*f5^3)*x2*x4^3 + (4*f1*f7 + 
    4*f3*f5 + 8*f4^2)*x2*x4^2*x5 - 2*f4*f5*x2*x4^2*x6 + (2*f3*f7 + 8*f4*f6 -
    17*f5^2)*x2*x4^2*x7 + (-8*f4*f7 + 8*f5*f6)*x2*x4^2*x8 + 6*f4*x2*x4*x5*x8
    + 4*f3*x2*x4*x6^2 - 7*f5*x2*x4*x7^2 + 4*f6*x2*x4*x7*x8 + 2*f4^2*f5*x3^4 
    + (-4*f0*f7^2 + 2*f2*f5*f7 + 12*f3*f4*f7 + 12*f3*f5*f6 + 12*f4^2*f6 + 
    17*f4*f5^2)*x3^3*x4 + 4*f4*f5*x3^3*x7 + 3*f5^2*x3^3*x8 + (-4*f1*f7^2 + 
    4*f2*f6*f7 + 23*f3*f5*f7 + 24*f3*f6^2 + 32*f4^2*f7 + 48*f4*f5*f6 + 
    6*f5^3)*x3^2*x4^2 + (-6*f3*f5 - 12*f4^2)*x3^2*x4*x5 + (-2*f2*f7 - 
    12*f3*f6 - 13*f4*f5)*x3^2*x4*x6 + (8*f3*f7 + 16*f4*f6 + 
    8*f5^2)*x3^2*x4*x7 + (-8*f4*f7 + 2*f5*f6)*x3^2*x4*x8 - 5*f5*x3^2*x6*x8 +
    (4*f2*f7^2 + 48*f3*f6*f7 + 109*f4*f5*f7 - 8*f4*f6^2 + 
    16*f5^2*f6)*x3*x4^3 + (-2*f2*f7 - 24*f3*f6 - 43*f4*f5)*x3*x4^2*x5 + 
    (38*f4*f7 + 18*f5*f6)*x3*x4^2*x7 - 8*f6^2*x3*x4^2*x8 + 6*f3*x3*x4*x5*x6 
    - 16*f4*x3*x4*x5*x7 - 3*f5*x3*x4*x5*x8 + 8*f4*x3*x4*x6^2 - 
    4*f7*x3*x4*x7*x8 + 2*x3*x6^2*x8 + 2*x3*x6*x7^2 + (22*f3*f7^2 - 
    12*f4*f6*f7 + 44*f5^2*f7)*x4^4 + (-24*f3*f7 + 4*f4*f6 - 18*f5^2)*x4^3*x5
    + (8*f4*f7 - 10*f5*f6)*x4^3*x6 + 45*f5*f7*x4^3*x7 - 12*f6*f7*x4^3*x8 + 
    6*f3*x4^2*x5^2 - 4*f4*x4^2*x5*x6 - 18*f5*x4^2*x5*x7 + 4*f6*x4^2*x5*x8 + 
    12*f5*x4^2*x6^2 - 4*f6*x4^2*x6*x7 - 8*f7*x4^2*x6*x8 + 4*f7*x4^2*x7^2 + 
    2*x4*x5*x6*x8 - 2*x4*x5*x7^2 + 4*x4*x6^2*x7,
4*f1^2*f3*x1^4 + (4*f1^2*f4 + 4*f1*f2*f3)*x1^3*x2 + (-7*f1^2*f5 - 4*f1*f2*f4
    - 8*f1*f3^2 + 4*f2^2*f3)*x1^3*x3 + (-48*f0*f3*f5 - 11*f1*f2*f5 + 
    8*f1*f3*f4 - 8*f2^2*f4)*x1^3*x4 + f1^2*x1^3*x6 + (-16*f0*f3 - 
    2*f1*f2)*x1^3*x7 + (8*f0*f4 + 7*f1*f3 + 2*f2^2)*x1^3*x8 + (4*f1^2*f5 + 
    8*f1*f2*f4 + 4*f1*f3^2)*x1^2*x2^2 + (32*f0*f3*f5 + 8*f1^2*f6 + 
    5*f1*f2*f5 - 24*f1*f3*f4 + 8*f2^2*f4 + 4*f2*f3^2)*x1^2*x2*x3 + 
    (-64*f0*f4*f5 + 10*f1^2*f7 + 4*f1*f2*f6 - 25*f1*f3*f5 + 8*f1*f4^2 + 
    8*f2^2*f5 - 12*f2*f3*f4)*x1^2*x2*x4 - 3*f1^2*x1^2*x2*x5 + (-8*f0*f3 - 
    2*f1*f2)*x1^2*x2*x6 + (-24*f0*f4 - 13*f1*f3 + 2*f2^2)*x1^2*x2*x7 + 
    (2*f0*f5 + 9*f1*f4)*x1^2*x2*x8 + (48*f0*f3*f6 - 8*f0*f4*f5 + f1^2*f7 + 
    18*f1*f2*f6 + 11*f1*f3*f5 + 4*f1*f4^2 - 6*f2^2*f5 - 4*f2*f3*f4 + 
    4*f3^3)*x1^2*x3^2 + (112*f0*f3*f7 - 48*f0*f4*f6 + 40*f0*f5^2 + 
    26*f1*f2*f7 + 30*f1*f3*f6 + 15*f1*f4*f5 + 8*f2^2*f6 - 19*f2*f3*f5 + 
    12*f2*f4^2 - 8*f3^2*f4)*x1^2*x3*x4 + (-32*f0*f3 - 8*f1*f2)*x1^2*x3*x5 + 
    (20*f0*f5 + 6*f1*f4 - 8*f2*f3)*x1^2*x3*x7 + (-32*f0*f6 + f1*f5 - 
    16*f2*f4 - 4*f3^2)*x1^2*x3*x8 + (-72*f0*f4*f7 + 77*f1*f3*f7 + 22*f1*f5^2
    + 6*f2^2*f7 + 51*f2*f4*f5 - 48*f3^2*f5 + 4*f3*f4^2)*x1^2*x4^2 + 
    (24*f0*f4 - 23*f1*f3 - 2*f2^2)*x1^2*x4*x5 + (10*f0*f5 - 3*f1*f4 + 
    4*f2*f3)*x1^2*x4*x6 + (15*f1*f5 + 24*f2*f4 - 16*f3^2)*x1^2*x4*x7 + 
    (-12*f0*f7 - 8*f1*f6 - 19*f2*f5 + 16*f3*f4)*x1^2*x4*x8 + 8*f0*x1^2*x5*x8
    + 2*f1*x1^2*x7^2 + 4*f3*x1^2*x8^2 + (-8*f0*f3*f5 - 4*f1^2*f6 - 
    2*f1*f2*f5 + 12*f1*f3*f4)*x1*x2^3 + (-16*f0*f3*f6 + 56*f0*f4*f5 - 
    12*f1*f2*f6 - 2*f1*f3*f5 - 20*f1*f4^2 - 2*f2^2*f5 + 
    12*f2*f3*f4)*x1*x2^2*x3 + (-32*f0*f3*f7 + 32*f0*f4*f6 - 30*f0*f5^2 - 
    8*f1*f2*f7 + 4*f1*f3*f6 - 34*f1*f4*f5 + 20*f2*f3*f5 - 8*f2*f4^2 - 
    4*f3^2*f4)*x1*x2^2*x4 + (8*f0*f3 + 2*f1*f2)*x1*x2^2*x5 + (-16*f0*f4 - 
    4*f1*f3)*x1*x2^2*x6 + (-14*f0*f5 - 19*f1*f4 + 4*f2*f3)*x1*x2^2*x7 + 
    (16*f0*f6 + 6*f1*f5 - 4*f2*f4)*x1*x2^2*x8 + (-8*f0*f3*f7 + 80*f0*f4*f6 -
    22*f0*f5^2 + 4*f1*f2*f7 - 6*f1*f3*f6 + 12*f1*f4*f5 - 8*f2^2*f6 - 
    11*f2*f3*f5 - 12*f2*f4^2 + 12*f3^2*f4)*x1*x2*x3^2 + (160*f0*f4*f7 - 
    12*f0*f5*f6 - 14*f1*f3*f7 + 54*f1*f4*f6 - 17*f1*f5^2 - 8*f2^2*f7 + 
    20*f2*f3*f6 - 36*f2*f4*f5 + 21*f3^2*f5 - 8*f3*f4^2)*x1*x2*x3*x4 + 
    (-56*f0*f4 + f1*f3 + 2*f2^2)*x1*x2*x3*x5 + (-8*f0*f7 + 6*f1*f6 + 
    15*f2*f5 - 16*f3*f4)*x1*x2*x3*x8 + (-2*f0*f5*f7 + 107*f1*f4*f7 - 
    14*f1*f5*f6 + 32*f2*f3*f7 - 28*f2*f4*f6 + 39*f2*f5^2 - 77*f3*f4*f5 + 
    4*f4^3)*x1*x2*x4^2 + (-4*f0*f5 - 34*f1*f4 - 8*f2*f3)*x1*x2*x4*x5 + 
    (-8*f0*f6 + 7*f1*f5 + 22*f2*f4 - 4*f3^2)*x1*x2*x4*x6 + (-12*f0*f7 + 
    21*f2*f5 - 28*f3*f4)*x1*x2*x4*x7 + (-4*f1*f7 - 16*f2*f6 - 33*f3*f5 - 
    2*f4^2)*x1*x2*x4*x8 + 2*f1*x1*x2*x5*x8 - 4*f2*x1*x2*x6*x8 + 
    4*f4*x1*x2*x8^2 + (8*f0*f4*f7 - 52*f0*f5*f6 - f1*f3*f7 - 2*f1*f4*f6 + 
    13*f1*f5^2 + 4*f2^2*f7 - 16*f2*f3*f6 - 4*f2*f4*f5 - f3^2*f5)*x1*x3^3 + 
    (-106*f0*f5*f7 - 32*f0*f6^2 - f1*f4*f7 - 18*f1*f5*f6 - 22*f2*f3*f7 - 
    32*f2*f4*f6 + 22*f2*f5^2 + 24*f3^2*f6 + 5*f3*f4*f5 - 4*f4^3)*x1*x3^2*x4 
    + (36*f0*f5 + 6*f2*f3)*x1*x3^2*x5 + (16*f0*f6 - 14*f1*f5 + 12*f2*f4 - 
    4*f3^2)*x1*x3^2*x6 + (-2*f1*f6 + 8*f2*f5 + 4*f3*f4)*x1*x3^2*x7 + (f1*f7 
    + 16*f2*f6 + 10*f3*f5 + 2*f4^2)*x1*x3^2*x8 + (-72*f0*f6*f7 - 62*f1*f5*f7
    - 62*f2*f4*f7 + 34*f2*f5*f6 + 44*f3^2*f7 - 16*f3*f4*f6 + 14*f3*f5^2 - 
    40*f4^2*f5)*x1*x3*x4^2 + (32*f0*f6 + 19*f1*f5 + 22*f2*f4 - 
    12*f3^2)*x1*x3*x4*x5 + (24*f2*f6 + 23*f3*f5 - 20*f4^2)*x1*x3*x4*x7 + 
    (12*f2*f7 - 20*f3*f6 + 46*f4*f5)*x1*x3*x4*x8 - 4*f0*x1*x3*x5*x6 + 
    f1*x1*x3*x6^2 + 4*f3*x1*x3*x7^2 + 6*f5*x1*x3*x8^2 + (-36*f0*f7^2 + 
    31*f2*f5*f7 + 8*f3*f4*f7 - 48*f3*f5*f6 - 70*f4*f5^2)*x1*x4^3 + (36*f0*f7
    - 12*f2*f5)*x1*x4^2*x5 + (-2*f1*f7 + 4*f2*f6 + 50*f3*f5 - 
    4*f4^2)*x1*x4^2*x6 + (36*f2*f7 - 16*f3*f6 - 67*f4*f5)*x1*x4^2*x7 + 
    (-42*f3*f7 + 24*f4*f6 - 24*f5^2)*x1*x4^2*x8 - 8*f0*x1*x4*x5^2 + 
    f1*x1*x4*x5*x6 - 12*f2*x1*x4*x5*x7 + 4*f3*x1*x4*x5*x8 + 2*f2*x1*x4*x6^2 
    + 12*f3*x1*x4*x6*x7 - 18*f4*x1*x4*x6*x8 - 16*f4*x1*x4*x7^2 - 
    25*f5*x1*x4*x7*x8 + 8*f6*x1*x4*x8^2 + (-16*f0*f4*f5 + 8*f1*f4^2)*x2^4 + 
    (-32*f0*f4*f6 + 14*f0*f5^2 + 8*f2*f4^2)*x2^3*x3 + (-32*f0*f4*f7 + 
    8*f0*f5*f6 - 4*f1*f4*f6 - 10*f1*f5^2 + 34*f2*f4*f5 - 4*f3*f4^2)*x2^3*x4 
    + 16*f0*f4*x2^3*x5 - 8*f1*f4*x2^3*x6 + (-8*f1*f5 + 8*f2*f4)*x2^3*x7 + 
    (-16*f0*f4*f7 + 28*f0*f5*f6 - 2*f1*f4*f6 - 11*f2*f4*f5 + 
    8*f3*f4^2)*x2^2*x3^2 + (40*f0*f5*f7 + 16*f0*f6^2 - 16*f1*f4*f7 + 
    18*f1*f5*f6 + 16*f2*f4*f6 - 31*f2*f5^2 + 43*f3*f4*f5 - 
    4*f4^3)*x2^2*x3*x4 + (-18*f0*f5 + 3*f1*f4)*x2^2*x3*x5 + (-2*f1*f6 - 
    11*f2*f5 + 8*f3*f4)*x2^2*x3*x7 - 4*f4^2*x2^2*x3*x8 + (16*f0*f6*f7 + 
    22*f1*f5*f7 + 12*f2*f4*f7 - 8*f2*f5*f6 + 4*f3*f4*f6 + 37*f3*f5^2 - 
    2*f4^2*f5)*x2^2*x4^2 + (-8*f0*f6 - 15*f1*f5 - 10*f2*f4)*x2^2*x4*x5 + 
    (4*f1*f6 - 2*f2*f5)*x2^2*x4*x6 + (-8*f1*f7 + 19*f3*f5 + 
    2*f4^2)*x2^2*x4*x7 - 24*f4*f5*x2^2*x4*x8 + (14*f0*f5*f7 - f1*f4*f7 - 
    8*f2*f4*f6 - 7*f3*f4*f5 + 4*f4^3)*x2*x3^3 + (32*f0*f6*f7 + 11*f1*f5*f7 -
    4*f2*f4*f7 - 24*f2*f5*f6 + 20*f3*f4*f6 - 25*f3*f5^2 + 
    24*f4^2*f5)*x2*x3^2*x4 + (-8*f0*f6 + 3*f1*f5 + 6*f2*f4)*x2*x3^2*x5 + 
    (-f1*f7 - 8*f2*f6 - 7*f3*f5 + 6*f4^2)*x2*x3^2*x7 + 7*f4*f5*x2*x3^2*x8 + 
    (24*f0*f7^2 + 26*f1*f6*f7 - 3*f2*f5*f7 - 16*f2*f6^2 + 22*f3*f4*f7 - 
    32*f3*f5*f6 - 8*f4^2*f6 - 10*f4*f5^2)*x2*x3*x4^2 + (-20*f0*f7 - 2*f1*f6 
    + 4*f2*f5 - 14*f3*f4)*x2*x3*x4*x5 + (-16*f4*f6 - f5^2)*x2*x3*x4*x8 + 
    4*f0*x2*x3*x5^2 - 3*f1*x2*x3*x5*x6 + (28*f1*f7^2 - 16*f2*f6*f7 - 
    39*f3*f5*f7 - 32*f4^2*f7 - 2*f4*f5*f6 - 2*f5^3)*x2*x4^3 + (-12*f1*f7 + 
    8*f2*f6 + 16*f3*f5 + 12*f4^2)*x2*x4^2*x5 + (-4*f2*f7 - 4*f3*f6 + 
    18*f4*f5)*x2*x4^2*x6 + (6*f3*f7 + 4*f4*f6 + 5*f5^2)*x2*x4^2*x7 + 
    (-28*f4*f7 + 24*f5*f6)*x2*x4^2*x8 + f1*x2*x4*x5^2 + 2*f2*x2*x4*x5*x6 + 
    14*f4*x2*x4*x5*x8 + 4*f3*x2*x4*x6^2 - 5*f5*x2*x4*x7^2 + 8*f6*x2*x4*x7*x8
    - 4*x2*x6*x7*x8 - 4*x2*x7^3 + (-4*f2*f4*f7 - 2*f4^2*f5)*x3^4 + 
    (12*f0*f7^2 - 24*f2*f5*f7 + 6*f3*f4*f7 + 4*f3*f5*f6 + 16*f4^2*f6 + 
    15*f4*f5^2)*x3^3*x4 + (-4*f0*f7 + 6*f2*f5 + 2*f3*f4)*x3^3*x5 + (-4*f2*f7
    - 4*f4*f5)*x3^3*x7 + 11*f5^2*x3^3*x8 + (11*f1*f7^2 - 32*f2*f6*f7 - 
    11*f3*f5*f7 + 8*f3*f6^2 + 44*f4^2*f7 + 68*f4*f5*f6 - 10*f5^3)*x3^2*x4^2 
    + (-4*f1*f7 + 12*f2*f6 - 16*f4^2)*x3^2*x4*x5 + (12*f2*f7 - 4*f3*f6 - 
    35*f4*f5)*x3^2*x4*x6 + (-2*f3*f7 + 16*f4*f6 - 14*f5^2)*x3^2*x4*x7 + 
    (-4*f4*f7 + 22*f5*f6)*x3^2*x4*x8 - 6*f2*x3^2*x5*x6 + 2*f3*x3^2*x5*x7 - 
    2*f4*x3^2*x5*x8 - 11*f5*x3^2*x6*x8 + (-36*f2*f7^2 + 8*f3*f6*f7 + 
    123*f4*f5*f7 - 24*f5^2*f6)*x3*x4^3 + (30*f2*f7 - 12*f3*f6 - 
    49*f4*f5)*x3*x4^2*x5 + (42*f4*f7 - 22*f5*f6)*x3*x4^2*x7 + 
    42*f5*f7*x3*x4^2*x8 - 6*f2*x3*x4*x5^2 + 6*f3*x3*x4*x5*x6 - 
    18*f4*x3*x4*x5*x7 - 15*f5*x3*x4*x5*x8 + 8*f4*x3*x4*x6^2 + 
    4*f6*x3*x4*x7^2 + 4*f7*x3*x4*x7*x8 - 2*x3*x5*x7*x8 - 2*x3*x6*x7^2 + 
    (-2*f3*f7^2 - 32*f5^2*f7)*x4^4 + (-10*f3*f7 + 14*f5^2)*x4^3*x5 + 
    (20*f4*f7 + 2*f5*f6)*x4^3*x6 - 19*f5*f7*x4^3*x7 - 8*f6*f7*x4^3*x8 + 
    4*f3*x4^2*x5^2 - 8*f4*x4^2*x5*x6 + 8*f5*x4^2*x5*x7 - 8*f5*x4^2*x6^2 - 
    4*f6*x4^2*x6*x7 + 8*f7*x4^2*x6*x8 + 12*f7*x4^2*x7^2 - 2*x4*x5*x6*x8 - 
    4*x4*x5*x7^2 + 2*x4*x6^2*x7,
-3*f1^2*f2*x1^4 + (-2*f1^2*f3 - f1*f2^2)*x1^3*x2 + (-8*f0*f1*f5 + f1^2*f4 + 
    4*f1*f2*f3 - f2^3)*x1^3*x3 + (12*f0*f2*f5 + 4*f1^2*f5 - 
    5*f1*f2*f4)*x1^3*x4 + 4*f0*f1*x1^3*x6 + (4*f0*f2 + 2*f1^2)*x1^3*x7 - 
    3*f1*f2*x1^3*x8 + (4*f0*f1*f5 + f1^2*f4 - f1*f2*f3)*x1^2*x2^2 + 
    (-8*f0*f2*f5 - 2*f1^2*f5 + 10*f1*f2*f4 + 2*f1*f3^2 - f2^2*f3)*x1^2*x2*x3
    + (16*f0*f1*f7 - 4*f1^2*f6 + 2*f1*f2*f5 - 3*f1*f3*f4 - 
    f2^2*f4)*x1^2*x2*x4 - 4*f0*f1*x1^2*x2*x5 + (2*f0*f2 + 3*f1^2)*x1^2*x2*x6
    + 3*f1*f2*x1^2*x2*x7 + (-10*f0*f4 - 5*f1*f3 + f2^2)*x1^2*x2*x8 + 
    (4*f0*f1*f7 - 12*f0*f2*f6 + f1*f2*f5 + 4*f2^2*f4 - f2*f3^2)*x1^2*x3^2 + 
    (-28*f0*f2*f7 + 8*f0*f4*f5 + 2*f1^2*f7 - 10*f1*f2*f6 - 12*f1*f3*f5 + 
    f1*f4^2 + 4*f2^2*f5 + 3*f2*f3*f4)*x1^2*x3*x4 + 8*f0*f2*x1^2*x3*x5 + 
    (4*f0*f4 - 2*f1*f3 + f2^2)*x1^2*x3*x7 + (-4*f0*f5 - 6*f1*f4)*x1^2*x3*x8 
    + (-31*f1*f2*f7 + 6*f1*f4*f5 + 12*f2*f3*f5 - 2*f2*f4^2)*x1^2*x4^2 + 
    9*f1*f2*x1^2*x4*x5 + (2*f0*f4 + 4*f1*f3 - f2^2)*x1^2*x4*x6 + (3*f1*f4 + 
    4*f2*f3)*x1^2*x4*x7 + (-4*f0*f6 + 16*f1*f5 + 4*f2*f4)*x1^2*x4*x8 - 
    2*f0*x1^2*x6*x8 + f1*x1^2*x7*x8 + (2*f0*f2*f5 - f1^2*f5 - 
    f1*f2*f4)*x1*x2^3 + (-8*f0*f1*f7 + 4*f0*f2*f6 - 3*f1*f2*f5 + 3*f1*f3*f4 
    - f2^2*f4)*x1*x2^2*x3 + (8*f0*f2*f7 - 14*f0*f4*f5 - 3*f1^2*f7 + 
    10*f1*f3*f5 + 3*f1*f4^2 - 4*f2^2*f5 - f2*f3*f4)*x1*x2^2*x4 - 
    2*f0*f2*x1*x2^2*x5 + f1*f2*x1*x2^2*x6 + (-2*f0*f4 + 4*f1*f3 - 
    f2^2)*x1*x2^2*x7 + (6*f0*f5 - 4*f1*f4)*x1*x2^2*x8 + (2*f0*f2*f7 + 
    6*f0*f4*f5 - f1*f3*f5 - 5*f1*f4^2 - f2^2*f5 - 2*f2*f3*f4)*x1*x2*x3^2 + 
    (-20*f0*f4*f6 + 9*f1*f2*f7 - 6*f1*f3*f6 + f1*f4*f5 - 2*f2^2*f6 - 
    4*f2*f3*f5 + 9*f2*f4^2 + f3^2*f4)*x1*x2*x3*x4 + (4*f0*f6 - 4*f1*f5 + 
    f2*f4)*x1*x2*x3*x8 + (-22*f0*f4*f7 + 8*f0*f5*f6 - 7*f1*f3*f7 - 
    6*f1*f4*f6 - 24*f1*f5^2 - 5*f2^2*f7 + 37*f2*f4*f5 - f3*f4^2)*x1*x2*x4^2 
    + (8*f0*f4 + 3*f1*f3 + f2^2)*x1*x2*x4*x5 + (-4*f0*f5 + 3*f1*f4 + 
    f2*f3)*x1*x2*x4*x6 + (4*f0*f6 - 12*f1*f5 + 12*f2*f4)*x1*x2*x4*x7 + 
    (4*f0*f7 + 2*f2*f5 - 2*f3*f4)*x1*x2*x4*x8 - 2*f0*x1*x2*x5*x8 + 
    f1*x1*x2*x6*x8 + (12*f0*f4*f6 - 4*f0*f5^2 - 6*f1*f4*f5 - 2*f2*f3*f5 - 
    5*f2*f4^2 - f3^2*f4)*x1*x3^3 + (10*f0*f4*f7 - 28*f0*f5*f6 + 2*f1*f3*f7 +
    8*f1*f4*f6 + 4*f1*f5^2 + 2*f2^2*f7 - 8*f2*f3*f6 - 13*f2*f4*f5 + 
    f3*f4^2)*x1*x3^2*x4 - 4*f0*f4*x1*x3^2*x5 + (6*f0*f5 + 5*f1*f4 + 
    f2*f3)*x1*x3^2*x6 + (-8*f0*f6 - f1*f5 - 4*f2*f4)*x1*x3^2*x7 + (-2*f0*f7 
    + f2*f5 + 3*f3*f4)*x1*x3^2*x8 + (-36*f0*f5*f7 - 8*f0*f6^2 + 15*f1*f4*f7 
    + 16*f1*f5*f6 - 14*f2*f3*f7 + 4*f2*f4*f6 + 16*f2*f5^2 + 
    6*f3*f4*f5)*x1*x3*x4^2 + (12*f0*f5 - 4*f1*f4 + 4*f2*f3)*x1*x3*x4*x5 + 
    (-12*f0*f7 - 2*f1*f6 + 8*f2*f5 + 3*f3*f4)*x1*x3*x4*x7 + (-7*f1*f7 - 
    13*f4^2)*x1*x3*x4*x8 + 4*f0*x1*x3*x5*x7 + f2*x1*x3*x7^2 + f3*x1*x3*x7*x8
    + f4*x1*x3*x8^2 + (-12*f0*f6*f7 + 52*f1*f5*f7 - 6*f2*f4*f7 + 12*f2*f5*f6
    + 2*f4^2*f5)*x1*x4^3 + (4*f0*f6 - 16*f1*f5 + f2*f4)*x1*x4^2*x5 + 
    (-6*f0*f7 + 4*f1*f6 - 6*f2*f5 + 2*f3*f4)*x1*x4^2*x6 + (5*f1*f7 + 4*f2*f6
    + f4^2)*x1*x4^2*x7 + (13*f2*f7 - 2*f3*f6 - 30*f4*f5)*x1*x4^2*x8 + 
    2*f0*x1*x4*x5*x6 - f1*x1*x4*x5*x7 - 5*f1*x1*x4*x6^2 - 2*f2*x1*x4*x6*x7 -
    f3*x1*x4*x6*x8 - 10*f4*x1*x4*x7*x8 - 4*f5*x1*x4*x8^2 + (2*f0*f4*f5 + 
    f1*f4^2)*x2^3*x3 + (4*f0*f5^2 + 6*f1*f4*f5 - f2*f4^2)*x2^3*x4 + 
    3*f1*f4*x2^3*x7 + (4*f0*f4*f6 - 2*f0*f5^2 + f1*f4*f5 - 
    f2*f4^2)*x2^2*x3^2 + (4*f0*f4*f7 + 12*f0*f5*f6 - 4*f1*f4*f6 + 8*f1*f5^2 
    - 9*f2*f4*f5 + f3*f4^2)*x2^2*x3*x4 - 2*f0*f4*x2^2*x3*x5 + (5*f1*f5 - 
    f2*f4)*x2^2*x3*x7 + (14*f0*f5*f7 - 8*f1*f4*f7 - 17*f2*f5^2 + 3*f3*f4*f5 
    + 2*f4^3)*x2^2*x4^2 + (-6*f0*f5 + 2*f1*f4)*x2^2*x4*x5 + (f1*f5 + 
    2*f2*f4)*x2^2*x4*x6 + (-6*f2*f5 + f3*f4)*x2^2*x4*x7 - f4^2*x2^2*x4*x8 + 
    (2*f0*f4*f7 - 4*f0*f5*f6 - 2*f1*f5^2 + f2*f4*f5 - f3*f4^2)*x2*x3^3 + 
    (8*f0*f6^2 - f1*f4*f7 - 12*f1*f5*f6 - 6*f2*f4*f6 + 4*f2*f5^2 - 
    6*f3*f4*f5 - 4*f4^3)*x2*x3^2*x4 + 2*f0*f5*x2*x3^2*x5 + (f2*f5 - 
    f3*f4)*x2*x3^2*x7 + 2*f4^2*x2*x3^2*x8 + (20*f0*f6*f7 - 18*f1*f5*f7 - 
    4*f2*f4*f7 - 4*f2*f5*f6 - 2*f3*f4*f6 - 2*f4^2*f5)*x2*x3*x4^2 + (-8*f0*f6
    + 6*f1*f5 + 3*f2*f4)*x2*x3*x4*x5 + 7*f4*f5*x2*x3*x4*x8 + 2*f1*x2*x3*x6^2
    + (12*f0*f7^2 - 10*f2*f5*f7 - 2*f3*f4*f7 + 4*f3*f5*f6 - 2*f4^2*f6 - 
    6*f4*f5^2)*x2*x4^3 + (-10*f0*f7 + 2*f2*f5 + f3*f4)*x2*x4^2*x5 + (f1*f7 -
    2*f3*f5 - 2*f4^2)*x2*x4^2*x6 + (-5*f2*f7 + 2*f3*f6 - 5*f4*f5)*x2*x4^2*x7
    + 24*f5^2*x2*x4^2*x8 + 2*f0*x2*x4*x5^2 - f2*x2*x4*x6^2 - f4*x2*x4*x7^2 +
    10*f5*x2*x4*x7*x8 + (-2*f0*f5*f7 + f3*f4*f5 + 2*f4^3)*x3^4 + (4*f0*f6*f7
    - 5*f1*f5*f7 - 2*f2*f4*f7 - 6*f2*f5*f6 - 2*f3*f4*f6 + 4*f4^2*f5)*x3^3*x4
    + (f3*f5 + 3*f4^2)*x3^3*x7 + 2*f4*f5*x3^3*x8 + (6*f0*f7^2 - 2*f1*f6*f7 -
    8*f2*f5*f7 - 12*f2*f6^2 - 4*f3*f4*f7 - 10*f3*f5*f6 - 6*f4^2*f6 + 
    4*f4*f5^2)*x3^2*x4^2 + (-2*f0*f7 + 3*f2*f5 + f3*f4)*x3^2*x4*x5 + 
    (3*f1*f7 + 6*f2*f6 + 3*f3*f5 + 6*f4^2)*x3^2*x4*x6 + (-2*f2*f7 - 2*f3*f6 
    + f4*f5)*x3^2*x4*x7 + (8*f4*f6 - 4*f5^2)*x3^2*x4*x8 - 3*f4*x3^2*x6*x8 + 
    (-f1*f7^2 - 18*f2*f6*f7 - 12*f3*f5*f7 - 4*f3*f6^2 - 12*f4^2*f7 + 
    12*f4*f5*f6 - 16*f5^3)*x3*x4^3 + (f1*f7 + 12*f2*f6 + 4*f3*f5 + 
    4*f4^2)*x3*x4^2*x5 + (-3*f3*f7 + 4*f4*f6 - 20*f5^2)*x3*x4^2*x7 + 
    11*f4*f7*x3*x4^2*x8 - 3*f2*x3*x4*x5*x6 + f3*x3*x4*x5*x7 - 
    4*f4*x3*x4*x5*x8 - 8*f5*x3*x4*x7^2 + 4*f6*x3*x4*x7*x8 - x3*x6*x7*x8 - 
    x3*x7^3 + (-f2*f7^2 - 6*f3*f6*f7 + 14*f4*f5*f7)*x4^4 + (9*f2*f7 + 
    2*f3*f6 - 4*f4*f5)*x4^3*x5 + (-3*f3*f7 + 2*f4*f6 - 8*f5^2)*x4^3*x6 + 
    4*f4*f7*x4^3*x7 - 8*f5*f7*x4^3*x8 - 3*f2*x4^2*x5^2 + f3*x4^2*x5*x6 - 
    f4*x4^2*x5*x7 - 6*f5*x4^2*x6*x7 + 4*f7*x4^2*x7*x8 - 2*x4*x5*x7*x8 + 
    x4*x6^2*x8 - x4*x6*x7^2,
-4*f1^2*f2*x1^4 + (-8*f1^2*f3 - 4*f1*f2^2)*x1^3*x2 + (8*f1*f2*f3 - 
    4*f2^3)*x1^3*x3 + (48*f0*f2*f5 + 8*f1^2*f5 - 8*f1*f2*f4 + 
    8*f2^2*f3)*x1^3*x4 + (16*f0*f2 + 4*f1^2)*x1^3*x7 + 4*f1*f2*x1^3*x8 - 
    12*f1*f2*f3*x1^2*x2^2 + (-32*f0*f2*f5 + 12*f1*f2*f4 + 16*f1*f3^2 - 
    12*f2^2*f3)*x1^2*x2*x3 + (96*f0*f3*f5 - 8*f1^2*f6 - 16*f1*f3*f4 - 
    4*f2^2*f4 + 16*f2*f3^2)*x1^2*x2*x4 + (8*f0*f2 + 4*f1^2)*x1^2*x2*x6 + 
    32*f0*f3*x1^2*x2*x7 + (-12*f1*f3 + 4*f2^2)*x1^2*x2*x8 + (-48*f0*f2*f6 + 
    8*f2^2*f4 - 4*f2*f3^2)*x1^2*x3^2 + (-112*f0*f2*f7 + 64*f0*f3*f6 + 
    16*f1^2*f7 - 32*f1*f2*f6 - 40*f1*f3*f5 + 8*f2^2*f5 - 
    8*f2*f3*f4)*x1^2*x3*x4 + (32*f0*f2 - 4*f1^2)*x1^2*x3*x5 - 
    8*f1*f3*x1^2*x3*x7 + (16*f0*f5 - 8*f1*f4 + 4*f2*f3)*x1^2*x3*x8 + 
    (96*f0*f3*f7 - 96*f0*f5^2 - 40*f1*f2*f7 + 16*f1*f4*f5 - 8*f2^2*f6 - 
    56*f2*f3*f5 - 4*f2*f4^2)*x1^2*x4^2 + (-32*f0*f3 + 12*f1*f2)*x1^2*x4*x5 +
    (12*f1*f3 - 4*f2^2)*x1^2*x4*x6 + (-80*f0*f5 + 8*f1*f4 - 
    24*f2*f3)*x1^2*x4*x7 + (16*f0*f6 + 20*f1*f5 + 4*f2*f4 - 
    12*f3^2)*x1^2*x4*x8 - 16*f0*x1^2*x6*x8 - 16*f0*x1^2*x7^2 + 
    8*f2*x1^2*x8^2 + (8*f0*f2*f5 - 4*f1^2*f5 - 4*f1*f2*f4 - 
    8*f1*f3^2)*x1*x2^3 + (16*f0*f2*f6 - 64*f0*f3*f5 + 16*f1^2*f6 - 
    8*f1*f2*f5 + 24*f1*f3*f4 - 4*f2^2*f4 - 8*f2*f3^2)*x1*x2^2*x3 + 
    (32*f0*f2*f7 - 32*f0*f3*f6 + 4*f1^2*f7 + 16*f1*f2*f6 + 44*f1*f3*f5 - 
    16*f2^2*f5 + 4*f2*f3*f4 + 8*f3^3)*x1*x2^2*x4 + (-8*f0*f2 - 
    4*f1^2)*x1*x2^2*x5 + (16*f0*f3 + 4*f1*f2)*x1*x2^2*x6 + (20*f1*f3 - 
    4*f2^2)*x1*x2^2*x7 + (16*f0*f5 + 8*f2*f3)*x1*x2^2*x8 + (8*f0*f2*f7 - 
    96*f0*f3*f6 + 4*f1^2*f7 + 24*f1*f2*f6 - 8*f1*f3*f5 + 12*f2*f3*f4 - 
    8*f3^3)*x1*x2*x3^2 + (-192*f0*f3*f7 + 32*f0*f5^2 + 44*f1*f2*f7 - 
    64*f1*f3*f6 - 16*f1*f4*f5 + 8*f2^2*f6 + 32*f2*f3*f5 + 
    12*f2*f4^2)*x1*x2*x3*x4 + (64*f0*f3 - 12*f1*f2)*x1*x2*x3*x5 + (-32*f0*f6
    + 12*f1*f5 - 4*f2*f4 + 8*f3^2)*x1*x2*x3*x8 + (64*f0*f5*f6 - 96*f1*f3*f7 
    - 16*f1*f4*f6 - 40*f1*f5^2 - 20*f2^2*f7 + 16*f2*f3*f6 + 24*f2*f4*f5 + 
    16*f3^2*f5 - 8*f3*f4^2)*x1*x2*x4^2 + (32*f1*f3 + 4*f2^2)*x1*x2*x4*x5 + 
    (-32*f0*f5 + 12*f1*f4 - 20*f2*f3)*x1*x2*x4*x6 + (16*f0*f6 - 20*f1*f5 + 
    8*f2*f4 + 4*f3^2)*x1*x2*x4*x7 + (-32*f0*f7 + 12*f2*f5 - 
    8*f3*f4)*x1*x2*x4*x8 + 16*f0*x1*x2*x5*x8 - 4*f1*x1*x2*x6*x8 + 
    8*f3*x1*x2*x8^2 + (4*f1*f2*f7 - 4*f1*f4*f5 + 8*f2^2*f6 + 8*f2*f3*f5 - 
    4*f2*f4^2)*x1*x3^3 + (48*f0*f5*f6 - 20*f1*f3*f7 - 8*f1*f4*f6 + 4*f1*f5^2
    + 32*f2^2*f7 + 24*f2*f3*f6 - 8*f2*f4*f5 + 20*f3^2*f5 + 
    8*f3*f4^2)*x1*x3^2*x4 + (8*f1*f3 - 8*f2^2)*x1*x3^2*x5 + (8*f0*f5 - 
    8*f2*f3)*x1*x3^2*x6 + (16*f0*f6 - 4*f1*f5 + 4*f3^2)*x1*x3^2*x7 + 
    (-16*f0*f7 + 8*f3*f4)*x1*x3^2*x8 + (96*f0*f5*f7 - 32*f0*f6^2 - 
    20*f1*f4*f7 + 56*f1*f5*f6 + 32*f2*f3*f7 - 16*f2*f4*f6 + 16*f2*f5^2 + 
    40*f3^2*f6 + 64*f3*f4*f5)*x1*x3*x4^2 + (-32*f0*f5 + 8*f1*f4 - 
    12*f2*f3)*x1*x3*x4*x5 + (8*f1*f6 + 16*f2*f5 + 32*f3*f4)*x1*x3*x4*x7 + 
    (-16*f1*f7 + 32*f2*f6 - 40*f3*f5)*x1*x3*x4*x8 + 4*f2*x1*x3*x7^2 - 
    8*f4*x1*x3*x8^2 + (-48*f0*f6*f7 + 92*f1*f5*f7 - 40*f2*f4*f7 + 
    32*f2*f5*f6 + 60*f3^2*f7 + 80*f3*f5^2 + 8*f4^2*f5)*x1*x4^3 + (16*f0*f6 -
    28*f1*f5 + 12*f2*f4 - 20*f3^2)*x1*x4^2*x5 + (-56*f0*f7 + 8*f1*f6 + 
    4*f2*f5 + 12*f3*f4)*x1*x4^2*x6 + (4*f1*f7 + 16*f2*f6 + 72*f3*f5 + 
    4*f4^2)*x1*x4^2*x7 + (92*f2*f7 - 16*f4*f5)*x1*x4^2*x8 + 
    16*f0*x1*x4*x5*x6 - 28*f2*x1*x4*x5*x8 - 8*f1*x1*x4*x6^2 + 
    12*f3*x1*x4*x6*x8 + 16*f3*x1*x4*x7^2 - 8*f4*x1*x4*x7*x8 - 
    28*f5*x1*x4*x8^2 + (16*f0*f3*f5 - 8*f1^2*f6 - 8*f1*f3*f4)*x2^4 + 
    (32*f0*f3*f6 - 4*f1^2*f7 - 16*f1*f2*f6 - 4*f1*f3*f5 - 
    8*f2*f3*f4)*x2^3*x3 + (32*f0*f3*f7 + 16*f1*f3*f6 + 4*f1*f4*f5 - 
    32*f2*f3*f5 - 4*f2*f4^2 + 8*f3^2*f4)*x2^3*x4 - 16*f0*f3*x2^3*x5 + 
    8*f1*f3*x2^3*x6 - 8*f2*f3*x2^3*x7 + (32*f0*f6 - 4*f1*f5)*x2^3*x8 + 
    (16*f0*f3*f7 - 8*f0*f5^2 - 8*f1*f2*f7 - 8*f1*f3*f6 + 4*f1*f4*f5 - 
    8*f2^2*f6 + 4*f2*f3*f5 - 8*f3^2*f4)*x2^2*x3^2 + (-48*f0*f5*f6 + 
    24*f1*f3*f7 + 16*f1*f4*f6 + 4*f1*f5^2 - 12*f2*f4*f5 - 28*f3^2*f5 + 
    8*f3*f4^2)*x2^2*x3*x4 - 4*f1*f3*x2^2*x3*x5 + (-32*f0*f6 + 4*f1*f5 - 
    8*f3^2)*x2^2*x3*x7 + (16*f0*f7 + 8*f1*f6 - 4*f2*f5)*x2^2*x3*x8 + 
    (-8*f0*f5*f7 + 32*f0*f6^2 + 28*f1*f4*f7 - 16*f1*f5*f6 - 8*f2*f3*f7 - 
    40*f2*f5^2 - 8*f3^2*f6 + 4*f3*f4*f5)*x2^2*x4^2 + (16*f0*f5 - 12*f1*f4 + 
    8*f2*f3)*x2^2*x4*x5 + (-32*f0*f6 + 8*f2*f4 - 8*f3^2)*x2^2*x4*x6 + 
    (16*f0*f7 - 8*f1*f6 - 16*f2*f5)*x2^2*x4*x7 + (-8*f1*f7 - 32*f2*f6 + 
    20*f3*f5 - 8*f4^2)*x2^2*x4*x8 + 4*f1*x2^2*x5*x8 + 8*f4*x2^2*x8^2 + 
    (-4*f1*f3*f7 - 8*f1*f4*f6 - 4*f2^2*f7 - 8*f2*f3*f6 + 4*f2*f4*f5 + 
    4*f3^2*f5 - 8*f3*f4^2)*x2*x3^3 + (32*f0*f6^2 - 20*f1*f4*f7 - 24*f1*f5*f6
    + 8*f2*f3*f7 + 16*f2*f5^2 - 8*f3^2*f6 - 36*f3*f4*f5)*x2*x3^2*x4 + 
    (-8*f0*f5 + 8*f1*f4 - 4*f2*f3)*x2*x3^2*x5 + (-16*f0*f7 - 8*f1*f6 + 
    4*f2*f5 - 8*f3*f4)*x2*x3^2*x7 + (4*f1*f7 + 8*f2*f6 - 8*f3*f5 + 
    4*f4^2)*x2*x3^2*x8 + (64*f0*f6*f7 + 24*f1*f5*f7 + 16*f1*f6^2 + 
    20*f2*f4*f7 - 16*f2*f5*f6 - 28*f3^2*f7 - 8*f3*f4*f6 - 
    8*f4^2*f5)*x2*x3*x4^2 + (-16*f0*f6 - 8*f1*f5 - 4*f2*f4 + 
    12*f3^2)*x2*x3*x4*x5 + (-24*f2*f7 - 8*f3*f6 + 16*f4*f5)*x2*x3*x4*x8 + 
    4*f2*x2*x3*x5*x8 + 12*f5*x2*x3*x8^2 + (-128*f0*f7^2 + 72*f1*f6*f7 + 
    48*f2*f5*f7 - 32*f2*f6^2 + 12*f3*f4*f7 - 32*f3*f5*f6 - 8*f4^2*f6 - 
    16*f4*f5^2)*x2*x4^3 + (88*f0*f7 - 24*f1*f6 - 16*f2*f5 - 
    4*f3*f4)*x2*x4^2*x5 + (-20*f1*f7 + 32*f2*f6 - 8*f3*f5 + 
    8*f4^2)*x2*x4^2*x6 + (-4*f2*f7 - 16*f3*f6 - 8*f4*f5)*x2*x4^2*x7 + 
    (40*f3*f7 + 8*f4*f6 + 56*f5^2)*x2*x4^2*x8 - 16*f0*x2*x4*x5^2 + 
    8*f1*x2*x4*x5*x6 - 20*f3*x2*x4*x5*x8 - 4*f2*x2*x4*x6^2 + 
    8*f5*x2*x4*x7*x8 + 32*f6*x2*x4*x8^2 - 8*x2*x6*x8^2 - 8*x2*x7^2*x8 + 
    (-8*f0*f5*f7 - 4*f2*f3*f7 - 8*f2*f4*f6 + 4*f3*f4*f5)*x3^4 + (48*f0*f6*f7
    - 40*f1*f5*f7 - 28*f2*f4*f7 - 16*f2*f5*f6 + 4*f3^2*f7 - 16*f3*f4*f6 - 
    16*f3*f5^2 + 4*f4^2*f5)*x3^3*x4 + (-16*f0*f6 + 8*f1*f5 + 8*f2*f4 - 
    4*f3^2)*x3^3*x5 + (-8*f2*f6 + 4*f3*f5)*x3^3*x7 + (4*f2*f7 - 
    4*f4*f5)*x3^3*x8 + (152*f0*f7^2 - 16*f1*f6*f7 - 84*f2*f5*f7 - 
    48*f3*f4*f7 - 80*f3*f5*f6)*x3^2*x4^2 + (-96*f0*f7 + 24*f2*f5 + 
    16*f3*f4)*x3^2*x4*x5 + (32*f1*f7 - 8*f2*f6 + 36*f3*f5 - 
    4*f4^2)*x3^2*x4*x6 + (-24*f2*f7 - 16*f3*f6 - 4*f4*f5)*x3^2*x4*x7 + 
    (-20*f3*f7 - 8*f4*f6 - 20*f5^2)*x3^2*x4*x8 + 16*f0*x3^2*x5^2 - 
    8*f1*x3^2*x5*x6 + 8*f2*x3^2*x5*x7 + 8*f3*x3^2*x5*x8 + (52*f1*f7^2 - 
    8*f2*f6*f7 - 192*f3*f5*f7 - 12*f4^2*f7 - 32*f5^3)*x3*x4^3 + (-40*f1*f7 +
    72*f3*f5 + 4*f4^2)*x3*x4^2*x5 + (-60*f3*f7 - 8*f4*f6 - 
    32*f5^2)*x3*x4^2*x7 + (-20*f4*f7 - 24*f5*f6)*x3*x4^2*x8 + 
    8*f1*x3*x4*x5^2 + 24*f3*x3*x4*x5*x7 + 8*f4*x3*x4*x5*x8 - 8*f3*x3*x4*x6^2
    - 8*f5*x3*x4*x7^2 + 16*f7*x3*x4*x8^2 - 4*x3*x5*x8^2 - 4*x3*x6*x7*x8 + 
    (60*f2*f7^2 - 16*f4*f5*f7 - 32*f5^2*f6)*x4^4 + (-44*f2*f7 + 
    8*f4*f5)*x4^3*x5 + (-20*f3*f7 + 8*f4*f6 + 8*f5^2)*x4^3*x6 + (-20*f4*f7 -
    32*f5*f6)*x4^3*x7 + (-84*f5*f7 + 32*f6^2)*x4^3*x8 + 8*f2*x4^2*x5^2 + 
    8*f3*x4^2*x5*x6 + 8*f4*x4^2*x5*x7 + 28*f5*x4^2*x5*x8 - 8*f4*x4^2*x6^2 + 
    12*f5*x4^2*x6*x7 - 40*f6*x4^2*x6*x8 - 8*f6*x4^2*x7^2 + 16*f7*x4^2*x7*x8 
    - 4*x4*x5*x7*x8 + 8*x4*x6^2*x8 + 4*x4*x6*x7^2,
(-16*f0*f1*f2 - 3*f1^3)*x1^4 + (-16*f0*f1*f3 - f1^2*f2)*x1^3*x2 + 
    (-64*f0^2*f5 + 16*f0*f1*f4 + 16*f0*f2*f3 + 8*f1^2*f3 - 
    3*f1*f2^2)*x1^3*x3 + (68*f0*f1*f5 - 16*f0*f2*f4 - 6*f1^2*f4 + 2*f1*f2*f3
    - 2*f2^3)*x1^3*x4 + 32*f0^2*x1^3*x6 + 28*f0*f1*x1^3*x7 + (-28*f0*f2 - 
    5*f1^2)*x1^3*x8 + (32*f0^2*f5 - 16*f0*f1*f4 - 3*f1^2*f3 + 
    2*f1*f2^2)*x1^2*x2^2 + (-64*f0*f1*f5 + 16*f0*f2*f4 + 16*f0*f3^2 + 
    11*f1^2*f4 - 5*f1*f2*f3 + 2*f2^3)*x1^2*x2*x3 + (128*f0^2*f7 - 
    32*f0*f1*f6 - 56*f0*f2*f5 - 16*f0*f3*f4 + 10*f1^2*f5 + 3*f1*f2*f4 + 
    2*f1*f3^2 - 4*f2^2*f3)*x1^2*x2*x4 - 32*f0^2*x1^2*x2*x5 + 
    34*f0*f1*x1^2*x2*x6 + (-4*f0*f2 + 8*f1^2)*x1^2*x2*x7 + (-60*f0*f3 + 
    4*f1*f2)*x1^2*x2*x8 + (32*f0^2*f7 - 84*f0*f1*f6 + 12*f0*f2*f5 - 
    16*f0*f3*f4 + 3*f1^2*f5 + 8*f1*f2*f4 - 7*f1*f3^2 + 2*f2^2*f3)*x1^2*x3^2 
    + (-140*f0*f1*f7 - 72*f0*f2*f6 - 112*f0*f3*f5 + 16*f0*f4^2 - 26*f1^2*f6 
    + 30*f1*f2*f5 + 8*f1*f3*f4 + 6*f2^2*f4 - 2*f2*f3^2)*x1^2*x3*x4 + 
    48*f0*f1*x1^2*x3*x5 + (-24*f0*f3 + 6*f1*f2)*x1^2*x3*x7 + (f1*f3 - 
    2*f2^2)*x1^2*x3*x8 + (-172*f0*f2*f7 + 32*f0*f4*f5 - 63*f1^2*f7 + 
    32*f1*f3*f5 - 3*f1*f4^2 + 28*f2^2*f5 + 2*f2*f3*f4)*x1^2*x4^2 + (52*f0*f2
    + 19*f1^2)*x1^2*x4*x5 + (28*f0*f3 - 6*f1*f2)*x1^2*x4*x6 + (16*f0*f4 + 
    10*f1*f3 + 10*f2^2)*x1^2*x4*x7 + (176*f0*f5 - 3*f1*f4 + 
    10*f2*f3)*x1^2*x4*x8 + 24*f0*x1^2*x7*x8 + (18*f0*f1*f5 - 5*f1^2*f4 + 
    2*f1*f2*f3)*x1*x2^3 + (-64*f0^2*f7 + 36*f0*f1*f6 + 28*f0*f2*f5 + 
    32*f0*f3*f4 - 8*f1^2*f5 - 13*f1*f2*f4 + 2*f1*f3^2 + 
    2*f2^2*f3)*x1*x2^2*x3 + (40*f0*f1*f7 + 8*f0*f2*f6 + 60*f0*f3*f5 - 
    16*f0*f4^2 + 2*f1^2*f6 - 23*f1*f2*f5 + f1*f3*f4 - 2*f2^2*f4 - 
    2*f2*f3^2)*x1*x2^2*x4 - 18*f0*f1*x1*x2^2*x5 + (-4*f0*f2 + 
    2*f1^2)*x1*x2^2*x6 + (36*f0*f3 - 6*f1*f2)*x1*x2^2*x7 + (-48*f0*f4 - 
    2*f1*f3 - 2*f2^2)*x1*x2^2*x8 + (-6*f0*f1*f7 + 48*f0*f2*f6 + 36*f0*f3*f5 
    - 16*f0*f4^2 - 4*f1^2*f6 - 5*f1*f2*f5 - 11*f1*f3*f4 - 6*f2^2*f4 + 
    4*f2*f3^2)*x1*x2*x3^2 + (128*f0*f2*f7 - 88*f0*f3*f6 - 64*f0*f4*f5 - 
    f1^2*f7 + 4*f1*f2*f6 + 6*f1*f3*f5 + 11*f1*f4^2 - 18*f2^2*f5 + 2*f2*f3*f4
    - 2*f3^3)*x1*x2*x3*x4 + (-28*f0*f2 + 3*f1^2)*x1*x2*x3*x5 + (-72*f0*f5 + 
    5*f1*f4 - 4*f2*f3)*x1*x2*x3*x8 + (-132*f0*f3*f7 - 32*f0*f4*f6 - 
    176*f0*f5^2 - 2*f1*f2*f7 + 4*f1*f3*f6 + 38*f1*f4*f5 - 8*f2^2*f6 + 
    6*f2*f3*f5 + 4*f2*f4^2 + 2*f3^2*f4)*x1*x2*x4^2 + (48*f0*f3 - 
    f1*f2)*x1*x2*x4*x5 + (56*f0*f4 - 2*f1*f3 + 6*f2^2)*x1*x2*x4*x6 + 
    (-88*f0*f5 + 16*f1*f4 - 2*f2*f3)*x1*x2*x4*x7 + (11*f1*f5 - 8*f2*f4 + 
    8*f3^2)*x1*x2*x4*x8 + 28*f0*x1*x2*x6*x8 + (-12*f0*f2*f7 + 72*f0*f3*f6 - 
    32*f0*f4*f5 - f1^2*f7 - 2*f1*f2*f6 - 11*f1*f3*f5 - 5*f1*f4^2 - 2*f2^2*f5
    - 6*f2*f3*f4 + 2*f3^3)*x1*x3^3 + (140*f0*f3*f7 - 32*f0*f4*f6 - 
    16*f0*f5^2 - 8*f1*f2*f7 + 6*f1*f3*f6 - 17*f1*f4*f5 - 12*f2^2*f6 - 
    16*f2*f3*f5 - 4*f2*f4^2 - 2*f3^2*f4)*x1*x3^2*x4 + (-40*f0*f3 + 
    2*f1*f2)*x1*x3^2*x5 + (24*f0*f4 + 6*f1*f3 + 2*f2^2)*x1*x3^2*x6 + 
    (-24*f0*f5 - 8*f1*f4 - 2*f2*f3)*x1*x3^2*x7 + (-40*f0*f6 + 5*f1*f5 + 
    2*f2*f4 - 2*f3^2)*x1*x3^2*x8 + (32*f0*f4*f7 + 64*f0*f5*f6 + 17*f1*f3*f7 
    - 14*f1*f4*f6 - 4*f1*f5^2 - 32*f2^2*f7 + 4*f2*f3*f6 - 20*f2*f4*f5 - 
    12*f3^2*f5)*x1*x3*x4^2 + (-7*f1*f3 + 10*f2^2)*x1*x3*x4*x5 + (-32*f0*f6 -
    14*f1*f5 - 10*f2*f4 - 6*f3^2)*x1*x3*x4*x7 + (-64*f0*f7 + 12*f1*f6 + 
    10*f2*f5 - 20*f3*f4)*x1*x3*x4*x8 - 3*f1*x1*x3*x7^2 - 2*f2*x1*x3*x7*x8 - 
    2*f3*x1*x3*x8^2 + (320*f0*f5*f7 - 45*f1*f4*f7 + 36*f1*f5*f6 + 
    14*f2*f3*f7 - 64*f2*f5^2 - 4*f3*f4*f5)*x1*x4^3 + (-96*f0*f5 + 13*f1*f4 -
    4*f2*f3)*x1*x4^2*x5 + (32*f0*f6 - 28*f1*f5 - 4*f3^2)*x1*x4^2*x6 + 
    (16*f0*f7 + 12*f1*f6 - 52*f2*f5 - 2*f3*f4)*x1*x4^2*x7 + (38*f1*f7 - 
    36*f3*f5 - 4*f4^2)*x1*x4^2*x8 - 9*f1*x1*x4*x5*x8 - 44*f0*x1*x4*x6^2 - 
    8*f1*x1*x4*x6*x7 - 8*f2*x1*x4*x6*x8 - 10*f2*x1*x4*x7^2 - 
    4*f3*x1*x4*x7*x8 + 6*f4*x1*x4*x8^2 + (-4*f0*f2*f5 + 3*f1^2*f5 + 
    2*f1*f2*f4)*x2^4 + (-8*f0*f2*f6 - 4*f0*f3*f5 + 16*f0*f4^2 + 2*f1^2*f6 + 
    7*f1*f2*f5 + 2*f1*f3*f4 + 2*f2^2*f4)*x2^3*x3 + (-8*f0*f2*f7 + 
    72*f0*f4*f5 + 4*f1^2*f7 - 5*f1*f3*f5 - 5*f1*f4^2 + 8*f2^2*f5 - 
    2*f2*f3*f4)*x2^3*x4 + (4*f0*f2 - f1^2)*x2^3*x5 - 2*f1*f2*x2^3*x6 + 
    (32*f0*f4 + 2*f1*f3 + 2*f2^2)*x2^3*x7 - 12*f0*f5*x2^3*x8 + (-4*f0*f2*f7 
    - 8*f0*f3*f6 + 8*f0*f4*f5 + f1^2*f7 + 2*f1*f2*f6 + 5*f1*f3*f5 + 
    2*f1*f4^2 + 2*f2^2*f5 + 4*f2*f3*f4)*x2^2*x3^2 + (-8*f0*f3*f7 - 
    48*f0*f4*f6 + 112*f0*f5^2 + 4*f1*f2*f7 - 14*f1*f3*f6 - 7*f1*f4*f5 + 
    4*f2^2*f6 + 6*f2*f3*f5 - 4*f2*f4^2 - 2*f3^2*f4)*x2^2*x3*x4 + (4*f0*f3 - 
    f1*f2)*x2^2*x3*x5 + (56*f0*f5 + 2*f1*f4 + 4*f2*f3)*x2^2*x3*x7 + 
    (-8*f0*f6 - 5*f1*f5)*x2^2*x3*x8 + (-80*f0*f4*f7 - 32*f0*f5*f6 - 
    20*f1*f3*f7 + 2*f1*f4*f6 + f1*f5^2 + 2*f2^2*f7 - 6*f2*f4*f5 + 2*f3^2*f5 
    + 4*f3*f4^2)*x2^2*x4^2 + (24*f0*f4 + 7*f1*f3 - 2*f2^2)*x2^2*x4*x5 + 
    (12*f0*f5 + 6*f1*f4 + 2*f2*f3)*x2^2*x4*x6 + (-8*f0*f6 + 2*f1*f5 - 
    2*f3^2)*x2^2*x4*x7 + (-16*f0*f7 + 8*f2*f5 + 6*f3*f4)*x2^2*x4*x8 + 
    4*f0*x2^2*x5*x8 + (-4*f0*f3*f7 + 16*f0*f4*f6 - 16*f0*f5^2 + f1*f2*f7 + 
    2*f1*f3*f6 + 4*f2*f3*f5 + 4*f2*f4^2 + 2*f3^2*f4)*x2*x3^3 + (-8*f0*f4*f7 
    - f1*f3*f7 - 14*f1*f4*f6 + f1*f5^2 + 4*f2^2*f7 + 14*f2*f4*f5 - 
    8*f3*f4^2)*x2*x3^2*x4 + (-8*f0*f4 - f1*f3)*x2*x3^2*x5 + (32*f0*f6 + 
    4*f2*f4 + 2*f3^2)*x2*x3^2*x7 + (-4*f0*f7 - 2*f1*f6 - 4*f2*f5)*x2*x3^2*x8
    + (-176*f0*f5*f7 - 8*f1*f4*f7 - 14*f1*f5*f6 - 6*f2*f3*f7 - 8*f2*f4*f6 + 
    16*f2*f5^2 + 12*f3^2*f6 + 4*f3*f4*f5)*x2*x3*x4^2 + (48*f0*f5 + 
    7*f1*f4)*x2*x3*x4*x5 + (-6*f1*f7 + 22*f3*f5 + 6*f4^2)*x2*x3*x4*x8 + 
    f1*x2*x3*x5*x8 + 16*f0*x2*x3*x6^2 - 2*f4*x2*x3*x8^2 + (-23*f1*f5*f7 - 
    18*f2*f4*f7 + 48*f2*f5*f6 + 16*f3^2*f7 + 4*f3*f4*f6 + 12*f3*f5^2 + 
    4*f4^2*f5)*x2*x4^3 + (15*f1*f5 + 8*f2*f4 - 6*f3^2)*x2*x4^2*x5 + 
    (16*f0*f7 - 2*f1*f6 - 14*f2*f5 - 10*f3*f4)*x2*x4^2*x6 + (8*f1*f7 + 
    16*f2*f6 - 2*f3*f5 + 2*f4^2)*x2*x4^2*x7 + (8*f2*f7 + 4*f4*f5)*x2*x4^2*x8
    - 4*f0*x2*x4*x5*x6 - f1*x2*x4*x6^2 - 6*f3*x2*x4*x6*x8 - 4*f3*x2*x4*x7^2 
    - 12*f5*x2*x4*x8^2 + (8*f0*f4*f7 + 8*f0*f5*f6 + f1*f3*f7 + 2*f1*f4*f6 + 
    2*f3^2*f5 + 4*f3*f4^2)*x3^4 + (72*f0*f5*f7 - 16*f0*f6^2 - f1*f4*f7 + 
    14*f1*f5*f6 + 4*f2*f3*f7 + 8*f2*f4*f6 + 2*f2*f5^2 - 4*f3^2*f6 + 
    2*f3*f4*f5)*x3^3*x4 + (-24*f0*f5 - 2*f1*f4)*x3^3*x5 + (16*f0*f7 + 
    2*f1*f6 + 4*f3*f4)*x3^3*x7 + (-f1*f7 - 4*f3*f5 - 2*f4^2)*x3^3*x8 + 
    (-40*f0*f6*f7 + 39*f1*f5*f7 - 12*f1*f6^2 + 18*f2*f4*f7 + 28*f2*f5*f6 - 
    4*f3^2*f7 - 8*f3*f4*f6 - 8*f3*f5^2 - 4*f4^2*f5)*x3^2*x4^2 + (-8*f0*f6 - 
    14*f1*f5 - 8*f2*f4 + 2*f3^2)*x3^2*x4*x5 + (-4*f0*f7 - 6*f2*f5 + 
    12*f3*f4)*x3^2*x4*x6 + (6*f1*f7 + 8*f2*f6 - 2*f3*f5 - 2*f4^2)*x3^2*x4*x7
    + (-4*f2*f7 + 8*f3*f6 - 2*f4*f5)*x3^2*x4*x8 + 16*f0*x3^2*x5*x6 - 
    2*f1*x3^2*x5*x7 + (-8*f0*f7^2 - 60*f1*f6*f7 + 98*f2*f5*f7 - 16*f2*f6^2 -
    6*f3*f4*f7 + 24*f3*f5*f6)*x3*x4^3 + (-16*f0*f7 + 18*f1*f6 - 34*f2*f5 + 
    2*f3*f4)*x3*x4^2*x5 + (22*f2*f7 + 16*f3*f6)*x3*x4^2*x7 + (14*f3*f7 + 
    4*f4*f6 - 8*f5^2)*x3*x4^2*x8 + 8*f0*x3*x4*x5^2 - 8*f2*x3*x4*x5*x7 - 
    4*f3*x3*x4*x5*x8 + 4*f2*x3*x4*x6^2 + 8*f5*x3*x4*x7*x8 - 8*f6*x3*x4*x8^2 
    + 2*x3*x6*x8^2 + 2*x3*x7^2*x8 + (-66*f1*f7^2 - 24*f2*f6*f7 + 44*f3*f5*f7
    + 32*f5^3)*x4^4 + (39*f1*f7 + 8*f2*f6 - 16*f3*f5)*x4^3*x5 + (-14*f2*f7 -
    4*f3*f6 - 4*f4*f5)*x4^3*x6 + (28*f3*f7 + 40*f5^2)*x4^3*x7 + (14*f4*f7 - 
    32*f5*f6)*x4^3*x8 - 6*f1*x4^2*x5^2 + 4*f2*x4^2*x5*x6 - 10*f3*x4^2*x5*x7 
    - 6*f4*x4^2*x5*x8 + 6*f3*x4^2*x6^2 - 2*f4*x4^2*x6*x7 + 28*f5*x4^2*x6*x8 
    + 16*f5*x4^2*x7^2 - 8*f6*x4^2*x7*x8 - 16*f7*x4^2*x8^2 + 4*x4*x5*x8^2 + 
    6*x4*x6*x7*x8 + 2*x4*x7^3,
(-40*f1^2*f3*f7 + 60*f1^2*f4*f6 - 84*f1^2*f5^2 - 60*f1*f2*f3*f6 - 
    90*f1*f2*f4*f5 + 15*f2^2*f4^2)*x1^4 + (-40*f1^2*f4*f7 - 60*f1^2*f5*f6 - 
    40*f1*f2*f3*f7 + 100*f1*f2*f4*f6 - 44*f1*f2*f5^2 - 60*f1*f3^2*f6 - 
    90*f1*f3*f4*f5 - 10*f2^2*f4*f5 + 30*f2*f3*f4^2)*x1^3*x2 + 
    (-240*f0*f3*f5*f6 + 120*f0*f4^2*f6 - 360*f0*f4*f5^2 + 112*f1^2*f5*f7 - 
    40*f1^2*f6^2 - 10*f1*f2*f4*f7 + 16*f1*f2*f5*f6 + 80*f1*f3^2*f7 - 
    20*f1*f3*f4*f6 + 144*f1*f3*f5^2 + 110*f1*f4^2*f5 - 40*f2^2*f3*f7 + 
    80*f2^2*f4*f6 - 56*f2^2*f5^2 + 60*f2*f3^2*f6 + 70*f2*f3*f4*f5 - 
    30*f2*f4^3)*x1^3*x3 + (480*f0*f3*f5*f7 + 180*f0*f4^2*f7 - 
    720*f0*f4*f5*f6 + 1008*f0*f5^3 - 60*f1^2*f6*f7 + 188*f1*f2*f5*f7 - 
    20*f1*f3*f4*f7 + 120*f1*f3*f5*f6 + 120*f1*f4^2*f6 + 12*f1*f4*f5^2 + 
    32*f2^2*f5*f6 - 60*f2*f3*f4*f6 - 72*f2*f3*f5^2 - 90*f2*f4^2*f5)*x1^3*x4 
    + (-60*f0*f4^2 + 20*f1^2*f6 - 12*f1*f2*f5 - 20*f1*f3*f4 + 
    10*f2^2*f4)*x1^3*x5 + (120*f0*f3*f6 + 180*f0*f4*f5 - 20*f1^2*f7 + 
    12*f1*f3*f5 - 10*f1*f4^2 + 10*f2*f3*f4)*x1^3*x6 + (160*f0*f3*f7 - 
    240*f0*f4*f6 + 336*f0*f5^2 + 20*f1*f2*f7 + 60*f1*f3*f6 + 90*f1*f4*f5 - 
    24*f2*f3*f5 - 10*f2*f4^2)*x1^3*x7 + (20*f0*f4*f7 + 48*f0*f5*f6 - 
    30*f1*f3*f7 + 80*f1*f4*f6 - 148*f1*f5^2 - 80*f2*f3*f6 - 86*f2*f4*f5 - 
    32*f3^2*f5)*x1^3*x8 + (120*f0*f3*f5*f6 - 60*f0*f4^2*f6 + 180*f0*f4*f5^2 
    - 140*f1^2*f5*f7 + 20*f1^2*f6^2 - 20*f1*f2*f4*f7 - 52*f1*f2*f5*f6 - 
    40*f1*f3^2*f7 + 20*f1*f3*f4*f6 - 32*f1*f3*f5^2 - 100*f1*f4^2*f5 + 
    5*f2^2*f5^2 - 10*f2*f3*f4*f5 + 30*f2*f4^3 + 15*f3^2*f4^2)*x1^2*x2^2 + 
    (-320*f0*f3*f5*f7 + 60*f0*f4^2*f7 + 560*f0*f4*f5*f6 - 512*f0*f5^3 + 
    20*f1^2*f6*f7 - 206*f1*f2*f5*f7 + 210*f1*f3*f4*f7 + 36*f1*f3*f5*f6 - 
    180*f1*f4^2*f6 + 46*f1*f4*f5^2 - 20*f2^2*f4*f7 - 32*f2^2*f5*f6 - 
    40*f2*f3^2*f7 + 120*f2*f3*f4*f6 - 24*f2*f3*f5^2 + 100*f2*f4^2*f5 + 
    60*f3^3*f6 + 70*f3^2*f4*f5 - 30*f3*f4^3)*x1^2*x2*x3 + (480*f0*f3*f6*f7 +
    1040*f0*f4*f5*f7 + 624*f0*f5^2*f6 + 40*f1^2*f7^2 - 60*f1*f2*f6*f7 + 
    236*f1*f3*f5*f7 - 120*f1*f3*f6^2 - 60*f1*f4^2*f7 - 540*f1*f4*f5*f6 + 
    216*f1*f5^3 - 20*f2^2*f5*f7 + 164*f2*f3*f5*f6 + 160*f2*f4^2*f6 - 
    150*f2*f4*f5^2 - 60*f3^2*f4*f6 - 8*f3^2*f5^2 - 90*f3*f4^2*f5)*x1^2*x2*x4
    + (-120*f0*f3*f6 - 140*f0*f4*f5 - 20*f1^2*f7 + 20*f1*f2*f6 - 4*f1*f3*f5 
    - 10*f1*f4^2 - 10*f2^2*f5 + 10*f2*f3*f4)*x1^2*x2*x5 + (80*f0*f3*f7 - 
    200*f0*f4*f6 + 88*f0*f5^2 + 20*f1*f2*f7 + 60*f1*f3*f6 + 128*f1*f4*f5 - 
    10*f2*f3*f5 - 20*f2*f4^2 + 10*f3^2*f4)*x1^2*x2*x6 + (140*f0*f4*f7 + 
    192*f0*f5*f6 + 90*f1*f3*f7 - 180*f1*f4*f6 + 192*f1*f5^2 - 20*f2^2*f7 + 
    80*f2*f3*f6 + 30*f2*f4*f5 + 8*f3^2*f5 - 10*f3*f4^2)*x1^2*x2*x7 + 
    (332*f0*f5*f7 - 60*f1*f4*f7 - 96*f1*f5*f6 + 40*f2*f3*f7 - 80*f2*f4*f6 + 
    18*f2*f5^2 - 140*f3^2*f6 - 226*f3*f4*f5 + 30*f4^3)*x1^2*x2*x8 + 
    (-360*f0*f3*f6*f7 + 160*f0*f4*f5*f7 + 880*f0*f4*f6^2 - 752*f0*f5^2*f6 + 
    5*f1^2*f7^2 - 182*f1*f3*f5*f7 - 120*f1*f4*f5*f6 + 12*f1*f5^3 - 
    36*f2^2*f5*f7 + 100*f2*f3*f4*f7 + 28*f2*f3*f5*f6 - 180*f2*f4^2*f6 + 
    148*f2*f4*f5^2 - 40*f3^3*f7 - 40*f3^2*f4*f6 - 72*f3^2*f5^2 - 
    90*f3*f4^2*f5 + 15*f4^4)*x1^2*x3^2 + (-1120*f0*f3*f7^2 + 
    1960*f0*f4*f6*f7 - 2608*f0*f5^2*f7 + 352*f0*f5*f6^2 + 20*f1*f2*f7^2 - 
    320*f1*f3*f6*f7 - 70*f1*f4*f5*f7 + 560*f1*f4*f6^2 - 608*f1*f5^2*f6 + 
    20*f2^2*f6*f7 + 168*f2*f3*f5*f7 - 160*f2*f3*f6^2 - 120*f2*f4^2*f7 - 
    780*f2*f4*f5*f6 + 280*f2*f5^3 + 20*f3^2*f4*f7 - 304*f3^2*f5*f6 + 
    100*f3*f4^2*f6 - 284*f3*f4*f5^2 + 110*f4^3*f5)*x1^2*x3*x4 + 
    (320*f0*f3*f7 - 480*f0*f4*f6 + 512*f0*f5^2 - 10*f1*f2*f7 + 40*f1*f3*f6 +
    44*f1*f4*f5 - 32*f2*f3*f5 + 20*f3^2*f4)*x1^2*x3*x5 + (-368*f0*f5*f7 - 
    10*f1*f4*f7 + 40*f2*f3*f7 - 160*f2*f4*f6 + 96*f2*f5^2 - 20*f3^2*f6 - 
    46*f3*f4*f5 + 10*f4^3)*x1^2*x3*x7 + (-160*f0*f6*f7 + 234*f1*f5*f7 + 
    40*f2*f4*f7 + 64*f2*f5*f6 + 20*f3^2*f7 - 40*f3*f4*f6 - 16*f3*f5^2 - 
    4*f4^2*f5)*x1^2*x3*x8 + (60*f0*f4*f7^2 + 528*f0*f5*f6*f7 - 
    890*f1*f3*f7^2 + 1320*f1*f4*f6*f7 - 1732*f1*f5^2*f7 + 80*f2^2*f7^2 - 
    480*f2*f3*f6*f7 - 790*f2*f4*f5*f7 - 488*f2*f5^2*f6 + 564*f3^2*f5*f7 + 
    200*f3*f4^2*f7 - 600*f3*f4*f5*f6 + 1152*f3*f5^3 + 60*f4^3*f6 + 
    36*f4^2*f5^2)*x1^2*x4^2 + (100*f0*f4*f7 - 176*f0*f5*f6 + 330*f1*f3*f7 - 
    400*f1*f4*f6 + 420*f1*f5^2 - 40*f2^2*f7 + 140*f2*f3*f6 + 124*f2*f4*f5 - 
    28*f3^2*f5 - 80*f3*f4^2)*x1^2*x4*x5 + (-136*f0*f5*f7 - 40*f1*f4*f7 + 
    60*f1*f5*f6 - 80*f2*f3*f7 + 120*f2*f4*f6 + 8*f2*f5^2 + 120*f3^2*f6 + 
    172*f3*f4*f5 - 10*f4^3)*x1^2*x4*x6 + (-204*f1*f5*f7 - 100*f2*f4*f7 - 
    184*f2*f5*f6 + 220*f3^2*f7 - 180*f3*f4*f6 + 456*f3*f5^2 + 
    50*f4^2*f5)*x1^2*x4*x7 + (-360*f0*f7^2 + 80*f1*f6*f7 - 12*f2*f5*f7 + 
    120*f3*f4*f7 + 376*f3*f5*f6 - 160*f4^2*f6 + 676*f4*f5^2)*x1^2*x4*x8 + 
    (-40*f0*f4 - 20*f1*f3 + 5*f2^2)*x1^2*x5^2 + (24*f0*f5 + 20*f1*f4 + 
    10*f2*f3)*x1^2*x5*x6 + (4*f1*f5 - 20*f2*f4 - 20*f3^2)*x1^2*x5*x7 + 
    (120*f0*f7 - 20*f1*f6 + 16*f2*f5 - 50*f3*f4)*x1^2*x5*x8 + (-20*f0*f6 - 
    8*f1*f5 - 10*f2*f4 + 5*f3^2)*x1^2*x6^2 + (40*f0*f7 + 20*f2*f5 - 
    10*f3*f4)*x1^2*x6*x7 + (-40*f1*f7 + 54*f3*f5)*x1^2*x6*x8 + (-20*f1*f7 + 
    24*f3*f5 - 5*f4^2)*x1^2*x7^2 + (40*f2*f7 + 66*f4*f5)*x1^2*x7*x8 + 
    9*f5^2*x1^2*x8^2 + (80*f0*f3*f5*f7 - 60*f0*f4^2*f7 - 160*f0*f4*f5*f6 + 
    88*f0*f5^3 - 80*f1*f3*f4*f7 - 32*f1*f3*f5*f6 + 80*f1*f4^2*f6 - 
    6*f1*f4*f5^2 - 10*f2*f4^2*f5 + 30*f3*f4^3)*x1*x2^3 + (-80*f0*f3*f6*f7 - 
    620*f0*f4*f5*f7 - 320*f0*f4*f6^2 - 136*f0*f5^2*f6 + 40*f1*f3*f5*f7 + 
    130*f1*f4^2*f7 + 280*f1*f4*f5*f6 - 48*f1*f5^3 - 80*f2*f3*f4*f7 - 
    32*f2*f3*f5*f6 + 60*f2*f4^2*f6 - 18*f2*f4*f5^2 + 120*f3^2*f4*f6 + 
    170*f3*f4^2*f5 - 30*f4^4)*x1*x2^2*x3 + (320*f0*f3*f7^2 - 800*f0*f4*f6*f7
    + 1052*f0*f5^2*f7 - 128*f0*f5*f6^2 - 100*f1*f3*f6*f7 - 40*f1*f4*f5*f7 + 
    228*f1*f5^2*f6 - 160*f2*f3*f5*f7 + 80*f2*f4^2*f7 + 352*f2*f4*f5*f6 - 
    164*f2*f5^3 + 312*f3^2*f5*f6 + 20*f3*f4^2*f6 + 230*f3*f4*f5^2 - 
    160*f4^3*f5)*x1*x2^2*x4 + (-80*f0*f3*f7 + 160*f0*f4*f6 - 84*f0*f5^2 - 
    30*f1*f4*f5 + 10*f2*f4^2)*x1*x2^2*x5 + (40*f0*f4*f7 + 64*f0*f5*f6 + 
    40*f1*f3*f7 - 80*f1*f4*f6 + 40*f1*f5^2 - 10*f3*f4^2)*x1*x2^2*x6 + 
    (188*f0*f5*f7 + 100*f1*f4*f7 + 140*f1*f5*f6 - 40*f2*f3*f7 + 80*f2*f4*f6 
    - 32*f2*f5^2 + 120*f3^2*f6 + 136*f3*f4*f5 - 40*f4^3)*x1*x2^2*x7 + 
    (80*f0*f6*f7 - 88*f1*f5*f7 + 40*f2*f4*f7 + 32*f2*f5*f6 - 160*f3*f4*f6 - 
    4*f3*f5^2 - 224*f4^2*f5)*x1*x2^2*x8 + (80*f0*f3*f7^2 - 440*f0*f4*f6*f7 +
    236*f0*f5^2*f7 - 496*f0*f5*f6^2 - 22*f1*f4*f5*f7 - 16*f1*f5^2*f6 + 
    80*f2*f3*f5*f7 + 80*f2*f4^2*f7 + 144*f2*f4*f5*f6 - 14*f2*f5^3 - 
    80*f3^2*f4*f7 - 32*f3^2*f5*f6 - 100*f3*f4^2*f6 - 38*f3*f4*f5^2 - 
    80*f4^3*f5)*x1*x2*x3^2 + (-800*f0*f4*f7^2 - 440*f0*f5*f6*f7 + 
    140*f1*f3*f7^2 - 380*f1*f4*f6*f7 + 228*f1*f5^2*f7 - 368*f1*f5*f6^2 + 
    60*f2*f3*f6*f7 + 256*f2*f4*f5*f7 + 160*f2*f4*f6^2 + 76*f2*f5^2*f6 - 
    260*f3^2*f5*f7 - 160*f3^2*f6^2 + 40*f3*f4^2*f7 - 200*f3*f4*f5*f6 - 
    304*f3*f5^3 - 60*f4^3*f6 - 108*f4^2*f5^2)*x1*x2*x3*x4 + (260*f0*f4*f7 + 
    320*f0*f5*f6 + 20*f1*f4*f6 + 12*f1*f5^2 - 28*f2*f4*f5 + 
    40*f3*f4^2)*x1*x2*x3*x5 + (80*f0*f7^2 - 88*f2*f5*f7 + 80*f3*f4*f7 - 
    88*f3*f5*f6 + 60*f4^2*f6 - 176*f4*f5^2)*x1*x2*x3*x8 + (212*f0*f5*f7^2 - 
    540*f1*f4*f7^2 - 504*f1*f5*f6*f7 - 200*f2*f3*f7^2 + 580*f2*f4*f6*f7 - 
    1070*f2*f5^2*f7 + 128*f2*f5*f6^2 - 180*f3^2*f6*f7 + 438*f3*f4*f5*f7 - 
    120*f3*f4*f6^2 - 544*f3*f5^2*f6 + 250*f4^3*f7 - 720*f4^2*f5*f6 + 
    172*f4*f5^3)*x1*x2*x4^2 + (-140*f0*f5*f7 + 220*f1*f4*f7 + 236*f1*f5*f6 +
    40*f2*f3*f7 - 80*f2*f4*f6 + 62*f2*f5^2 + 80*f3^2*f6 + 112*f3*f4*f5 - 
    100*f4^3)*x1*x2*x4*x5 + (-40*f0*f6*f7 + 20*f1*f5*f7 - 80*f2*f4*f7 - 
    96*f2*f5*f6 + 40*f3^2*f7 + 120*f3*f4*f6 + 92*f3*f5^2 + 
    278*f4^2*f5)*x1*x2*x4*x6 + (40*f0*f7^2 + 20*f1*f6*f7 - 272*f2*f5*f7 + 
    220*f3*f4*f7 - 308*f3*f5*f6 - 200*f4^2*f6 + 2*f4*f5^2)*x1*x2*x4*x7 + 
    (60*f1*f7^2 - 60*f2*f6*f7 + 448*f3*f5*f7 - 80*f3*f6^2 + 140*f4^2*f7 - 
    392*f4*f5*f6 + 348*f5^3)*x1*x2*x4*x8 + (16*f0*f5 - 20*f1*f4)*x1*x2*x5^2 
    + (-4*f3*f5 - 30*f4^2)*x1*x2*x5*x8 + (-20*f0*f7 + 10*f2*f5 - 
    10*f3*f4)*x1*x2*x6^2 + (40*f3*f6 + 96*f4*f5)*x1*x2*x6*x8 + 
    (20*f0*f4*f7^2 + 48*f0*f5*f6*f7 - 6*f1*f5^2*f7 + 106*f2*f4*f5*f7 + 
    96*f2*f5^2*f6 + 40*f3^2*f5*f7 - 50*f3*f4^2*f7 - 4*f3*f4*f5*f6 - 
    112*f3*f5^3 + 100*f4^3*f6 - 202*f4^2*f5^2)*x1*x3^3 + (644*f0*f5*f7^2 - 
    160*f0*f6^2*f7 + 60*f1*f4*f7^2 + 128*f1*f5*f6*f7 + 60*f2*f3*f7^2 + 
    120*f2*f4*f6*f7 + 220*f2*f5^2*f7 + 248*f2*f5*f6^2 - 220*f3^2*f6*f7 - 
    14*f3*f4*f5*f7 + 320*f3*f4*f6^2 - 392*f3*f5^2*f6 + 110*f4^3*f7 + 
    384*f4^2*f5*f6 - 168*f4*f5^3)*x1*x3^2*x4 + (-200*f0*f5*f7 + 10*f1*f4*f7 
    + 20*f1*f5*f6 - 30*f3*f4*f5 - 10*f4^3)*x1*x3^2*x5 + (40*f0*f6*f7 + 
    12*f1*f5*f7 - 60*f2*f4*f7 - 124*f2*f5*f6 + 40*f3^2*f7 + 80*f3*f4*f6 + 
    102*f3*f5^2 + 120*f4^2*f5)*x1*x3^2*x6 + (-60*f0*f7^2 + 76*f2*f5*f7 - 
    60*f3*f4*f7 - 44*f3*f5*f6 + 180*f4^2*f6 - 152*f4*f5^2)*x1*x3^2*x7 + 
    (-164*f3*f5*f7 + 10*f4^2*f7 - 84*f4*f5*f6 + 98*f5^3)*x1*x3^2*x8 + 
    (-320*f0*f6*f7^2 + 634*f1*f5*f7^2 - 80*f1*f6^2*f7 + 420*f2*f4*f7^2 + 
    528*f2*f5*f6*f7 - 500*f3^2*f7^2 + 980*f3*f4*f6*f7 - 1104*f3*f5^2*f7 + 
    768*f3*f5*f6^2 + 946*f4^2*f5*f7 + 240*f4^2*f6^2 + 528*f4*f5^2*f6 + 
    672*f5^4)*x1*x3*x4^2 + (-134*f1*f5*f7 + 40*f1*f6^2 - 100*f2*f4*f7 - 
    168*f2*f5*f6 + 140*f3^2*f7 - 240*f3*f4*f6 + 248*f3*f5^2 - 
    122*f4^2*f5)*x1*x3*x4*x5 + (-40*f1*f7^2 + 40*f2*f6*f7 - 176*f3*f5*f7 + 
    200*f4^2*f7 + 396*f4*f5*f6 + 88*f5^3)*x1*x3*x4*x7 + (-40*f2*f7^2 - 
    60*f3*f6*f7 - 220*f4*f5*f7 - 320*f4*f6^2 + 4*f5^2*f6)*x1*x3*x4*x8 + 
    (40*f0*f6 - 20*f1*f5 - 10*f2*f4)*x1*x3*x5^2 + (-20*f0*f7 - 20*f1*f6 + 
    18*f2*f5)*x1*x3*x5*x6 + 10*f1*f7*x1*x3*x5*x7 + (-10*f1*f7 + 20*f2*f6 + 
    16*f3*f5)*x1*x3*x6^2 + (80*f4*f6 - 40*f5^2)*x1*x3*x7^2 + (-20*f4*f7 - 
    32*f5*f6)*x1*x3*x7*x8 + 8*f5*f7*x1*x3*x8^2 + (-120*f0*f7^3 - 
    120*f1*f6*f7^2 + 276*f2*f5*f7^2 - 200*f3*f4*f7^2 + 2472*f3*f5*f6*f7 + 
    840*f4^2*f6*f7 + 1100*f4*f5^2*f7 - 720*f4*f5*f6^2 + 
    1856*f5^3*f6)*x1*x4^3 + (-80*f0*f7^2 + 100*f1*f6*f7 - 16*f2*f5*f7 + 
    10*f3*f4*f7 - 624*f3*f5*f6 - 240*f4^2*f6 - 184*f4*f5^2)*x1*x4^2*x5 + 
    (-20*f1*f7^2 + 20*f2*f6*f7 - 606*f3*f5*f7 + 120*f3*f6^2 - 240*f4^2*f7 + 
    720*f4*f5*f6 - 1024*f5^3)*x1*x4^2*x6 + (400*f3*f6*f7 + 594*f4*f5*f7 - 
    240*f4*f6^2 + 1064*f5^2*f6)*x1*x4^2*x7 + (460*f3*f7^2 - 960*f4*f6*f7 + 
    1510*f5^2*f7 - 64*f5*f6^2)*x1*x4^2*x8 + (100*f0*f7 - 20*f1*f6 - 24*f2*f5
    + 10*f3*f4)*x1*x4*x5^2 + (-60*f1*f7 + 58*f3*f5 + 90*f4^2)*x1*x4*x5*x6 + 
    (20*f2*f7 - 60*f3*f6 + 8*f4*f5)*x1*x4*x5*x7 + (-60*f3*f7 + 160*f4*f6 - 
    114*f5^2)*x1*x4*x5*x8 + (40*f2*f7 - 140*f3*f6 - 198*f4*f5)*x1*x4*x6^2 + 
    (-160*f3*f7 + 120*f4*f6 - 384*f5^2)*x1*x4*x6*x7 + (-60*f4*f7 + 
    72*f5*f6)*x1*x4*x6*x8 + (100*f4*f7 + 152*f5*f6)*x1*x4*x7^2 + (224*f5*f7 
    - 56*f6^2)*x1*x4*x7*x8 + 80*f6*f7*x1*x4*x8^2 - 20*f0*x1*x5^3 + 
    20*f1*x1*x5^2*x6 - 10*f2*x1*x5^2*x7 - 10*f2*x1*x5*x6^2 + 
    30*f3*x1*x5*x6*x7 + 70*f4*x1*x5*x6*x8 + 10*f4*x1*x5*x7^2 - 
    32*f6*x1*x5*x8^2 - 10*f3*x1*x6^3 + 10*f4*x1*x6^2*x7 - 20*f5*x1*x6*x7^2 -
    28*f6*x1*x6*x7*x8 - 78*f7*x1*x6*x8^2 + (80*f0*f4*f5*f7 + 64*f0*f5^2*f6 -
    40*f1*f4^2*f7 - 32*f1*f4*f5*f6 + 4*f1*f5^3 + 15*f4^4)*x2^4 + 
    (160*f0*f4*f6*f7 - 160*f0*f5^2*f7 + 128*f0*f5*f6^2 + 40*f1*f4*f5*f7 - 
    24*f1*f5^2*f6 - 40*f2*f4^2*f7 - 32*f2*f4*f5*f6 + 4*f2*f5^3 + 
    60*f3*f4^2*f6 + 100*f4^3*f5)*x2^3*x3 + (160*f0*f4*f7^2 + 168*f0*f5*f6*f7
    - 20*f1*f4*f6*f7 + 84*f1*f5^2*f7 - 160*f2*f4*f5*f7 - 128*f2*f5^2*f6 + 
    312*f3*f4*f5*f6 + 80*f4^3*f6 + 314*f4^2*f5^2)*x2^3*x4 + (-80*f0*f4*f7 - 
    64*f0*f5*f6 - 4*f1*f5^2)*x2^3*x5 + (40*f1*f4*f7 + 32*f1*f5*f6 - 
    20*f4^3)*x2^3*x6 + (80*f1*f5*f7 - 40*f2*f4*f7 - 32*f2*f5*f6 + 
    120*f3*f4*f6 + 158*f4^2*f5)*x2^3*x7 + (-20*f4^2*f6 - 4*f4*f5^2)*x2^3*x8 
    + (80*f0*f4*f7^2 - 256*f0*f5*f6*f7 + 4*f1*f5^2*f7 + 80*f2*f4*f5*f7 + 
    8*f2*f5^2*f6 - 40*f3*f4^2*f7 - 32*f3*f4*f5*f6 + 4*f3*f5^3 - 60*f4^3*f6 -
    2*f4^2*f5^2)*x2^2*x3^2 + (-280*f0*f5*f7^2 + 80*f0*f6^2*f7 + 
    20*f1*f4*f7^2 - 316*f1*f5*f6*f7 - 100*f2*f4*f6*f7 + 244*f2*f5^2*f7 - 
    64*f2*f5*f6^2 - 340*f3*f4*f5*f7 - 160*f3*f4*f6^2 + 192*f3*f5^2*f6 - 
    40*f4^3*f7 - 192*f4^2*f5*f6 + 66*f4*f5^3)*x2^2*x3*x4 + (160*f0*f5*f7 - 
    4*f2*f5^2 + 20*f4^3)*x2^2*x3*x5 + (80*f2*f5*f7 - 40*f3*f4*f7 + 
    88*f3*f5*f6 - 80*f4^2*f6 + 106*f4*f5^2)*x2^2*x3*x7 + (20*f4^2*f7 - 
    8*f5^3)*x2^2*x3*x8 + (80*f0*f6*f7^2 - 428*f1*f5*f7^2 - 40*f2*f4*f7^2 - 
    112*f2*f5*f6*f7 - 260*f3*f4*f6*f7 - 408*f3*f5^2*f7 + 160*f3*f5*f6^2 - 
    532*f4^2*f5*f7 - 20*f4^2*f6^2 + 656*f4*f5^2*f6 - 580*f5^4)*x2^2*x4^2 + 
    (-40*f0*f6*f7 + 164*f1*f5*f7 + 40*f2*f4*f7 + 32*f2*f5*f6 + 80*f3*f4*f6 -
    4*f3*f5^2 + 124*f4^2*f5)*x2^2*x4*x5 + (20*f1*f6*f7 + 40*f3*f4*f7 - 
    72*f3*f5*f6 - 140*f4^2*f6 + 60*f4*f5^2)*x2^2*x4*x6 + (-20*f1*f7^2 - 
    20*f2*f6*f7 - 220*f3*f5*f7 + 80*f3*f6^2 - 60*f4^2*f7 + 280*f4*f5*f6 - 
    248*f5^3)*x2^2*x4*x7 + (236*f4*f5*f7 + 64*f5^2*f6)*x2^2*x4*x8 - 
    4*f4*f5*x2^2*x5*x8 + (40*f4*f6 + 4*f5^2)*x2^2*x6*x8 + (-160*f0*f5*f7^2 +
    4*f2*f5^2*f7 + 80*f3*f4*f5*f7 - 52*f3*f5^2*f6 - 50*f4^3*f7 - 
    8*f4^2*f5*f6 - 66*f4*f5^3)*x2*x3^3 + (120*f0*f6*f7^2 - 164*f1*f5*f7^2 - 
    60*f2*f4*f7^2 - 40*f2*f5*f6*f7 - 300*f3*f4*f6*f7 + 288*f3*f5^2*f7 - 
    288*f3*f5*f6^2 - 258*f4^2*f5*f7 + 160*f4^2*f6^2 - 644*f4*f5^2*f6 - 
    60*f5^4)*x2*x3^2*x4 + (-4*f3*f5^2 + 6*f4^2*f5)*x2*x3^2*x5 + (80*f3*f5*f7
    - 70*f4^2*f7 - 76*f4*f5*f6 - 64*f5^3)*x2*x3^2*x7 + (-76*f4*f5*f7 + 
    12*f5^2*f6)*x2*x3^2*x8 + (80*f0*f7^3 + 100*f1*f6*f7^2 - 108*f2*f5*f7^2 -
    40*f2*f6^2*f7 - 100*f3*f4*f7^2 - 4*f3*f5*f6*f7 - 160*f3*f6^3 + 
    140*f4^2*f6*f7 - 226*f4*f5^2*f7 - 272*f4*f5*f6^2 + 
    136*f5^3*f6)*x2*x3*x4^2 + (-40*f0*f7^2 + 4*f2*f5*f7 + 100*f3*f4*f7 + 
    96*f3*f5*f6 - 40*f4^2*f6 + 134*f4*f5^2)*x2*x3*x4*x5 + (180*f4*f6*f7 + 
    76*f5^2*f7 + 128*f5*f6^2)*x2*x3*x4*x8 - 20*f4^2*x2*x3*x5*x6 + (60*f3*f6 
    + 66*f4*f5)*x2*x3*x6^2 + (100*f1*f7^3 - 20*f2*f6*f7^2 + 544*f3*f5*f7^2 -
    240*f3*f6^2*f7 + 280*f4^2*f7^2 - 568*f4*f5*f6*f7 + 460*f5^3*f7 - 
    128*f5^2*f6^2)*x2*x4^3 + (-40*f1*f7^2 + 20*f2*f6*f7 - 200*f3*f5*f7 + 
    80*f3*f6^2 - 50*f4^2*f7 + 84*f4*f5*f6 - 44*f5^3)*x2*x4^2*x5 + 
    (-100*f3*f6*f7 - 216*f4*f5*f7 + 40*f4*f6^2 - 148*f5^2*f6)*x2*x4^2*x6 + 
    (-20*f3*f7^2 - 140*f4*f6*f7 + 124*f5^2*f7 + 48*f5*f6^2)*x2*x4^2*x7 + 
    (80*f4*f7^2 + 168*f5*f6*f7)*x2*x4^2*x8 + (4*f3*f5 - 20*f4^2)*x2*x4*x5^2 
    + 40*f3*f6*x2*x4*x5*x6 - 60*f4*f7*x2*x4*x5*x8 + (-40*f3*f7 + 40*f4*f6 - 
    128*f5^2)*x2*x4*x6^2 + 56*f6^2*x2*x4*x7^2 - 30*f4*x2*x5*x6*x7 + 
    4*f5*x2*x5*x6*x8 - 6*f5*x2*x5*x7^2 + 32*f6*x2*x5*x7*x8 - 
    30*f5*x2*x6^2*x7 - 20*f6*x2*x6^2*x8 + 28*f6*x2*x6*x7^2 + 
    78*f7*x2*x6*x7*x8 - 20*f7*x2*x7^3 + (4*f3*f5^2*f7 - 10*f4^2*f5*f7 + 
    8*f4*f5^2*f6 + 33*f5^4)*x3^4 + (40*f0*f7^3 - 24*f2*f5*f7^2 - 
    120*f3*f4*f7^2 - 244*f3*f5*f6*f7 - 20*f4^2*f6*f7 - 326*f4*f5^2*f7 + 
    32*f4*f5*f6^2 - 300*f5^3*f6)*x3^3*x4 - 16*f4*f5^2*x3^3*x5 + 
    (-50*f4*f5*f7 - 40*f5^2*f6)*x3^3*x7 - 100*f5^2*f7*x3^3*x8 + (40*f1*f7^3 
    - 60*f2*f6*f7^2 - 148*f3*f5*f7^2 - 400*f3*f6^2*f7 - 220*f4^2*f7^2 - 
    428*f4*f5*f6*f7 + 240*f4*f6^3 - 334*f5^3*f7 - 876*f5^2*f6^2)*x3^2*x4^2 +
    (56*f3*f5*f7 + 80*f4^2*f7 + 4*f4*f5*f6 + 50*f5^3)*x3^2*x4*x5 + 
    (20*f2*f7^2 + 220*f3*f6*f7 + 188*f4*f5*f7 - 80*f4*f6^2 + 
    492*f5^2*f6)*x3^2*x4*x6 + (-80*f3*f7^2 - 80*f4*f6*f7 - 252*f5^2*f7 - 
    240*f5*f6^2)*x3^2*x4*x7 + (80*f4*f7^2 - 108*f5*f6*f7)*x3^2*x4*x8 + 
    5*f4^2*x3^2*x5^2 + 48*f4*f5*x3^2*x5*x6 + 4*f5^2*x3^2*x5*x7 - 
    32*f5*f6*x3^2*x5*x8 + 38*f5*f7*x3^2*x6*x8 + (-40*f2*f7^3 - 
    660*f3*f6*f7^2 - 624*f4*f5*f7^2 + 720*f4*f6^2*f7 - 1820*f5^2*f6*f7 + 
    128*f5*f6^3)*x3*x4^3 + (20*f2*f7^2 + 320*f3*f6*f7 + 190*f4*f5*f7 - 
    240*f4*f6^2 + 740*f5^2*f6)*x3*x4^2*x5 + (-300*f4*f7^2 - 512*f5*f6*f7 - 
    112*f6^3)*x3*x4^2*x7 + (-288*f5*f7^2 + 80*f6^2*f7)*x3*x4^2*x8 + 
    36*f4*f5*x3*x4*x5^2 + (-60*f3*f7 + 100*f4*f6 - 112*f5^2)*x3*x4*x5*x6 + 
    (100*f4*f7 + 152*f5*f6)*x3*x4*x5*x7 + (100*f5*f7 - 64*f6^2)*x3*x4*x5*x8 
    - 40*f4*f7*x3*x4*x6^2 - 176*f6*f7*x3*x4*x6*x8 + 20*f6*f7*x3*x4*x7^2 + 
    40*f7^2*x3*x4*x7*x8 + 10*f4*x3*x5^2*x7 - 40*f4*x3*x5*x6^2 - 
    2*f5*x3*x5*x6*x7 + 32*f6*x3*x5*x6*x8 - 38*f5*x3*x6^3 + 48*f6*x3*x6^2*x7 
    + 58*f7*x3*x6^2*x8 - 40*f7*x3*x6*x7^2 + (-220*f3*f7^3 + 600*f4*f6*f7^2 -
    239*f5^2*f7^2 + 192*f5*f6^2*f7)*x4^4 + (240*f3*f7^2 - 360*f4*f6*f7 + 
    226*f5^2*f7 - 64*f5*f6^2)*x4^3*x5 + (-80*f4*f7^2 - 104*f5*f6*f7)*x4^3*x6
    + (-104*f5*f7^2 - 168*f6^2*f7)*x4^3*x7 + 80*f6*f7^2*x4^3*x8 + (-60*f3*f7
    + 60*f4*f6 - 63*f5^2)*x4^2*x5^2 + (130*f4*f7 + 20*f5*f6)*x4^2*x5*x6 + 
    (-4*f5*f7 + 56*f6^2)*x4^2*x5*x7 - 136*f6*f7*x4^2*x5*x8 + (164*f5*f7 - 
    20*f6^2)*x4^2*x6^2 - 64*f6*f7*x4^2*x6*x7 - 154*f7^2*x4^2*x6*x8 + 
    40*f7^2*x4^2*x7^2 - 30*f4*x4*x5^2*x6 + 16*f5*x4*x5^2*x7 + 
    32*f6*x4*x5^2*x8 - 56*f5*x4*x5*x6^2 + 28*f6*x4*x5*x6*x7 + 
    58*f7*x4*x5*x6*x8 - 20*f7*x4*x5*x7^2 + 20*f6*x4*x6^3 - 20*f7*x4*x6^2*x7 
    + 5*x5^2*x7^2 - 10*x5*x6^2*x7 + 5*x6^4,
(40*f1^2*f2*f7 - 160*f1^2*f3*f6 + 160*f1^2*f4*f5 - 40*f1*f2^2*f6 + 
    60*f1*f2*f3*f5 + 160*f1*f2*f4^2 + 20*f2^3*f5 - 40*f2^2*f3*f4)*x1^4 + 
    (80*f1^2*f3*f7 + 36*f1^2*f4*f6 + 245*f1^2*f5^2 + 130*f1*f2^2*f7 - 
    220*f1*f2*f3*f6 + 152*f1*f2*f4*f5 + 60*f1*f3^2*f5 + 160*f1*f3*f4^2 + 
    60*f2^2*f3*f5 - 80*f2*f3^2*f4)*x1^3*x2 + (-80*f0*f1*f5*f7 - 
    320*f0*f3*f4*f6 + 240*f0*f3*f5^2 + 640*f0*f4^2*f5 - 12*f1^2*f4*f7 - 
    380*f1^2*f5*f6 - 70*f1*f2*f3*f7 + 68*f1*f2*f4*f6 + 540*f1*f2*f5^2 + 
    240*f1*f3^2*f6 - 328*f1*f3*f4*f5 - 160*f1*f4^3 + 130*f2^3*f7 - 
    100*f2^2*f3*f6 + 68*f2^2*f4*f5 - 20*f2*f3^2*f5 - 80*f2*f3*f4^2)*x1^3*x3 
    + (-480*f0*f2*f5*f7 - 480*f0*f3*f4*f7 + 1920*f0*f3*f5*f6 - 
    1920*f0*f4*f5^2 - 435*f1^2*f5*f7 + 200*f1*f2*f4*f7 - 30*f1*f2*f5*f6 - 
    120*f1*f3^2*f7 - 320*f1*f3*f4*f6 - 120*f1*f3*f5^2 - 10*f2^2*f3*f7 - 
    136*f2^2*f4*f6 - 10*f2^2*f5^2 + 376*f2*f3*f4*f5 + 160*f2*f4^3)*x1^3*x4 +
    (-80*f0*f2*f5 + 160*f0*f3*f4 + 135*f1^2*f5 - 44*f1*f2*f4 + 40*f1*f3^2 - 
    20*f2^2*f3)*x1^3*x5 + (40*f0*f1*f7 + 80*f0*f2*f6 - 120*f0*f3*f5 - 
    320*f0*f4^2 - 40*f1^2*f6 - 15*f1*f2*f5 - 26*f1*f3*f4 + 20*f2^2*f4 - 
    20*f2*f3^2)*x1^3*x6 + (-240*f0*f2*f7 + 640*f0*f3*f6 - 640*f0*f4*f5 - 
    15*f1^2*f7 + 40*f1*f2*f6 - 60*f1*f3*f5 - 160*f1*f4^2 - 85*f2^2*f5 + 
    132*f2*f3*f4)*x1^3*x7 + (-60*f0*f3*f7 + 104*f0*f4*f6 - 940*f0*f5^2 - 
    50*f1*f2*f7 - 100*f1*f3*f6 + 355*f1*f4*f5 - 100*f2^2*f6 - 85*f2*f3*f5 + 
    278*f2*f4^2 + 46*f3^2*f4)*x1^3*x8 + (40*f0*f1*f5*f7 + 160*f0*f3*f4*f6 - 
    120*f0*f3*f5^2 - 320*f0*f4^2*f5 + 86*f1^2*f4*f7 + 150*f1^2*f5*f6 + 
    180*f1*f2*f3*f7 + 16*f1*f2*f4*f6 - 250*f1*f2*f5^2 - 140*f1*f3^2*f6 + 
    186*f1*f3*f4*f5 + 160*f1*f4^3 + 60*f2^2*f4*f5 + 40*f2*f3^2*f5 - 
    80*f2*f3*f4^2 - 40*f3^3*f4)*x1^2*x2^2 + (840*f0*f2*f5*f7 - 
    160*f0*f3*f4*f7 - 1200*f0*f3*f5*f6 + 1248*f0*f4*f5^2 - 335*f1^2*f5*f7 + 
    160*f1^2*f6^2 - 6*f1*f2*f4*f7 - 200*f1*f2*f5*f6 - 190*f1*f3^2*f7 + 
    296*f1*f3*f4*f6 + 170*f1*f3*f5^2 - 44*f1*f4^2*f5 + 180*f2^2*f3*f7 + 
    136*f2^2*f4*f6 - 120*f2^2*f5^2 - 60*f2*f3^2*f6 - 128*f2*f3*f4*f5 - 
    160*f2*f4^3 - 20*f3^3*f5 - 80*f3^2*f4^2)*x1^2*x2*x3 + (160*f0*f1*f7^2 + 
    320*f0*f2*f6*f7 - 1320*f0*f3*f5*f7 - 1280*f0*f4^2*f7 - 640*f0*f4*f5*f6 -
    1060*f0*f5^3 + 230*f1^2*f6*f7 - 590*f1*f2*f5*f7 - 64*f1*f3*f4*f7 + 
    250*f1*f3*f5*f6 + 392*f1*f4^2*f6 - 204*f1*f4*f5^2 + 210*f2^2*f4*f7 + 
    120*f2^2*f5*f6 - 100*f2*f3^2*f7 - 572*f2*f3*f4*f6 + 390*f2*f3*f5^2 + 
    560*f2*f4^2*f5 + 284*f3^2*f4*f5 + 160*f3*f4^3)*x1^2*x2*x4 + 
    (-40*f0*f1*f7 - 80*f0*f2*f6 + 40*f0*f3*f5 + 320*f0*f4^2 - 80*f1^2*f6 + 
    75*f1*f2*f5 + 62*f1*f3*f4 - 20*f2^2*f4 - 20*f2*f3^2)*x1^2*x2*x5 + 
    (-260*f0*f2*f7 + 360*f0*f3*f6 - 304*f0*f4*f5 + 5*f1^2*f7 + 60*f1*f2*f6 -
    105*f1*f3*f5 - 294*f1*f4^2 - 60*f2^2*f5 + 80*f2*f3*f4 - 
    20*f3^3)*x1^2*x2*x6 + (-340*f0*f3*f7 - 248*f0*f4*f6 - 40*f0*f5^2 - 
    100*f1*f2*f7 + 280*f1*f3*f6 - 507*f1*f4*f5 + 60*f2^2*f6 - 25*f2*f3*f5 - 
    10*f2*f4^2 + 86*f3^2*f4)*x1^2*x2*x7 + (-368*f0*f4*f7 - 80*f0*f5*f6 + 
    85*f1*f3*f7 + 224*f1*f4*f6 + 10*f1*f5^2 - 135*f2^2*f7 - 60*f2*f3*f6 - 
    49*f2*f4*f5 + 25*f3^2*f5 + 558*f3*f4^2)*x1^2*x2*x8 + (40*f0*f1*f7^2 + 
    1360*f0*f2*f6*f7 - 60*f0*f3*f5*f7 - 1760*f0*f3*f6^2 - 320*f0*f4^2*f7 + 
    1720*f0*f4*f5*f6 + 1020*f0*f5^3 + 20*f1^2*f6*f7 - 190*f1*f2*f5*f7 + 
    40*f1*f2*f6^2 - 12*f1*f3*f4*f7 + 700*f1*f3*f5*f6 + 604*f1*f4^2*f6 - 
    601*f1*f4*f5^2 - 162*f2^2*f4*f7 - 90*f2^2*f5*f6 + 10*f2*f3^2*f7 + 
    160*f2*f3*f4*f6 - 525*f2*f3*f5^2 - 394*f2*f4^2*f5 - 80*f3^3*f6 + 
    174*f3^2*f4*f5 + 120*f3*f4^3)*x1^2*x3^2 + (2520*f0*f2*f7^2 - 
    4440*f0*f3*f6*f7 + 4640*f0*f4*f5*f7 - 560*f0*f4*f6^2 + 1600*f0*f5^2*f6 -
    180*f1^2*f7^2 + 730*f1*f2*f6*f7 + 680*f1*f3*f5*f7 - 920*f1*f3*f6^2 + 
    644*f1*f4^2*f7 + 1036*f1*f4*f5*f6 - 610*f1*f5^3 - 520*f2^2*f5*f7 - 
    120*f2^2*f6^2 - 298*f2*f3*f4*f7 + 900*f2*f3*f5*f6 + 816*f2*f4^2*f6 - 
    760*f2*f4*f5^2 + 120*f3^3*f7 + 12*f3^2*f4*f6 + 280*f3^2*f5^2 + 
    316*f3*f4^2*f5 - 160*f4^4)*x1^2*x3*x4 + (-760*f0*f2*f7 + 1040*f0*f3*f6 -
    1248*f0*f4*f5 + 55*f1^2*f7 + 40*f1*f2*f6 - 170*f1*f3*f5 - 272*f1*f4^2 - 
    45*f2^2*f5 + 136*f2*f3*f4 - 40*f3^3)*x1^2*x3*x5 + (128*f0*f4*f7 + 
    760*f0*f5*f6 + 20*f1*f3*f7 + 44*f1*f4*f6 - 550*f1*f5^2 - 120*f2^2*f7 + 
    280*f2*f3*f6 - 218*f2*f4*f5 + 20*f3^2*f5 + 28*f3*f4^2)*x1^2*x3*x7 + 
    (660*f0*f5*f7 - 640*f0*f6^2 - 118*f1*f4*f7 + 160*f1*f5*f6 + 80*f2*f3*f7 
    - 72*f2*f4*f6 + 170*f2*f5^2 - 20*f3^2*f6 + 38*f3*f4*f5 - 
    108*f4^3)*x1^2*x3*x8 + (-300*f0*f3*f7^2 - 840*f0*f4*f6*f7 + 
    1920*f0*f5^2*f7 + 935*f1*f2*f7^2 - 2660*f1*f3*f6*f7 + 2795*f1*f4*f5*f7 +
    220*f1*f5^2*f6 - 370*f2^2*f6*f7 + 895*f2*f3*f5*f7 + 1634*f2*f4^2*f7 + 
    330*f2*f4*f5*f6 + 1210*f2*f5^3 - 462*f3^2*f4*f7 + 1920*f3^2*f5*f6 - 
    160*f3*f4^2*f6 - 2512*f3*f4*f5^2 - 160*f4^3*f5)*x1^2*x4^2 + 
    (-140*f0*f3*f7 + 280*f0*f4*f6 - 360*f0*f5^2 - 200*f1*f2*f7 + 
    780*f1*f3*f6 - 837*f1*f4*f5 + 140*f2^2*f6 - 155*f2*f3*f5 - 482*f2*f4^2 +
    154*f3^2*f4)*x1^2*x4*x5 + (40*f0*f4*f7 + 700*f0*f5*f6 + 55*f1*f3*f7 - 
    76*f1*f4*f6 - 205*f1*f5^2 + 95*f2^2*f7 - 100*f2*f3*f6 + 81*f2*f4*f5 - 
    80*f3^2*f5 - 346*f3*f4^2)*x1^2*x4*x6 + (1180*f0*f5*f7 - 42*f1*f4*f7 + 
    110*f1*f5*f6 + 230*f2*f3*f7 + 224*f2*f4*f6 + 560*f2*f5^2 + 640*f3^2*f6 -
    1120*f3*f4*f5 - 160*f4^3)*x1^2*x4*x7 + (-1980*f0*f6*f7 - 45*f1*f5*f7 - 
    240*f1*f6^2 + 450*f2*f4*f7 + 420*f2*f5*f6 - 175*f3^2*f7 + 216*f3*f4*f6 -
    775*f3*f5^2 - 1817*f4^2*f5)*x1^2*x4*x8 + (80*f0*f3 - 30*f1*f2)*x1^2*x5^2
    + (8*f0*f4 - 50*f1*f3 + 20*f2^2)*x1^2*x5*x6 + (-160*f0*f5 + 8*f1*f4 - 
    20*f2*f3)*x1^2*x5*x7 + (320*f0*f6 - 60*f1*f5 - 78*f2*f4 + 
    40*f3^2)*x1^2*x5*x8 + (-20*f0*f5 + 14*f1*f4 + 40*f2*f3)*x1^2*x6^2 + 
    (160*f0*f6 + 20*f1*f5 - 50*f2*f4 + 20*f3^2)*x1^2*x6*x7 + (100*f0*f7 - 
    40*f1*f6 + 210*f2*f5 - 142*f3*f4)*x1^2*x6*x8 + (140*f0*f7 + 100*f2*f5 - 
    92*f3*f4)*x1^2*x7^2 + (20*f1*f7 + 120*f2*f6 + 40*f3*f5 - 
    268*f4^2)*x1^2*x7*x8 + (-120*f2*f7 + 120*f3*f6 + 18*f4*f5)*x1^2*x8^2 + 
    (-340*f0*f2*f5*f7 + 160*f0*f3*f4*f7 + 280*f0*f3*f5*f6 - 304*f0*f4*f5^2 +
    300*f1^2*f5*f7 - 80*f1^2*f6^2 + 90*f1*f2*f4*f7 + 60*f1*f2*f5*f6 + 
    90*f1*f3^2*f7 - 44*f1*f3*f4*f6 - 280*f1*f3*f5^2 + 18*f1*f4^2*f5 - 
    20*f2^2*f5^2 + 80*f2*f3*f4*f5 - 80*f3^2*f4^2)*x1*x2^3 + (-80*f0*f1*f7^2 
    - 680*f0*f2*f6*f7 + 860*f0*f3*f5*f7 + 560*f0*f3*f6^2 + 640*f0*f4^2*f7 + 
    40*f0*f4*f5*f6 - 900*f0*f5^3 - 240*f1^2*f6*f7 + 500*f1*f2*f5*f7 - 
    40*f1*f2*f6^2 - 196*f1*f3*f4*f7 - 380*f1*f3*f5*f6 - 496*f1*f4^2*f6 + 
    564*f1*f4*f5^2 + 90*f2^2*f4*f7 - 20*f2^2*f5*f6 + 90*f2*f3^2*f7 + 
    116*f2*f3*f4*f6 - 210*f2*f3*f5^2 - 86*f2*f4^2*f5 - 170*f3^2*f4*f5 - 
    240*f3*f4^3)*x1*x2^2*x3 + (-1040*f0*f2*f7^2 + 1480*f0*f3*f6*f7 - 
    1712*f0*f4*f5*f7 + 384*f0*f4*f6^2 - 1100*f0*f5^2*f6 - 145*f1^2*f7^2 - 
    110*f1*f2*f6*f7 - 565*f1*f3*f5*f7 + 80*f1*f3*f6^2 - 44*f1*f4^2*f7 - 
    510*f1*f4*f5*f6 + 735*f1*f5^3 + 465*f2^2*f5*f7 - 480*f2*f3*f5*f6 - 
    176*f2*f4^2*f6 + 432*f2*f4*f5^2 - 90*f3^3*f7 - 236*f3^2*f4*f6 + 
    100*f3^2*f5^2 + 30*f3*f4^2*f5 + 160*f4^4)*x1*x2^2*x4 + (260*f0*f2*f7 - 
    280*f0*f3*f6 + 312*f0*f4*f5 + 65*f1^2*f7 - 60*f1*f2*f6 + 55*f1*f3*f5 + 
    130*f1*f4^2 + 40*f2^2*f5 - 40*f2*f3*f4)*x1*x2^2*x5 + (-100*f0*f3*f7 - 
    192*f0*f4*f6 + 430*f0*f5^2 - 125*f1*f2*f7 + 140*f1*f3*f6 - 185*f1*f4*f5 
    - 40*f2*f3*f5 + 20*f2*f4^2 + 40*f3^2*f4)*x1*x2^2*x6 + (-56*f0*f4*f7 - 
    140*f0*f5*f6 - 155*f1*f3*f7 - 316*f1*f4*f6 + 245*f1*f5^2 + 125*f2^2*f7 -
    60*f2*f3*f6 - 39*f2*f4*f5 - 30*f3^2*f5 - 158*f3*f4^2)*x1*x2^2*x7 + 
    (-780*f0*f5*f7 + 320*f0*f6^2 - 20*f1*f4*f7 + 130*f1*f5*f6 - 180*f2*f3*f7
    - 296*f2*f4*f6 + 195*f2*f5^2 + 172*f3*f4*f5 + 592*f4^3)*x1*x2^2*x8 + 
    (20*f0*f2*f7^2 + 1240*f0*f3*f6*f7 - 112*f0*f4*f5*f7 + 912*f0*f4*f6^2 - 
    1980*f0*f5^2*f6 - 55*f1^2*f7^2 - 410*f1*f2*f6*f7 + 365*f1*f3*f5*f7 - 
    40*f1*f3*f6^2 + 2*f1*f4^2*f7 + 908*f1*f4*f5*f6 + 10*f1*f5^3 + 
    80*f2^2*f5*f7 - 40*f2^2*f6^2 - 156*f2*f3*f4*f7 - 200*f2*f3*f5*f6 - 
    528*f2*f4^2*f6 - 13*f2*f4*f5^2 + 90*f3^3*f7 - 24*f3^2*f4*f6 - 
    330*f3^2*f5^2 - 10*f3*f4^2*f5 + 160*f4^4)*x1*x2*x3^2 + (1920*f0*f3*f7^2 
    + 1024*f0*f4*f6*f7 - 2800*f0*f5^2*f7 - 480*f0*f5*f6^2 - 710*f1*f2*f7^2 +
    1400*f1*f3*f6*f7 + 808*f1*f4*f5*f7 + 968*f1*f4*f6^2 - 470*f1*f5^2*f6 + 
    70*f2^2*f6*f7 - 530*f2*f3*f5*f7 - 520*f2*f3*f6^2 - 1046*f2*f4^2*f7 + 
    96*f2*f4*f5*f6 + 560*f2*f5^3 - 34*f3^2*f4*f7 - 600*f3^2*f5*f6 + 
    1124*f3*f4^2*f6 + 458*f3*f4*f5^2 + 168*f4^3*f5)*x1*x2*x3*x4 + 
    (-620*f0*f3*f7 - 632*f0*f4*f6 + 1180*f0*f5^2 + 240*f1*f2*f7 - 
    60*f1*f3*f6 - 401*f1*f4*f5 + 20*f2^2*f6 + 75*f2*f3*f5 + 194*f2*f4^2 - 
    30*f3^2*f4)*x1*x2*x3*x5 + (680*f0*f6*f7 - 435*f1*f5*f7 + 40*f1*f6^2 + 
    110*f2*f4*f7 - 30*f2*f5*f6 - 90*f3^2*f7 - 96*f3*f4*f6 + 460*f3*f5^2 + 
    707*f4^2*f5)*x1*x2*x3*x8 + (-944*f0*f4*f7^2 + 1360*f0*f5*f6*f7 + 
    1130*f1*f3*f7^2 + 2012*f1*f4*f6*f7 + 450*f1*f5^2*f7 + 100*f1*f5*f6^2 + 
    495*f2^2*f7^2 - 1320*f2*f3*f6*f7 + 1457*f2*f4*f5*f7 - 384*f2*f4*f6^2 - 
    690*f2*f5^2*f6 - 65*f3^2*f5*f7 + 410*f3*f4^2*f7 + 2098*f3*f4*f5*f6 - 
    660*f3*f5^3 + 356*f4^3*f6 + 47*f4^2*f5^2)*x1*x2*x4^2 + (360*f0*f4*f7 + 
    180*f0*f5*f6 - 420*f1*f3*f7 - 660*f1*f4*f6 + 255*f1*f5^2 - 10*f2^2*f7 + 
    300*f2*f3*f6 - 476*f2*f4*f5 + 15*f3^2*f5 - 176*f3*f4^2)*x1*x2*x4*x5 + 
    (520*f0*f5*f7 - 160*f0*f6^2 - 145*f1*f4*f7 + 110*f1*f5*f6 + 145*f2*f3*f7
    + 468*f2*f4*f6 - 405*f2*f5^2 + 140*f3^2*f6 - 411*f3*f4*f5 - 
    614*f4^3)*x1*x2*x4*x6 + (900*f0*f6*f7 + 485*f1*f5*f7 + 160*f1*f6^2 - 
    186*f2*f4*f7 - 500*f2*f5*f6 + 85*f3^2*f7 + 908*f3*f4*f6 - 85*f3*f5^2 + 
    61*f4^2*f5)*x1*x2*x4*x7 + (760*f0*f7^2 - 120*f1*f6*f7 + 20*f2*f5*f7 - 
    200*f2*f6^2 + 78*f3*f4*f7 + 670*f3*f5*f6 + 36*f4^2*f6 - 
    560*f4*f5^2)*x1*x2*x4*x8 + (-8*f0*f4 + 20*f1*f3 - 20*f2^2)*x1*x2*x5^2 + 
    (-300*f0*f7 + 60*f1*f6 - 60*f2*f5 + 22*f3*f4)*x1*x2*x5*x8 + (-10*f1*f5 +
    40*f3^2)*x1*x2*x6^2 + (85*f1*f7 + 120*f2*f6 + 90*f3*f5 - 
    298*f4^2)*x1*x2*x6*x8 + (-90*f3*f7 + 120*f4*f6 - 10*f5^2)*x1*x2*x8^2 + 
    (-60*f0*f3*f7^2 + 600*f0*f4*f6*f7 - 1020*f0*f5^2*f7 - 1840*f0*f5*f6^2 - 
    80*f1*f2*f7^2 - 20*f1*f3*f6*f7 + 214*f1*f4*f5*f7 + 120*f1*f4*f6^2 + 
    500*f1*f5^2*f6 - 160*f2^2*f6*f7 + 110*f2*f3*f5*f7 - 80*f2*f3*f6^2 + 
    92*f2*f4^2*f7 - 64*f2*f4*f5*f6 - 140*f2*f5^3 + 44*f3^2*f4*f7 - 
    360*f3^2*f5*f6 - 692*f3*f4^2*f6 + 802*f3*f4*f5^2 + 476*f4^3*f5)*x1*x3^3 
    + (464*f0*f4*f7^2 - 7180*f0*f5*f6*f7 - 640*f0*f6^3 + 225*f1*f3*f7^2 + 
    1222*f1*f4*f6*f7 - 400*f1*f5^2*f7 - 680*f1*f5*f6^2 - 700*f2^2*f7^2 + 
    180*f2*f3*f6*f7 + 310*f2*f4*f5*f7 - 256*f2*f4*f6^2 + 980*f2*f5^2*f6 - 
    380*f3^2*f5*f7 - 1080*f3^2*f6^2 - 882*f3*f4^2*f7 + 126*f3*f4*f5*f6 + 
    1715*f3*f5^3 + 292*f4^3*f6 + 609*f4^2*f5^2)*x1*x3^2*x4 + (-176*f0*f4*f7 
    + 1700*f0*f5*f6 - 100*f1*f3*f7 - 240*f1*f4*f6 - 160*f1*f5^2 + 
    170*f2^2*f7 + 60*f2*f3*f6 + 20*f2*f4*f5 + 35*f3^2*f5 + 
    200*f3*f4^2)*x1*x3^2*x5 + (-510*f0*f5*f7 - 80*f0*f6^2 + 138*f1*f4*f7 - 
    400*f1*f5*f6 + 30*f2*f3*f7 + 328*f2*f4*f6 + 210*f2*f5^2 + 80*f3^2*f6 - 
    317*f3*f4*f5 - 190*f4^3)*x1*x3^2*x6 + (-380*f0*f6*f7 + 275*f1*f5*f7 - 
    40*f1*f6^2 + 2*f2*f4*f7 + 190*f2*f5*f6 + 15*f3^2*f7 - 392*f3*f4*f6 + 
    530*f3*f5^2 + 511*f4^2*f5)*x1*x3^2*x7 + (140*f0*f7^2 + 20*f1*f6*f7 - 
    85*f2*f5*f7 + 80*f2*f6^2 - 126*f3*f4*f7 + 340*f3*f5*f6 + 476*f4^2*f6 - 
    490*f4*f5^2)*x1*x3^2*x8 + (-3360*f0*f5*f7^2 - 4200*f0*f6^2*f7 + 
    1293*f1*f4*f7^2 - 3260*f1*f5*f6*f7 - 160*f1*f6^3 - 65*f2*f3*f7^2 + 
    1830*f2*f4*f6*f7 + 260*f2*f5^2*f7 + 840*f2*f5*f6^2 - 2690*f3^2*f6*f7 + 
    752*f3*f4*f5*f7 - 1376*f3*f4*f6^2 + 1630*f3*f5^2*f6 - 308*f4^3*f7 + 
    232*f4^2*f5*f6 - 1612*f4*f5^3)*x1*x3*x4^2 + (1960*f0*f5*f7 + 960*f0*f6^2
    - 710*f1*f4*f7 + 480*f1*f5*f6 + 130*f2*f3*f7 - 120*f2*f4*f6 - 
    190*f2*f5^2 + 540*f3^2*f6 - 420*f3*f4*f5 - 4*f4^3)*x1*x3*x4*x5 + 
    (-110*f1*f6*f7 + 170*f2*f5*f7 + 240*f2*f6^2 - 354*f3*f4*f7 + 
    250*f3*f5*f6 + 284*f4^2*f6 - 166*f4*f5^2)*x1*x3*x4*x7 + (80*f1*f7^2 - 
    960*f2*f6*f7 + 780*f3*f5*f7 + 400*f3*f6^2 + 220*f4^2*f7 + 222*f4*f5*f6 -
    1190*f5^3)*x1*x3*x4*x8 + (-280*f0*f5 + 90*f1*f4 - 30*f2*f3)*x1*x3*x5^2 +
    (160*f0*f6 + 150*f1*f5 - 64*f2*f4 + 50*f3^2)*x1*x3*x5*x6 + (40*f0*f7 - 
    100*f1*f6 - 50*f2*f5 + 52*f3*f4)*x1*x3*x6^2 + (10*f2*f7 - 100*f3*f6 + 
    160*f4*f5)*x1*x3*x7^2 + (-60*f3*f7 - 24*f4*f6 - 60*f5^2)*x1*x3*x7*x8 + 
    (226*f4*f7 + 140*f5*f6)*x1*x3*x8^2 + (-4860*f0*f6*f7^2 - 2295*f1*f5*f7^2
    - 240*f1*f6^2*f7 + 2915*f2*f4*f7^2 + 1200*f2*f5*f6*f7 - 1125*f3^2*f7^2 -
    3344*f3*f4*f6*f7 - 1885*f3*f5^2*f7 + 1920*f3*f5*f6^2 - 246*f4^2*f5*f7 - 
    2036*f4*f5^2*f6 - 2540*f5^4)*x1*x4^3 + (2580*f0*f6*f7 + 815*f1*f5*f7 + 
    80*f1*f6^2 - 1230*f2*f4*f7 - 710*f2*f5*f6 + 375*f3^2*f7 + 1008*f3*f4*f6 
    + 235*f3*f5^2 + 80*f4^2*f5)*x1*x4^2*x5 + (70*f0*f7^2 - 670*f1*f6*f7 + 
    305*f2*f5*f7 + 160*f2*f6^2 + 5*f3*f4*f7 - 980*f3*f5*f6 - 356*f4^2*f6 + 
    1443*f4*f5^2)*x1*x4^2*x6 + (135*f1*f7^2 + 400*f2*f6*f7 - 1230*f3*f5*f7 +
    640*f3*f6^2 - 31*f4^2*f7 - 874*f4*f5*f6 - 2190*f5^3)*x1*x4^2*x7 + 
    (-1525*f2*f7^2 + 1940*f3*f6*f7 - 2688*f4*f5*f7 + 480*f4*f6^2 - 
    560*f5^2*f6)*x1*x4^2*x8 + (-320*f0*f6 - 20*f1*f5 + 92*f2*f4)*x1*x4*x5^2 
    + (60*f0*f7 + 200*f1*f6 - 80*f2*f5 - 34*f3*f4)*x1*x4*x5*x6 + (-80*f1*f7 
    - 240*f2*f6 + 80*f3*f5 - 44*f4^2)*x1*x4*x5*x7 + (450*f2*f7 - 320*f3*f6 +
    748*f4*f5)*x1*x4*x5*x8 + (-20*f1*f7 - 100*f2*f6 - 10*f3*f5 + 
    454*f4^2)*x1*x4*x6^2 + (-70*f2*f7 - 300*f3*f6 + 584*f4*f5)*x1*x4*x6*x7 +
    (85*f3*f7 - 76*f4*f6 - 60*f5^2)*x1*x4*x6*x8 + (-200*f3*f7 - 88*f4*f6 - 
    530*f5^2)*x1*x4*x7^2 + (-454*f4*f7 + 410*f5*f6)*x1*x4*x7*x8 + (335*f5*f7
    + 360*f6^2)*x1*x4*x8^2 - 20*f0*x1*x5^2*x6 + 10*f1*x1*x5^2*x7 + 
    10*f1*x1*x5*x6^2 + 30*f2*x1*x5*x6*x7 - 100*f3*x1*x5*x6*x8 - 
    68*f4*x1*x5*x7*x8 - 145*f5*x1*x5*x8^2 - 20*f2*x1*x6^3 - 30*f3*x1*x6^2*x7
    + 62*f4*x1*x6^2*x8 + 30*f4*x1*x6*x7^2 + 205*f5*x1*x6*x7*x8 - 
    35*f5*x1*x7^3 - 145*f7*x1*x7*x8^2 + (-180*f0*f3*f5*f7 - 192*f0*f4*f5*f6 
    + 450*f0*f5^3 + 90*f1^2*f6*f7 + 45*f1*f2*f5*f7 + 90*f1*f3*f4*f7 + 
    96*f1*f4^2*f6 - 282*f1*f4*f5^2 + 40*f2*f4^2*f5 - 40*f3*f4^3)*x2^4 + 
    (-360*f0*f3*f6*f7 + 72*f0*f4*f5*f7 - 384*f0*f4*f6^2 + 1280*f0*f5^2*f6 + 
    45*f1^2*f7^2 + 270*f1*f2*f6*f7 + 45*f1*f3*f5*f7 - 16*f1*f4^2*f7 - 
    248*f1*f4*f5*f6 - 225*f1*f5^3 + 45*f2^2*f5*f7 + 90*f2*f3*f4*f7 + 
    176*f2*f4^2*f6 - 162*f2*f4*f5^2 - 150*f3*f4^2*f5 - 160*f4^4)*x2^3*x3 + 
    (-360*f0*f3*f7^2 - 384*f0*f4*f6*f7 + 700*f0*f5^2*f7 + 160*f0*f5*f6^2 + 
    90*f1*f2*f7^2 - 180*f1*f3*f6*f7 - 53*f1*f4*f5*f7 - 80*f1*f4*f6^2 - 
    230*f1*f5^2*f6 + 315*f2*f3*f5*f7 + 170*f2*f4^2*f7 + 524*f2*f4*f5*f6 - 
    700*f2*f5^3 - 90*f3^2*f4*f7 - 236*f3*f4^2*f6 - 170*f3*f4*f5^2 - 
    522*f4^3*f5)*x2^3*x4 + (180*f0*f3*f7 + 192*f0*f4*f6 - 470*f0*f5^2 - 
    45*f1*f2*f7 + 77*f1*f4*f5 - 20*f2*f4^2)*x2^3*x5 + (-90*f1*f3*f7 - 
    96*f1*f4*f6 + 225*f1*f5^2 - 40*f2*f4*f5 + 60*f3*f4^2)*x2^3*x6 + 
    (4*f1*f4*f7 - 190*f1*f5*f6 + 90*f2*f3*f7 + 176*f2*f4*f6 - 165*f2*f5^2 - 
    160*f3*f4*f5 - 324*f4^3)*x2^3*x7 + (-360*f0*f6*f7 + 45*f1*f5*f7 - 
    90*f2*f4*f7 + 17*f4^2*f5)*x2^3*x8 + (-180*f0*f3*f7^2 - 48*f0*f4*f6*f7 + 
    940*f0*f5^2*f7 + 760*f0*f5*f6^2 + 135*f1*f2*f7^2 + 90*f1*f3*f6*f7 - 
    322*f1*f4*f5*f7 - 80*f1*f4*f6^2 + 180*f2^2*f6*f7 - 86*f2*f4^2*f7 - 
    164*f2*f4*f5*f6 + 90*f3^2*f4*f7 + 56*f3*f4^2*f6 - 262*f3*f4*f5^2 - 
    126*f4^3*f5)*x2^2*x3^2 + (144*f0*f4*f7^2 + 1260*f0*f5*f6*f7 + 
    320*f0*f6^3 - 270*f1*f3*f7^2 - 548*f1*f4*f6*f7 + 170*f1*f5^2*f7 + 
    600*f1*f5*f6^2 + 90*f2^2*f7^2 - 90*f2*f3*f6*f7 - 50*f2*f4*f5*f7 - 
    88*f2*f4*f6^2 - 700*f2*f5^2*f6 + 315*f3^2*f5*f7 + 16*f3*f4^2*f7 + 
    64*f3*f4*f5*f6 - 935*f3*f5^3 + 560*f4^3*f6 - 950*f4^2*f5^2)*x2^2*x3*x4 +
    (-72*f0*f4*f7 - 460*f0*f5*f6 + 45*f1*f3*f7 + 80*f1*f4*f6 - 45*f2^2*f7 - 
    3*f2*f4*f5 + 10*f3*f4^2)*x2^2*x3*x5 + (360*f0*f6*f7 - 205*f1*f5*f7 - 
    86*f2*f4*f7 - 90*f2*f5*f6 + 90*f3^2*f7 + 56*f3*f4*f6 - 305*f3*f5^2 - 
    517*f4^2*f5)*x2^2*x3*x7 + (-180*f0*f7^2 - 90*f1*f6*f7 - 90*f2*f5*f7 - 
    20*f4^2*f6 + 139*f4*f5^2)*x2^2*x3*x8 + (-350*f0*f5*f7^2 - 40*f0*f6^2*f7 
    - 311*f1*f4*f7^2 + 970*f1*f5*f6*f7 - 274*f2*f4*f6*f7 + 590*f2*f5^2*f7 - 
    400*f2*f5*f6^2 + 90*f3^2*f6*f7 + 405*f3*f4*f5*f7 + 80*f3*f4*f6^2 - 
    1490*f3*f5^2*f6 + 1006*f4^3*f7 - 188*f4^2*f5*f6 - 975*f4*f5^3)*x2^2*x4^2
    + (60*f0*f5*f7 - 160*f0*f6^2 + 121*f1*f4*f7 - 380*f1*f5*f6 - 45*f2*f3*f7
    + 4*f2*f4*f6 + 165*f2*f5^2 - 113*f3*f4*f5 - 302*f4^3)*x2^2*x4*x5 + 
    (360*f0*f6*f7 - 130*f1*f5*f7 + 80*f1*f6^2 - 170*f2*f4*f7 + 20*f2*f5*f6 +
    90*f3^2*f7 + 376*f3*f4*f6 - 105*f3*f5^2 - 295*f4^2*f5)*x2^2*x4*x6 + 
    (-180*f0*f7^2 - 30*f1*f6*f7 + 220*f2*f5*f7 - 120*f2*f6^2 + 96*f3*f4*f7 -
    570*f3*f5*f6 - 32*f4^2*f6 - 445*f4*f5^2)*x2^2*x4*x7 + (90*f1*f7^2 + 
    360*f2*f6*f7 - 225*f3*f5*f7 + 110*f4^2*f7 - 432*f4*f5*f6 + 
    375*f5^3)*x2^2*x4*x8 + (-45*f1*f7 - 18*f4^2)*x2^2*x5*x8 + (90*f2*f7 + 
    68*f4*f5)*x2^2*x6*x8 - 90*f4*f7*x2^2*x8^2 + (72*f0*f4*f7^2 + 
    1180*f0*f5*f6*f7 + 45*f1*f3*f7^2 + 10*f1*f4*f6*f7 - 20*f1*f5^2*f7 + 
    90*f2^2*f7^2 + 180*f2*f3*f6*f7 - 222*f2*f4*f5*f7 - 40*f2*f4*f6^2 - 
    45*f3^2*f5*f7 + 34*f3*f4^2*f7 - 264*f3*f4*f5*f6 + 30*f3*f5^3 - 
    240*f4^3*f6 + 423*f4^2*f5^2)*x2*x3^3 + (600*f0*f5*f7^2 + 520*f0*f6^2*f7 
    + 179*f1*f4*f7^2 + 1290*f1*f5*f6*f7 - 45*f2*f3*f7^2 - 450*f2*f4*f6*f7 - 
    760*f2*f5^2*f7 - 120*f2*f5*f6^2 + 90*f3^2*f6*f7 + 548*f3*f4*f5*f7 - 
    256*f3*f4*f6^2 - 680*f3*f5^2*f6 - 146*f4^3*f7 + 588*f4^2*f5*f6 + 
    1402*f4*f5^3)*x2*x3^2*x4 + (-330*f0*f5*f7 - 80*f0*f6^2 - 60*f1*f4*f7 + 
    60*f2*f4*f6 - 20*f2*f5^2 + 47*f3*f4*f5 + 142*f4^3)*x2*x3^2*x5 + 
    (180*f0*f7^2 + 90*f1*f6*f7 - 185*f2*f5*f7 - 40*f2*f6^2 + 34*f3*f4*f7 - 
    190*f3*f5*f6 - 260*f4^2*f6 + 478*f4*f5^2)*x2*x3^2*x7 + (-45*f1*f7^2 - 
    180*f2*f6*f7 + 90*f3*f5*f7 + 59*f4^2*f7 + 154*f4*f5*f6 + 
    85*f5^3)*x2*x3^2*x8 + (-80*f0*f6*f7^2 + 530*f1*f5*f7^2 + 460*f1*f6^2*f7 
    - 785*f2*f4*f7^2 + 340*f2*f5*f6*f7 - 80*f2*f6^3 + 315*f3^2*f7^2 + 
    278*f3*f4*f6*f7 - 320*f3*f5^2*f7 - 40*f3*f5*f6^2 + 1330*f4^2*f5*f7 + 
    48*f4^2*f6^2 + 552*f4*f5^2*f6)*x2*x3*x4^2 + (-100*f0*f6*f7 - 
    350*f1*f5*f7 - 80*f1*f6^2 + 228*f2*f4*f7 - 135*f3^2*f7 + 32*f3*f4*f6 + 
    235*f3*f5^2 - 492*f4^2*f5)*x2*x3*x4*x5 + (270*f2*f7^2 + 90*f3*f6*f7 - 
    464*f4*f5*f7 - 184*f4*f6^2 + 590*f5^2*f6)*x2*x3*x4*x8 + 
    20*f1*f5*x2*x3*x5^2 + (20*f1*f7 - 10*f3*f5 - 178*f4^2)*x2*x3*x6^2 - 
    135*f5*f7*x2*x3*x8^2 + (1360*f0*f7^3 - 130*f1*f6*f7^2 - 1115*f2*f5*f7^2 
    + 400*f2*f6^2*f7 - 387*f3*f4*f7^2 + 850*f3*f5*f6*f7 + 66*f4^2*f6*f7 + 
    1226*f4*f5^2*f7 - 1052*f4*f5*f6^2 + 1020*f5^3*f6)*x2*x4^3 + 
    (-790*f0*f7^2 - 90*f1*f6*f7 - 105*f2*f5*f7 + 40*f2*f6^2 + 117*f3*f4*f7 +
    20*f3*f5*f6 - 8*f4^2*f6 - 1235*f4*f5^2)*x2*x4^2*x5 + (145*f1*f7^2 - 
    230*f2*f6*f7 + 410*f3*f5*f7 - 80*f3*f6^2 - 300*f4^2*f7 + 734*f4*f5*f6 + 
    1625*f5^3)*x2*x4^2*x6 + (-385*f2*f7^2 + 200*f3*f6*f7 - 446*f4*f5*f7 - 
    336*f4*f6^2 - 350*f5^2*f6)*x2*x4^2*x7 + (-450*f3*f7^2 - 674*f4*f6*f7 - 
    740*f5^2*f7 + 80*f5*f6^2)*x2*x4^2*x8 + (60*f0*f7 + 40*f1*f6 + 100*f2*f5 
    + 8*f3*f4)*x2*x4*x5^2 + (-20*f2*f6 + 40*f4^2)*x2*x4*x5*x6 + (225*f3*f7 +
    212*f4*f6)*x2*x4*x5*x8 + (-140*f3*f6 - 40*f4*f5)*x2*x4*x6^2 - 
    590*f5*f6*x2*x4*x7^2 - 40*f6^2*x2*x4*x7*x8 - 360*f6*f7*x2*x4*x8^2 + 
    20*f0*x2*x5^3 - 20*f1*x2*x5^2*x6 + 30*f2*x2*x5^2*x7 + 20*f2*x2*x5*x6^2 +
    50*f3*x2*x5*x6*x7 + 8*f4*x2*x5*x6*x8 + 126*f4*x2*x5*x7^2 + 
    165*f5*x2*x5*x7*x8 - 20*f3*x2*x6^3 - 42*f4*x2*x6^2*x7 - 85*f5*x2*x6^2*x8
    - 345*f5*x2*x6*x7^2 - 120*f6*x2*x6*x7*x8 + 90*f7*x2*x6*x8^2 - 
    80*f6*x2*x7^3 + 275*f7*x2*x7^2*x8 + (490*f0*f5*f7^2 - 20*f1*f4*f7^2 + 
    90*f2*f3*f7^2 + 160*f2*f4*f6*f7 - 282*f3*f4*f5*f7 - 60*f4^3*f7 - 
    174*f4^2*f5*f6 + 18*f4*f5^3)*x3^4 + (-180*f0*f6*f7^2 + 820*f1*f5*f7^2 + 
    562*f2*f4*f7^2 - 30*f2*f5*f6*f7 - 45*f3^2*f7^2 - 88*f3*f4*f6*f7 - 
    315*f3*f5^2*f7 - 560*f3*f5*f6^2 - 516*f4^2*f5*f7 + 184*f4^2*f6^2 - 
    342*f4*f5^2*f6 + 580*f5^4)*x3^3*x4 + (140*f0*f6*f7 - 100*f1*f5*f7 - 
    170*f2*f4*f7 + 60*f2*f5*f6 + 45*f3^2*f7 + 20*f3*f4*f6 + 
    263*f4^2*f5)*x3^3*x5 + (160*f2*f6*f7 - 245*f3*f5*f7 - 40*f4^2*f7 - 
    274*f4*f5*f6 + 300*f5^3)*x3^3*x7 + (-90*f2*f7^2 + 371*f4*f5*f7 + 
    100*f5^2*f6)*x3^3*x8 + (-1750*f0*f7^3 + 480*f1*f6*f7^2 + 2070*f2*f5*f7^2
    - 700*f2*f6^2*f7 + 548*f3*f4*f7^2 - 130*f3*f5*f6*f7 - 1120*f3*f6^3 - 
    12*f4^2*f6*f7 - 1179*f4*f5^2*f7 + 1404*f4*f5*f6^2 - 
    700*f5^3*f6)*x3^2*x4^2 + (1160*f0*f7^2 - 60*f1*f6*f7 - 390*f2*f5*f7 + 
    120*f2*f6^2 - 238*f3*f4*f7 + 280*f3*f5*f6 + 128*f4^2*f6 + 
    826*f4*f5^2)*x3^2*x4*x5 + (-350*f1*f7^2 + 510*f2*f6*f7 - 705*f3*f5*f7 + 
    560*f3*f6^2 + 395*f4^2*f7 - 782*f4*f5*f6 - 725*f5^3)*x3^2*x4*x6 + 
    (540*f2*f7^2 - 240*f3*f6*f7 + 27*f4*f5*f7 + 64*f4*f6^2 + 
    290*f5^2*f6)*x3^2*x4*x7 + (225*f3*f7^2 + 426*f4*f6*f7 + 885*f5^2*f7 + 
    400*f5*f6^2)*x3^2*x4*x8 + (-200*f0*f7 - 30*f2*f5 + 10*f3*f4)*x3^2*x5^2 +
    (100*f1*f7 - 60*f2*f6 - 40*f3*f5 - 194*f4^2)*x3^2*x5*x6 + (-170*f2*f7 + 
    20*f3*f6)*x3^2*x5*x7 + (-90*f3*f7 - 20*f4*f6 - 110*f5^2)*x3^2*x5*x8 - 
    144*f4*f7*x3^2*x6*x8 + (-645*f1*f7^3 - 30*f2*f6*f7^2 + 2610*f3*f5*f7^2 -
    2360*f3*f6^2*f7 - 601*f4^2*f7^2 + 2452*f4*f5*f6*f7 + 512*f4*f6^3 - 
    840*f5^3*f7 - 2040*f5^2*f6^2)*x3*x4^3 + (510*f1*f7^2 + 570*f2*f6*f7 - 
    1040*f3*f5*f7 + 1040*f3*f6^2 + 501*f4^2*f7 - 308*f4*f5*f6 + 
    500*f5^3)*x3*x4^2*x5 + (675*f3*f7^2 + 198*f4*f6*f7 - 190*f5^2*f7 + 
    380*f5*f6^2)*x3*x4^2*x7 + (473*f4*f7^2 + 1290*f5*f6*f7 + 
    400*f6^3)*x3*x4^2*x8 + (-100*f1*f7 - 120*f2*f6 + 20*f3*f5 - 
    118*f4^2)*x3*x4*x5^2 + (-120*f2*f7 - 300*f3*f6 - 184*f4*f5)*x3*x4*x5*x6 
    + (-300*f3*f7 - 308*f4*f6 + 250*f5^2)*x3*x4*x5*x7 + (-166*f4*f7 - 
    360*f5*f6)*x3*x4*x5*x8 + 80*f3*f7*x3*x4*x6^2 + 204*f4*f7*x3*x4*x6*x7 + 
    (60*f5*f7 + 80*f6^2)*x3*x4*x7^2 - 90*f6*f7*x3*x4*x7*x8 - 
    180*f7^2*x3*x4*x8^2 + 30*f2*x3*x5^2*x6 + 10*f3*x3*x5^2*x7 - 
    10*f4*x3*x5^2*x8 + 40*f3*x3*x5*x6^2 + 64*f4*x3*x5*x6*x7 + 
    100*f5*x3*x5*x6*x8 + 5*f5*x3*x5*x7^2 - 20*f6*x3*x5*x7*x8 + 
    45*f7*x3*x5*x8^2 - 18*f4*x3*x6^3 - 310*f5*x3*x6^2*x7 - 100*f6*x3*x6^2*x8
    - 100*f6*x3*x6*x7^2 + 190*f7*x3*x6*x7*x8 - 20*f7*x3*x7^3 + (205*f2*f7^3 
    - 1180*f3*f6*f7^2 + 2494*f4*f5*f7^2 + 768*f4*f6^2*f7 - 
    3620*f5^2*f6*f7)*x4^4 + (390*f2*f7^2 + 1060*f3*f6*f7 - 738*f4*f5*f7 - 
    256*f4*f6^2 + 1560*f5^2*f6)*x4^3*x5 + (205*f3*f7^2 + 390*f4*f6*f7 - 
    1570*f5^2*f7 + 540*f5*f6^2)*x4^3*x6 + (345*f4*f7^2 + 
    390*f5*f6*f7)*x4^3*x7 + (1325*f5*f7^2 + 80*f6^2*f7)*x4^3*x8 + 
    (-240*f2*f7 - 240*f3*f6 - 14*f4*f5)*x4^2*x5^2 + (-240*f3*f7 - 144*f4*f6 
    + 395*f5^2)*x4^2*x5*x6 + (-566*f4*f7 + 160*f5*f6)*x4^2*x5*x7 + 
    (-690*f5*f7 - 200*f6^2)*x4^2*x5*x8 + (362*f4*f7 - 850*f5*f6)*x4^2*x6^2 +
    (1160*f5*f7 + 80*f6^2)*x4^2*x6*x7 + 1010*f6*f7*x4^2*x6*x8 + 
    170*f6*f7*x4^2*x7^2 - 695*f7^2*x4^2*x7*x8 + 30*f2*x4*x5^3 + 
    50*f3*x4*x5^2*x6 + 150*f4*x4*x5^2*x7 + 90*f5*x4*x5^2*x8 - 
    94*f4*x4*x5*x6^2 - 460*f5*x4*x5*x6*x7 - 140*f6*x4*x5*x6*x8 + 
    230*f7*x4*x5*x7*x8 + 145*f5*x4*x6^3 - 120*f6*x4*x6^2*x7 - 
    110*f7*x4*x6^2*x8 - 45*f7*x4*x6*x7^2 - 10*x5^2*x7*x8 + 10*x5*x6^2*x8 - 
    10*x5*x6*x7^2 + 10*x6^3*x7,
(-150*f1^3*f7 - 80*f1^2*f2*f6 + 540*f1^2*f3*f5 + 220*f1^2*f4^2 + 
    40*f1*f2^2*f5 + 180*f1*f2*f3*f4)*x1^4 + (-230*f1^2*f2*f7 + 8*f1^2*f3*f6 
    - 1050*f1^2*f4*f5 - 200*f1*f2^2*f6 + 566*f1*f2*f3*f5 + 460*f1*f2*f4^2 + 
    180*f1*f3^2*f4)*x1^3*x2 + (720*f0*f3*f4*f5 + 456*f1^2*f3*f7 + 
    40*f1^2*f4*f6 + 5*f1^2*f5^2 - 330*f1*f2^2*f7 + 64*f1*f2*f3*f6 - 
    1890*f1*f2*f4*f5 - 1024*f1*f3^2*f5 - 620*f1*f3*f4^2 - 200*f2^3*f6 + 
    514*f2^2*f3*f5 + 460*f2^2*f4^2 - 180*f2*f3^2*f4)*x1^3*x3 + 
    (2280*f0*f1*f5*f7 - 6480*f0*f3*f5^2 - 2640*f0*f4^2*f5 + 30*f1^2*f4*f7 - 
    520*f1^2*f5*f6 + 72*f1*f2*f3*f7 - 340*f1*f2*f4*f6 + 605*f1*f2*f5^2 + 
    720*f1*f3*f4*f5 + 440*f1*f4^3 - 100*f2^3*f7 - 48*f2^2*f3*f6 - 
    530*f2^2*f4*f5 + 168*f2*f3^2*f5 + 180*f2*f3*f4^2)*x1^3*x4 + 
    (-160*f0*f1*f5 - 110*f1^2*f4 + 28*f1*f2*f3)*x1^3*x5 + (160*f0*f1*f6 - 
    360*f0*f3*f4 - 100*f1^2*f5 - 20*f1*f2*f4 - 28*f1*f3^2)*x1^3*x6 + 
    (600*f0*f1*f7 - 2160*f0*f3*f5 - 880*f0*f4^2 - 260*f1^2*f6 + 300*f1*f2*f5
    - 180*f1*f3*f4 + 60*f2^2*f4 + 56*f2*f3^2)*x1^3*x7 + (380*f0*f2*f7 + 
    32*f0*f3*f6 + 3700*f0*f4*f5 - 250*f1^2*f7 - 500*f1*f2*f6 + 770*f1*f3*f5 
    + 170*f1*f4^2 + 200*f2^2*f5 + 164*f2*f3*f4 + 28*f3^3)*x1^3*x8 + 
    (-360*f0*f3*f4*f5 - 254*f1^2*f3*f7 - 85*f1^2*f5^2 + 100*f1*f2^2*f7 - 
    152*f1*f2*f3*f6 + 770*f1*f2*f4*f5 + 498*f1*f3^2*f5 + 
    640*f1*f3*f4^2)*x1^2*x2^2 + (-1000*f0*f1*f5*f7 - 800*f0*f2*f5*f6 + 
    4104*f0*f3*f5^2 + 2720*f0*f4^2*f5 + 620*f1^2*f4*f7 + 80*f1^2*f5*f6 - 
    250*f1*f2*f3*f7 + 220*f1*f2*f4*f6 - 465*f1*f2*f5^2 - 112*f1*f3^2*f6 - 
    1272*f1*f3*f4*f5 - 900*f1*f4^3 + 100*f2^3*f7 - 152*f2^2*f3*f6 + 
    650*f2^2*f4*f5 + 486*f2*f3^2*f5 + 280*f2*f3*f4^2 - 
    180*f3^3*f4)*x1^2*x2*x3 + (640*f0*f1*f6*f7 + 320*f0*f2*f5*f7 - 
    1440*f0*f3*f4*f7 - 1120*f0*f3*f5*f6 + 5200*f0*f4*f5^2 + 390*f1^2*f5*f7 +
    520*f1^2*f6^2 - 330*f1*f2*f4*f7 - 180*f1*f2*f5*f6 - 40*f1*f3^2*f7 + 
    196*f1*f3*f4*f6 - 827*f1*f3*f5^2 - 2920*f1*f4^2*f5 - 200*f2^2*f3*f7 - 
    200*f2^2*f4*f6 + 30*f2^2*f5^2 - 96*f2*f3^2*f6 - 1010*f2*f3*f4*f5 + 
    460*f2*f4^3 + 112*f3^3*f5 + 180*f3^2*f4^2)*x1^2*x2*x4 + (-160*f0*f1*f6 +
    360*f0*f3*f4 - 10*f1^2*f5 + 20*f1*f2*f4 + 56*f1*f3^2)*x1^2*x2*x5 + 
    (280*f0*f1*f7 + 400*f0*f2*f6 - 972*f0*f3*f5 - 920*f0*f4^2 - 100*f1^2*f6 
    + 10*f1*f2*f5 - 152*f1*f3*f4)*x1^2*x2*x6 + (-20*f0*f2*f7 - 384*f0*f3*f6 
    + 500*f0*f4*f5 + 380*f1^2*f7 + 420*f1*f2*f6 - 956*f1*f3*f5 - 630*f1*f4^2
    - 130*f2^2*f5 - 140*f2*f3*f4 + 28*f3^3)*x1^2*x2*x7 + (200*f0*f3*f7 + 
    120*f0*f4*f6 + 1210*f0*f5^2 + 350*f1*f2*f7 - 8*f1*f3*f6 - 620*f1*f4*f5 +
    300*f2^2*f6 - 332*f2*f3*f5 - 600*f2*f4^2 + 324*f3^2*f4)*x1^2*x2*x8 + 
    (-1560*f0*f1*f6*f7 - 380*f0*f2*f5*f7 - 1600*f0*f2*f6^2 - 360*f0*f3*f4*f7
    + 6240*f0*f3*f5*f6 + 4560*f0*f4^2*f6 - 3700*f0*f4*f5^2 - 60*f1^2*f5*f7 -
    800*f1^2*f6^2 + 610*f1*f2*f4*f7 + 100*f1*f2*f5*f6 - 490*f1*f3^2*f7 - 
    128*f1*f3*f4*f6 + 372*f1*f3*f5^2 + 2160*f1*f4^2*f5 + 204*f2^2*f3*f7 + 
    180*f2^2*f4*f6 - 320*f2^2*f5^2 - 40*f2*f3^2*f6 + 838*f2*f3*f4*f5 - 
    920*f2*f4^3 + 512*f3^3*f5 + 400*f3^2*f4^2)*x1^2*x3^2 + (-4080*f0*f1*f7^2
    - 2440*f0*f2*f6*f7 + 13224*f0*f3*f5*f7 - 320*f0*f3*f6^2 + 
    9040*f0*f4^2*f7 + 1640*f0*f4*f5*f6 + 3000*f0*f5^3 - 2980*f1^2*f6*f7 + 
    1440*f1*f2*f5*f7 - 2720*f1*f2*f6^2 - 516*f1*f3*f4*f7 + 6588*f1*f3*f5*f6 
    + 3080*f1*f4^2*f6 + 445*f1*f4*f5^2 - 160*f2^2*f4*f7 + 1200*f2^2*f5*f6 - 
    296*f2*f3^2*f7 + 668*f2*f3*f4*f6 - 2225*f2*f3*f5^2 - 2090*f2*f4^2*f5 + 
    56*f3^3*f6 - 112*f3^2*f4*f5 - 620*f3*f4^3)*x1^2*x3*x4 + (1160*f0*f1*f7 +
    800*f0*f2*f6 - 4104*f0*f3*f5 - 2720*f0*f4^2 + 500*f1^2*f6 - 200*f1*f2*f5
    + 264*f1*f3*f4 + 60*f2^2*f4 + 28*f2*f3^2)*x1^2*x3*x5 + (-624*f0*f3*f7 + 
    320*f0*f4*f6 + 1500*f0*f5^2 + 350*f1*f2*f7 + 992*f1*f3*f6 + 
    1370*f1*f4*f5 + 180*f2^2*f6 - 904*f2*f3*f5 - 460*f2*f4^2 + 
    124*f3^2*f4)*x1^2*x3*x7 + (-640*f0*f4*f7 - 2880*f0*f5*f6 + 328*f1*f3*f7 
    + 820*f1*f4*f6 + 1105*f1*f5^2 - 320*f2^2*f7 - 96*f2*f3*f6 - 860*f2*f4*f5
    - 306*f3^2*f5 + 276*f3*f4^2)*x1^2*x3*x8 + (-60*f0*f2*f7^2 - 
    480*f0*f3*f6*f7 - 660*f0*f4*f5*f7 + 8160*f0*f5^2*f6 - 3840*f1^2*f7^2 - 
    5280*f1*f2*f6*f7 + 13206*f1*f3*f5*f7 + 6500*f1*f4^2*f7 - 680*f1*f4*f5*f6
    - 1370*f1*f5^3 + 2300*f2^2*f5*f7 - 160*f2^2*f6^2 + 1284*f2*f3*f4*f7 + 
    2760*f2*f3*f5*f6 - 260*f2*f4^2*f6 - 4855*f2*f4*f5^2 + 84*f3^3*f7 - 
    6816*f3^2*f5^2 - 2460*f3*f4^2*f5 + 220*f4^4)*x1^2*x4^2 + (20*f0*f2*f7 + 
    160*f0*f3*f6 + 220*f0*f4*f5 + 1450*f1^2*f7 + 1620*f1*f2*f6 - 
    3546*f1*f3*f5 - 2070*f1*f4^2 - 750*f2^2*f5 - 316*f2*f3*f4 - 
    28*f3^3)*x1^2*x4*x5 + (-144*f0*f3*f7 + 520*f0*f4*f6 - 330*f0*f5^2 - 
    530*f1*f2*f7 - 268*f1*f3*f6 + 1130*f1*f4*f5 - 300*f2^2*f6 + 248*f2*f3*f5
    + 600*f2*f4^2 - 388*f3^2*f4)*x1^2*x4*x6 + (-1080*f0*f4*f7 + 
    6800*f0*f5*f6 + 1092*f1*f3*f7 - 340*f1*f4*f6 - 1365*f1*f5^2 + 
    320*f2^2*f7 + 952*f2*f3*f6 - 1800*f2*f4*f5 - 2440*f3^2*f5 - 
    1060*f3*f4^2)*x1^2*x4*x7 + (-1400*f0*f5*f7 + 3600*f0*f6^2 - 90*f1*f4*f7 
    - 340*f1*f5*f6 + 1022*f2*f3*f7 - 1440*f2*f4*f6 - 1515*f2*f5^2 + 
    208*f3^2*f6 + 1164*f3*f4*f5 - 450*f4^3)*x1^2*x4*x8 - 90*f1^2*x1^2*x5^2 +
    (-56*f0*f3 + 150*f1*f2)*x1^2*x5*x6 + (360*f0*f4 - 216*f1*f3 - 
    110*f2^2)*x1^2*x5*x7 + (680*f0*f5 - 30*f1*f4 - 234*f2*f3)*x1^2*x5*x8 + 
    82*f1*f3*x1^2*x6^2 + (-360*f0*f5 + 90*f1*f4 - 70*f2*f3)*x1^2*x6*x7 + 
    (1280*f0*f6 - 520*f1*f5 - 330*f2*f4 - 126*f3^2)*x1^2*x6*x8 + (1360*f0*f6
    - 340*f1*f5 - 260*f2*f4 - 56*f3^2)*x1^2*x7^2 + (40*f0*f7 + 180*f1*f6 + 
    120*f2*f5 - 164*f3*f4)*x1^2*x7*x8 + (-80*f1*f7 + 394*f3*f5 + 
    140*f4^2)*x1^2*x8^2 + (120*f0*f1*f5*f7 + 400*f0*f2*f5*f6 - 
    972*f0*f3*f5^2 - 920*f0*f4^2*f5 - 230*f1^2*f4*f7 + 240*f1^2*f5*f6 + 
    100*f1*f2*f3*f7 - 200*f1*f2*f4*f6 - 20*f1*f2*f5^2 + 48*f1*f3^2*f6 + 
    1304*f1*f3*f4*f5 + 460*f1*f4^3)*x1*x2^3 + (240*f0*f1*f6*f7 + 
    420*f0*f2*f5*f7 + 800*f0*f2*f6^2 + 720*f0*f3*f4*f7 - 1480*f0*f3*f5*f6 - 
    1840*f0*f4^2*f6 + 2340*f0*f4*f5^2 + 80*f1^2*f5*f7 + 720*f1^2*f6^2 - 
    350*f1*f2*f4*f7 + 360*f1*f2*f5*f6 + 184*f1*f3^2*f7 - 228*f1*f3*f4*f6 - 
    523*f1*f3*f5^2 - 710*f1*f4^2*f5 + 100*f2^2*f3*f7 - 200*f2^2*f4*f6 + 
    20*f2^2*f5^2 + 48*f2*f3^2*f6 + 1212*f2*f3*f4*f5 + 460*f2*f4^3 - 
    360*f3^2*f4^2)*x1*x2^2*x3 + (1120*f0*f1*f7^2 + 2000*f0*f2*f6*f7 - 
    3064*f0*f3*f5*f7 + 192*f0*f3*f6^2 - 3680*f0*f4^2*f7 + 1920*f0*f4*f5*f6 -
    2930*f0*f5^3 + 1680*f1^2*f6*f7 - 1770*f1*f2*f5*f7 + 520*f1*f2*f6^2 + 
    246*f1*f3*f4*f7 - 2420*f1*f3*f5*f6 - 500*f1*f4^2*f6 - 515*f1*f4*f5^2 - 
    100*f2^2*f4*f7 - 500*f2^2*f5*f6 - 100*f2*f3^2*f7 - 248*f2*f3*f4*f6 + 
    1646*f2*f3*f5^2 + 710*f2*f4^2*f5 - 48*f3^3*f6 - 1020*f3^2*f4*f5 + 
    640*f3*f4^3)*x1*x2^2*x4 + (-280*f0*f1*f7 - 400*f0*f2*f6 + 916*f0*f3*f5 +
    920*f0*f4^2 - 300*f1^2*f6 + 60*f1*f2*f5)*x1*x2^2*x5 + (-200*f0*f2*f7 - 
    96*f0*f3*f6 - 1420*f0*f4*f5 + 150*f1^2*f7 + 100*f1*f2*f6 - 210*f1*f3*f5 
    - 280*f1*f4^2)*x1*x2^2*x6 + (256*f0*f3*f7 - 520*f0*f4*f6 - 1630*f0*f5^2 
    - 370*f1*f2*f7 - 508*f1*f3*f6 + 300*f1*f4*f5 - 100*f2^2*f6 + 
    198*f2*f3*f5 + 320*f2*f4^2 - 304*f3^2*f4)*x1*x2^2*x7 + (280*f0*f4*f7 - 
    1400*f0*f5*f6 - 292*f1*f3*f7 + 320*f1*f4*f6 + 405*f1*f5^2 - 100*f2^2*f7 
    + 152*f2*f3*f6 - 420*f2*f4*f5 - 204*f3^2*f5 - 44*f3*f4^2)*x1*x2^2*x8 + 
    (320*f0*f1*f7^2 + 40*f0*f2*f6*f7 - 652*f0*f3*f5*f7 + 736*f0*f3*f6^2 + 
    40*f0*f4^2*f7 + 1040*f0*f4*f5*f6 - 1110*f0*f5^3 + 180*f1^2*f6*f7 + 
    280*f1*f2*f5*f7 + 1160*f1*f2*f6^2 - 616*f1*f3*f4*f7 - 936*f1*f3*f5*f6 - 
    580*f1*f4^2*f6 + 765*f1*f4*f5^2 - 20*f2^2*f4*f7 + 280*f2^2*f5*f6 + 
    284*f2*f3^2*f7 - 164*f2*f3*f4*f6 - 449*f2*f3*f5^2 + 110*f2*f4^2*f5 + 
    48*f3^3*f6 + 1430*f3^2*f4*f5 + 160*f3*f4^3)*x1*x2*x3^2 + (880*f0*f2*f7^2
    + 2320*f0*f3*f6*f7 + 4400*f0*f4*f5*f7 + 240*f0*f4*f6^2 - 620*f0*f5^2*f6 
    + 900*f1^2*f7^2 + 2640*f1*f2*f6*f7 - 4294*f1*f3*f5*f7 - 1576*f1*f3*f6^2 
    - 2070*f1*f4^2*f7 - 1660*f1*f4*f5*f6 - 515*f1*f5^3 - 1090*f2^2*f5*f7 + 
    120*f2^2*f6^2 - 432*f2*f3*f4*f7 + 868*f2*f3*f5*f6 + 1040*f2*f4^2*f6 - 
    1680*f2*f4*f5^2 - 184*f3^3*f7 + 452*f3^2*f4*f6 + 2719*f3^2*f5^2 + 
    2364*f3*f4^2*f5 - 900*f4^4)*x1*x2*x3*x4 + (-420*f0*f2*f7 - 576*f0*f3*f6 
    - 2700*f0*f4*f5 - 160*f1^2*f7 - 640*f1*f2*f6 + 802*f1*f3*f5 + 
    810*f1*f4^2 - 20*f2^2*f5 + 12*f2*f3*f4)*x1*x2*x3*x5 + (780*f0*f5*f7 - 
    2240*f0*f6^2 - 110*f1*f4*f7 + 160*f1*f5*f6 - 532*f2*f3*f7 + 500*f2*f4*f6
    + 355*f2*f5^2 - 48*f3^2*f6 - 1184*f3*f4*f5 + 450*f4^3)*x1*x2*x3*x8 + 
    (24*f0*f3*f7^2 + 2440*f0*f4*f6*f7 + 5110*f0*f5^2*f7 - 15360*f0*f5*f6^2 -
    770*f1*f2*f7^2 - 1940*f1*f3*f6*f7 - 1380*f1*f4*f5*f7 + 680*f1*f4*f6^2 + 
    4010*f1*f5^2*f6 - 1500*f2^2*f6*f7 + 4972*f2*f3*f5*f7 - 512*f2*f3*f6^2 + 
    2420*f2*f4^2*f7 + 3800*f2*f4*f5*f6 + 2045*f2*f5^3 + 212*f3^2*f4*f7 + 
    1624*f3^2*f5*f6 + 188*f3*f4^2*f6 - 739*f3*f4*f5^2 - 
    3270*f4^3*f5)*x1*x2*x4^2 + (-280*f0*f3*f7 - 640*f0*f4*f6 - 2160*f0*f5^2 
    + 240*f1*f2*f7 + 580*f1*f3*f6 + 790*f1*f4*f5 + 200*f2^2*f6 - 
    1258*f2*f3*f5 - 460*f2*f4^2 - 88*f3^2*f4)*x1*x2*x4*x5 + (-140*f0*f4*f7 +
    2920*f0*f5*f6 + 180*f1*f3*f7 - 660*f1*f4*f6 + 60*f1*f5^2 + 300*f2^2*f7 +
    244*f2*f3*f6 + 1380*f2*f4*f5 - 668*f3^2*f5 - 812*f3*f4^2)*x1*x2*x4*x6 + 
    (-880*f0*f5*f7 - 6320*f0*f6^2 + 920*f1*f4*f7 + 2200*f1*f5*f6 - 
    194*f2*f3*f7 + 3120*f2*f4*f6 + 1285*f2*f5^2 + 504*f3^2*f6 - 782*f3*f4*f5
    - 890*f4^3)*x1*x2*x4*x7 + (-4160*f0*f6*f7 + 770*f1*f5*f7 + 400*f1*f6^2 +
    870*f2*f4*f7 + 900*f2*f5*f6 + 900*f3^2*f7 + 148*f3*f4*f6 - 3575*f3*f5^2 
    - 2010*f4^2*f5)*x1*x2*x4*x8 + (56*f0*f3 - 40*f1*f2)*x1*x2*x5^2 + 
    (760*f0*f6 + 50*f1*f5 - 110*f2*f4 - 124*f3^2)*x1*x2*x5*x8 + (-220*f0*f5 
    + 110*f1*f4)*x1*x2*x6^2 + (-200*f0*f7 + 120*f1*f6 - 70*f2*f5 - 
    304*f3*f4)*x1*x2*x6*x8 + 100*f1*f6*x1*x2*x7^2 + (200*f3*f6 + 
    190*f4*f5)*x1*x2*x8^2 + (380*f0*f2*f7^2 + 768*f0*f3*f6*f7 + 
    3700*f0*f4*f5*f7 - 1600*f0*f4*f6^2 - 4940*f0*f5^2*f6 + 60*f1^2*f7^2 + 
    80*f1*f2*f6*f7 - 610*f1*f3*f5*f7 + 480*f1*f3*f6^2 - 570*f1*f4^2*f7 + 
    1220*f1*f4*f5*f6 + 1155*f1*f5^3 + 30*f2^2*f5*f7 + 400*f2^2*f6^2 - 
    394*f2*f3*f4*f7 - 732*f2*f3*f5*f6 - 340*f2*f4^2*f6 + 1290*f2*f4*f5^2 + 
    184*f3^3*f7 + 144*f3^2*f4*f6 + 191*f3^2*f5^2 - 1052*f3*f4^2*f5 + 
    460*f4^4)*x1*x3^3 + (2520*f0*f3*f7^2 - 2320*f0*f4*f6*f7 - 
    7130*f0*f5^2*f7 - 2160*f0*f5*f6^2 + 680*f1*f2*f7^2 - 420*f1*f3*f6*f7 + 
    2990*f1*f4*f5*f7 - 1040*f1*f4*f6^2 - 570*f1*f5^2*f6 + 1000*f2^2*f6*f7 - 
    3250*f2*f3*f5*f7 - 928*f2*f3*f6^2 - 2050*f2*f4^2*f7 + 240*f2*f4*f5*f6 + 
    1380*f2*f5^3 + 322*f3^2*f4*f7 + 2348*f3^2*f5*f6 + 2276*f3*f4^2*f6 - 
    4153*f3*f4*f5^2 + 2310*f4^3*f5)*x1*x3^2*x4 + (-736*f0*f3*f7 + 
    600*f0*f4*f6 + 2260*f0*f5^2 - 60*f1*f2*f7 + 40*f1*f3*f6 - 270*f1*f4*f5 -
    400*f2^2*f6 + 390*f2*f3*f5 + 460*f2*f4^2 - 210*f3^2*f4)*x1*x3^2*x5 + 
    (320*f0*f4*f7 + 2640*f0*f5*f6 + 366*f1*f3*f7 - 960*f1*f4*f6 - 
    1365*f1*f5^2 + 120*f2^2*f7 + 384*f2*f3*f6 - 910*f2*f4*f5 - 566*f3^2*f5 -
    590*f3*f4^2)*x1*x3^2*x6 + (-760*f0*f5*f7 + 80*f0*f6^2 - 230*f1*f4*f7 + 
    260*f1*f5*f6 - 204*f2*f3*f7 + 140*f2*f4*f6 + 600*f2*f5^2 - 356*f3^2*f6 -
    822*f3*f4*f5 + 400*f4^3)*x1*x3^2*x7 + (800*f0*f6*f7 + 80*f1*f5*f7 - 
    480*f1*f6^2 + 130*f2*f4*f7 + 20*f2*f5*f6 - 392*f3^2*f7 + 208*f3*f4*f6 + 
    10*f3*f5^2 + 1990*f4^2*f5)*x1*x3^2*x8 + (3240*f0*f4*f7^2 - 
    5120*f0*f5*f6*f7 + 5920*f0*f6^3 - 636*f1*f3*f7^2 - 6240*f1*f4*f6*f7 - 
    1430*f1*f5^2*f7 - 4360*f1*f5*f6^2 - 1020*f2^2*f7^2 - 1376*f2*f3*f6*f7 + 
    1100*f2*f4*f5*f7 - 4280*f2*f4*f6^2 + 1010*f2*f5^2*f6 + 5634*f3^2*f5*f7 +
    32*f3^2*f6^2 + 2696*f3*f4^2*f7 + 1376*f3*f4*f5*f6 - 1086*f3*f5^3 + 
    1800*f4^3*f6 + 4100*f4^2*f5^2)*x1*x3*x4^2 + (-2160*f0*f4*f7 + 
    2640*f0*f5*f6 + 344*f1*f3*f7 + 1560*f1*f4*f6 + 505*f1*f5^2 + 410*f2^2*f7
    + 260*f2*f3*f6 + 330*f2*f4*f5 - 1830*f3^2*f5 - 872*f3*f4^2)*x1*x3*x4*x5 
    + (-160*f0*f6*f7 - 200*f1*f5*f7 - 640*f1*f6^2 + 210*f2*f4*f7 + 
    440*f2*f5*f6 - 468*f3^2*f7 + 572*f3*f4*f6 + 1317*f3*f5^2 + 
    2770*f4^2*f5)*x1*x3*x4*x7 + (-80*f0*f7^2 + 480*f1*f6*f7 + 2230*f2*f5*f7 
    + 1520*f2*f6^2 + 170*f3*f4*f7 - 1724*f3*f5*f6 - 200*f4^2*f6 + 
    4950*f4*f5^2)*x1*x3*x4*x8 + (360*f0*f4 - 60*f1*f3)*x1*x3*x5^2 + 
    (-400*f0*f5 + 40*f1*f4 + 68*f2*f3)*x1*x3*x5*x6 + (-440*f0*f6 + 140*f1*f5
    + 110*f2*f4 + 56*f3^2)*x1*x3*x6^2 + (-20*f1*f7 - 240*f2*f6 + 390*f3*f5 +
    140*f4^2)*x1*x3*x7^2 + (300*f2*f7 - 232*f3*f6 - 190*f4*f5)*x1*x3*x7*x8 +
    (108*f3*f7 - 600*f4*f6 + 360*f5^2)*x1*x3*x8^2 + (18960*f0*f5*f7^2 + 
    8880*f0*f6^2*f7 - 7110*f1*f4*f7^2 - 9340*f1*f5*f6*f7 + 2154*f2*f3*f7^2 -
    8820*f2*f4*f6*f7 - 8705*f2*f5^2*f7 + 4720*f2*f5*f6^2 + 48*f3^2*f6*f7 + 
    2148*f3*f4*f5*f7 - 3648*f3*f5^2*f6 + 4460*f4^3*f7 - 2800*f4^2*f5*f6 + 
    11830*f4*f5^3)*x1*x4^3 + (-11240*f0*f5*f7 - 2960*f0*f6^2 + 3680*f1*f4*f7
    + 3540*f1*f5*f6 - 1284*f2*f3*f7 + 2740*f2*f4*f6 + 2890*f2*f5^2 - 
    16*f3^2*f6 - 580*f3*f4*f5 - 1340*f4^3)*x1*x4^2*x5 + (7160*f0*f6*f7 - 
    250*f1*f5*f7 - 520*f1*f6^2 - 2350*f2*f4*f7 - 4040*f2*f5*f6 - 634*f3^2*f7
    - 268*f3*f4*f6 + 5654*f3*f5^2 + 2630*f4^2*f5)*x1*x4^2*x6 + (4080*f0*f7^2
    - 1880*f1*f6*f7 - 3100*f2*f5*f7 + 1680*f2*f6^2 - 720*f3*f4*f7 + 
    168*f3*f5*f6 - 960*f4^2*f6 + 10335*f4*f5^2)*x1*x4^2*x7 + (2480*f1*f7^2 +
    2840*f2*f6*f7 - 12026*f3*f5*f7 + 280*f3*f6^2 - 3510*f4^2*f7 + 
    3800*f4*f5*f6 - 1260*f5^3)*x1*x4^2*x8 + (1640*f0*f5 - 470*f1*f4 + 
    206*f2*f3)*x1*x4*x5^2 + (-2160*f0*f6 - 430*f1*f5 + 770*f2*f4 + 
    98*f3^2)*x1*x4*x5*x6 + (-2800*f0*f7 + 740*f1*f6 + 1140*f2*f5 + 
    128*f3*f4)*x1*x4*x5*x7 + (-830*f1*f7 - 1360*f2*f6 + 1574*f3*f5 + 
    770*f4^2)*x1*x4*x5*x8 + (640*f0*f7 + 360*f1*f6 + 90*f2*f5 + 
    532*f3*f4)*x1*x4*x6^2 + (270*f1*f7 - 1120*f2*f6 + 1692*f3*f5 + 
    350*f4^2)*x1*x4*x6*x7 + (-800*f2*f7 - 928*f3*f6 - 100*f4*f5)*x1*x4*x6*x8
    + (-660*f2*f7 + 456*f3*f6 + 2610*f4*f5)*x1*x4*x7^2 + (-548*f3*f7 - 
    3700*f4*f6 - 1745*f5^2)*x1*x4*x7*x8 + (-1500*f4*f7 + 
    1480*f5*f6)*x1*x4*x8^2 + 480*f0*x1*x5^2*x7 - 220*f0*x1*x5*x6^2 - 
    230*f1*x1*x5*x6*x7 + 210*f2*x1*x5*x6*x8 + 260*f2*x1*x5*x7^2 + 
    556*f3*x1*x5*x7*x8 + 690*f4*x1*x5*x8^2 + 70*f1*x1*x6^3 - 
    110*f2*x1*x6^2*x7 - 334*f3*x1*x6^2*x8 + 70*f3*x1*x6*x7^2 - 
    980*f4*x1*x6*x7*x8 + 200*f4*x1*x7^3 + 40*f7*x1*x8^3 + (-200*f0*f2*f5*f7 
    - 96*f0*f3*f5*f6 - 1420*f0*f4*f5^2 + 40*f1^2*f5*f7 - 160*f1^2*f6^2 + 
    100*f1*f2*f4*f7 - 100*f1*f2*f5*f6 + 48*f1*f3*f4*f6 + 164*f1*f3*f5^2 + 
    930*f1*f4^2*f5)*x2^4 + (-400*f0*f2*f6*f7 - 368*f0*f3*f5*f7 - 
    192*f0*f3*f6^2 - 2320*f0*f4*f5*f6 + 830*f0*f5^3 - 140*f1^2*f6*f7 + 
    200*f1*f2*f5*f7 - 520*f1*f2*f6^2 + 184*f1*f3*f4*f7 + 476*f1*f3*f5*f6 + 
    180*f1*f4^2*f6 + 55*f1*f4*f5^2 + 100*f2^2*f4*f7 - 100*f2^2*f5*f6 + 
    48*f2*f3*f4*f6 + 164*f2*f3*f5^2 + 850*f2*f4^2*f5 - 180*f3*f4^3)*x2^3*x3 
    + (-400*f0*f2*f7^2 - 192*f0*f3*f6*f7 - 2700*f0*f4*f5*f7 + 
    2000*f0*f5^2*f6 + 60*f1^2*f7^2 - 200*f1*f2*f6*f7 + 188*f1*f3*f5*f7 + 
    320*f1*f3*f6^2 + 150*f1*f4^2*f7 - 1220*f1*f4*f5*f6 - 935*f1*f5^3 + 
    400*f2^2*f5*f7 - 100*f2*f3*f4*f7 + 292*f2*f3*f5*f6 - 200*f2*f4^2*f6 + 
    2380*f2*f4*f5^2 - 48*f3^2*f4*f6 - 40*f3^2*f5^2 - 1256*f3*f4^2*f5 + 
    460*f4^4)*x2^3*x4 + (200*f0*f2*f7 + 96*f0*f3*f6 + 1420*f0*f4*f5 + 
    20*f1^2*f7 + 100*f1*f2*f6 - 164*f1*f3*f5 - 180*f1*f4^2)*x2^3*x5 + 
    (-220*f0*f5^2 - 100*f1*f2*f7 - 48*f1*f3*f6 - 570*f1*f4*f5)*x2^3*x6 + 
    (880*f0*f5*f6 + 184*f1*f3*f7 - 540*f1*f4*f6 - 515*f1*f5^2 + 100*f2^2*f7 
    + 48*f2*f3*f6 + 490*f2*f4*f5 - 332*f3*f4^2)*x2^3*x7 + (-440*f0*f5*f7 + 
    640*f0*f6^2 + 140*f1*f4*f7 - 100*f1*f5*f6 + 200*f2*f4*f6 - 204*f3*f4*f5 
    - 340*f4^3)*x2^3*x8 + (-200*f0*f2*f7^2 - 832*f0*f3*f6*f7 - 
    1740*f0*f4*f5*f7 + 1040*f0*f4*f6^2 + 1860*f0*f5^2*f6 - 30*f1^2*f7^2 - 
    340*f1*f2*f6*f7 + 284*f1*f3*f5*f7 - 120*f1*f3*f6^2 + 330*f1*f4^2*f7 - 
    600*f1*f4*f5*f6 + 60*f2^2*f5*f7 - 360*f2^2*f6^2 + 284*f2*f3*f4*f7 + 
    328*f2*f3*f5*f6 + 220*f2*f4^2*f6 - 435*f2*f4*f5^2 + 48*f3^2*f4*f6 + 
    154*f3^2*f5^2 + 1042*f3*f4^2*f5 - 240*f4^4)*x2^2*x3^2 + (-736*f0*f3*f7^2
    + 1320*f0*f4*f6*f7 + 1780*f0*f5^2*f7 + 480*f0*f5*f6^2 + 60*f1*f2*f7^2 - 
    792*f1*f3*f6*f7 - 1690*f1*f4*f5*f7 + 720*f1*f4*f6^2 + 836*f2*f3*f5*f7 + 
    616*f2*f3*f6^2 + 300*f2*f4^2*f7 + 180*f2*f4*f5*f6 - 1325*f2*f5^3 - 
    184*f3^2*f4*f7 + 212*f3^2*f5*f6 + 100*f3*f4^2*f6 + 4045*f3*f4*f5^2 + 
    1510*f4^3*f5)*x2^2*x3*x4 + (368*f0*f3*f7 - 520*f0*f4*f6 - 870*f0*f5^2 + 
    20*f1*f2*f7 - 100*f1*f3*f6 + 360*f1*f4*f5 + 100*f2^2*f6 - 164*f2*f3*f5 -
    140*f2*f4^2)*x2^2*x3*x5 + (500*f0*f5*f7 + 240*f0*f6^2 - 30*f1*f4*f7 - 
    600*f1*f5*f6 + 284*f2*f3*f7 - 500*f2*f4*f6 - 435*f2*f5^2 + 48*f3^2*f6 + 
    644*f3*f4*f5 - 50*f4^3)*x2^2*x3*x7 + (20*f1*f5*f7 + 120*f1*f6^2 + 
    200*f2*f5*f6 - 348*f3*f5^2 - 810*f4^2*f5)*x2^2*x3*x8 + (280*f0*f4*f7^2 -
    4880*f0*f5*f6*f7 + 640*f0*f6^3 - 1528*f1*f3*f7^2 + 1980*f1*f4*f6*f7 + 
    2305*f1*f5^2*f7 - 1040*f1*f5*f6^2 + 100*f2^2*f7^2 + 248*f2*f3*f6*f7 + 
    1890*f2*f4*f5*f7 + 200*f2*f4*f6^2 + 140*f2*f5^2*f6 + 268*f3^2*f5*f7 - 
    160*f3^2*f6^2 + 288*f3*f4^2*f7 + 1576*f3*f4*f5*f6 + 4375*f3*f5^3 - 
    500*f4^3*f6 + 9390*f4^2*f5^2)*x2^2*x4^2 + (-140*f0*f4*f7 + 520*f0*f5*f6 
    + 572*f1*f3*f7 - 460*f1*f4*f6 - 510*f1*f5^2 - 100*f2^2*f7 - 148*f2*f3*f6
    - 690*f2*f4*f5 - 84*f3^2*f5 + 64*f3*f4^2)*x2^2*x4*x5 + (880*f0*f5*f7 - 
    640*f0*f6^2 - 10*f1*f4*f7 + 60*f1*f5*f6 + 100*f2*f3*f7 + 200*f2*f4*f6 + 
    20*f2*f5^2 + 48*f3^2*f6 - 340*f3*f4*f5 - 580*f4^3)*x2^2*x4*x6 + 
    (-880*f0*f6*f7 + 460*f1*f5*f7 - 520*f1*f6^2 + 530*f2*f4*f7 + 20*f2*f5*f6
    - 184*f3^2*f7 + 744*f3*f4*f6 + 2015*f3*f5^2 + 4150*f4^2*f5)*x2^2*x4*x7 +
    (-800*f0*f7^2 - 200*f1*f6*f7 + 240*f2*f5*f7 - 640*f2*f6^2 + 964*f3*f4*f7
    + 4*f3*f5*f6 - 20*f4^2*f6 - 1770*f4*f5^2)*x2^2*x4*x8 + (200*f0*f7 + 
    100*f1*f6 - 124*f3*f4)*x2^2*x5*x8 + (-140*f1*f7 - 200*f2*f6 + 204*f3*f5 
    + 70*f4^2)*x2^2*x6*x8 + (200*f4*f6 - 10*f5^2)*x2^2*x8^2 + 
    (-368*f0*f3*f7^2 - 120*f0*f4*f6*f7 + 610*f0*f5^2*f7 + 1600*f0*f5*f6^2 - 
    40*f1*f2*f7^2 - 100*f1*f3*f6*f7 - 210*f1*f4*f5*f7 + 120*f1*f4*f6^2 - 
    200*f2^2*f6*f7 + 304*f2*f3*f5*f7 - 320*f2*f3*f6^2 + 210*f2*f4^2*f7 - 
    560*f2*f4*f5*f6 + 184*f3^2*f4*f7 + 388*f3^2*f5*f6 + 440*f3*f4^2*f6 - 
    181*f3*f4*f5^2 - 1050*f4^3*f5)*x2*x3^3 + (-500*f0*f4*f7^2 + 
    2120*f0*f5*f6*f7 + 800*f0*f6^3 - 352*f1*f3*f7^2 - 240*f1*f4*f6*f7 - 
    600*f1*f5^2*f7 + 1960*f1*f5*f6^2 + 200*f2^2*f7^2 + 100*f2*f3*f6*f7 - 
    50*f2*f4*f5*f7 + 40*f2*f4*f6^2 - 1680*f2*f5^2*f6 + 560*f3^2*f5*f7 + 
    712*f3^2*f6^2 + 402*f3*f4^2*f7 + 2584*f3*f4*f5*f6 - 479*f3*f5^3 + 
    380*f4^3*f6 - 6660*f4^2*f5^2)*x2*x3^2*x4 + (320*f0*f4*f7 - 1440*f0*f5*f6
    + 40*f1*f4*f6 + 180*f1*f5^2 + 240*f2*f4*f5 - 144*f3^2*f5 - 
    334*f3*f4^2)*x2*x3^2*x5 + (120*f0*f6*f7 - 210*f1*f5*f7 + 120*f1*f6^2 - 
    150*f2*f4*f7 - 560*f2*f5*f6 + 184*f3^2*f7 - 280*f3*f4*f6 + 199*f3*f5^2 -
    2210*f4^2*f5)*x2*x3^2*x7 + (-160*f0*f7^2 + 100*f1*f6*f7 - 140*f2*f5*f7 +
    320*f2*f6^2 - 448*f3*f5*f6 - 220*f4^2*f6 + 145*f4*f5^2)*x2*x3^2*x8 + 
    (-5460*f0*f5*f7^2 + 3200*f0*f6^2*f7 + 920*f1*f4*f7^2 + 1100*f1*f5*f6*f7 
    + 1040*f1*f6^3 - 632*f2*f3*f7^2 + 160*f2*f4*f6*f7 + 1155*f2*f5^2*f7 - 
    240*f2*f5*f6^2 + 1972*f3^2*f6*f7 + 2854*f3*f4*f5*f7 - 776*f3*f4*f6^2 - 
    2144*f3*f5^2*f6 - 2100*f4^3*f7 - 4900*f4^2*f5*f6 - 
    390*f4*f5^3)*x2*x3*x4^2 + (1940*f0*f5*f7 - 1280*f0*f6^2 - 140*f1*f4*f7 -
    680*f1*f5*f6 + 124*f2*f3*f7 + 120*f2*f4*f6 + 40*f2*f5^2 - 444*f3^2*f6 - 
    1636*f3*f4*f5 + 400*f4^3)*x2*x3*x4*x5 + (-340*f1*f7^2 - 600*f2*f6*f7 + 
    1540*f3*f5*f7 - 952*f3*f6^2 + 450*f4^2*f7 - 2860*f4*f5*f6 - 
    115*f5^3)*x2*x3*x4*x8 - 124*f3*f4*x2*x3*x6^2 + (-60*f4*f7 + 
    260*f5*f6)*x2*x3*x8^2 + (800*f0*f6*f7^2 - 2790*f1*f5*f7^2 + 
    2520*f1*f6^2*f7 - 2890*f2*f4*f7^2 + 8960*f2*f5*f6*f7 - 640*f2*f6^3 + 
    1964*f3^2*f7^2 - 1328*f3*f4*f6*f7 + 767*f3*f5^2*f7 + 464*f3*f5*f6^2 - 
    13520*f4^2*f5*f7 + 160*f4^2*f6^2 - 3190*f4*f5^2*f6 + 2770*f5^4)*x2*x4^3 
    + (-400*f0*f6*f7 + 1670*f1*f5*f7 - 840*f1*f6^2 + 1570*f2*f4*f7 - 
    400*f2*f5*f6 - 1088*f3^2*f7 + 436*f3*f4*f6 + 2200*f3*f5^2 + 
    3510*f4^2*f5)*x2*x4^2*x5 + (2560*f0*f7^2 - 520*f1*f6*f7 - 1360*f2*f5*f7 
    + 440*f2*f6^2 - 854*f3*f4*f7 - 8*f3*f5*f6 + 120*f4^2*f6 - 
    6100*f4*f5^2)*x2*x4^2*x6 + (380*f1*f7^2 + 3440*f2*f6*f7 + 2434*f3*f5*f7 
    + 232*f3*f6^2 - 750*f4^2*f7 + 5200*f4*f5*f6 + 3715*f5^3)*x2*x4^2*x7 + 
    (400*f2*f7^2 + 8*f3*f6*f7 - 1990*f4*f5*f7 + 200*f4*f6^2 - 
    5200*f5^2*f6)*x2*x4^2*x8 + (120*f0*f6 - 20*f1*f5 - 220*f2*f4 + 
    124*f3^2)*x2*x4*x5^2 + (-1520*f0*f7 + 130*f3*f4)*x2*x4*x5*x6 - 
    4*f3*f6*x2*x4*x5*x8 + (580*f1*f7 + 1160*f3*f5 + 500*f4^2)*x2*x4*x6^2 - 
    964*f3*f7*x2*x4*x6*x8 + (3300*f4*f6 + 785*f5^2)*x2*x4*x7^2 - 
    2700*f5*f6*x2*x4*x7*x8 + (-480*f5*f7 + 640*f6^2)*x2*x4*x8^2 + 
    220*f0*x2*x5^2*x6 + 60*f1*x2*x5^2*x7 - 180*f1*x2*x5*x6^2 - 
    100*f2*x2*x5*x6*x7 + 124*f3*x2*x5*x6*x8 - 282*f3*x2*x5*x7^2 - 
    540*f4*x2*x5*x7*x8 + 20*f5*x2*x5*x8^2 + 294*f3*x2*x6^2*x7 + 
    160*f4*x2*x6^2*x8 + 1450*f4*x2*x6*x7^2 - 210*f5*x2*x6*x7*x8 - 
    200*f6*x2*x6*x8^2 - 190*f5*x2*x7^3 - 160*f6*x2*x7^2*x8 + 
    (-320*f0*f4*f7^2 + 920*f0*f5*f6*f7 - 20*f1*f3*f7^2 + 80*f1*f4*f6*f7 - 
    10*f2^2*f7^2 - 160*f2*f3*f6*f7 - 130*f2*f4*f5*f7 - 320*f2*f4*f6^2 + 
    224*f3^2*f5*f7 + 480*f3*f4^2*f7 - 12*f3*f4*f5*f6 - 266*f3*f5^3 + 
    360*f4^3*f6 - 180*f4^2*f5^2)*x3^4 + (720*f0*f5*f7^2 + 80*f0*f6^2*f7 - 
    530*f1*f4*f7^2 + 700*f1*f5*f6*f7 + 136*f2*f3*f7^2 - 680*f2*f4*f6*f7 - 
    110*f2*f5^2*f7 - 600*f2*f5*f6^2 + 276*f3^2*f6*f7 + 2620*f3*f4*f5*f7 + 
    512*f3*f4*f6^2 + 1004*f3*f5^2*f6 + 2020*f4^3*f7 + 3020*f4^2*f5*f6 - 
    2775*f4*f5^3)*x3^3*x4 + (-360*f0*f5*f7 - 240*f0*f6^2 + 80*f1*f4*f7 + 
    40*f1*f5*f6 - 20*f2*f3*f7 + 280*f2*f4*f6 + 20*f2*f5^2 - 60*f3^2*f6 - 
    256*f3*f4*f5 - 520*f4^3)*x3^3*x5 + (80*f1*f6*f7 - 130*f2*f5*f7 - 
    320*f2*f6^2 + 120*f3*f4*f7 - 12*f3*f5*f6 + 180*f4^2*f6 - 
    1720*f4*f5^2)*x3^3*x7 + (20*f1*f7^2 + 160*f2*f6*f7 - 284*f3*f5*f7 - 
    240*f4^2*f7 + 340*f4*f5*f6 + 255*f5^3)*x3^3*x8 + (-2000*f0*f6*f7^2 + 
    550*f1*f5*f7^2 - 680*f1*f6^2*f7 + 1300*f2*f4*f7^2 - 2400*f2*f5*f6*f7 + 
    80*f2*f6^3 + 166*f3^2*f7^2 + 2784*f3*f4*f6*f7 + 499*f3*f5^2*f7 + 
    3592*f3*f5*f6^2 + 10830*f4^2*f5*f7 + 1560*f4^2*f6^2 + 1420*f4*f5^2*f6 - 
    1810*f5^4)*x3^2*x4^2 + (-160*f0*f6*f7 - 300*f1*f5*f7 - 160*f1*f6^2 - 
    530*f2*f4*f7 + 560*f2*f5*f6 + 36*f3^2*f7 - 736*f3*f4*f6 - 1722*f3*f5^2 -
    2960*f4^2*f5)*x3^2*x4*x5 + (560*f0*f7^2 + 460*f1*f6*f7 - 1230*f2*f5*f7 -
    360*f2*f6^2 - 138*f3*f4*f7 - 2636*f3*f5*f6 - 880*f4^2*f6 + 
    2075*f4*f5^2)*x3^2*x4*x6 + (-330*f1*f7^2 - 520*f2*f6*f7 + 1004*f3*f5*f7 
    + 512*f3*f6^2 + 1510*f4^2*f7 - 3760*f4*f5*f6 - 1660*f5^3)*x3^2*x4*x7 + 
    (-280*f2*f7^2 - 316*f3*f6*f7 - 320*f4*f5*f7 - 40*f4*f6^2 + 
    2030*f5^2*f6)*x3^2*x4*x8 + (200*f0*f6 - 60*f1*f5 + 40*f2*f4 - 
    10*f3^2)*x3^2*x5^2 + (-180*f0*f7 - 40*f1*f6 + 300*f2*f5 + 
    78*f3*f4)*x3^2*x5*x6 + (80*f1*f7 + 280*f2*f6 - 430*f4^2)*x3^2*x5*x7 + 
    (20*f2*f7 + 120*f3*f6 + 160*f4*f5)*x3^2*x5*x8 + 115*f5^2*x3^2*x6*x8 + 
    (-4320*f0*f7^3 - 2380*f1*f6*f7^2 + 5110*f2*f5*f7^2 - 4960*f2*f6^2*f7 + 
    2598*f3*f4*f7^2 + 7816*f3*f5*f6*f7 - 1104*f3*f6^3 + 4340*f4^2*f6*f7 + 
    6325*f4*f5^2*f7 + 2560*f4*f5*f6^2 - 80*f5^3*f6)*x3*x4^3 + (3240*f0*f7^2 
    + 140*f1*f6*f7 - 2070*f2*f5*f7 - 360*f2*f6^2 - 1574*f3*f4*f7 - 
    5744*f3*f5*f6 - 1140*f4^2*f6 - 1915*f4*f5^2)*x3*x4^2*x5 + (1160*f2*f7^2 
    + 2084*f3*f6*f7 + 3090*f4*f5*f7 - 6720*f4*f6^2 + 
    1330*f5^2*f6)*x3*x4^2*x7 + (236*f3*f7^2 + 1420*f4*f6*f7 - 280*f5^2*f7 + 
    1920*f5*f6^2)*x3*x4^2*x8 + (-720*f0*f7 + 40*f1*f6 + 100*f2*f5 + 
    216*f3*f4)*x3*x4*x5^2 + (960*f2*f6 + 1858*f3*f5)*x3*x4*x5*x6 + 
    (-510*f2*f7 - 104*f3*f6 - 860*f4*f5)*x3*x4*x5*x7 + (-216*f3*f7 + 
    440*f4*f6 - 255*f5^2)*x3*x4*x5*x8 + 950*f2*f7*x3*x4*x6^2 - 
    96*f3*f7*x3*x4*x6*x7 - 110*f4*f7*x3*x4*x6*x8 + (170*f4*f7 + 
    1800*f5*f6)*x3*x4*x7^2 + (-440*f5*f7 - 720*f6^2)*x3*x4*x7*x8 - 
    80*f6*f7*x3*x4*x8^2 + 40*f0*x3*x5^3 + 60*f1*x3*x5^2*x6 + 
    40*f2*x3*x5^2*x7 + 20*f3*x3*x5^2*x8 - 320*f2*x3*x5*x6^2 - 
    178*f3*x3*x5*x6*x7 - 310*f4*x3*x5*x6*x8 - 20*f4*x3*x5*x7^2 - 
    20*f5*x3*x5*x7*x8 - 60*f6*x3*x5*x8^2 + 266*f3*x3*x6^3 + 
    1360*f4*x3*x6^2*x7 - 480*f5*x3*x6^2*x8 - 280*f5*x3*x6*x7^2 + 
    340*f6*x3*x6*x7*x8 + 60*f7*x3*x6*x8^2 + 180*f6*x3*x7^3 - 
    120*f7*x3*x7^2*x8 + (-3960*f1*f7^3 - 6520*f2*f6*f7^2 + 3960*f3*f5*f7^2 -
    1656*f3*f6^2*f7 + 2860*f4^2*f7^2 + 4160*f4*f5*f6*f7 - 20*f5^3*f7 - 
    640*f5^2*f6^2)*x4^4 + (2770*f1*f7^2 + 1100*f2*f6*f7 - 7088*f3*f5*f7 + 
    552*f3*f6^2 - 1300*f4^2*f7 - 1440*f4*f5*f6 + 230*f5^3)*x4^3*x5 + 
    (-2420*f2*f7^2 - 744*f3*f6*f7 + 5670*f4*f5*f7 - 160*f4*f6^2 + 
    790*f5^2*f6)*x4^3*x6 + (2484*f3*f7^2 - 9920*f4*f6*f7 + 2685*f5^2*f7 - 
    640*f5*f6^2)*x4^3*x7 + (2980*f4*f7^2 + 1600*f5*f6*f7 + 640*f6^3)*x4^3*x8
    + (-800*f1*f7 + 320*f2*f6 + 1948*f3*f5 + 140*f4^2)*x4^2*x5^2 + 
    (1800*f2*f7 + 228*f3*f6 - 1400*f4*f5)*x4^2*x5*x6 + (-820*f3*f7 + 
    3280*f4*f6 - 750*f5^2)*x4^2*x5*x7 + (-470*f4*f7 - 560*f5*f6)*x4^2*x5*x8 
    + (-40*f3*f7 + 380*f4*f6 + 190*f5^2)*x4^2*x6^2 + (-5280*f4*f7 + 
    320*f5*f6)*x4^2*x6*x7 + (2640*f5*f7 - 840*f6^2)*x4^2*x6*x8 + (3120*f5*f7
    - 160*f6^2)*x4^2*x7^2 - 840*f6*f7*x4^2*x7*x8 - 840*f7^2*x4^2*x8^2 + 
    100*f1*x4*x5^3 - 320*f2*x4*x5^2*x6 - 20*f3*x4*x5^2*x7 - 
    160*f4*x4*x5^2*x8 + 128*f3*x4*x5*x6^2 + 1830*f4*x4*x5*x6*x7 - 
    710*f5*x4*x5*x6*x8 - 1030*f5*x4*x5*x7^2 + 300*f6*x4*x5*x7*x8 + 
    240*f7*x4*x5*x8^2 - 380*f4*x4*x6^3 + 580*f5*x4*x6^2*x7 + 
    20*f6*x4*x6^2*x8 + 60*f6*x4*x6*x7^2 + 340*f7*x4*x6*x7*x8 + 
    320*f7*x4*x7^3 - 10*x5^2*x8^2 - 130*x5*x6*x7*x8 - 110*x5*x7^3 + 
    110*x6^3*x8 + 100*x6^2*x7^2,
(150*f1^3*f7 - 120*f1^2*f2*f6 - 840*f1^2*f3*f5 - 370*f1^2*f4^2 - 
    40*f1*f2^2*f5 - 280*f1*f2*f3*f4)*x1^4 + (230*f1^2*f2*f7 - 128*f1^2*f3*f6
    + 1600*f1^2*f4*f5 - 756*f1*f2*f3*f5 - 760*f1*f2*f4^2 - 
    280*f1*f3^2*f4)*x1^3*x2 + (-1120*f0*f3*f4*f5 - 546*f1^2*f3*f7 - 
    40*f1^2*f4*f6 - 180*f1^2*f5^2 + 380*f1*f2^2*f7 + 376*f1*f2*f3*f6 + 
    2840*f1*f2*f4*f5 + 1584*f1*f3^2*f5 + 1020*f1*f3*f4^2 - 724*f2^2*f3*f5 - 
    760*f2^2*f4^2 + 280*f2*f3^2*f4)*x1^3*x3 + (-2280*f0*f1*f5*f7 + 
    2400*f0*f2*f5*f6 + 10080*f0*f3*f5^2 + 4440*f0*f4^2*f5 - 180*f1^2*f4*f7 +
    920*f1^2*f5*f6 - 102*f1*f2*f3*f7 + 40*f1*f2*f4*f6 - 1380*f1*f2*f5^2 - 
    1120*f1*f3*f4*f5 - 740*f1*f4^3 + 150*f2^3*f7 + 168*f2^2*f3*f6 + 
    880*f2^2*f4*f5 - 288*f2*f3^2*f5 - 280*f2*f3*f4^2)*x1^3*x4 + 
    (160*f0*f1*f5 + 160*f1^2*f4 - 48*f1*f2*f3)*x1^3*x5 + (-160*f0*f1*f6 + 
    560*f0*f3*f4 + 200*f1^2*f5 + 20*f1*f2*f4 + 48*f1*f3^2)*x1^3*x6 + 
    (-600*f0*f1*f7 + 800*f0*f2*f6 + 3360*f0*f3*f5 + 1480*f0*f4^2 + 
    460*f1^2*f6 - 600*f1*f2*f5 + 280*f1*f3*f4 - 60*f2^2*f4 - 
    96*f2*f3^2)*x1^3*x7 + (-580*f0*f2*f7 - 112*f0*f3*f6 - 5600*f0*f4*f5 + 
    250*f1^2*f7 + 400*f1*f2*f6 - 1320*f1*f3*f5 - 320*f1*f4^2 - 300*f2^2*f5 -
    224*f2*f3*f4 - 48*f3^3)*x1^3*x8 + (560*f0*f3*f4*f5 + 264*f1^2*f3*f7 + 
    210*f1^2*f5^2 - 150*f1*f2^2*f7 - 168*f1*f2*f3*f6 - 1120*f1*f2*f4*f5 - 
    668*f1*f3^2*f5 - 1040*f1*f3*f4^2)*x1^2*x2^2 + (800*f0*f1*f5*f7 - 
    800*f0*f2*f5*f6 - 6064*f0*f3*f5^2 - 4520*f0*f4^2*f5 - 670*f1^2*f4*f7 - 
    280*f1^2*f5*f6 + 250*f1*f2*f3*f7 + 480*f1*f2*f4*f6 + 840*f1*f2*f5^2 + 
    392*f1*f3^2*f6 + 1852*f1*f3*f4*f5 + 1500*f1*f4^3 - 150*f2^3*f7 - 
    168*f2^2*f3*f6 - 1000*f2^2*f4*f5 - 676*f2*f3^2*f5 - 480*f2*f3*f4^2 + 
    280*f3^3*f4)*x1^2*x2*x3 + (-640*f0*f1*f6*f7 - 520*f0*f2*f5*f7 + 
    2240*f0*f3*f4*f7 + 2720*f0*f3*f5*f6 - 8000*f0*f4*f5^2 - 40*f1^2*f5*f7 - 
    920*f1^2*f6^2 + 330*f1*f2*f4*f7 + 880*f1*f2*f5*f6 + 90*f1*f3^2*f7 - 
    536*f1*f3*f4*f6 + 932*f1*f3*f5^2 + 4620*f1*f4^2*f5 + 300*f2^2*f3*f7 - 
    80*f2^2*f5^2 + 336*f2*f3^2*f6 + 1660*f2*f3*f4*f5 - 760*f2*f4^3 - 
    192*f3^3*f5 - 280*f3^2*f4^2)*x1^2*x2*x4 + (160*f0*f1*f6 - 560*f0*f3*f4 -
    40*f1^2*f5 - 20*f1*f2*f4 - 96*f1*f3^2)*x1^2*x2*x5 + (-180*f0*f1*f7 + 
    1352*f0*f3*f5 + 1520*f0*f4^2 + 300*f1^2*f6 - 60*f1*f2*f5 + 
    232*f1*f3*f4)*x1^2*x2*x6 + (20*f0*f2*f7 + 944*f0*f3*f6 - 800*f0*f4*f5 - 
    330*f1^2*f7 - 120*f1*f2*f6 + 1396*f1*f3*f5 + 1080*f1*f4^2 + 180*f2^2*f5 
    + 240*f2*f3*f4 - 48*f3^3)*x1^2*x2*x7 + (-300*f0*f3*f7 - 320*f0*f4*f6 - 
    1760*f0*f5^2 - 350*f1*f2*f7 - 372*f1*f3*f6 + 920*f1*f4*f5 - 100*f2^2*f6 
    + 412*f2*f3*f5 + 1000*f2*f4^2 - 484*f3^2*f4)*x1^2*x2*x8 + 
    (1160*f0*f1*f6*f7 + 580*f0*f2*f5*f7 - 800*f0*f2*f6^2 + 560*f0*f3*f4*f7 -
    9040*f0*f3*f5*f6 - 7560*f0*f4^2*f6 + 5600*f0*f4*f5^2 + 110*f1^2*f5*f7 + 
    800*f1^2*f6^2 - 710*f1*f2*f4*f7 + 100*f1*f2*f5*f6 + 690*f1*f3^2*f7 + 
    248*f1*f3*f4*f6 - 352*f1*f3*f5^2 - 3260*f1*f4^2*f5 - 314*f2^2*f3*f7 + 
    320*f2^2*f4*f6 + 420*f2^2*f5^2 - 160*f2*f3^2*f6 - 1408*f2*f3*f4*f5 + 
    1520*f2*f4^3 - 792*f3^3*f5 - 650*f3^2*f4^2)*x1^2*x3^2 + (3480*f0*f1*f7^2
    - 3160*f0*f2*f6*f7 - 19584*f0*f3*f5*f7 + 1120*f0*f3*f6^2 - 
    15040*f0*f4^2*f7 - 2240*f0*f4*f5*f6 - 4000*f0*f5^3 + 2980*f1^2*f6*f7 - 
    940*f1*f2*f5*f7 + 1720*f1*f2*f6^2 + 1006*f1*f3*f4*f7 - 10008*f1*f3*f5*f6
    - 5080*f1*f4^2*f6 - 420*f1*f4*f5^2 + 110*f2^2*f4*f7 - 400*f2^2*f5*f6 + 
    486*f2*f3^2*f7 - 688*f2*f3*f4*f6 + 3100*f2*f3*f5^2 + 3440*f2*f4^2*f5 - 
    96*f3^3*f6 + 192*f3^2*f4*f5 + 1020*f3*f4^3)*x1^2*x3*x4 + (-960*f0*f1*f7 
    + 800*f0*f2*f6 + 6064*f0*f3*f5 + 4520*f0*f4^2 - 500*f1^2*f6 + 
    100*f1*f2*f5 - 424*f1*f3*f4 - 60*f2^2*f4 - 48*f2*f3^2)*x1^2*x3*x5 + 
    (984*f0*f3*f7 - 320*f0*f4*f6 - 2000*f0*f5^2 - 350*f1*f2*f7 - 
    1472*f1*f3*f6 - 1920*f1*f4*f5 + 120*f2^2*f6 + 1264*f2*f3*f5 + 
    760*f2*f4^2 - 184*f3^2*f4)*x1^2*x3*x7 + (1040*f0*f4*f7 + 4080*f0*f5*f6 -
    348*f1*f3*f7 - 1120*f1*f4*f6 - 1880*f1*f5^2 + 470*f2^2*f7 + 336*f2*f3*f6
    + 1360*f2*f4*f5 + 396*f3^2*f5 - 416*f3*f4^2)*x1^2*x3*x8 + (60*f0*f2*f7^2
    + 1680*f0*f3*f6*f7 + 960*f0*f4*f5*f7 - 12960*f0*f5^2*f6 + 3540*f1^2*f7^2
    + 2980*f1*f2*f6*f7 - 18396*f1*f3*f5*f7 - 10850*f1*f4^2*f7 + 
    1280*f1*f4*f5*f6 + 2920*f1*f5^3 - 3400*f2^2*f5*f7 + 160*f2^2*f6^2 - 
    1894*f2*f3*f4*f7 - 2760*f2*f3*f5*f6 + 160*f2*f4^2*f6 + 7180*f2*f4*f5^2 -
    144*f3^3*f7 + 10656*f3^2*f5^2 + 4160*f3*f4^2*f5 - 370*f4^4)*x1^2*x4^2 + 
    (-20*f0*f2*f7 - 560*f0*f3*f6 - 320*f0*f4*f5 - 1350*f1^2*f7 - 
    920*f1*f2*f6 + 5136*f1*f3*f5 + 3420*f1*f4^2 + 1100*f2^2*f5 + 
    456*f2*f3*f4 + 48*f3^3)*x1^2*x4*x5 + (204*f0*f3*f7 - 720*f0*f4*f6 + 
    680*f0*f5^2 + 580*f1*f2*f7 + 588*f1*f3*f6 - 1680*f1*f4*f5 + 100*f2^2*f6 
    - 268*f2*f3*f5 - 1000*f2*f4^2 + 608*f3^2*f4)*x1^2*x4*x6 + (1680*f0*f4*f7
    - 10800*f0*f5*f6 - 1122*f1*f3*f7 + 640*f1*f4*f6 + 2740*f1*f5^2 - 
    470*f2^2*f7 - 1032*f2*f3*f6 + 2600*f2*f4*f5 + 3840*f3^2*f5 + 
    1760*f3*f4^2)*x1^2*x4*x7 + (1800*f0*f5*f7 - 5200*f0*f6^2 + 290*f1*f4*f7 
    + 1140*f1*f5*f6 - 1602*f2*f3*f7 + 2240*f2*f4*f6 + 2240*f2*f5^2 - 
    428*f3^2*f6 - 1924*f3*f4*f5 + 700*f4^3)*x1^2*x4*x8 + 90*f1^2*x1^2*x5^2 +
    (96*f0*f3 - 200*f1*f2)*x1^2*x5*x6 + (-560*f0*f4 + 256*f1*f3 + 
    160*f2^2)*x1^2*x5*x7 + (-880*f0*f5 - 20*f1*f4 + 344*f2*f3)*x1^2*x5*x8 - 
    112*f1*f3*x1^2*x6^2 + (560*f0*f5 - 140*f1*f4 + 120*f2*f3)*x1^2*x6*x7 + 
    (-2080*f0*f6 + 920*f1*f5 + 480*f2*f4 + 216*f3^2)*x1^2*x6*x8 + 
    (-2160*f0*f6 + 640*f1*f5 + 360*f2*f4 + 96*f3^2)*x1^2*x7^2 + (-40*f0*f7 -
    280*f1*f6 - 120*f2*f5 + 224*f3*f4)*x1^2*x7*x8 + (30*f1*f7 - 504*f3*f5 - 
    240*f4^2)*x1^2*x8^2 + (-20*f0*f1*f5*f7 + 1352*f0*f3*f5^2 + 
    1520*f0*f4^2*f5 + 230*f1^2*f4*f7 - 340*f1^2*f5*f6 - 150*f1*f2*f3*f7 + 
    20*f1*f2*f5^2 - 168*f1*f3^2*f6 - 1864*f1*f3*f4*f5 - 760*f1*f4^3)*x1*x2^3
    + (-40*f0*f1*f6*f7 - 620*f0*f2*f5*f7 - 1120*f0*f3*f4*f7 + 
    1280*f0*f3*f5*f6 + 3040*f0*f4^2*f6 - 3440*f0*f4*f5^2 - 230*f1^2*f5*f7 - 
    720*f1^2*f6^2 + 450*f1*f2*f4*f7 - 760*f1*f2*f5*f6 - 294*f1*f3^2*f7 + 
    648*f1*f3*f4*f6 + 768*f1*f3*f5^2 + 960*f1*f4^2*f5 - 150*f2^2*f3*f7 - 
    20*f2^2*f5^2 - 168*f2*f3^2*f6 - 1792*f2*f3*f4*f5 - 760*f2*f4^3 + 
    560*f3^2*f4^2)*x1*x2^2*x3 + (-720*f0*f1*f7^2 - 600*f0*f2*f6*f7 + 
    4124*f0*f3*f5*f7 - 672*f0*f3*f6^2 + 6080*f0*f4^2*f7 - 3120*f0*f4*f5*f6 +
    4080*f0*f5^3 - 2080*f1^2*f6*f7 + 2320*f1*f2*f5*f7 - 520*f1*f2*f6^2 - 
    536*f1*f3*f4*f7 + 4020*f1*f3*f5*f6 + 800*f1*f4^2*f6 + 440*f1*f4*f5^2 + 
    150*f2^2*f4*f7 - 300*f2^2*f5*f6 + 150*f2*f3^2*f7 + 168*f2*f3*f4*f6 - 
    2336*f2*f3*f5^2 - 1260*f2*f4^2*f5 + 168*f3^3*f6 + 1620*f3^2*f4*f5 - 
    1040*f3*f4^3)*x1*x2^2*x4 + (180*f0*f1*f7 - 1256*f0*f3*f5 - 1520*f0*f4^2 
    + 300*f1^2*f6 - 60*f1*f2*f5)*x1*x2^2*x5 + (300*f0*f2*f7 + 336*f0*f3*f6 +
    2120*f0*f4*f5 - 150*f1^2*f7 + 100*f1*f2*f6 + 260*f1*f3*f5 + 
    480*f1*f4^2)*x1*x2^2*x6 + (-396*f0*f3*f7 + 720*f0*f4*f6 + 2280*f0*f5^2 +
    470*f1*f2*f7 + 1028*f1*f3*f6 - 600*f1*f4*f5 - 100*f2^2*f6 - 268*f2*f3*f5
    - 520*f2*f4^2 + 464*f3^2*f4)*x1*x2^2*x7 + (-480*f0*f4*f7 + 2400*f0*f5*f6
    + 472*f1*f3*f7 - 720*f1*f4*f6 - 580*f1*f5^2 + 150*f2^2*f7 - 32*f2*f3*f6 
    + 620*f2*f4*f5 + 264*f3^2*f5 + 104*f3*f4^2)*x1*x2^2*x8 + 
    (-420*f0*f1*f7^2 + 160*f0*f2*f6*f7 + 1132*f0*f3*f5*f7 - 2176*f0*f3*f6^2 
    - 40*f0*f4^2*f7 - 1440*f0*f4*f5*f6 + 1360*f0*f5^3 - 180*f1^2*f6*f7 - 
    480*f1*f2*f5*f7 - 1160*f1*f2*f6^2 + 956*f1*f3*f4*f7 + 1376*f1*f3*f5*f6 +
    880*f1*f4^2*f6 - 1040*f1*f4*f5^2 + 70*f2^2*f4*f7 - 380*f2^2*f5*f6 - 
    444*f2*f3^2*f7 + 224*f2*f3*f4*f6 + 584*f2*f3*f5^2 - 160*f2*f4^2*f5 - 
    168*f3^3*f6 - 2280*f3^2*f4*f5 - 260*f3*f4^3)*x1*x2*x3^2 + 
    (-1280*f0*f2*f7^2 - 5720*f0*f3*f6*f7 - 6400*f0*f4*f5*f7 - 640*f0*f4*f6^2
    + 1120*f0*f5^2*f6 - 950*f1^2*f7^2 - 2540*f1*f2*f6*f7 + 6054*f1*f3*f5*f7 
    + 1216*f1*f3*f6^2 + 3570*f1*f4^2*f7 + 2560*f1*f4*f5*f6 + 340*f1*f5^3 + 
    1690*f2^2*f5*f7 - 520*f2^2*f6^2 + 562*f2*f3*f4*f7 - 1688*f2*f3*f5*f6 - 
    840*f2*f4^2*f6 + 2580*f2*f4*f5^2 + 294*f3^3*f7 - 632*f3^2*f4*f6 - 
    4004*f3^2*f5^2 - 3824*f3*f4^2*f5 + 1500*f4^4)*x1*x2*x3*x4 + 
    (620*f0*f2*f7 + 1616*f0*f3*f6 + 4000*f0*f4*f5 + 160*f1^2*f7 + 
    640*f1*f2*f6 - 1132*f1*f3*f5 - 1260*f1*f4^2 + 20*f2^2*f5 + 
    8*f2*f3*f4)*x1*x2*x3*x5 + (-1280*f0*f5*f7 + 3040*f0*f6^2 + 160*f1*f4*f7 
    - 460*f1*f5*f6 + 812*f2*f3*f7 - 800*f2*f4*f6 - 480*f2*f5^2 + 168*f3^2*f6
    + 1944*f3*f4*f5 - 700*f4^3)*x1*x2*x3*x8 + (-84*f0*f3*f7^2 - 
    3840*f0*f4*f6*f7 - 7360*f0*f5^2*f7 + 23360*f0*f5*f6^2 + 420*f1*f2*f7^2 +
    1140*f1*f3*f6*f7 + 3980*f1*f4*f5*f7 - 1280*f1*f4*f6^2 - 7360*f1*f5^2*f6 
    + 700*f2^2*f6*f7 - 7102*f2*f3*f5*f7 + 992*f2*f3*f6^2 - 4020*f2*f4^2*f7 -
    2800*f2*f4*f5*f6 - 2820*f2*f5^3 - 242*f3^2*f4*f7 - 2384*f3^2*f5*f6 - 
    408*f3*f4^2*f6 + 1324*f3*f4*f5^2 + 5420*f4^3*f5)*x1*x2*x4^2 + 
    (480*f0*f3*f7 + 1040*f0*f4*f6 + 3160*f0*f5^2 - 140*f1*f2*f7 - 
    280*f1*f3*f6 - 1440*f1*f4*f5 + 1828*f2*f3*f5 + 760*f2*f4^2 + 
    108*f3^2*f4)*x1*x2*x4*x5 + (240*f0*f4*f7 - 4720*f0*f5*f6 - 130*f1*f3*f7 
    + 1260*f1*f4*f6 + 140*f1*f5^2 - 450*f2^2*f7 - 404*f2*f3*f6 - 
    2080*f2*f4*f5 + 988*f3^2*f5 + 1292*f3*f4^2)*x1*x2*x4*x6 + (1280*f0*f5*f7
    + 9520*f0*f6^2 - 920*f1*f4*f7 - 3500*f1*f5*f6 + 354*f2*f3*f7 - 
    3520*f2*f4*f6 - 1760*f2*f5^2 - 764*f3^2*f6 + 1312*f3*f4*f5 + 
    1540*f4^3)*x1*x2*x4*x7 + (5760*f0*f6*f7 - 920*f1*f5*f7 - 400*f1*f6^2 - 
    1220*f2*f4*f7 - 400*f2*f5*f6 - 1400*f3^2*f7 - 368*f3*f4*f6 + 
    5200*f3*f5^2 + 3260*f4^2*f5)*x1*x2*x4*x8 + (-96*f0*f3 + 
    40*f1*f2)*x1*x2*x5^2 + (-960*f0*f6 - 100*f1*f5 + 160*f2*f4 + 
    184*f3^2)*x1*x2*x5*x8 + (320*f0*f5 - 160*f1*f4)*x1*x2*x6^2 + (300*f0*f7 
    - 20*f1*f6 + 120*f2*f5 + 464*f3*f4)*x1*x2*x6*x8 + (-200*f3*f6 - 
    240*f4*f5)*x1*x2*x8^2 + (-580*f0*f2*f7^2 - 1288*f0*f3*f6*f7 - 
    5600*f0*f4*f5*f7 + 2400*f0*f4*f6^2 + 6640*f0*f5^2*f6 - 60*f1^2*f7^2 - 
    80*f1*f2*f6*f7 + 860*f1*f3*f5*f7 - 480*f1*f3*f6^2 + 770*f1*f4^2*f7 - 
    2020*f1*f4*f5*f6 - 1680*f1*f5^3 - 30*f2^2*f5*f7 - 400*f2^2*f6^2 + 
    654*f2*f3*f4*f7 + 1012*f2*f3*f5*f6 + 240*f2*f4^2*f6 - 1840*f2*f4*f5^2 - 
    294*f3^3*f7 - 304*f3^2*f4*f6 - 456*f3^2*f5^2 + 1632*f3*f4^2*f5 - 
    760*f4^4)*x1*x3^3 + (-4020*f0*f3*f7^2 + 3120*f0*f4*f6*f7 + 
    9280*f0*f5^2*f7 + 2960*f0*f5*f6^2 - 780*f1*f2*f7^2 + 20*f1*f3*f6*f7 - 
    5390*f1*f4*f5*f7 + 1640*f1*f4*f6^2 + 20*f1*f5^2*f6 - 500*f2^2*f6*f7 + 
    4700*f2*f3*f5*f7 + 448*f2*f3*f6^2 + 3400*f2*f4^2*f7 - 1540*f2*f4*f5*f6 -
    1780*f2*f5^3 - 602*f3^2*f4*f7 - 3268*f3^2*f5*f6 - 3616*f3*f4^2*f6 + 
    6648*f3*f4*f5^2 - 3760*f4^3*f5)*x1*x3^2*x4 + (1176*f0*f3*f7 - 
    800*f0*f4*f6 - 2960*f0*f5^2 + 60*f1*f2*f7 - 40*f1*f3*f6 + 520*f1*f4*f5 +
    400*f2^2*f6 - 540*f2*f3*f5 - 760*f2*f4^2 + 360*f3^2*f4)*x1*x3^2*x5 + 
    (-520*f0*f4*f7 - 3640*f0*f5*f6 - 556*f1*f3*f7 + 1360*f1*f4*f6 + 
    2040*f1*f5^2 - 170*f2^2*f7 - 544*f2*f3*f6 + 1360*f2*f4*f5 + 956*f3^2*f5 
    + 940*f3*f4^2)*x1*x3^2*x6 + (1160*f0*f5*f7 - 80*f0*f6^2 + 180*f1*f4*f7 -
    660*f1*f5*f6 + 314*f2*f3*f7 - 640*f2*f4*f6 - 800*f2*f5^2 + 596*f3^2*f6 +
    1352*f3*f4*f5 - 700*f4^3)*x1*x3^2*x7 + (-1400*f0*f6*f7 - 80*f1*f5*f7 + 
    480*f1*f6^2 - 230*f2*f4*f7 - 20*f2*f5*f6 + 622*f3^2*f7 - 128*f3*f4*f6 + 
    240*f3*f5^2 - 3040*f4^2*f5)*x1*x3^2*x8 + (-5040*f0*f4*f7^2 + 
    7120*f0*f5*f6*f7 - 9120*f0*f6^3 - 474*f1*f3*f7^2 + 8840*f1*f4*f6*f7 + 
    380*f1*f5^2*f7 + 6360*f1*f5*f6^2 + 1520*f2^2*f7^2 + 216*f2*f3*f6*f7 - 
    1400*f2*f4*f5*f7 + 5080*f2*f4*f6^2 - 960*f2*f5^2*f6 - 8544*f3^2*f5*f7 + 
    488*f3^2*f6^2 - 4536*f3*f4^2*f7 - 1016*f3*f4*f5*f6 + 2776*f3*f5^3 - 
    3000*f4^3*f6 - 6200*f4^2*f5^2)*x1*x3*x4^2 + (3360*f0*f4*f7 - 
    3840*f0*f5*f6 - 4*f1*f3*f7 - 2360*f1*f4*f6 - 80*f1*f5^2 - 610*f2^2*f7 + 
    40*f2*f3*f6 - 580*f2*f4*f5 + 2780*f3^2*f5 + 1452*f3*f4^2)*x1*x3*x4*x5 + 
    (160*f0*f6*f7 - 100*f1*f5*f7 + 440*f1*f6^2 - 310*f2*f4*f7 - 840*f2*f5*f6
    + 738*f3^2*f7 - 352*f3*f4*f6 - 1372*f3*f5^2 - 4320*f4^2*f5)*x1*x3*x4*x7 
    + (80*f0*f7^2 - 780*f1*f6*f7 - 3330*f2*f5*f7 - 1120*f2*f6^2 - 
    120*f3*f4*f7 + 1784*f3*f5*f6 + 400*f4^2*f6 - 7300*f4*f5^2)*x1*x3*x4*x8 +
    (-560*f0*f4 + 60*f1*f3)*x1*x3*x5^2 + (600*f0*f5 - 40*f1*f4 - 
    88*f2*f3)*x1*x3*x5*x6 + 100*f1*f5*x1*x3*x5*x7 + (640*f0*f6 - 240*f1*f5 -
    160*f2*f4 - 96*f3^2)*x1*x3*x6^2 + (-30*f1*f7 + 240*f2*f6 - 540*f3*f5 - 
    240*f4^2)*x1*x3*x7^2 + (-450*f2*f7 + 312*f3*f6 + 240*f4*f5)*x1*x3*x7*x8 
    + (-178*f3*f7 + 800*f4*f6 - 460*f5^2)*x1*x3*x8^2 + (-28560*f0*f5*f7^2 - 
    13680*f0*f6^2*f7 + 9210*f1*f4*f7^2 + 15140*f1*f5*f6*f7 - 3414*f2*f3*f7^2
    + 9620*f2*f4*f6*f7 + 12480*f2*f5^2*f7 - 4720*f2*f5*f6^2 + 732*f3^2*f6*f7
    - 2968*f3*f4*f5*f7 + 6768*f3*f5^2*f6 - 7460*f4^3*f7 + 4800*f4^2*f5*f6 - 
    17880*f4*f5^3)*x1*x4^3 + (16840*f0*f5*f7 + 4560*f0*f6^2 - 5130*f1*f4*f7 
    - 5340*f1*f5*f6 + 1944*f2*f3*f7 - 3040*f2*f4*f6 - 4140*f2*f5^2 - 
    244*f3^2*f6 + 780*f3*f4*f5 + 2240*f4^3)*x1*x4^2*x5 + (-11160*f0*f6*f7 - 
    300*f1*f5*f7 + 920*f1*f6^2 + 3400*f2*f4*f7 + 4740*f2*f5*f6 + 
    1044*f3^2*f7 + 588*f3*f4*f6 - 8864*f3*f5^2 - 4280*f4^2*f5)*x1*x4^2*x6 + 
    (-5880*f0*f7^2 + 2380*f1*f6*f7 + 4500*f2*f5*f7 - 1680*f2*f6^2 + 
    1270*f3*f4*f7 + 712*f3*f5*f6 + 1660*f4^2*f6 - 15660*f4*f5^2)*x1*x4^2*x7 
    + (-2280*f1*f7^2 - 740*f2*f6*f7 + 18016*f3*f5*f7 - 480*f3*f6^2 + 
    5960*f4^2*f7 - 6200*f4*f5*f6 + 1760*f5^3)*x1*x4^2*x8 + (-2440*f0*f5 + 
    720*f1*f4 - 296*f2*f3)*x1*x4*x5^2 + (3360*f0*f6 + 680*f1*f5 - 1120*f2*f4
    - 168*f3^2)*x1*x4*x5*x6 + (4000*f0*f7 - 840*f1*f6 - 1640*f2*f5 - 
    248*f3*f4)*x1*x4*x5*x7 + (780*f1*f7 + 1160*f2*f6 - 2184*f3*f5 - 
    1320*f4^2)*x1*x4*x5*x8 + (-940*f0*f7 - 760*f1*f6 - 140*f2*f5 - 
    812*f3*f4)*x1*x4*x6^2 + (-670*f1*f7 + 1320*f2*f6 - 2772*f3*f5 - 
    600*f4^2)*x1*x4*x6*x7 + (1200*f2*f7 + 1548*f3*f6 + 
    100*f4*f5)*x1*x4*x6*x8 + (910*f2*f7 - 496*f3*f6 - 3960*f4*f5)*x1*x4*x7^2
    + (768*f3*f7 + 5400*f4*f6 + 2320*f5^2)*x1*x4*x7*x8 + (2150*f4*f7 - 
    2380*f5*f6)*x1*x4*x8^2 - 680*f0*x1*x5^2*x7 + 320*f0*x1*x5*x6^2 + 
    380*f1*x1*x5*x6*x7 - 310*f2*x1*x5*x6*x8 - 360*f2*x1*x5*x7^2 - 
    796*f3*x1*x5*x7*x8 - 990*f4*x1*x5*x8^2 - 120*f1*x1*x6^3 + 
    160*f2*x1*x6^2*x7 + 544*f3*x1*x6^2*x8 - 120*f3*x1*x6*x7^2 + 
    1480*f4*x1*x6*x7*x8 - 300*f4*x1*x7^3 - 40*f7*x1*x8^3 + (300*f0*f2*f5*f7 
    + 336*f0*f3*f5*f6 + 2120*f0*f4*f5^2 - 90*f1^2*f5*f7 + 160*f1^2*f6^2 - 
    150*f1*f2*f4*f7 + 100*f1*f2*f5*f6 - 168*f1*f3*f4*f6 - 224*f1*f3*f5^2 - 
    1380*f1*f4^2*f5)*x2^4 + (600*f0*f2*f6*f7 + 588*f0*f3*f5*f7 + 
    672*f0*f3*f6^2 + 3520*f0*f4*f5*f6 - 1080*f0*f5^3 + 140*f1^2*f6*f7 - 
    350*f1*f2*f5*f7 + 520*f1*f2*f6^2 - 294*f1*f3*f4*f7 - 716*f1*f3*f5*f6 - 
    280*f1*f4^2*f6 - 80*f1*f4*f5^2 - 150*f2^2*f4*f7 + 100*f2^2*f5*f6 - 
    168*f2*f3*f4*f6 - 224*f2*f3*f5^2 - 1300*f2*f4^2*f5 + 
    280*f3*f4^3)*x2^3*x3 + (600*f0*f2*f7^2 + 672*f0*f3*f6*f7 + 
    4000*f0*f4*f5*f7 - 2800*f0*f5^2*f6 - 110*f1^2*f7^2 + 200*f1*f2*f6*f7 - 
    208*f1*f3*f5*f7 - 320*f1*f3*f6^2 - 350*f1*f4^2*f7 + 1820*f1*f4*f5*f6 + 
    1460*f1*f5^3 - 600*f2^2*f5*f7 + 150*f2*f3*f4*f7 - 772*f2*f3*f5*f6 - 
    3580*f2*f4*f5^2 + 168*f3^2*f4*f6 + 40*f3^2*f5^2 + 1996*f3*f4^2*f5 - 
    760*f4^4)*x2^3*x4 + (-300*f0*f2*f7 - 336*f0*f3*f6 - 2120*f0*f4*f5 - 
    20*f1^2*f7 - 100*f1*f2*f6 + 224*f1*f3*f5 + 280*f1*f4^2)*x2^3*x5 + 
    (320*f0*f5^2 + 150*f1*f2*f7 + 168*f1*f3*f6 + 820*f1*f4*f5)*x2^3*x6 + 
    (-1280*f0*f5*f6 - 294*f1*f3*f7 + 840*f1*f4*f6 + 740*f1*f5^2 - 
    150*f2^2*f7 - 168*f2*f3*f6 - 740*f2*f4*f5 + 512*f3*f4^2)*x2^3*x7 + 
    (740*f0*f5*f7 - 640*f0*f6^2 - 190*f1*f4*f7 + 100*f1*f5*f6 - 200*f2*f4*f6
    + 264*f3*f4*f5 + 540*f4^3)*x2^3*x8 + (300*f0*f2*f7^2 + 1512*f0*f3*f6*f7 
    + 2640*f0*f4*f5*f7 - 1440*f0*f4*f6^2 - 2560*f0*f5^2*f6 + 30*f1^2*f7^2 + 
    340*f1*f2*f6*f7 - 444*f1*f3*f5*f7 + 120*f1*f3*f6^2 - 480*f1*f4^2*f7 + 
    1100*f1*f4*f5*f6 - 110*f2^2*f5*f7 + 360*f2^2*f6^2 - 444*f2*f3*f4*f7 - 
    448*f2*f3*f5*f6 - 320*f2*f4^2*f6 + 560*f2*f4*f5^2 - 168*f3^2*f4*f6 - 
    214*f3^2*f5^2 - 1672*f3*f4^2*f5 + 390*f4^4)*x2^2*x3^2 + (1176*f0*f3*f7^2
    - 1920*f0*f4*f6*f7 - 2280*f0*f5^2*f7 - 880*f0*f5*f6^2 - 110*f1*f2*f7^2 +
    1572*f1*f3*f6*f7 + 2340*f1*f4*f5*f7 - 1120*f1*f4*f6^2 + 700*f1*f5^2*f6 -
    100*f2^2*f6*f7 - 1226*f2*f3*f5*f7 - 856*f2*f3*f6^2 - 500*f2*f4^2*f7 - 
    880*f2*f4*f5*f6 + 1700*f2*f5^3 + 294*f3^2*f4*f7 - 692*f3^2*f5*f6 - 
    6320*f3*f4*f5^2 - 2360*f4^3*f5)*x2^2*x3*x4 + (-588*f0*f3*f7 + 
    720*f0*f4*f6 + 1120*f0*f5^2 - 20*f1*f2*f7 + 100*f1*f3*f6 - 560*f1*f4*f5 
    - 100*f2^2*f6 + 224*f2*f3*f5 + 240*f2*f4^2)*x2^2*x3*x5 + (-800*f0*f5*f7 
    - 640*f0*f6^2 + 80*f1*f4*f7 + 1100*f1*f5*f6 - 444*f2*f3*f7 + 
    800*f2*f4*f6 + 560*f2*f5^2 - 168*f3^2*f6 - 1104*f3*f4*f5 + 
    100*f4^3)*x2^2*x3*x7 + (200*f0*f6*f7 + 30*f1*f5*f7 - 120*f1*f6^2 - 
    200*f2*f5*f6 + 468*f3*f5^2 + 1260*f4^2*f5)*x2^2*x3*x8 + (-480*f0*f4*f7^2
    + 7480*f0*f5*f6*f7 - 640*f0*f6^3 + 2398*f1*f3*f7^2 - 2880*f1*f4*f6*f7 - 
    3730*f1*f5^2*f7 + 1040*f1*f5*f6^2 - 150*f2^2*f7^2 - 368*f2*f3*f6*f7 - 
    2790*f2*f4*f5*f7 - 200*f2*f4*f6^2 - 1940*f2*f5^2*f6 - 438*f3^2*f5*f7 + 
    160*f3^2*f6^2 - 408*f3*f4^2*f7 - 2316*f3*f4*f5*f6 - 6700*f3*f5^3 + 
    800*f4^3*f6 - 14540*f4^2*f5^2)*x2^2*x4^2 + (240*f0*f4*f7 - 720*f0*f5*f6 
    - 902*f1*f3*f7 + 660*f1*f4*f6 + 560*f1*f5^2 + 150*f2^2*f7 + 268*f2*f3*f6
    + 1040*f2*f4*f5 + 144*f3^2*f5 - 124*f3*f4^2)*x2^2*x4*x5 + 
    (-1380*f0*f5*f7 + 640*f0*f6^2 + 210*f1*f4*f7 + 40*f1*f5*f6 - 
    150*f2*f3*f7 + 200*f2*f4*f6 - 20*f2*f5^2 - 168*f3^2*f6 + 440*f3*f4*f5 + 
    980*f4^3)*x2^2*x4*x6 + (1480*f0*f6*f7 - 1010*f1*f5*f7 + 520*f1*f6^2 - 
    780*f2*f4*f7 - 720*f2*f5*f6 + 294*f3^2*f7 - 1104*f3*f4*f6 - 3040*f3*f5^2
    - 6400*f4^2*f5)*x2^2*x4*x7 + (1200*f0*f7^2 + 200*f1*f6*f7 - 440*f2*f5*f7
    + 640*f2*f6^2 - 1474*f3*f4*f7 + 236*f3*f5*f6 - 80*f4^2*f6 + 
    2520*f4*f5^2)*x2^2*x4*x8 + (-300*f0*f7 - 100*f1*f6 + 
    184*f3*f4)*x2^2*x5*x8 + (190*f1*f7 + 200*f2*f6 - 264*f3*f5 - 
    120*f4^2)*x2^2*x6*x8 + (-200*f4*f6 + 10*f5^2)*x2^2*x8^2 + 
    (588*f0*f3*f7^2 + 320*f0*f4*f6*f7 - 760*f0*f5^2*f7 - 2400*f0*f5*f6^2 + 
    40*f1*f2*f7^2 + 100*f1*f3*f6*f7 + 360*f1*f4*f5*f7 - 120*f1*f4*f6^2 + 
    200*f2^2*f6*f7 - 464*f2*f3*f5*f7 + 320*f2*f3*f6^2 - 360*f2*f4^2*f7 + 
    860*f2*f4*f5*f6 - 294*f3^2*f4*f7 - 508*f3^2*f5*f6 - 840*f3*f4^2*f6 + 
    196*f3*f4*f5^2 + 1600*f4^3*f5)*x2*x3^3 + (800*f0*f4*f7^2 - 
    2720*f0*f5*f6*f7 - 800*f0*f6^3 + 582*f1*f3*f7^2 + 40*f1*f4*f6*f7 + 
    1300*f1*f5^2*f7 - 2760*f1*f5*f6^2 - 300*f2^2*f7^2 - 100*f2*f3*f6*f7 - 
    50*f2*f4*f5*f7 - 440*f2*f4*f6^2 + 2780*f2*f5^2*f6 - 860*f3^2*f5*f7 - 
    1192*f3^2*f6^2 - 632*f3*f4^2*f7 - 4444*f3*f4*f5*f6 + 264*f3*f5^3 - 
    680*f4^3*f6 + 10260*f4^2*f5^2)*x2*x3^2*x4 + (-520*f0*f4*f7 + 
    2040*f0*f5*f6 - 40*f1*f4*f6 - 280*f1*f5^2 - 340*f2*f4*f5 + 204*f3^2*f5 +
    544*f3*f4^2)*x2*x3^2*x5 + (-320*f0*f6*f7 + 360*f1*f5*f7 - 120*f1*f6^2 + 
    200*f2*f4*f7 + 860*f2*f5*f6 - 294*f3^2*f7 + 280*f3*f4*f6 - 484*f3*f5^2 +
    3360*f4^2*f5)*x2*x3^2*x7 + (260*f0*f7^2 - 100*f1*f6*f7 + 240*f2*f5*f7 - 
    320*f2*f6^2 + 568*f3*f5*f6 + 420*f4^2*f6 - 120*f4*f5^2)*x2*x3^2*x8 + 
    (8560*f0*f5*f7^2 - 4000*f0*f6^2*f7 - 1220*f1*f4*f7^2 - 1000*f1*f5*f6*f7 
    - 1040*f1*f6^3 + 962*f2*f3*f7^2 + 340*f2*f4*f6*f7 - 1780*f2*f5^2*f7 + 
    440*f2*f5*f6^2 - 3352*f3^2*f6*f7 - 4364*f3*f4*f5*f7 + 1016*f3*f4*f6^2 + 
    2904*f3*f5^2*f6 + 3300*f4^3*f7 + 7400*f4^2*f5*f6 + 
    440*f4*f5^3)*x2*x3*x4^2 + (-3040*f0*f5*f7 + 1680*f0*f6^2 + 240*f1*f4*f7 
    + 880*f1*f5*f6 - 184*f2*f3*f7 - 120*f2*f4*f6 - 40*f2*f5^2 + 804*f3^2*f6 
    + 2476*f3*f4*f5 - 600*f4^3)*x2*x3*x4*x5 + (490*f1*f7^2 + 600*f2*f6*f7 - 
    2390*f3*f5*f7 + 1432*f3*f6^2 - 750*f4^2*f7 + 4560*f4*f5*f6 + 
    140*f5^3)*x2*x3*x4*x8 + 184*f3*f4*x2*x3*x6^2 + (110*f4*f7 - 
    260*f5*f6)*x2*x3*x8^2 + (-2400*f0*f6*f7^2 + 5540*f1*f5*f7^2 - 
    2520*f1*f6^2*f7 + 4290*f2*f4*f7^2 - 11260*f2*f5*f6*f7 + 640*f2*f6^3 - 
    3024*f3^2*f7^2 + 2048*f3*f4*f6*f7 - 2372*f3*f5^2*f7 - 1024*f3*f5*f6^2 + 
    20920*f4^2*f5*f7 - 360*f4^2*f6^2 + 4440*f4*f5^2*f6 - 4120*f5^4)*x2*x4^3 
    + (1400*f0*f6*f7 - 2820*f1*f5*f7 + 840*f1*f6^2 - 2320*f2*f4*f7 + 
    300*f2*f5*f6 + 1658*f3^2*f7 - 676*f3*f4*f6 - 3100*f3*f5^2 - 
    5360*f4^2*f5)*x2*x4^2*x5 + (-3760*f0*f7^2 + 720*f1*f6*f7 + 2110*f2*f5*f7
    - 440*f2*f6^2 + 1314*f3*f4*f7 - 72*f3*f5*f6 - 120*f4^2*f6 + 
    9500*f4*f5^2)*x2*x4^2*x6 + (-330*f1*f7^2 - 4740*f2*f6*f7 - 4094*f3*f5*f7
    - 512*f3*f6^2 + 1250*f4^2*f7 - 8000*f4*f5*f6 - 5340*f5^3)*x2*x4^2*x7 + 
    (-600*f2*f7^2 + 472*f3*f6*f7 + 2840*f4*f5*f7 - 200*f4*f6^2 + 
    8600*f5^2*f6)*x2*x4^2*x8 + (-320*f0*f6 + 120*f1*f5 + 320*f2*f4 - 
    184*f3^2)*x2*x4*x5^2 + (2220*f0*f7 - 180*f3*f4)*x2*x4*x5*x6 - 
    236*f3*f6*x2*x4*x5*x8 + (-980*f1*f7 - 200*f2*f6 - 1860*f3*f5 - 
    800*f4^2)*x2*x4*x6^2 + 1474*f3*f7*x2*x4*x6*x8 + (-5000*f4*f6 - 
    1160*f5^2)*x2*x4*x7^2 + 4200*f5*f6*x2*x4*x7*x8 + (780*f5*f7 - 
    640*f6^2)*x2*x4*x8^2 - 320*f0*x2*x5^2*x6 - 60*f1*x2*x5^2*x7 + 
    280*f1*x2*x5*x6^2 + 150*f2*x2*x5*x6*x7 - 184*f3*x2*x5*x6*x8 + 
    412*f3*x2*x5*x7^2 + 790*f4*x2*x5*x7*x8 - 20*f5*x2*x5*x8^2 - 
    504*f3*x2*x6^2*x7 - 260*f4*x2*x6^2*x8 - 2200*f4*x2*x6*x7^2 + 
    260*f5*x2*x6*x7*x8 + 200*f6*x2*x6*x8^2 + 240*f5*x2*x7^3 + 
    160*f6*x2*x7^2*x8 + (520*f0*f4*f7^2 - 1520*f0*f5*f6*f7 + 20*f1*f3*f7^2 -
    80*f1*f4*f6*f7 + 10*f2^2*f7^2 + 160*f2*f3*f6*f7 + 180*f2*f4*f5*f7 + 
    320*f2*f4*f6^2 - 334*f3^2*f5*f7 - 780*f3*f4^2*f7 + 92*f3*f4*f5*f6 + 
    456*f3*f5^3 - 560*f4^3*f6 + 230*f4^2*f5^2)*x3^4 + (-1120*f0*f5*f7^2 + 
    320*f0*f6^2*f7 + 580*f1*f4*f7^2 - 1500*f1*f5*f6*f7 - 176*f2*f3*f7^2 + 
    280*f2*f4*f6*f7 + 110*f2*f5^2*f7 + 200*f2*f5*f6^2 - 416*f3^2*f6*f7 - 
    3970*f3*f4*f5*f7 - 992*f3*f4*f6^2 - 1664*f3*f5^2*f6 - 3220*f4^3*f7 - 
    4620*f4^2*f5*f6 + 4200*f4*f5^3)*x3^3*x4 + (560*f0*f5*f7 + 240*f0*f6^2 - 
    80*f1*f4*f7 - 40*f1*f5*f6 + 20*f2*f3*f7 - 280*f2*f4*f6 - 20*f2*f5^2 + 
    60*f3^2*f6 + 396*f3*f4*f5 + 820*f4^3)*x3^3*x5 + (-80*f1*f6*f7 + 
    180*f2*f5*f7 + 320*f2*f6^2 - 220*f3*f4*f7 + 92*f3*f5*f6 - 280*f4^2*f6 + 
    2520*f4*f5^2)*x3^3*x7 + (-20*f1*f7^2 - 160*f2*f6*f7 + 444*f3*f5*f7 + 
    390*f4^2*f7 - 540*f4*f5*f6 - 280*f5^3)*x3^3*x8 + (4200*f0*f6*f7^2 - 
    1600*f1*f5*f7^2 + 680*f1*f6^2*f7 - 1750*f2*f4*f7^2 + 1300*f2*f5*f6*f7 - 
    880*f2*f6^3 - 306*f3^2*f7^2 - 4944*f3*f4*f6*f7 - 184*f3*f5^2*f7 - 
    6672*f3*f5*f6^2 - 16780*f4^2*f5*f7 - 2560*f4^2*f6^2 - 1920*f4*f5^2*f6 + 
    2560*f5^4)*x3^2*x4^2 + (-440*f0*f6*f7 + 600*f1*f5*f7 + 160*f1*f6^2 + 
    680*f2*f4*f7 - 360*f2*f5*f6 - 26*f3^2*f7 + 1376*f3*f4*f6 + 2552*f3*f5^2 
    + 4560*f4^2*f5)*x3^2*x4*x5 + (-860*f0*f7^2 - 260*f1*f6*f7 + 
    1830*f2*f5*f7 + 760*f2*f6^2 + 208*f3*f4*f7 + 4676*f3*f5*f6 + 
    1380*f4^2*f6 - 3400*f4*f5^2)*x3^2*x4*x6 + (280*f1*f7^2 + 120*f2*f6*f7 - 
    1414*f3*f5*f7 - 992*f3*f6^2 - 2410*f4^2*f7 + 5660*f4*f5*f6 + 
    2260*f5^3)*x3^2*x4*x7 + (380*f2*f7^2 + 356*f3*f6*f7 + 470*f4*f5*f7 + 
    40*f4*f6^2 - 2980*f5^2*f6)*x3^2*x4*x8 + (-200*f0*f6 + 60*f1*f5 - 
    40*f2*f4 + 10*f3^2)*x3^2*x5^2 + (280*f0*f7 + 40*f1*f6 - 450*f2*f5 - 
    148*f3*f4)*x3^2*x5*x6 + (-80*f1*f7 - 280*f2*f6 + 680*f4^2)*x3^2*x5*x7 + 
    (-20*f2*f7 - 120*f3*f6 - 210*f4*f5)*x3^2*x5*x8 - 240*f5^2*x3^2*x6*x8 + 
    (6120*f0*f7^3 + 3080*f1*f6*f7^2 - 7410*f2*f5*f7^2 + 5160*f2*f6^2*f7 - 
    4118*f3*f4*f7^2 - 13856*f3*f5*f6*f7 + 1664*f3*f6^3 - 7340*f4^2*f6*f7 - 
    9400*f4*f5^2*f7 - 3760*f4*f5*f6^2 - 720*f5^3*f6)*x3*x4^3 + 
    (-4440*f0*f7^2 - 340*f1*f6*f7 + 2870*f2*f5*f7 + 1160*f2*f6^2 + 
    2534*f3*f4*f7 + 9704*f3*f5*f6 + 1940*f4^2*f6 + 2840*f4*f5^2)*x3*x4^2*x5 
    + (-1610*f2*f7^2 - 3844*f3*f6*f7 - 4540*f4*f5*f7 + 10120*f4*f6^2 - 
    2880*f5^2*f6)*x3*x4^2*x7 + (-226*f3*f7^2 - 2320*f4*f6*f7 + 780*f5^2*f7 -
    2920*f5*f6^2)*x3*x4^2*x8 + (920*f0*f7 - 40*f1*f6 - 100*f2*f5 - 
    356*f3*f4)*x3*x4*x5^2 + (-1460*f2*f6 - 2928*f3*f5)*x3*x4*x5*x6 + 
    (660*f2*f7 + 464*f3*f6 + 1260*f4*f5)*x3*x4*x5*x7 + (256*f3*f7 - 
    540*f4*f6 + 280*f5^2)*x3*x4*x5*x8 - 1400*f2*f7*x3*x4*x6^2 + 
    136*f3*f7*x3*x4*x6*x7 + 260*f4*f7*x3*x4*x6*x8 + (-220*f4*f7 - 
    2800*f5*f6)*x3*x4*x7^2 + (640*f5*f7 + 1120*f6^2)*x3*x4*x7*x8 + 
    280*f6*f7*x3*x4*x8^2 - 40*f0*x3*x5^3 - 60*f1*x3*x5^2*x6 - 
    40*f2*x3*x5^2*x7 - 20*f3*x3*x5^2*x8 + 470*f2*x3*x5*x6^2 + 
    248*f3*x3*x5*x6*x7 + 410*f4*x3*x5*x6*x8 + 20*f4*x3*x5*x7^2 + 
    20*f5*x3*x5*x7*x8 + 60*f6*x3*x5*x8^2 - 456*f3*x3*x6^3 - 
    2060*f4*x3*x6^2*x7 + 680*f5*x3*x6^2*x8 + 380*f5*x3*x6*x7^2 - 
    540*f6*x3*x6*x7*x8 - 110*f7*x3*x6*x8^2 - 280*f6*x3*x7^3 + 
    170*f7*x3*x7^2*x8 + (4710*f1*f7^3 + 8620*f2*f6*f7^2 - 5160*f3*f5*f7^2 + 
    2496*f3*f6^2*f7 - 4810*f4^2*f7^2 - 6360*f4*f5*f6*f7 - 680*f5^3*f7 + 
    640*f5^2*f6^2)*x4^4 + (-3320*f1*f7^2 - 1200*f2*f6*f7 + 10508*f3*f5*f7 - 
    832*f3*f6^2 + 2200*f4^2*f7 + 2240*f4*f5*f6 - 80*f5^3)*x4^3*x5 + 
    (3570*f2*f7^2 + 904*f3*f6*f7 - 8520*f4*f5*f7 + 360*f4*f6^2 - 
    1040*f5^2*f6)*x4^3*x6 + (-3744*f3*f7^2 + 14820*f4*f6*f7 - 4560*f5^2*f7 +
    640*f5*f6^2)*x4^3*x7 + (-4530*f4*f7^2 - 3100*f5*f6*f7 - 
    640*f6^3)*x4^3*x8 + (900*f1*f7 - 520*f2*f6 - 2968*f3*f5 - 
    240*f4^2)*x4^2*x5^2 + (-2650*f2*f7 - 248*f3*f6 + 2100*f4*f5)*x4^2*x5*x6 
    + (1270*f3*f7 - 4880*f4*f6 + 1300*f5^2)*x4^2*x5*x7 + (820*f4*f7 + 
    1060*f5*f6)*x4^2*x5*x8 + (190*f3*f7 - 680*f4*f6 - 490*f5^2)*x4^2*x6^2 + 
    (8030*f4*f7 - 420*f5*f6)*x4^2*x6*x7 + (-3740*f5*f7 + 
    840*f6^2)*x4^2*x6*x8 + (-4520*f5*f7 + 160*f6^2)*x4^2*x7^2 + 
    1440*f6*f7*x4^2*x7*x8 + 1240*f7^2*x4^2*x8^2 - 100*f1*x4*x5^3 + 
    470*f2*x4*x5^2*x6 + 20*f3*x4*x5^2*x7 + 210*f4*x4*x5^2*x8 - 
    248*f3*x4*x5*x6^2 - 2780*f4*x4*x5*x6*x7 + 960*f5*x4*x5*x6*x8 + 
    1480*f5*x4*x5*x7^2 - 500*f6*x4*x5*x7*x8 - 340*f7*x4*x5*x8^2 + 
    580*f4*x4*x6^3 - 880*f5*x4*x6^2*x7 + 80*f6*x4*x6^2*x8 - 60*f6*x4*x6*x7^2
    - 490*f7*x4*x6*x7*x8 - 470*f7*x4*x7^3 + 10*x5^2*x8^2 + 180*x5*x6*x7*x8 +
    160*x5*x7^3 - 160*x6^3*x8 - 150*x6^2*x7^2,
(240*f0*f1^2*f7 + 96*f0*f1*f2*f6 - 48*f0*f2^2*f5 - 132*f1^3*f6 + 
    392*f1^2*f2*f5 - 188*f1^2*f3*f4 - 4*f1*f2^2*f4 + 48*f1*f2*f3^2)*x1^4 + 
    (384*f0*f1*f2*f7 + 96*f0*f1*f3*f6 - 96*f0*f2*f3*f5 + 24*f1^3*f7 - 
    124*f1^2*f2*f6 + 88*f1^2*f3*f5 - 44*f1^2*f4^2 + 616*f1*f2^2*f5 - 
    288*f1*f2*f3*f4 + 48*f1*f3^3)*x1^3*x2 + (-480*f0*f1*f3*f7 - 
    288*f0*f1*f4*f6 + 288*f0*f1*f5^2 + 384*f0*f2^2*f7 - 96*f0*f2*f3*f6 + 
    176*f0*f2*f4*f5 + 192*f0*f3^2*f5 + 30*f1^2*f2*f7 + 124*f1^2*f3*f6 + 
    3*f1^2*f4*f5 - 188*f1*f2^2*f6 - 750*f1*f2*f3*f5 + 52*f1*f2*f4^2 + 
    328*f1*f3^2*f4 + 614*f2^3*f5 - 280*f2^2*f3*f4 - 48*f2*f3^3)*x1^3*x3 + 
    (-3456*f0^2*f5*f7 + 192*f0*f1*f4*f7 + 1392*f0*f1*f5*f6 + 96*f0*f2*f4*f6 
    - 3648*f0*f2*f5^2 + 2256*f0*f3*f4*f5 - 165*f1^2*f3*f7 - 264*f1^2*f4*f6 -
    144*f1^2*f5^2 + 12*f1*f2^2*f7 - 30*f1*f2*f3*f6 + 815*f1*f2*f4*f5 - 
    96*f1*f3^2*f5 - 376*f1*f3*f4^2 - 68*f2^3*f6 + 7*f2^2*f3*f5 + 
    88*f2^2*f4^2 + 48*f2*f3^2*f4)*x1^3*x4 + (192*f0^2*f5 + 96*f0*f1*f4 + 
    55*f1^2*f3 - 2*f1*f2^2)*x1^3*x5 + (-192*f0^2*f6 - 144*f0*f1*f5 - 
    40*f0*f2*f4 - 96*f0*f3^2 - 10*f1^2*f4 - 60*f1*f2*f3)*x1^3*x6 + 
    (-960*f0^2*f7 + 432*f0*f1*f6 - 1184*f0*f2*f5 + 752*f0*f3*f4 - 72*f1^2*f5
    + 14*f1*f2*f4 - 48*f1*f3^2 + 58*f2^2*f3)*x1^3*x7 + (288*f0*f1*f7 - 
    176*f0*f2*f6 + 316*f0*f3*f5 - 48*f0*f4^2 - 252*f1^2*f6 + 438*f1*f2*f5 - 
    270*f1*f3*f4 - 14*f2^2*f4 + 115*f2*f3^2)*x1^3*x8 + (384*f0*f1*f3*f7 + 
    192*f0*f1*f4*f6 - 144*f0*f1*f5^2 - 136*f0*f2*f4*f5 - 144*f0*f3^2*f5 + 
    20*f1^2*f2*f7 - 116*f1^2*f3*f6 + 213*f1^2*f4*f5 + 68*f1*f2^2*f6 + 
    747*f1*f2*f3*f5 - 96*f1*f2*f4^2 - 236*f1*f3^2*f4)*x1^2*x2^2 + 
    (2304*f0^2*f5*f7 - 960*f0*f1*f4*f7 - 1728*f0*f1*f5*f6 + 384*f0*f2*f3*f7 
    - 96*f0*f2*f4*f6 + 3552*f0*f2*f5^2 - 96*f0*f3^2*f6 - 1696*f0*f3*f4*f5 - 
    107*f1^2*f3*f7 + 468*f1^2*f4*f6 + 24*f1^2*f5^2 + 48*f1*f2^2*f7 - 
    278*f1*f2*f3*f6 - 985*f1*f2*f4*f5 - 76*f1*f3^2*f5 + 796*f1*f3*f4^2 + 
    68*f2^3*f6 + 745*f2^2*f3*f5 - 88*f2^2*f4^2 - 328*f2*f3^2*f4 - 
    48*f3^4)*x1^2*x2*x3 + (-768*f0^2*f6*f7 - 1440*f0*f1*f5*f7 + 
    192*f0*f1*f6^2 + 224*f0*f2*f4*f7 - 2720*f0*f2*f5*f6 - 384*f0*f3^2*f7 + 
    96*f0*f3*f4*f6 - 632*f0*f3*f5^2 + 624*f0*f4^2*f5 - 34*f1^2*f4*f7 + 
    960*f1^2*f5*f6 - 184*f1*f2*f3*f7 - 4*f1*f2*f4*f6 - 1588*f1*f2*f5^2 + 
    66*f1*f3^2*f6 + 931*f1*f3*f4*f5 - 88*f1*f4^3 - 136*f2^2*f3*f6 + 
    568*f2^2*f4*f5 - 114*f2*f3^2*f5 - 104*f2*f3*f4^2 + 
    48*f3^3*f4)*x1^2*x2*x4 + (192*f0^2*f6 + 48*f0*f1*f5 + 40*f0*f2*f4 + 
    96*f0*f3^2 + 24*f1^2*f4 + 34*f1*f2*f3)*x1^2*x2*x5 + (-768*f0^2*f7 + 
    648*f0*f1*f6 - 1088*f0*f2*f5 + 520*f0*f3*f4 + 16*f1*f2*f4 - 
    117*f1*f3^2)*x1^2*x2*x6 + (-768*f0*f1*f7 - 816*f0*f2*f6 - 284*f0*f3*f5 +
    224*f0*f4^2 + 540*f1^2*f6 - 1126*f1*f2*f5 + 564*f1*f3*f4 - 10*f2^2*f4 + 
    19*f2*f3^2)*x1^2*x2*x7 + (-672*f0*f2*f7 - 524*f0*f3*f6 - 878*f0*f4*f5 - 
    24*f1^2*f7 + 456*f1*f2*f6 - 26*f1*f3*f5 - 92*f1*f4^2 - 732*f2^2*f5 + 
    321*f2*f3*f4 + 172*f3^3)*x1^2*x2*x8 + (3840*f0^2*f6*f7 + 48*f0*f1*f5*f7 
    - 3120*f0*f1*f6^2 - 808*f0*f2*f4*f7 + 6464*f0*f2*f5*f6 + 144*f0*f3^2*f7 
    - 2736*f0*f3*f4*f6 - 316*f0*f3*f5^2 - 96*f1^2*f4*f7 + 12*f1^2*f5*f6 - 
    117*f1*f2*f3*f7 + 352*f1*f2*f4*f6 + 266*f1*f2*f5^2 + 176*f1*f3^2*f6 + 
    14*f1*f3*f4*f5 - 48*f1*f4^3 + 28*f2^3*f7 - 30*f2^2*f3*f6 - 
    988*f2^2*f4*f5 + 411*f2*f3^2*f5 + 516*f2*f3*f4^2 - 
    140*f3^3*f4)*x1^2*x3^2 + (8448*f0^2*f7^2 - 2832*f0*f1*f6*f7 + 
    10544*f0*f2*f5*f7 - 896*f0*f2*f6^2 - 6608*f0*f3*f4*f7 - 440*f0*f3*f5*f6 
    + 352*f0*f4^2*f6 - 904*f0*f4*f5^2 - 408*f1^2*f5*f7 - 1896*f1^2*f6^2 - 
    258*f1*f2*f4*f7 + 6620*f1*f2*f5*f6 + 324*f1*f3^2*f7 - 1786*f1*f3*f4*f6 +
    616*f1*f3*f5^2 - 221*f1*f4^2*f5 - 200*f2^2*f3*f7 + 172*f2^2*f4*f6 - 
    2864*f2^2*f5^2 + 260*f2*f3^2*f6 + 799*f2*f3*f4*f5 - 132*f2*f4^3 + 
    288*f3^3*f5 + 328*f3^2*f4^2)*x1^2*x3*x4 + (-2496*f0^2*f7 + 1632*f0*f1*f6
    - 3648*f0*f2*f5 + 1792*f0*f3*f4 + 96*f1^2*f5 + 46*f1*f2*f4 - 124*f1*f3^2
    + 36*f2^2*f3)*x1^2*x3*x5 + (-504*f0*f2*f7 + 160*f0*f3*f6 - 452*f0*f4*f5 
    - 48*f1^2*f7 + 480*f1*f2*f6 + 148*f1*f3*f5 - 58*f1*f4^2 - 840*f2^2*f5 + 
    386*f2*f3*f4 + 48*f3^3)*x1^2*x3*x7 + (-12*f0*f3*f7 + 384*f0*f4*f6 + 
    96*f0*f5^2 + 8*f1*f2*f7 + 38*f1*f3*f6 - 265*f1*f4*f5 - 76*f2^2*f6 - 
    268*f2*f3*f5 + 146*f2*f4^2 + 136*f3^2*f4)*x1^2*x3*x8 + (6816*f0*f1*f7^2 
    - 960*f0*f2*f6*f7 - 4764*f0*f3*f5*f7 + 912*f0*f4^2*f7 - 192*f0*f4*f5*f6 
    - 192*f0*f5^3 - 3900*f1^2*f6*f7 + 9310*f1*f2*f5*f7 - 4534*f1*f3*f4*f7 + 
    1644*f1*f3*f5*f6 - 132*f1*f4^2*f6 - 334*f1*f4*f5^2 - 118*f2^2*f4*f7 + 
    1688*f2^2*f5*f6 + 537*f2*f3^2*f7 - 30*f2*f3*f4*f6 - 3544*f2*f3*f5^2 - 
    269*f2*f4^2*f5 + 2160*f3^2*f4*f5 - 188*f3*f4^3)*x1^2*x4^2 + 
    (-2400*f0*f1*f7 + 352*f0*f2*f6 + 628*f0*f3*f5 - 224*f0*f4^2 + 
    1212*f1^2*f6 - 2838*f1*f2*f5 + 1386*f1*f3*f4 + 16*f2^2*f4 - 
    163*f2*f3^2)*x1^2*x4*x5 + (648*f0*f2*f7 - 132*f0*f3*f6 + 26*f0*f4*f5 - 
    96*f1^2*f7 - 512*f1*f2*f6 - 78*f1*f3*f5 + 34*f1*f4^2 + 738*f2^2*f5 - 
    367*f2*f3*f4 - 96*f3^3)*x1^2*x4*x6 + (-1044*f0*f3*f7 - 96*f0*f4*f6 - 
    192*f0*f5^2 + 108*f1*f2*f7 + 558*f1*f3*f6 - 187*f1*f4*f5 + 524*f2^2*f6 -
    1304*f2*f3*f5 - 278*f2*f4^2 + 704*f3^2*f4)*x1^2*x4*x7 + (-284*f0*f4*f7 -
    672*f0*f5*f6 + 63*f1*f3*f7 + 208*f1*f4*f6 - 480*f1*f5^2 + 56*f2^2*f7 + 
    114*f2*f3*f6 + 363*f2*f4*f5 - 368*f3^2*f5 - 105*f3*f4^2)*x1^2*x4*x8 + 
    96*f0*f1*x1^2*x5^2 + (-44*f0*f2 + 24*f1^2)*x1^2*x5*x6 + (28*f0*f3 - 
    30*f1*f2)*x1^2*x5*x7 + (68*f0*f4 - 41*f1*f3 - 4*f2^2)*x1^2*x5*x8 + 
    2*f1*f2*x1^2*x6^2 + (68*f0*f4 + 41*f1*f3)*x1^2*x6*x7 + (-288*f0*f5 + 
    14*f1*f4 - 44*f2*f3)*x1^2*x6*x8 + (-48*f0*f5 - 10*f1*f4 - 
    78*f2*f3)*x1^2*x7^2 + (336*f0*f6 - 120*f1*f5 - 24*f2*f4 - 
    96*f3^2)*x1^2*x7*x8 + (288*f0*f7 - 108*f1*f6 + 28*f2*f5 - 
    144*f3*f4)*x1^2*x8^2 + (-576*f0^2*f5*f7 + 480*f0*f1*f4*f7 + 
    648*f0*f1*f5*f6 - 1184*f0*f2*f5^2 + 424*f0*f3*f4*f5 + 66*f1^2*f3*f7 - 
    252*f1^2*f4*f6 - 24*f1^2*f5^2 + 68*f1*f2*f3*f6 + 628*f1*f2*f4*f5 + 
    122*f1*f3^2*f5 - 376*f1*f3*f4^2)*x1*x2^3 + (-1152*f0^2*f6*f7 + 
    288*f0*f1*f5*f7 + 1296*f0*f1*f6^2 + 464*f0*f2*f4*f7 - 1464*f0*f2*f5*f6 +
    192*f0*f3^2*f7 + 848*f0*f3*f4*f6 + 952*f0*f3*f5^2 - 400*f0*f4^2*f5 + 
    96*f1^2*f4*f7 - 732*f1^2*f5*f6 + 136*f1*f2*f3*f7 - 492*f1*f2*f4*f6 + 
    74*f1*f2*f5^2 - 120*f1*f3^2*f6 - 496*f1*f3*f4*f5 + 228*f1*f4^3 + 
    68*f2^2*f3*f6 + 626*f2^2*f4*f5 + 122*f2*f3^2*f5 - 368*f2*f3*f4^2 - 
    96*f3^3*f4)*x1*x2^2*x3 + (-3072*f0^2*f7^2 + 2592*f0*f1*f6*f7 - 
    3944*f0*f2*f5*f7 + 272*f0*f2*f6^2 + 2464*f0*f3*f4*f7 - 648*f0*f3*f5*f6 -
    176*f0*f4^2*f6 + 162*f0*f4*f5^2 - 24*f1^2*f5*f7 + 120*f1^2*f6^2 + 
    236*f1*f2*f4*f7 - 2172*f1*f2*f5*f6 - 136*f1*f3^2*f7 + 52*f1*f3*f4*f6 - 
    496*f1*f3*f5^2 + 783*f1*f4^2*f5 - 68*f2^2*f4*f6 + 2086*f2^2*f5^2 - 
    68*f2*f3^2*f6 - 494*f2*f3*f4*f5 + 88*f2*f4^3 - 331*f3^3*f5 - 
    144*f3^2*f4^2)*x1*x2^2*x4 + (768*f0^2*f7 - 648*f0*f1*f6 + 1140*f0*f2*f5 
    - 520*f0*f3*f4 + 120*f1^2*f5 - 14*f1*f2*f4 + 45*f1*f3^2)*x1*x2^2*x5 + 
    (-192*f0*f1*f7 - 136*f0*f2*f6 - 238*f0*f3*f5 + 136*f0*f4^2 + 228*f1^2*f6
    - 490*f1*f2*f5 + 215*f1*f3*f4)*x1*x2^2*x6 + (208*f0*f2*f7 - 252*f0*f3*f6
    + 438*f0*f4*f5 + 48*f1^2*f7 - 472*f1*f2*f6 - 196*f1*f3*f5 + 194*f1*f4^2 
    + 488*f2^2*f5 - 211*f2*f3*f4 - 96*f3^3)*x1*x2^2*x7 + (-400*f0*f3*f7 - 
    96*f0*f4*f6 + 384*f0*f5^2 + 36*f1*f2*f7 + 90*f1*f3*f6 - 89*f1*f4*f5 - 
    68*f2^2*f6 - 411*f2*f3*f5 + 62*f2*f4^2 + 248*f3^2*f4)*x1*x2^2*x8 + 
    (-192*f0^2*f7^2 - 696*f0*f1*f6*f7 + 16*f0*f2*f5*f7 + 1536*f0*f2*f6^2 + 
    328*f0*f3*f4*f7 + 2052*f0*f3*f5*f6 - 624*f0*f4^2*f6 + 1002*f0*f4*f5^2 - 
    120*f1^2*f5*f7 + 4*f1*f2*f4*f7 - 1240*f1*f2*f5*f6 + 90*f1*f3^2*f7 + 
    178*f1*f3*f4*f6 + 72*f1*f3*f5^2 - 453*f1*f4^2*f5 + 70*f2^2*f3*f7 - 
    176*f2^2*f4*f6 - 268*f2^2*f5^2 - 52*f2*f3^2*f6 + 16*f2*f3*f4*f5 + 
    132*f2*f4^3 + 98*f3^3*f5 - 136*f3^2*f4^2)*x1*x2*x3^2 + (-1536*f0*f1*f7^2
    + 3424*f0*f2*f6*f7 + 4064*f0*f3*f5*f7 - 1240*f0*f3*f6^2 - 
    2304*f0*f4^2*f7 - 1564*f0*f4*f5*f6 + 84*f1^2*f6*f7 - 2628*f1*f2*f5*f7 + 
    232*f1*f2*f6^2 + 826*f1*f3*f4*f7 + 642*f1*f3*f5*f6 - 36*f1*f4^2*f6 + 
    1303*f1*f4*f5^2 + 244*f2^2*f4*f7 - 72*f2^2*f5*f6 - 332*f2*f3^2*f7 - 
    346*f2*f3*f4*f6 + 1246*f2*f3*f5^2 - 500*f2*f4^2*f5 + 278*f3^3*f6 - 
    669*f3^2*f4*f5 + 612*f3*f4^3)*x1*x2*x3*x4 + (384*f0*f1*f7 - 992*f0*f2*f6
    - 1076*f0*f3*f5 + 496*f0*f4^2 + 732*f1*f2*f5 - 210*f1*f3*f4 - 12*f2^2*f4
    + 45*f2*f3^2)*x1*x2*x3*x5 + (-56*f0*f4*f7 + 1008*f0*f5*f6 + 3*f1*f3*f7 -
    72*f1*f4*f6 - 312*f1*f5^2 + 12*f2^2*f7 - 38*f2*f3*f6 + 155*f2*f4*f5 + 
    88*f3^2*f5 + 115*f3*f4^2)*x1*x2*x3*x8 + (2112*f0*f2*f7^2 - 
    1716*f0*f3*f6*f7 - 6930*f0*f4*f5*f7 + 192*f0*f4*f6^2 + 3552*f0*f5^2*f6 -
    192*f1^2*f7^2 - 220*f1*f2*f6*f7 + 1096*f1*f3*f5*f7 - 60*f1*f3*f6^2 - 
    1104*f1*f4^2*f7 + 1886*f1*f4*f5*f6 + 1200*f1*f5^3 + 3552*f2^2*f5*f7 - 
    272*f2^2*f6^2 - 1745*f2*f3*f4*f7 + 918*f2*f3*f5*f6 + 488*f2*f4^2*f6 - 
    2877*f2*f4*f5^2 + 324*f3^3*f7 + 66*f3^2*f4*f6 + 636*f3^2*f5^2 + 
    2605*f3*f4^2*f5 - 44*f4^4)*x1*x2*x4^2 + (-536*f0*f2*f7 + 560*f0*f3*f6 + 
    1316*f0*f4*f5 + 72*f1^2*f7 - 64*f1*f2*f6 - 362*f1*f3*f5 + 358*f1*f4^2 - 
    628*f2^2*f5 + 308*f2*f3*f4 - 124*f3^3)*x1*x2*x4*x5 + (-184*f0*f3*f7 - 
    144*f0*f4*f6 - 192*f0*f5^2 - 120*f1*f2*f7 - 28*f1*f3*f6 - 586*f1*f4*f5 +
    204*f2^2*f6 - 59*f2*f3*f5 - 252*f2*f4^2 + 40*f3^2*f4)*x1*x2*x4*x6 + 
    (-1196*f0*f4*f7 + 1776*f0*f5*f6 + 57*f1*f3*f7 + 664*f1*f4*f6 + 
    984*f1*f5^2 + 96*f2^2*f7 + 378*f2*f3*f6 - 1551*f2*f4*f5 + 334*f3^2*f5 + 
    1035*f3*f4^2)*x1*x2*x4*x7 + (384*f0*f5*f7 + 576*f0*f6^2 + 246*f1*f4*f7 +
    1032*f1*f5*f6 + 176*f2*f3*f7 + 56*f2*f4*f6 - 2360*f2*f5^2 + 4*f3^2*f6 + 
    1155*f3*f4*f5 + 34*f4^3)*x1*x2*x4*x8 + 44*f0*f2*x1*x2*x5^2 + (-480*f0*f5
    - 48*f1*f4 - 4*f2*f3)*x1*x2*x5*x8 + 24*f1*f3*x1*x2*x6^2 + (264*f0*f6 + 
    216*f1*f5 + 24*f2*f4 - 62*f3^2)*x1*x2*x6*x8 + 192*f1*f5*x1*x2*x7^2 + 
    (-48*f1*f7 - 216*f3*f5 - 48*f4^2)*x1*x2*x8^2 + (-192*f0*f1*f7^2 - 
    312*f0*f2*f6*f7 + 412*f0*f3*f5*f7 + 1248*f0*f3*f6^2 + 336*f0*f4^2*f7 + 
    2332*f0*f4*f5*f6 + 96*f0*f5^3 - 226*f1*f2*f5*f7 + 275*f1*f3*f4*f7 - 
    98*f1*f3*f5*f6 - 300*f1*f4^2*f6 - 343*f1*f4*f5^2 - 90*f2^2*f4*f7 - 
    668*f2^2*f5*f6 + 94*f2*f3^2*f7 + 136*f2*f3*f4*f6 - 54*f2*f3*f5^2 + 
    276*f2*f4^2*f5 - 168*f3^3*f6 - 89*f3^2*f4*f5 - 236*f3*f4^3)*x1*x3^3 + 
    (-840*f0*f2*f7^2 + 3432*f0*f3*f6*f7 + 5462*f0*f4*f5*f7 + 192*f0*f4*f6^2 
    - 2400*f0*f5^2*f6 - 72*f1^2*f7^2 + 92*f1*f2*f6*f7 + 1037*f1*f3*f5*f7 - 
    292*f1*f3*f6^2 - 80*f1*f4^2*f7 + 54*f1*f4*f5*f6 - 144*f1*f5^3 - 
    2306*f2^2*f5*f7 - 600*f2^2*f6^2 + 1046*f2*f3*f4*f7 + 1380*f2*f3*f5*f6 + 
    180*f2*f4^2*f6 + 1168*f2*f4*f5^2 - 255*f3^3*f7 - 1214*f3^2*f4*f6 - 
    648*f3^2*f5^2 - 1005*f3*f4^2*f5 + 44*f4^4)*x1*x3^2*x4 + (108*f0*f2*f7 - 
    620*f0*f3*f6 - 1248*f0*f4*f5 - 267*f1*f3*f5 + 24*f1*f4^2 + 490*f2^2*f5 -
    166*f2*f3*f4 + 69*f3^3)*x1*x3^2*x5 + (-282*f0*f3*f7 - 472*f0*f4*f6 - 
    192*f0*f5^2 - 18*f1*f2*f7 + 74*f1*f3*f6 + 329*f1*f4*f5 + 180*f2^2*f6 - 
    234*f2*f3*f5 - 108*f2*f4^2 + 89*f3^2*f4)*x1*x3^2*x6 + (796*f0*f4*f7 - 
    912*f0*f5*f6 + 134*f1*f3*f7 - 480*f1*f4*f6 - 48*f1*f5^2 - 28*f2^2*f7 - 
    82*f2*f3*f6 + 466*f2*f4*f5 - 110*f3^2*f5 - 400*f3*f4^2)*x1*x3^2*x7 + 
    (-624*f0*f6^2 - 96*f1*f4*f7 + 24*f1*f5*f6 - 9*f2*f3*f7 - 180*f2*f4*f6 + 
    230*f2*f5^2 + 168*f3^2*f6 - 20*f3*f4*f5 - 24*f4^3)*x1*x3^2*x8 + 
    (3324*f0*f3*f7^2 + 584*f0*f4*f6*f7 - 1056*f0*f5^2*f7 - 1920*f0*f5*f6^2 +
    84*f1*f2*f7^2 - 1170*f1*f3*f6*f7 + 2206*f1*f4*f5*f7 - 1120*f1*f4*f6^2 - 
    2400*f1*f5^2*f6 - 1312*f2^2*f6*f7 + 4092*f2*f3*f5*f7 - 316*f2*f3*f6^2 + 
    750*f2*f4^2*f7 + 1934*f2*f4*f5*f6 - 184*f2*f5^3 - 2482*f3^2*f4*f7 - 
    548*f3^2*f5*f6 - 844*f3*f4^2*f6 - 270*f3*f4*f5^2 + 
    468*f4^3*f5)*x1*x3*x4^2 + (-1032*f0*f3*f7 + 136*f0*f4*f6 + 96*f0*f5^2 - 
    50*f1*f2*f7 + 192*f1*f3*f6 - 733*f1*f4*f5 + 416*f2^2*f6 - 1062*f2*f3*f5 
    - 260*f2*f4^2 + 670*f3^2*f4)*x1*x3*x4*x5 + (480*f0*f5*f7 - 192*f0*f6^2 +
    48*f1*f4*f7 - 1632*f1*f5*f6 + 54*f2*f3*f7 - 912*f2*f4*f6 + 1192*f2*f5^2 
    + 282*f3^2*f6 - 799*f3*f4*f5 + 234*f4^3)*x1*x3*x4*x7 + (-1344*f0*f6*f7 -
    48*f1*f5*f7 + 936*f1*f6^2 - 344*f2*f4*f7 - 2440*f2*f5*f6 + 396*f3^2*f7 +
    204*f3*f4*f6 + 712*f3*f5^2 - 1702*f4^2*f5)*x1*x3*x4*x8 + 
    28*f0*f3*x1*x3*x5^2 + (68*f0*f4 + 27*f1*f3 - 2*f2^2)*x1*x3*x5*x6 + 
    (96*f0*f5 - 10*f1*f4 + 20*f2*f3)*x1*x3*x6^2 + (192*f0*f7 - 180*f1*f6 + 
    322*f2*f5 - 144*f3*f4)*x1*x3*x7^2 + (-52*f2*f6 + 45*f3*f5 + 
    14*f4^2)*x1*x3*x7*x8 + (-40*f2*f7 - 12*f3*f6 + 240*f4*f5)*x1*x3*x8^2 + 
    (3084*f0*f4*f7^2 - 7104*f0*f5*f6*f7 - 387*f1*f3*f7^2 - 2736*f1*f4*f6*f7 
    - 2208*f1*f5^2*f7 + 1584*f1*f5*f6^2 + 120*f2^2*f7^2 - 594*f2*f3*f6*f7 + 
    7925*f2*f4*f5*f7 - 7808*f2*f5^2*f6 - 1764*f3^2*f5*f7 - 2770*f3*f4^2*f7 +
    2316*f3*f4*f5*f6 - 620*f3*f5^3 + 826*f4^2*f5^2)*x1*x4^3 + (-664*f0*f4*f7
    + 1344*f0*f5*f6 + 108*f1*f3*f7 + 824*f1*f4*f6 + 624*f1*f5^2 - 64*f2^2*f7
    + 188*f2*f3*f6 - 2338*f2*f4*f5 + 556*f3^2*f5 + 798*f3*f4^2)*x1*x4^2*x5 +
    (2784*f0*f5*f7 - 192*f0*f6^2 - 52*f1*f4*f7 - 1032*f1*f5*f6 - 
    272*f2*f3*f7 - 192*f2*f4*f6 + 2700*f2*f5^2 - 36*f3^2*f6 - 1630*f3*f4*f5 
    + 44*f4^3)*x1*x4^2*x6 + (-1632*f0*f6*f7 - 504*f1*f5*f7 + 528*f1*f6^2 - 
    288*f2*f4*f7 - 4296*f2*f5*f6 + 96*f3^2*f7 + 782*f3*f4*f6 - 508*f3*f5^2 +
    793*f4^2*f5)*x1*x4^2*x7 + (-5376*f0*f7^2 + 1896*f1*f6*f7 - 6894*f2*f5*f7
    + 232*f2*f6^2 + 2998*f3*f4*f7 - 1620*f3*f5*f6 - 228*f4^2*f6 - 
    1772*f4*f5^2)*x1*x4^2*x8 + (-68*f0*f4 + 7*f1*f3 + 6*f2^2)*x1*x4*x5^2 + 
    (-288*f0*f5 + 6*f1*f4 + 70*f2*f3)*x1*x4*x5*x6 + (192*f0*f6 + 96*f1*f5 + 
    132*f2*f4 - 48*f3^2)*x1*x4*x5*x7 + (1440*f0*f7 - 648*f1*f6 + 1928*f2*f5 
    - 534*f3*f4)*x1*x4*x5*x8 + (24*f0*f6 + 120*f1*f5 - 20*f2*f4 + 
    151*f3^2)*x1*x4*x6^2 + (1056*f0*f7 - 180*f1*f6 + 614*f2*f5 - 
    376*f3*f4)*x1*x4*x6*x7 + (168*f1*f7 - 56*f2*f6 - 204*f3*f5 + 
    242*f4^2)*x1*x4*x6*x8 + (48*f1*f7 - 516*f2*f6 - 59*f3*f5 + 
    190*f4^2)*x1*x4*x7^2 + (-104*f2*f7 - 710*f3*f6 - 199*f4*f5)*x1*x4*x7*x8 
    + (-172*f3*f7 + 56*f4*f6 + 288*f5^2)*x1*x4*x8^2 - 192*f0*x1*x5*x6*x7 - 
    144*f1*x1*x5*x6*x8 - 24*f1*x1*x5*x7^2 + 200*f3*x1*x5*x8^2 + 
    48*f0*x1*x6^3 + 24*f1*x1*x6^2*x7 - 16*f2*x1*x6^2*x8 - 24*f2*x1*x6*x7^2 -
    152*f3*x1*x6*x7*x8 + 20*f3*x1*x7^3 + (96*f0*f1*f5*f7 - 136*f0*f2*f5*f6 -
    334*f0*f3*f5^2 + 88*f0*f4^2*f5 - 72*f1^2*f4*f7 + 252*f1^2*f5*f6 + 
    68*f1*f2*f4*f6 + 124*f1*f2*f5^2 + 122*f1*f3*f4*f5 - 92*f1*f4^3)*x2^4 + 
    (192*f0*f1*f6*f7 + 88*f0*f2*f5*f7 - 272*f0*f2*f6^2 - 608*f0*f3*f5*f6 + 
    176*f0*f4^2*f6 - 274*f0*f4*f5^2 + 96*f1^2*f5*f7 - 140*f1*f2*f4*f7 + 
    820*f1*f2*f5*f6 - 120*f1*f3*f4*f6 + 47*f1*f3*f5^2 - 51*f1*f4^2*f5 + 
    68*f2^2*f4*f6 + 124*f2^2*f5^2 + 122*f2*f3*f4*f5 - 88*f2*f4^3 - 
    48*f3^2*f4^2)*x2^3*x3 + (192*f0*f1*f7^2 - 272*f0*f2*f6*f7 - 
    868*f0*f3*f5*f7 + 656*f0*f4^2*f7 - 624*f0*f4*f5*f6 - 192*f0*f5^3 + 
    60*f1^2*f6*f7 + 128*f1*f2*f5*f7 + 106*f1*f3*f4*f7 - 594*f1*f3*f5*f6 - 
    252*f1*f4^2*f6 - 223*f1*f4*f5^2 + 272*f2^2*f5*f6 - 68*f2*f3*f4*f6 + 
    548*f2*f3*f5^2 + 252*f2*f4^2*f5 - 331*f3^2*f4*f5 - 192*f3*f4^3)*x2^3*x4 
    + (-96*f0*f1*f7 + 136*f0*f2*f6 + 334*f0*f3*f5 - 136*f0*f4^2 - 
    124*f1*f2*f5 + 45*f1*f3*f4)*x2^3*x5 + (96*f0*f4*f5 + 24*f1^2*f7 - 
    68*f1*f2*f6 - 167*f1*f3*f5 + 92*f1*f4^2)*x2^3*x6 + (-192*f0*f4*f6 - 
    192*f0*f5^2 - 44*f1*f2*f7 - 30*f1*f3*f6 + 41*f1*f4*f5 + 68*f2^2*f6 + 
    167*f2*f3*f5 - 86*f2*f4^2 - 96*f3^2*f4)*x2^3*x7 + (96*f0*f4*f7 - 
    1128*f0*f5*f6 + 60*f1*f4*f6 + 120*f1*f5^2 - 244*f2*f4*f5 + 
    76*f3*f4^2)*x2^3*x8 + (96*f0*f1*f7^2 + 40*f0*f2*f6*f7 - 148*f0*f3*f5*f7 
    + 120*f0*f3*f6^2 - 8*f0*f4^2*f7 - 212*f0*f4*f5*f6 - 48*f0*f5^3 + 
    364*f1*f2*f5*f7 - 234*f1*f3*f4*f7 + 264*f1*f3*f5*f6 + 216*f1*f4^2*f6 + 
    24*f1*f4*f5^2 - 68*f2^2*f4*f7 + 500*f2^2*f5*f6 - 52*f2*f3*f4*f6 + 
    4*f2*f3*f5^2 - 171*f2*f4^2*f5 + 98*f3^2*f4*f5 + 4*f3*f4^3)*x2^2*x3^2 + 
    (176*f0*f2*f7^2 - 280*f0*f3*f6*f7 - 96*f0*f4*f6^2 + 1824*f0*f5^2*f6 + 
    76*f1*f2*f6*f7 - 664*f1*f3*f5*f7 + 178*f1*f4^2*f7 - 572*f1*f4*f5*f6 - 
    216*f1*f5^3 + 184*f2^2*f5*f7 + 136*f2^2*f6^2 + 102*f2*f3*f4*f7 - 
    348*f2*f3*f5*f6 - 340*f2*f4^2*f6 + 663*f2*f4*f5^2 + 278*f3^2*f4*f6 + 
    316*f3^2*f5^2 - 753*f3*f4^2*f5 + 44*f4^4)*x2^2*x3*x4 + (-88*f0*f2*f7 - 
    60*f0*f3*f6 + 178*f0*f4*f5 + 120*f1*f3*f5 - 48*f1*f4^2 - 124*f2^2*f5 + 
    45*f2*f3*f4)*x2^2*x3*x5 + (-384*f0*f4*f7 + 1008*f0*f5*f6 - 93*f1*f3*f7 +
    216*f1*f4*f6 + 24*f1*f5^2 - 20*f2^2*f7 + 38*f2*f3*f6 - 149*f2*f4*f5 + 
    47*f3^2*f5 + 7*f3*f4^2)*x2^2*x3*x7 + (-576*f0*f5*f7 - 240*f0*f6^2 + 
    96*f1*f4*f7 - 204*f1*f5*f6 - 248*f2*f5^2 + 135*f3*f4*f5 + 
    34*f4^3)*x2^2*x3*x8 + (-400*f0*f3*f7^2 + 192*f0*f4*f6*f7 + 
    3312*f0*f5^2*f7 - 2880*f0*f5*f6^2 + 68*f1*f2*f7^2 - 90*f1*f3*f6*f7 - 
    1439*f1*f4*f5*f7 + 120*f1*f4*f6^2 - 492*f1*f5^2*f6 + 68*f2^2*f6*f7 + 
    263*f2*f3*f5*f7 - 94*f2*f4^2*f7 - 560*f2*f4*f5*f6 + 1956*f2*f5^3 + 
    220*f3^2*f4*f7 + 274*f3^2*f5*f6 + 168*f3*f4^2*f6 - 765*f3*f4*f5^2 + 
    154*f4^3*f5)*x2^2*x4^2 + (200*f0*f3*f7 + 48*f0*f4*f6 - 768*f0*f5^2 - 
    12*f1*f2*f7 + 394*f1*f4*f5 - 68*f2^2*f6 - 51*f2*f3*f5 + 104*f2*f4^2 - 
    124*f3^2*f4)*x2^2*x4*x5 + (-864*f0*f4*f7 + 1416*f0*f5*f6 - 100*f1*f3*f7 
    + 420*f1*f4*f6 + 240*f1*f5^2 + 68*f2*f3*f6 - 980*f2*f4*f5 + 184*f3^2*f5 
    + 376*f3*f4^2)*x2^2*x4*x6 + (480*f0*f5*f7 - 816*f0*f6^2 - 226*f1*f4*f7 -
    180*f1*f5*f6 + 96*f2*f3*f7 - 112*f2*f4*f6 + 914*f2*f5^2 - 4*f3^2*f6 - 
    356*f3*f4*f5 - 48*f4^3)*x2^2*x4*x7 + (-480*f0*f6*f7 + 264*f1*f5*f7 - 
    216*f2*f4*f7 + 992*f2*f5*f6 - 451*f3*f5^2 + 352*f4^2*f5)*x2^2*x4*x8 + 
    (120*f0*f6 - 120*f1*f5 - 4*f2*f4)*x2^2*x5*x8 + (96*f0*f7 - 60*f1*f6 + 
    244*f2*f5 - 62*f3*f4)*x2^2*x6*x8 - 216*f4*f5*x2^2*x8^2 + (88*f0*f2*f7^2 
    + 432*f0*f3*f6*f7 - 178*f0*f4*f5*f7 + 288*f0*f4*f6^2 - 576*f0*f5^2*f6 + 
    120*f1*f3*f5*f7 + 48*f1*f4^2*f7 + 240*f1*f4*f5*f6 + 244*f2^2*f5*f7 - 
    230*f2*f3*f4*f7 + 512*f2*f3*f5*f6 + 244*f2*f4^2*f6 + 24*f2*f4*f5^2 - 
    168*f3^2*f4*f6 - 72*f3^2*f5^2 + 105*f3*f4^2*f5 - 44*f4^4)*x2*x3^3 + 
    (172*f0*f3*f7^2 + 1336*f0*f4*f6*f7 - 1152*f0*f5^2*f7 + 768*f0*f5*f6^2 - 
    36*f1*f2*f7^2 + 444*f1*f3*f6*f7 + 710*f1*f4*f5*f7 - 312*f1*f4*f6^2 + 
    312*f1*f5^2*f6 + 120*f2^2*f6*f7 - 404*f2*f3*f5*f7 + 32*f2*f3*f6^2 - 
    38*f2*f4^2*f7 + 1204*f2*f4*f5*f6 - 224*f2*f5^3 + 227*f3^2*f4*f7 - 
    128*f3^2*f5*f6 - 770*f3*f4^2*f6 + 129*f3*f4*f5^2 - 
    608*f4^3*f5)*x2*x3^2*x4 + (-186*f0*f3*f7 - 144*f0*f4*f6 + 576*f0*f5^2 - 
    240*f1*f4*f5 - 4*f2*f3*f5 - 56*f2*f4^2 + 69*f3^2*f4)*x2*x3^2*x5 + 
    (288*f0*f5*f7 + 768*f0*f6^2 + 48*f1*f4*f7 + 240*f1*f5*f6 - 89*f2*f3*f7 +
    244*f2*f4*f6 + 62*f2*f5^2 - 78*f3^2*f6 - 23*f3*f4*f5 - 
    54*f4^3)*x2*x3^2*x7 + (-120*f0*f6*f7 - 120*f1*f5*f7 + 96*f2*f4*f7 - 
    512*f2*f5*f6 + 90*f3*f4*f6 + 254*f3*f5^2 - 17*f4^2*f5)*x2*x3^2*x8 + 
    (1000*f0*f4*f7^2 - 4224*f0*f5*f6*f7 + 1152*f0*f6^3 + 365*f1*f3*f7^2 + 
    856*f1*f4*f6*f7 - 1392*f1*f5^2*f7 - 48*f1*f5*f6^2 + 12*f2^2*f7^2 + 
    38*f2*f3*f6*f7 - 1867*f2*f4*f5*f7 + 168*f2*f4*f6^2 - 216*f2*f5^2*f6 + 
    804*f3^2*f5*f7 + 68*f3^2*f6^2 + 100*f3*f4^2*f7 + 404*f3*f4*f5*f6 + 
    116*f4^3*f6 + 110*f4^2*f5^2)*x2*x3*x4^2 + (-644*f0*f4*f7 + 1152*f0*f5*f6
    - 162*f1*f3*f7 + 576*f1*f5^2 + 4*f2^2*f7 - 24*f2*f3*f6 + 108*f2*f4*f5 - 
    294*f3^2*f5 + 224*f3*f4^2)*x2*x3*x4*x5 + (192*f0*f7^2 - 132*f1*f6*f7 + 
    644*f2*f5*f7 - 32*f2*f6^2 - 636*f3*f4*f7 + 826*f3*f5*f6 + 192*f4^2*f6 + 
    247*f4*f5^2)*x2*x3*x4*x8 - 48*f3^2*x2*x3*x6^2 + (-12*f4*f6 - 
    336*f5^2)*x2*x3*x8^2 + (1728*f0*f5*f7^2 + 1728*f0*f6^2*f7 + 
    1370*f1*f4*f7^2 + 552*f1*f5*f6*f7 - 268*f2*f4*f6*f7 - 6928*f2*f5^2*f7 + 
    1808*f2*f5*f6^2 + 132*f3^2*f6*f7 + 819*f3*f4*f5*f7 - 60*f3*f4*f6^2 - 
    20*f3*f5^2*f6 + 436*f4^3*f7 - 138*f4^2*f5*f6 - 714*f4*f5^3)*x2*x4^3 + 
    (-1824*f0*f5*f7 - 576*f0*f6^2 - 596*f1*f4*f7 + 648*f1*f5*f6 - 
    56*f2*f3*f7 + 44*f2*f4*f6 + 1004*f2*f5^2 - 34*f3^2*f6 - 58*f3*f4*f5 - 
    160*f4^3)*x2*x4^2*x5 + (1152*f0*f6*f7 + 744*f1*f5*f7 - 120*f1*f6^2 + 
    168*f2*f4*f7 - 840*f2*f5*f6 + 110*f3^2*f7 - 222*f3*f4*f6 - 616*f3*f5^2 -
    566*f4^2*f5)*x2*x4^2*x6 + (96*f0*f7^2 + 1116*f1*f6*f7 - 1854*f2*f5*f7 + 
    280*f2*f6^2 + 154*f3*f4*f7 + 194*f3*f5*f6 - 124*f4^2*f6 - 
    1031*f4*f5^2)*x2*x4^2*x7 + (48*f1*f7^2 + 208*f2*f6*f7 - 1024*f3*f5*f7 + 
    208*f4^2*f7 - 688*f4*f5*f6 + 1152*f5^3)*x2*x4^2*x8 + (192*f0*f5 + 
    48*f1*f4 + 4*f2*f3)*x2*x4*x5^2 + (-408*f0*f6 - 17*f3^2)*x2*x4*x5*x6 + 
    (-24*f1*f7 + 16*f2*f6 - 126*f4^2)*x2*x4*x5*x8 + (384*f0*f7 - 168*f1*f6 +
    404*f2*f5 - 174*f3*f4)*x2*x4*x6^2 + 24*f2*f7*x2*x4*x6*x8 + (102*f3*f6 - 
    241*f4*f5)*x2*x4*x7^2 + (-212*f4*f6 + 912*f5^2)*x2*x4*x7*x8 + (288*f4*f7
    - 1128*f5*f6)*x2*x4*x8^2 - 96*f0*x2*x5^2*x7 - 48*f0*x2*x5*x6^2 + 
    144*f1*x2*x5*x6*x7 + 4*f2*x2*x5*x6*x8 - 20*f2*x2*x5*x7^2 - 
    224*f3*x2*x5*x7*x8 - 24*f4*x2*x5*x8^2 + 16*f2*x2*x6^2*x7 - 
    14*f3*x2*x6^2*x8 + 134*f3*x2*x6*x7^2 + 24*f4*x2*x6*x7*x8 + 
    216*f5*x2*x6*x8^2 + 48*f4*x2*x7^3 + 216*f5*x2*x7^2*x8 + (186*f0*f3*f7^2 
    + 48*f0*f4*f6*f7 - 48*f0*f5^2*f7 + 48*f0*f5*f6^2 + 244*f2*f3*f5*f7 + 
    62*f2*f4^2*f7 + 488*f2*f4*f5*f6 - 18*f2*f5^3 - 186*f3^2*f4*f7 + 
    12*f3^2*f5*f6 + 30*f3*f4^2*f6 + 24*f3*f4*f5^2 + 206*f4^3*f5)*x3^4 + 
    (164*f0*f4*f7^2 + 1968*f0*f5*f6*f7 - 864*f0*f6^3 + 114*f1*f3*f7^2 - 
    552*f1*f4*f6*f7 + 648*f1*f5^2*f7 + 216*f1*f5*f6^2 - 28*f2^2*f7^2 + 
    232*f2*f3*f6*f7 + 2154*f2*f4*f5*f7 + 464*f2*f4*f6^2 + 1468*f2*f5^2*f6 - 
    296*f3^2*f5*f7 - 216*f3^2*f6^2 - 582*f3*f4^2*f7 - 262*f3*f4*f5*f6 + 
    72*f3*f5^3 - 204*f4^3*f6 + 95*f4^2*f5^2)*x3^3*x4 + (96*f0*f4*f7 - 
    144*f0*f5*f6 - 192*f1*f5^2 - 490*f2*f4*f5 + 144*f3^2*f5 + 
    62*f3*f4^2)*x3^3*x5 + (480*f0*f6*f7 + 62*f2*f4*f7 + 488*f2*f5*f6 - 
    93*f3^2*f7 + 30*f3*f4*f6 - 107*f3*f5^2 + 340*f4^2*f5)*x3^3*x7 + 
    (-244*f2*f5*f7 + 141*f3*f4*f7 - 24*f3*f5*f6 - 60*f4^2*f6 + 
    165*f4*f5^2)*x3^3*x8 + (-1392*f0*f5*f7^2 - 432*f0*f6^2*f7 - 
    868*f1*f4*f7^2 + 240*f1*f5*f6*f7 - 528*f1*f6^3 + 281*f2*f3*f7^2 + 
    1332*f2*f4*f6*f7 + 5444*f2*f5^2*f7 + 2424*f2*f5*f6^2 - 346*f3^2*f6*f7 - 
    317*f3*f4*f5*f7 - 1112*f3*f4*f6^2 + 880*f3*f5^2*f6 - 568*f4^3*f7 - 
    1464*f4^2*f5*f6 + 714*f4*f5^3)*x3^2*x4^2 + (1632*f0*f5*f7 + 336*f0*f6^2 
    + 288*f1*f4*f7 - 288*f1*f5*f6 - 52*f2*f3*f7 - 572*f2*f4*f6 - 
    1186*f2*f5^2 + 204*f3^2*f6 + 62*f3*f4*f5 + 204*f4^3)*x3^2*x4*x5 + 
    (-1752*f0*f6*f7 - 480*f1*f5*f7 - 168*f1*f6^2 + 66*f2*f4*f7 - 
    112*f2*f5*f6 - 176*f3^2*f7 + 650*f3*f4*f6 + 10*f3*f5^2 + 
    1133*f4^2*f5)*x3^2*x4*x6 + (864*f0*f7^2 - 120*f1*f6*f7 + 1574*f2*f5*f7 +
    464*f2*f6^2 - 337*f3*f4*f7 - 250*f3*f5*f6 - 236*f4^2*f6 + 
    536*f4*f5^2)*x3^2*x4*x7 + (72*f1*f7^2 - 232*f2*f6*f7 + 325*f3*f5*f7 + 
    432*f3*f6^2 - 80*f4^2*f7 + 626*f4*f5*f6)*x3^2*x4*x8 - 
    288*f0*f5*x3^2*x5^2 + (576*f0*f6 + 2*f2*f4 - 24*f3^2)*x3^2*x5*x6 + 
    (-192*f0*f7 - 414*f2*f5 + 82*f3*f4)*x3^2*x5*x7 + (29*f3*f5 + 
    72*f4^2)*x3^2*x5*x8 - 203*f4*f5*x3^2*x6*x8 + (1104*f0*f6*f7^2 - 
    1008*f1*f5*f7^2 - 3768*f1*f6^2*f7 + 188*f2*f4*f7^2 + 9172*f2*f5*f6*f7 - 
    80*f2*f6^3 - 36*f3^2*f7^2 - 2778*f3*f4*f6*f7 + 2548*f3*f5^2*f7 + 
    1688*f3*f5*f6^2 - 2621*f4^2*f5*f7 + 136*f4^2*f6^2 + 1840*f4*f5^2*f6 - 
    768*f5^4)*x3*x4^3 + (-864*f0*f6*f7 + 888*f1*f5*f7 + 648*f1*f6^2 - 
    376*f2*f4*f7 - 2216*f2*f5*f6 + 140*f3^2*f7 + 934*f3*f4*f6 - 880*f3*f5^2 
    + 971*f4^2*f5)*x3*x4^2*x5 + (1108*f2*f6*f7 + 869*f3*f5*f7 + 36*f3*f6^2 -
    598*f4^2*f7 + 1182*f4*f5*f6 - 1152*f5^3)*x3*x4^2*x7 + (-168*f2*f7^2 + 
    548*f3*f6*f7 + 480*f4*f5*f7 + 256*f4*f6^2 - 48*f5^2*f6)*x3*x4^2*x8 + 
    (240*f0*f6 - 192*f1*f5 + 106*f2*f4 - 48*f3^2)*x3*x4*x5^2 + (576*f0*f7 - 
    48*f1*f6 - 234*f2*f5 - 102*f3*f4)*x3*x4*x5*x6 + (-420*f2*f6 - 257*f3*f5 
    + 248*f4^2)*x3*x4*x5*x7 + (52*f2*f7 + 226*f3*f6 - 165*f4*f5)*x3*x4*x5*x8
    + (-216*f1*f7 - 136*f4^2)*x3*x4*x6^2 + 216*f2*f7*x3*x4*x6*x7 + 
    348*f3*f7*x3*x4*x6*x8 + (12*f3*f7 - 48*f4*f6 - 576*f5^2)*x3*x4*x7^2 + 
    (-316*f4*f7 + 528*f5*f6)*x3*x4*x7*x8 + (-240*f5*f7 - 
    240*f6^2)*x3*x4*x8^2 - 192*f0*x3*x5^2*x6 + 192*f1*x3*x5*x6^2 - 
    74*f2*x3*x5*x6*x7 - 269*f3*x3*x5*x6*x8 + 20*f3*x3*x5*x7^2 + 
    96*f4*x3*x5*x7*x8 + 96*f5*x3*x5*x8^2 + 18*f2*x3*x6^3 + 131*f3*x3*x6^2*x7
    + 14*f4*x3*x6^2*x8 + 62*f4*x3*x6*x7^2 - 48*f5*x3*x6*x7*x8 + 
    12*f6*x3*x6*x8^2 - 96*f5*x3*x7^3 + 60*f6*x3*x7^2*x8 + 48*f7*x3*x7*x8^2 +
    (96*f0*f7^3 - 4596*f1*f6*f7^2 + 5018*f2*f5*f7^2 - 120*f2*f6^2*f7 - 
    1718*f3*f4*f7^2 + 2412*f3*f5*f6*f7 + 204*f4^2*f6*f7 + 2132*f4*f5^2*f7 + 
    1728*f5^3*f6)*x4^4 + (-384*f0*f7^2 + 2064*f1*f6*f7 - 1710*f2*f5*f7 + 
    40*f2*f6^2 + 1032*f3*f4*f7 - 784*f3*f5*f6 - 68*f4^2*f6 - 
    798*f4*f5^2)*x4^3*x5 + (-384*f1*f7^2 - 164*f2*f6*f7 + 1108*f3*f5*f7 + 
    60*f3*f6^2 - 160*f4^2*f7 + 2*f4*f5*f6 - 672*f5^3)*x4^3*x6 + (264*f2*f7^2
    - 6*f3*f6*f7 + 1035*f4*f5*f7 + 1968*f5^2*f6)*x4^3*x7 + (-244*f3*f7^2 + 
    1008*f4*f6*f7 + 288*f5^2*f7 - 1728*f5*f6^2)*x4^3*x8 + (432*f0*f7 - 
    192*f1*f6 + 52*f2*f5 - 174*f3*f4)*x4^2*x5^2 + (-168*f1*f7 + 12*f2*f6 - 
    322*f3*f5 + 68*f4^2)*x4^2*x5*x6 + (-172*f2*f7 + 12*f3*f6 - 
    414*f4*f5)*x4^2*x5*x7 + (788*f3*f7 - 248*f4*f6 - 288*f5^2)*x4^2*x5*x8 + 
    (-40*f2*f7 + 54*f3*f6 + 228*f4*f5)*x4^2*x6^2 + (-260*f3*f7 + 56*f4*f6 - 
    480*f5^2)*x4^2*x6*x7 + (-176*f4*f7 + 1704*f5*f6)*x4^2*x6*x8 + 
    (-284*f4*f7 + 672*f5*f6)*x4^2*x7^2 + (-432*f5*f7 - 240*f6^2)*x4^2*x7*x8 
    - 480*f6*f7*x4^2*x8^2 - 96*f0*x4*x5^3 + 96*f1*x4*x5^2*x6 + 
    30*f2*x4*x5^2*x7 - 221*f3*x4*x5^2*x8 + 10*f2*x4*x5*x6^2 + 
    113*f3*x4*x5*x6*x7 - 10*f4*x4*x5*x6*x8 + 82*f4*x4*x5*x7^2 + 
    96*f5*x4*x5*x7*x8 + 120*f6*x4*x5*x8^2 - 10*f3*x4*x6^3 - 44*f4*x4*x6^2*x7
    - 72*f5*x4*x6^2*x8 - 24*f5*x4*x6*x7^2 + 132*f6*x4*x6*x7*x8 - 
    96*f7*x4*x6*x8^2 + 60*f6*x4*x7^3 - 48*f7*x4*x7^2*x8 + 24*x5*x6*x8^2 + 
    24*x5*x7^2*x8 + 24*x6^2*x7*x8 + 24*x6*x7^3,
(-32*f0*f1^2*f6 + 6*f0*f1*f2*f5 - 4*f0*f2^2*f4 + 24*f1^3*f5 + 
    15*f1^2*f2*f4)*x1^4 + (-32*f0*f1*f2*f6 + 6*f0*f1*f3*f5 + 2*f0*f2^2*f5 - 
    8*f0*f2*f3*f4 + 6*f1^2*f3*f4 + 21*f1*f2^2*f4)*x1^3*x2 + (-32*f0^2*f4*f6 
    + 24*f0^2*f5^2 + 2*f0*f1*f2*f7 + 56*f0*f1*f3*f6 + 2*f0*f1*f4*f5 - 
    28*f0*f2^2*f6 - 2*f0*f2*f3*f5 + 8*f0*f2*f4^2 - 57*f1^2*f3*f5 - 
    3*f1^2*f4^2 - 30*f1*f2*f3*f4 + 21*f2^3*f4)*x1^3*x3 + (-48*f0^2*f4*f7 + 
    384*f0^2*f5*f6 - 12*f0*f1*f3*f7 - 64*f0*f1*f4*f6 - 300*f0*f1*f5^2 + 
    8*f0*f2^2*f7 - 134*f0*f2*f4*f5 + 42*f1^2*f4*f5 - 9*f1*f2*f3*f5 + 
    27*f1*f2*f4^2 - 6*f2^2*f3*f4)*x1^3*x4 + (16*f0^2*f4 + 4*f0*f1*f3 - 
    2*f0*f2^2)*x1^3*x5 + (-12*f0^2*f5 - 4*f0*f1*f4 - 2*f0*f2*f3)*x1^3*x6 + 
    (128*f0^2*f6 - 102*f0*f1*f5 - 44*f0*f2*f4 - 3*f1^2*f4)*x1^3*x7 + 
    (-4*f0^2*f7 - 56*f0*f1*f6 + 38*f0*f2*f5 + 6*f0*f3*f4 + 42*f1^2*f5 + 
    21*f1*f2*f4)*x1^3*x8 + (16*f0^2*f4*f6 - 12*f0^2*f5^2 - 4*f0*f1*f2*f7 - 
    28*f0*f1*f3*f6 + 2*f0*f1*f4*f5 + 2*f0*f2*f3*f5 - 8*f0*f2*f4^2 - 
    4*f0*f3^2*f4 + 15*f1^2*f3*f5 + 6*f1^2*f4^2 + 27*f1*f2*f3*f4)*x1^2*x2^2 +
    (-16*f0^2*f4*f7 - 240*f0^2*f5*f6 - 2*f0*f1*f3*f7 + 88*f0*f1*f4*f6 + 
    178*f0*f1*f5^2 - 4*f0*f2^2*f7 - 24*f0*f2*f3*f6 + 122*f0*f2*f4*f5 - 
    2*f0*f3^2*f5 + 8*f0*f3*f4^2 - 66*f1^2*f4*f5 + 21*f1*f2*f3*f5 - 
    42*f1*f2*f4^2 - 12*f1*f3^2*f4 + 27*f2^2*f3*f4)*x1^2*x2*x3 + 
    (-16*f0^2*f5*f7 - 28*f0*f1*f4*f7 + 124*f0*f1*f5*f6 + 8*f0*f2*f3*f7 - 
    48*f0*f2*f4*f6 + 150*f0*f2*f5^2 - 38*f0*f3*f4*f5 + 6*f1^2*f4*f6 - 
    60*f1^2*f5^2 - 84*f1*f2*f4*f5 - 9*f1*f3^2*f5 + 9*f1*f3*f4^2 + 
    21*f2^2*f4^2 - 12*f2*f3^2*f4)*x1^2*x2*x4 + (4*f0^2*f5 + 8*f0*f1*f4 - 
    2*f0*f2*f3)*x1^2*x2*x5 + (64*f0^2*f6 - 44*f0*f1*f5 - 36*f0*f2*f4 - 
    2*f0*f3^2)*x1^2*x2*x6 + (4*f0^2*f7 + 88*f0*f1*f6 + 34*f0*f2*f5 - 
    14*f0*f3*f4 - 54*f1^2*f5 - 45*f1*f2*f4)*x1^2*x2*x7 + (2*f0*f1*f7 + 
    24*f0*f2*f6 + 34*f0*f3*f5 - 20*f0*f4^2 - 24*f1*f2*f5 + 6*f1*f3*f4 - 
    24*f2^2*f4)*x1^2*x2*x8 + (-8*f0^2*f5*f7 - 352*f0^2*f6^2 - 6*f0*f1*f4*f7 
    + 248*f0*f1*f5*f6 - 4*f0*f2*f3*f7 + 276*f0*f2*f4*f6 - 40*f0*f2*f5^2 - 
    24*f0*f3^2*f6 - 4*f0*f4^3 - 6*f1^2*f5^2 - 12*f1*f2*f4*f5 + 42*f1*f3^2*f5
    + 6*f1*f3*f4^2 + 6*f2^2*f3*f5 - 39*f2^2*f4^2 + 15*f2*f3^2*f4)*x1^2*x3^2 
    + (-792*f0^2*f6*f7 + 590*f0*f1*f5*f7 - 240*f0*f1*f6^2 + 454*f0*f2*f4*f7 
    + 252*f0*f2*f5*f6 + 12*f0*f3^2*f7 - 12*f0*f3*f4*f6 + 100*f0*f3*f5^2 - 
    14*f0*f4^2*f5 - 12*f1^2*f4*f7 + 132*f1^2*f5*f6 + 156*f1*f2*f4*f6 - 
    60*f1*f2*f5^2 - 27*f1*f3*f4*f5 - 3*f1*f4^3 - 126*f2^2*f4*f5 + 
    9*f2*f3^2*f5 - 15*f2*f3*f4^2)*x1^2*x3*x4 + (224*f0^2*f6 - 168*f0*f1*f5 -
    132*f0*f2*f4 - 4*f0*f3^2 + 3*f1^2*f4)*x1^2*x3*x5 + (-2*f0*f1*f7 + 
    56*f0*f2*f6 + 38*f0*f3*f5 - 4*f0*f4^2 - 6*f1*f2*f5 + 6*f1*f3*f4 - 
    33*f2^2*f4)*x1^2*x3*x7 + (8*f0*f2*f7 + 24*f0*f3*f6 + 2*f0*f4*f5 - 
    3*f1*f3*f5 - 18*f2*f3*f4)*x1^2*x3*x8 + (84*f0^2*f7^2 - 616*f0*f1*f6*f7 +
    106*f0*f2*f5*f7 - 114*f0*f3*f4*f7 + 384*f0*f3*f5*f6 - 32*f0*f4^2*f6 - 
    4*f0*f4*f5^2 + 390*f1^2*f5*f7 + 324*f1*f2*f4*f7 - 270*f1*f3*f5^2 + 
    18*f1*f4^2*f5 + 6*f2^2*f4*f6 - 48*f2^2*f5^2 - 111*f2*f3*f4*f5 + 
    12*f2*f4^3)*x1^2*x4^2 + (-52*f0^2*f7 + 184*f0*f1*f6 - 36*f0*f2*f5 + 
    38*f0*f3*f4 - 114*f1^2*f5 - 99*f1*f2*f4)*x1^2*x4*x5 + (12*f0*f1*f7 - 
    32*f0*f2*f6 + 10*f0*f3*f5 + 2*f0*f4^2 + 6*f1*f2*f5 - 9*f1*f3*f4 + 
    24*f2^2*f4)*x1^2*x4*x6 + (-16*f0*f2*f7 + 128*f0*f3*f6 - 2*f0*f4*f5 - 
    87*f1*f3*f5 - 3*f1*f4^2 - 6*f2^2*f5 - 30*f2*f3*f4)*x1^2*x4*x7 + 
    (-26*f0*f3*f7 - 44*f0*f4*f6 - 144*f0*f5^2 + 6*f1*f2*f7 - 12*f1*f3*f6 + 
    51*f1*f4*f5 + 9*f2*f3*f5 + 6*f2*f4^2 + 9*f3^2*f4)*x1^2*x4*x8 + 
    8*f0^2*x1^2*x5^2 - 4*f0*f1*x1^2*x5*x6 + 4*f0*f2*x1^2*x5*x7 + 
    2*f0*f3*x1^2*x5*x8 + (2*f0*f2 + 3*f1^2)*x1^2*x6^2 + (2*f0*f3 - 
    6*f1*f2)*x1^2*x6*x7 + (-8*f0*f4 - 6*f1*f3)*x1^2*x6*x8 + 3*f2^2*x1^2*x7^2
    + (-26*f0*f5 + 3*f1*f4 + 6*f2*f3)*x1^2*x7*x8 + (-12*f0*f6 + 6*f2*f4 + 
    3*f3^2)*x1^2*x8^2 + (16*f0^2*f4*f7 + 56*f0^2*f5*f6 - 28*f0*f1*f4*f6 - 
    38*f0*f1*f5^2 - 40*f0*f2*f4*f5 - 8*f0*f3*f4^2 + 18*f1^2*f4*f5 + 
    21*f1*f2*f4^2 + 6*f1*f3^2*f4)*x1*x2^3 + (12*f0^2*f5*f7 + 112*f0^2*f6^2 +
    10*f0*f1*f4*f7 - 104*f0*f1*f5*f6 - 108*f0*f2*f4*f6 - 36*f0*f2*f5^2 + 
    30*f0*f3*f4*f5 + 8*f0*f4^3 - 12*f1^2*f4*f6 + 18*f1^2*f5^2 + 
    45*f1*f2*f4*f5 - 9*f1*f3^2*f5 - 21*f1*f3*f4^2 + 21*f2^2*f4^2 + 
    6*f2*f3^2*f4)*x1*x2^2*x3 + (224*f0^2*f6*f7 - 136*f0*f1*f5*f7 - 
    180*f0*f2*f4*f7 - 104*f0*f2*f5*f6 - 4*f0*f3*f4*f6 - 12*f0*f3*f5^2 + 
    16*f0*f4^2*f5 - 18*f1*f2*f4*f6 + 66*f1*f2*f5^2 - 30*f1*f3*f4*f5 + 
    9*f1*f4^3 + 75*f2^2*f4*f5 + 15*f2*f3*f4^2 - 6*f3^3*f4)*x1*x2^2*x4 + 
    (-56*f0^2*f6 + 38*f0*f1*f5 + 40*f0*f2*f4 + 3*f1^2*f4)*x1*x2^2*x5 + 
    (8*f0^2*f7 + 28*f0*f1*f6 - 2*f0*f2*f5 - 8*f0*f3*f4 - 12*f1^2*f5 - 
    18*f1*f2*f4)*x1*x2^2*x6 + (2*f0*f1*f7 - 24*f0*f2*f6 - 20*f0*f3*f5 + 
    12*f0*f4^2 + 24*f1*f2*f5 - 15*f1*f3*f4 + 18*f2^2*f4)*x1*x2^2*x7 + 
    (24*f0*f4*f5 + 9*f1*f3*f5 - 12*f2*f3*f4)*x1*x2^2*x8 + (48*f0^2*f6*f7 - 
    58*f0*f1*f5*f7 - 6*f0*f2*f4*f7 - 76*f0*f2*f5*f6 + 40*f0*f3*f4*f6 - 
    74*f0*f3*f5^2 + 16*f0*f4^2*f5 - 3*f1^2*f4*f7 - 30*f1*f2*f4*f6 + 
    6*f1*f2*f5^2 + 66*f1*f3*f4*f5 - 3*f1*f4^3 + 12*f2^2*f4*f5 - 9*f2*f3^2*f5
    - 6*f2*f3*f4^2 + 6*f3^3*f4)*x1*x2*x3^2 + (-32*f0^2*f7^2 + 88*f0*f1*f6*f7
    - 150*f0*f2*f5*f7 - 64*f0*f2*f6^2 + 134*f0*f3*f4*f7 - 56*f0*f3*f5*f6 + 
    32*f0*f4^2*f6 + 16*f0*f4*f5^2 - 90*f1^2*f5*f7 - 81*f1*f2*f4*f7 - 
    24*f1*f2*f5*f6 + 42*f1*f3*f4*f6 + 39*f1*f3*f5^2 - 39*f1*f4^2*f5 + 
    24*f2^2*f4*f6 + 18*f2^2*f5^2 + 48*f2*f3*f4*f5 - 39*f2*f4^3 + 9*f3^3*f5 +
    3*f3^2*f4^2)*x1*x2*x3*x4 + (12*f0^2*f7 + 36*f0*f2*f5 - 50*f0*f3*f4 + 
    18*f1*f2*f4)*x1*x2*x3*x5 + (68*f0*f4*f6 + 36*f0*f5^2 - 45*f1*f4*f5 + 
    9*f2*f3*f5 + 3*f2*f4^2 - 6*f3^2*f4)*x1*x2*x3*x8 + (-18*f0*f1*f7^2 - 
    152*f0*f2*f6*f7 + 198*f0*f3*f5*f7 - 112*f0*f4^2*f7 + 492*f0*f4*f5*f6 + 
    116*f0*f5^3 - 54*f1*f2*f5*f7 + 63*f1*f3*f4*f7 + 6*f1*f3*f5*f6 + 
    6*f1*f4^2*f6 - 342*f1*f4*f5^2 + 108*f2^2*f4*f7 - 12*f2*f3*f4*f6 + 
    75*f2*f3*f5^2 - 147*f2*f4^2*f5 - 21*f3^2*f4*f5 + 3*f3*f4^3)*x1*x2*x4^2 +
    (6*f0*f1*f7 + 32*f0*f2*f6 - 50*f0*f3*f5 + 38*f0*f4^2 + 12*f1*f2*f5 - 
    21*f1*f3*f4 - 21*f2^2*f4)*x1*x2*x4*x5 + (-12*f0*f2*f7 + 28*f0*f3*f6 - 
    20*f0*f4*f5 + 6*f1^2*f7 - 6*f1*f3*f5 - 12*f1*f4^2)*x1*x2*x4*x6 + 
    (18*f0*f3*f7 + 212*f0*f4*f6 + 58*f0*f5^2 - 12*f1*f2*f7 + 12*f1*f3*f6 - 
    147*f1*f4*f5 + 33*f2*f3*f5 - 60*f2*f4^2 - 3*f3^2*f4)*x1*x2*x4*x7 + 
    (56*f0*f4*f7 + 152*f0*f5*f6 - 6*f1*f3*f7 - 108*f1*f5^2 - 72*f2*f4*f5 - 
    21*f3^2*f5)*x1*x2*x4*x8 + 2*f0*f2*x1*x2*x5*x6 - 16*f0*f4*x1*x2*x5*x8 + 
    4*f0*f3*x1*x2*x6^2 - 14*f0*f5*x1*x2*x6*x8 - 12*f0*f7*x1*x2*x8^2 + 
    (-4*f0^2*f7^2 + 42*f0*f2*f5*f7 + 8*f0*f3*f4*f7 - 164*f0*f3*f5*f6 - 
    8*f0*f4^2*f6 + 12*f0*f4*f5^2 - 6*f1*f2*f4*f7 + 63*f1*f3*f5^2 + 
    21*f1*f4^2*f5 - 12*f2^2*f4*f6 + 12*f2^2*f5^2 + 3*f2*f3*f4*f5 + 
    15*f2*f4^3 - 9*f3^3*f5 - 3*f3^2*f4^2)*x1*x3^3 + (-2*f0*f1*f7^2 + 
    40*f0*f2*f6*f7 - 278*f0*f3*f5*f7 - 176*f0*f3*f6^2 + 20*f0*f4^2*f7 - 
    216*f0*f4*f5*f6 + 44*f0*f5^3 + 12*f1*f2*f5*f7 + 15*f1*f3*f4*f7 + 
    78*f1*f3*f5*f6 + 30*f1*f4^2*f6 + 63*f1*f4*f5^2 - 60*f2^2*f4*f7 + 
    24*f2^2*f5*f6 + 60*f2*f3*f4*f6 + 6*f2*f3*f5^2 + 96*f2*f4^2*f5 - 
    6*f3^2*f4*f5 - 3*f3*f4^3)*x1*x3^2*x4 + (82*f0*f3*f5 - 10*f0*f4^2 - 
    6*f1*f3*f4 + 12*f2^2*f4)*x1*x3^2*x5 + (-4*f0*f2*f7 + 24*f0*f3*f6 - 
    18*f0*f4*f5 - 57*f1*f3*f5 - 3*f1*f4^2 - 12*f2^2*f5 - 
    3*f2*f3*f4)*x1*x3^2*x6 + (4*f0*f3*f7 - 84*f0*f4*f6 + 28*f0*f5^2 + 
    30*f1*f4*f5 + 30*f2*f4^2 - 3*f3^2*f4)*x1*x3^2*x7 + (-2*f0*f4*f7 + 
    56*f0*f5*f6 - 36*f1*f5^2 + 12*f2*f4*f5 + 18*f3^2*f5 + 
    3*f3*f4^2)*x1*x3^2*x8 + (16*f0*f2*f7^2 - 348*f0*f3*f6*f7 - 
    96*f0*f4*f5*f7 - 200*f0*f4*f6^2 + 408*f0*f5^2*f6 + 12*f1*f2*f6*f7 + 
    120*f1*f3*f5*f7 - 24*f1*f3*f6^2 + 30*f1*f4^2*f7 + 18*f1*f4*f5*f6 - 
    216*f1*f5^3 + 30*f2^2*f5*f7 + 117*f2*f3*f4*f7 + 18*f2*f3*f5*f6 + 
    114*f2*f4^2*f6 + 36*f2*f4*f5^2 - 30*f3^2*f4*f6 + 54*f3^2*f5^2 - 
    30*f3*f4^2*f5)*x1*x3*x4^2 + (-6*f0*f2*f7 + 84*f0*f3*f6 + 24*f0*f4*f5 - 
    27*f1*f3*f5 - 12*f1*f4^2 - 12*f2^2*f5 - 30*f2*f3*f4)*x1*x3*x4*x5 + 
    (-6*f0*f4*f7 + 156*f0*f5*f6 - 36*f1*f4*f6 - 48*f1*f5^2 - 6*f2^2*f7 + 
    12*f2*f3*f6 + 60*f2*f4*f5 + 27*f3^2*f5 - 15*f3*f4^2)*x1*x3*x4*x7 + 
    (74*f0*f5*f7 + 64*f0*f6^2 - 3*f1*f4*f7 - 36*f1*f5*f6 - 6*f2*f3*f7 - 
    72*f2*f4*f6 + 42*f2*f5^2 + 12*f3^2*f6 + 66*f3*f4*f5 - 
    21*f4^3)*x1*x3*x4*x8 + 6*f0*f3*x1*x3*x5*x6 + 8*f0*f4*x1*x3*x6^2 + 
    (-4*f0*f6 + 6*f1*f5 + 9*f2*f4)*x1*x3*x7^2 + (8*f0*f7 + 6*f2*f5 - 
    3*f3*f4)*x1*x3*x7*x8 + (6*f3*f5 + 3*f4^2)*x1*x3*x8^2 + (-30*f0*f3*f7^2 -
    556*f0*f4*f6*f7 + 344*f0*f5^2*f7 + 384*f0*f5*f6^2 + 18*f1*f2*f7^2 - 
    36*f1*f3*f6*f7 + 213*f1*f4*f5*f7 - 288*f1*f5^2*f6 - 9*f2*f3*f5*f7 + 
    267*f2*f4^2*f7 - 168*f2*f4*f5*f6 + 48*f2*f5^3 - 45*f3^2*f4*f7 - 
    42*f3*f4*f5^2)*x1*x4^3 + (4*f0*f3*f7 + 164*f0*f4*f6 - 116*f0*f5^2 - 
    6*f1*f2*f7 + 12*f1*f3*f6 - 57*f1*f4*f5 - 81*f2*f4^2 + 
    15*f3^2*f4)*x1*x4^2*x5 + (26*f0*f4*f7 - 332*f0*f5*f6 - 18*f1*f3*f7 - 
    6*f1*f4*f6 + 300*f1*f5^2 + 117*f2*f4*f5 + 18*f3^2*f5 - 
    3*f3*f4^2)*x1*x4^2*x6 + (314*f0*f5*f7 + 128*f0*f6^2 - 48*f1*f4*f7 - 
    96*f1*f5*f6 + 18*f2*f3*f7 - 60*f2*f4*f6 - 45*f3*f4*f5)*x1*x4^2*x7 + 
    (420*f0*f6*f7 - 300*f1*f5*f7 - 24*f1*f6^2 - 258*f2*f4*f7 - 36*f2*f5*f6 +
    18*f3^2*f7 - 6*f3*f4*f6 - 48*f3*f5^2 - 42*f4^2*f5)*x1*x4^2*x8 + 
    2*f0*f3*x1*x4*x5^2 + (-8*f0*f4 + 6*f1*f3)*x1*x4*x5*x6 + (-104*f0*f5 + 
    15*f1*f4 - 6*f2*f3)*x1*x4*x5*x7 + (-32*f0*f6 + 84*f1*f5 + 60*f2*f4 - 
    6*f3^2)*x1*x4*x5*x8 + (22*f0*f5 + 3*f1*f4)*x1*x4*x6^2 + (-96*f0*f6 + 
    114*f1*f5 + 30*f2*f4)*x1*x4*x6*x7 + (48*f0*f7 - 12*f1*f6 - 30*f2*f5 - 
    12*f3*f4)*x1*x4*x6*x8 + (44*f0*f7 - 24*f2*f5 - 12*f3*f4)*x1*x4*x7^2 + 
    (6*f1*f7 - 36*f2*f6 - 57*f3*f5 - 18*f4^2)*x1*x4*x7*x8 + (12*f2*f7 + 
    27*f4*f5)*x1*x4*x8^2 - 21*f0*x1*x5*x6*x8 - 14*f0*x1*x5*x7^2 - 
    30*f1*x1*x5*x7*x8 - 2*f0*x1*x6^2*x7 - 6*f1*x1*x6^2*x8 + 6*f1*x1*x6*x7^2 
    - 18*f2*x1*x6*x7*x8 - 6*f2*x1*x7^3 + (-12*f0*f3*f4*f5 - 4*f0*f4^3 + 
    6*f1^2*f4*f6 - 3*f1^2*f5^2 + 3*f1*f2*f4*f5 + 6*f1*f3*f4^2)*x2^4 + 
    (-24*f0*f3*f4*f6 + 18*f0*f3*f5^2 - 10*f0*f4^2*f5 + 3*f1^2*f4*f7 + 
    18*f1*f2*f4*f6 - 6*f1*f2*f5^2 - 6*f1*f3*f4*f5 - 3*f1*f4^3 + 3*f2^2*f4*f5
    + 6*f2*f3*f4^2)*x2^3*x3 + (-24*f0*f3*f4*f7 - 28*f0*f4^2*f6 - 
    28*f0*f4*f5^2 + 6*f1*f2*f4*f7 - 12*f1*f3*f4*f6 - 3*f1*f3*f5^2 + 
    3*f1*f4^2*f5 + 21*f2*f3*f4*f5 + 21*f2*f4^3 - 6*f3^2*f4^2)*x2^3*x4 + 
    (12*f0*f3*f4 - 3*f1*f2*f4)*x2^3*x5 + (6*f0*f4^2 - 6*f1*f3*f4)*x2^3*x6 + 
    (-16*f0*f4*f5 - 9*f1*f3*f5 - 3*f1*f4^2 + 6*f2*f3*f4)*x2^3*x7 + 
    (-24*f0*f4*f6 + 12*f0*f5^2 + 3*f1*f4*f5 - 6*f2*f4^2)*x2^3*x8 + 
    (-12*f0*f3*f4*f7 + 36*f0*f3*f5*f6 + 4*f0*f4^2*f6 - 2*f0*f4*f5^2 + 
    9*f1*f2*f4*f7 + 6*f1*f3*f4*f6 - 6*f1*f3*f5^2 + 6*f1*f4^2*f5 + 
    12*f2^2*f4*f6 - 3*f2^2*f5^2 - 9*f2*f3*f4*f5 - 9*f2*f4^3 + 
    6*f3^2*f4^2)*x2^2*x3^2 + (36*f0*f3*f5*f7 + 18*f0*f4^2*f7 - 
    24*f0*f4*f5*f6 - 70*f0*f5^3 - 18*f1*f3*f4*f7 + 36*f1*f3*f5*f6 - 
    12*f1*f4^2*f6 + 111*f1*f4*f5^2 + 6*f2^2*f4*f7 - 6*f2*f3*f4*f6 - 
    21*f2*f3*f5^2 + 33*f2*f4^2*f5 + 30*f3^2*f4*f5 - 3*f3*f4^3)*x2^2*x3*x4 + 
    (-18*f0*f3*f5 - 4*f0*f4^2 + 3*f1*f3*f4 - 3*f2^2*f4)*x2^2*x3*x5 + 
    (16*f0*f4*f6 - 32*f0*f5^2 + 18*f1*f4*f5 - 9*f2*f3*f5 - 9*f2*f4^2 + 
    6*f3^2*f4)*x2^2*x3*x7 + (-12*f0*f4*f7 - 6*f1*f4*f6 + 6*f1*f5^2 - 
    6*f2*f4*f5)*x2^2*x3*x8 + (94*f0*f4*f5*f7 - 24*f0*f4*f6^2 - 
    272*f0*f5^2*f6 + 3*f1^2*f7^2 + 39*f1*f3*f5*f7 - 21*f1*f4^2*f7 + 
    48*f1*f4*f5*f6 + 180*f1*f5^3 - 6*f2*f4^2*f6 + 186*f2*f4*f5^2 + 
    6*f3^2*f4*f6 + 9*f3^2*f5^2 - 6*f3*f4^2*f5 + 3*f4^4)*x2^2*x4^2 + 
    (-36*f0*f4*f5 - 18*f1*f3*f5 + 9*f1*f4^2 - 3*f2*f3*f4)*x2^2*x4*x5 + 
    (80*f0*f4*f6 - 8*f0*f5^2 - 33*f1*f4*f5 - 36*f2*f4^2 + 
    6*f3^2*f4)*x2^2*x4*x6 + (-4*f0*f4*f7 - 120*f0*f5*f6 + 18*f1*f4*f6 + 
    78*f1*f5^2 + 78*f2*f4*f5 + 9*f3^2*f5 + 3*f3*f4^2)*x2^2*x4*x7 + 
    (-12*f0*f5*f7 + 12*f1*f4*f7 + 24*f2*f4*f6 - 12*f2*f5^2 - 27*f3*f4*f5 + 
    3*f4^3)*x2^2*x4*x8 - 3*f1*f4*x2^2*x5*x8 + 6*f2*f4*x2^2*x6*x8 - 
    3*f4^2*x2^2*x8^2 + (18*f0*f3*f5*f7 + 2*f0*f4^2*f7 - 16*f0*f4*f5*f6 + 
    2*f0*f5^3 + 3*f1*f3*f4*f7 + 6*f1*f4^2*f6 + 6*f2^2*f4*f7 + 12*f2*f3*f4*f6
    - 6*f2*f3*f5^2 - 18*f2*f4^2*f5 - 12*f3^2*f4*f5 + 3*f3*f4^3)*x2*x3^3 + 
    (-8*f0*f4*f5*f7 - 64*f0*f4*f6^2 - 20*f0*f5^2*f6 + 18*f1*f3*f5*f7 + 
    18*f1*f4^2*f7 + 54*f1*f4*f5*f6 + 24*f1*f5^3 - 3*f2*f3*f4*f7 + 
    12*f2*f4^2*f6 - 105*f2*f4*f5^2 + 6*f3^2*f4*f6 - 21*f3^2*f5^2 + 
    33*f3*f4^2*f5 - 6*f4^4)*x2*x3^2*x4 + (14*f0*f4*f5 - 
    6*f1*f4^2)*x2*x3^2*x5 + (8*f0*f4*f7 - 28*f0*f5*f6 + 6*f1*f4*f6 + 
    24*f1*f5^2 - 30*f2*f4*f5 - 9*f3^2*f5 + 3*f3*f4^2)*x2*x3^2*x7 + 
    (-3*f1*f4*f7 - 12*f2*f4*f6 + 6*f2*f5^2 + 15*f3*f4*f5 + 
    3*f4^3)*x2*x3^2*x8 + (-8*f0*f4*f6*f7 + 18*f0*f5^2*f7 + 64*f0*f5*f6^2 + 
    6*f1*f2*f7^2 - 12*f1*f3*f6*f7 - 6*f1*f4*f5*f7 - 12*f1*f4*f6^2 - 
    48*f1*f5^2*f6 + 3*f2*f3*f5*f7 - 51*f2*f4^2*f7 - 54*f2*f4*f5*f6 + 
    21*f3^2*f4*f7 - 24*f3^2*f5*f6 - 18*f3*f4*f5^2)*x2*x3*x4^2 + (24*f0*f4*f6
    - 2*f0*f5^2 - 18*f1*f4*f5 + 3*f2*f4^2 - 9*f3^2*f4)*x2*x3*x4*x5 + 
    (-24*f0*f6*f7 + 6*f1*f5*f7 + 24*f2*f4*f7 + 18*f3*f4*f6 - 21*f3*f5^2 - 
    9*f4^2*f5)*x2*x3*x4*x8 - 3*f4*f5*x2*x3*x8^2 + (104*f0*f4*f7^2 - 
    120*f0*f5*f6*f7 - 18*f1*f3*f7^2 - 54*f1*f4*f6*f7 + 132*f1*f5^2*f7 + 
    48*f1*f5*f6^2 - 207*f2*f4*f5*f7 + 24*f2*f4*f6^2 + 168*f2*f5^2*f6 - 
    27*f3^2*f5*f7 - 15*f3*f4^2*f7 + 18*f3*f4*f5*f6 + 54*f3*f5^3 + 
    6*f4^2*f5^2)*x2*x4^3 + (-82*f0*f4*f7 - 32*f0*f5*f6 + 6*f1*f3*f7 + 
    18*f1*f4*f6 - 96*f1*f5^2 + 51*f2*f4*f5 + 12*f3^2*f5 + 
    6*f3*f4^2)*x2*x4^2*x5 + (50*f0*f5*f7 - 6*f1*f4*f7 - 12*f1*f5*f6 - 
    18*f2*f4*f6 - 60*f2*f5^2 + 36*f3*f4*f5 - 6*f4^3)*x2*x4^2*x6 + 
    (-140*f0*f6*f7 + 126*f1*f5*f7 + 24*f1*f6^2 - 6*f2*f4*f7 + 180*f2*f5*f6 +
    18*f3*f4*f6 + 81*f3*f5^2 + 9*f4^2*f5)*x2*x4^2*x7 + (-36*f0*f7^2 + 
    12*f2*f5*f7 - 12*f3*f4*f7 - 6*f4^2*f6 - 102*f4*f5^2)*x2*x4^2*x8 + 
    16*f0*f4*x2*x4*x5^2 + (12*f0*f7 + 9*f3*f4)*x2*x4*x5*x8 + (-28*f0*f6 + 
    48*f1*f5 + 15*f2*f4)*x2*x4*x6^2 - 6*f1*f7*x2*x4*x6*x8 + (48*f2*f6 + 
    15*f3*f5 + 3*f4^2)*x2*x4*x7^2 - 48*f4*f5*x2*x4*x7*x8 + (-24*f4*f6 + 
    12*f5^2)*x2*x4*x8^2 + 7*f0*x2*x5*x6*x7 + 30*f1*x2*x5*x7^2 - 2*f0*x2*x6^3
    + 12*f1*x2*x6^2*x7 + 12*f2*x2*x6*x7^2 - 6*f3*x2*x6*x7*x8 - 6*f3*x2*x7^3 
    + (-2*f0*f4*f5*f7 - 12*f0*f5^2*f6 - 12*f1*f5^3 + 6*f2*f3*f4*f7 + 
    12*f2*f4^2*f6 - 3*f3^2*f5^2 - 12*f3*f4^2*f5 + 3*f4^4)*x3^4 + 
    (-56*f0*f4*f6*f7 - 96*f0*f5^2*f7 - 112*f0*f5*f6^2 + 51*f1*f4*f5*f7 + 
    36*f1*f5^2*f6 + 54*f2*f4^2*f7 + 60*f2*f4*f5*f6 - 18*f2*f5^3 - 
    3*f3^2*f4*f7 + 6*f3*f4^2*f6 + 9*f3*f4*f5^2 + 3*f4^3*f5)*x3^3*x4 + 
    (12*f0*f4*f6 + 24*f0*f5^2 - 6*f1*f4*f5 - 12*f2*f4^2 + 3*f3^2*f4)*x3^3*x5
    + (-14*f0*f5*f7 + 12*f2*f4*f6 - 12*f2*f5^2 - 18*f3*f4*f5 + 
    3*f4^3)*x3^3*x7 + (-6*f2*f4*f7 + 15*f3*f5^2 + 9*f4^2*f5)*x3^3*x8 + 
    (-102*f0*f4*f7^2 - 212*f0*f5*f6*f7 - 176*f0*f6^3 + 30*f1*f4*f6*f7 - 
    108*f1*f5^2*f7 + 96*f1*f5*f6^2 + 3*f2^2*f7^2 - 12*f2*f3*f6*f7 + 
    186*f2*f4*f5*f7 + 48*f2*f4*f6^2 - 48*f2*f5^2*f6 - 9*f3^2*f5*f7 + 
    12*f3^2*f6^2 + 24*f3*f4^2*f7 + 102*f3*f4*f5*f6 - 18*f3*f5^3 - 6*f4^3*f6 
    + 12*f4^2*f5^2)*x3^2*x4^2 + (68*f0*f4*f7 + 104*f0*f5*f6 + 48*f1*f5^2 - 
    45*f2*f4*f5 - 9*f3*f4^2)*x3^2*x4*x5 + (16*f0*f5*f7 + 112*f0*f6^2 - 
    27*f1*f4*f7 - 120*f1*f5*f6 - 24*f2*f4*f6 + 18*f2*f5^2 - 69*f3*f4*f5 + 
    9*f4^3)*x3^2*x4*x6 + (-56*f0*f6*f7 + 18*f1*f5*f7 + 54*f2*f4*f7 - 
    48*f2*f5*f6 + 18*f3*f4*f6 - 30*f3*f5^2 + 6*f4^2*f5)*x3^2*x4*x7 + 
    (-12*f0*f7^2 + 6*f2*f5*f7 + 27*f3*f4*f7 + 30*f3*f5*f6 + 30*f4^2*f6 + 
    21*f4*f5^2)*x3^2*x4*x8 - 12*f0*f4*x3^2*x5^2 + (-17*f0*f5 + 
    6*f1*f4)*x3^2*x5*x6 + (-30*f1*f5 - 12*f2*f4)*x3^2*x5*x7 - 
    6*f3*f4*x3^2*x5*x8 + (-3*f3*f5 - 3*f4^2)*x3^2*x6*x8 + (-290*f0*f5*f7^2 -
    120*f0*f6^2*f7 - 12*f1*f4*f7^2 - 60*f1*f5*f6*f7 - 48*f1*f6^3 - 
    18*f2*f3*f7^2 + 84*f2*f4*f6*f7 + 78*f2*f5^2*f7 - 72*f2*f5*f6^2 + 
    36*f3^2*f6*f7 + 189*f3*f4*f5*f7 - 12*f3*f4*f6^2 + 24*f3*f5^2*f6 - 
    9*f4^3*f7 + 12*f4^2*f5*f6 + 72*f4*f5^3)*x3*x4^3 + (168*f0*f5*f7 + 
    176*f0*f6^2 + 21*f1*f4*f7 + 12*f1*f5*f6 + 6*f2*f3*f7 - 30*f2*f4*f6 - 
    6*f2*f5^2 - 12*f3^2*f6 - 69*f3*f4*f5 + 3*f4^3)*x3*x4^2*x5 + (-40*f0*f7^2
    - 12*f1*f6*f7 + 42*f2*f5*f7 - 72*f2*f6^2 + 54*f3*f4*f7 + 18*f3*f5*f6 + 
    6*f4^2*f6 + 84*f4*f5^2)*x3*x4^2*x7 + (-12*f1*f7^2 + 24*f2*f6*f7 + 
    90*f3*f5*f7 + 66*f4^2*f7 + 78*f4*f5*f6 - 72*f5^3)*x3*x4^2*x8 + 
    (-24*f0*f5 - 6*f1*f4)*x3*x4*x5^2 + (-90*f0*f6 + 9*f2*f4)*x3*x4*x5*x6 + 
    (14*f0*f7 - 60*f1*f6 - 21*f3*f4)*x3*x4*x5*x7 + (-15*f3*f5 - 
    24*f4^2)*x3*x4*x5*x8 + (2*f0*f7 + 6*f3*f4)*x3*x4*x6^2 - 
    6*f1*f7*x3*x4*x6*x7 - 6*f2*f7*x3*x4*x6*x8 + (6*f2*f7 + 24*f3*f6 + 
    30*f4*f5)*x3*x4*x7^2 + (12*f3*f7 + 12*f4*f6 - 48*f5^2)*x3*x4*x7*x8 - 
    24*f4*f7*x3*x4*x8^2 + 5*f0*x3*x5*x6^2 + 30*f1*x3*x5*x6*x7 + 
    3*f4*x3*x5*x8^2 + 12*f1*x3*x6^3 + 12*f2*x3*x6^2*x7 - 6*f3*x3*x6^2*x8 - 
    6*f3*x3*x6*x7^2 + 6*f4*x3*x6*x7*x8 - 6*f5*x3*x6*x8^2 + 3*f4*x3*x7^3 - 
    6*f5*x3*x7^2*x8 + (184*f0*f6*f7^2 - 336*f1*f5*f7^2 - 72*f1*f6^2*f7 - 
    24*f2*f4*f7^2 - 108*f2*f5*f6*f7 + 27*f3^2*f7^2 - 18*f3*f4*f6*f7 + 
    18*f4^2*f5*f7 + 24*f4*f5^2*f6 + 96*f5^4)*x4^4 + (60*f0*f6*f7 + 
    228*f1*f5*f7 + 24*f1*f6^2 + 21*f2*f4*f7 + 36*f2*f5*f6 - 18*f3^2*f7 + 
    6*f3*f4*f6 + 6*f3*f5^2 - 6*f4^2*f5)*x4^3*x5 + (96*f0*f7^2 - 36*f1*f6*f7 
    - 96*f2*f5*f7 + 6*f3*f4*f7 + 18*f3*f5*f6 - 18*f4*f5^2)*x4^3*x6 + 
    (-18*f1*f7^2 - 108*f2*f6*f7 + 9*f3*f5*f7 + 9*f4^2*f7 + 24*f4*f5*f6 + 
    168*f5^3)*x4^3*x7 + (36*f2*f7^2 + 249*f4*f5*f7 - 24*f4*f6^2 - 
    96*f5^2*f6)*x4^3*x8 + (-44*f0*f6 - 36*f1*f5 - 3*f2*f4 + 
    3*f3^2)*x4^2*x5^2 + (-83*f0*f7 + 12*f1*f6 + 36*f2*f5 - 
    3*f3*f4)*x4^2*x5*x6 + (-84*f1*f7 + 36*f2*f6 - 3*f4^2)*x4^2*x5*x7 + 
    (-12*f2*f7 - 87*f4*f5)*x4^2*x5*x8 + (-24*f3*f5 + 3*f4^2)*x4^2*x6^2 + 
    (-72*f2*f7 - 21*f4*f5)*x4^2*x6*x7 + (30*f4*f6 + 60*f5^2)*x4^2*x6*x8 + 
    (36*f3*f7 + 6*f4*f6 + 108*f5^2)*x4^2*x7^2 + (36*f4*f7 - 
    72*f5*f6)*x4^2*x7*x8 - 36*f5*f7*x4^2*x8^2 + 17*f0*x4*x5^2*x6 + 
    30*f1*x4*x5^2*x7 + 24*f2*x4*x5*x6*x7 - 12*f3*x4*x5*x7^2 - 
    15*f4*x4*x5*x7*x8 - 3*f4*x4*x6^2*x8 - 6*f4*x4*x6*x7^2 + 
    42*f5*x4*x6*x7*x8 + 30*f5*x4*x7^3 - 12*f6*x4*x7^2*x8 - 12*f7*x4*x7*x8^2 
    + 3*x6^2*x8^2 + 6*x6*x7^2*x8 + 3*x7^4]);
end intrinsic;


intrinsic KummerPoint(P::JacHypPt) -> Pt
{ Compute the image on the associated Kummer variety of a point P on the Jacobian 
of a hyperelliptic genus 3 curve with a rational Weierstrass point at infinity.}
    C := Curve(Parent(P));
    f, h := HyperellipticPolynomials(C);
    require IsZero(h):
        "Need a simplified model (h=0).";
    require Genus(C) eq 3:
        "The curve must have genus 3";
    require Degree(f) eq 7:
        "f must have Degree 7.";
 
    return KummerThreefold(Parent(P)) ! kappa(P);
end intrinsic;

intrinsic KummerPoint(P::JacHypPt, K::Sch) -> Pt
{ Compute the image on the associated Kummer variety of a point P on the Jacobian 
of a hyperelliptic genus 3 curve with a rational Weierstrass point at infinity.}
    return K ! kappa(P);
end intrinsic;


intrinsic TwoTorsionAdditionMatrix(g::RngUPolElt, h::RngUPolElt) -> AlgMatElt
{ Let C:y^2=f(x) with degree(f)=7 and let J be the Jacobian of C. Let P be a point 
of order 2 in J, represented by the divisor (O1, 0) + (O2, 0) + (O3, 0)) - 3(infinity).
Put g(x)=(x-O1)*(x-O2)*(x-O3) and f(x)=g(x)*h(x). This describes translation by P 
in the Kummer threefold.}
/*
	This is due to Sylvain Duquesne (see his PhD thesis)
*/
    require Degree(g) eq 3:
            "g must have degree 3";
    require Degree(h) eq 4:
            "h must have degree 4";

    return Matrix(8,
        [ -h4*g2*h2*g0+g1^2*h2*h4,
        -h4*g3*h2*g0+g1*h4*g2*h2-h4*g2*h3*g0+g1^2*h4*h3,
        g1^2*h4^2+2*g1*h4*g2*h3+g2^2*h4*h2-2*h4*g3*h3*g0-g0*h4^2*g2,
        3*g2^2*h4*h3+2*g2*h4*g3*h2-3*g0*h4^2*g3+3*g1*h4^2*g2,
        g0*h4,
        -g1*h4,
        g2*h4,
        g3*h4,
        -h4*g1*h2*g0-h4*g2*h1*g0+h3*g2*h2*g0+g1^2*h1*h4-g1^2*h2*h3-h2*g3*h0*g2+g2*g3*h1^2,
        -g1*h3*g2*h2+h3*g3*h2*g0-h3*g3*h0*g2+h4*g2*g1*h1+h1*g3*g2*h2+h1^2*g3^2-g1^2*h3^2-h4*g2*h2*g0+g2*h3^2*g0-h2*h0*g3^2-h1*g0*g3*h4-h4*g1*h3*g0,
        -h4*g3*h2*g0+2*h1*g3^2*h2-2*g1^2*h4*h3-2*h3*h0*g3^2-g0*h4^2*g1-2*g1*h3^2*g2-h4*g3*h0*g2+h1*g2^2*h4+h2^2*g3*g2-g2^2*h3*h2+2*g3*h3^2*g0,
        -3*h4*h0*g3^2-g1*h2*g3*h4-g0*h4^2*g2-2*g1^2*h4^2+3*h4*g3*h3*g0+h1*g3*g2*h4+g2^2*h4*h2+3*h2^2*g3^2-6*g1*h4*g2*h3-3*g2^2*h3^2,
        -g0*h3+g3*h0,
        g1*h3-h1*g3+g0*h4,
        -g2*h3+h2*g3-g1*h4,
        -g2*h4,
        -g1*g0*h1*h4+h2*g1*h3*g0+h3*g2*h1*g0-g2*h2^2*g0-g1^2*h1*h3+g1^2*h2^2-h2*g3*h0*g1+g1*g3*h1^2+h2*h0*g2^2-g2^2*h1^2-h1*g2*h0*g3,
        g1*h2*g3*h1+g1*h2^2*g2+g1*h3^2*g0+h3*g3*h1*g0-g2^2*h1*h2-h1*h0*g3^2-g2*h1*g1*h3-h3*g3*h0*g1-g1^2*h1*h4+g1^2*h2*h3-g3*h2^2*g0+h3*h0*g2^2-g2*g3*h1^2,
        -h3*g3*h2*g0-h2*h0*g3^2-h4*g3*h0*g1+g2*h3^2*g0+h1*g0*g3*h4+g1*h2^2*g3+h4*h0*g2^2+2*g1*h3*g2*h2-g2^2*h1*h3+h3*g3*h0*g2-2*h4*g2*g1*h1+2*h4*g1*h3*g0-2*h1*g3*g2*h2+g1^2*h3^2-h1^2*g3^2,
        -3*h1*g3^2*h2+3*g1*h2*g3*h3-h1*g2^2*h4-2*h1*g3*g1*h4+2*h4*g3*h0*g2+2*g0*h4^2*g1+4*h4*g2*h3*g0-3*g2*h1*g3*h3+2*g1^2*h4*h3+3*g1*h3^2*g2,
        g0*h2-g2*h0,
        -g0*h3+g3*h0-g1*h2+g2*h1,
        g1*h3-h1*g3+g0*h4,
        g1*h4,
        h3*h1*g1*g0-h2^2*g1*g0-h1*h0*g3*g1+h1*h0*g2^2,
        -g2*h2^2*g0-h2*g3*h0*g1+h2*h0*g2^2+h1*g2*h0*g3+g1*g0*h1*h4-h2*g1*h3*g0+h3*g2*h1*g0,
        h3*g3*h1*g0+h3*h0*g2^2+2*h2*g3*h0*g2-g1*h3^2*g0-2*h3*g2*h2*g0+2*h4*g2*h1*g0-g3*h2^2*g0-h3*g3*h0*g1+h1*h0*g3^2,
        3*h2*h0*g3^2+h4*h0*g2^2-h4*g3*h0*g1-3*h3*g3*h2*g0+3*h3*g3*h0*g2+3*h1*g0*g3*h4-3*g2*h3^2*g0-2*h4*g1*h3*g0,
        -g0*h1+g1*h0,
        g0*h2-g2*h0,
        -g0*h3+g3*h0,
        -g0*h4,
        -g2^3*h4*h1^2-2*h1*g3*g0^2*h4^2-h2^2*g3^2*g2*h0+g2^2*h3^2*h2*g0-g1^2*h2*h3^2*g2+g1^2*h2^2*h3*g3-g2^2*g3*h1^2*h3+g2*g3^2*h1^2*h2+2*h4*h2^2*g1^2*g2-2*g2^2*h4*g0*h2^2+g0^3*h4^3+g2^2*h0*g0*h4^2+g3^2*h0^2*h4*g2-g2*h0*g1^2*h4^2-g3^2*h0*h4*h2*g0-g0^2*h2*h4^2*g2+g0^2*h3*h4*g3*h2-g0*h3*h4*g3*h0*g2+g2^3*h4*h0*h2+g2*h4*g1*g3*h1^2+g1^2*h0*g3*h3*h4-g2*h4*g1*h0*g3*h2+g0*h1^2*g3^2*h4+2*h1^2*g3^2*g1*h3-2*g1^2*h3^2*h1*g3+2*g0*h4^2*g3*h0*g1-4*h4*g3^2*h0*h1*g1-h1*g3*g2*h2*g0*h4+g2^2*h0*h3*h2*g3-g0*h2^2*g3*g2*h3+g1^2*h2*g3*h1*h4+2*g2^2*h4*h0*g3*h1-2*g1*h0*g3^2*h3*h2-4*g0*h2^2*g3*g1*h4-2*g3^2*h0*h1*g2*h3+2*g0*h3^2*g1*h2*g3+2*g0*h1*g3*h3^2*g2,
        g3^3*h0^2*h4+g1*h4^3*g0^2-g1*h2*g2^2*h3^2+h2^2*g3^2*g2*h1-g2*h4^2*g1^2*h1+g2^3*h4*h0*h3+g1^2*h3^2*h2*g3-g0*h2^2*g3^2*h3+g2^2*h0*g3*h3^2-h1^2*g3^2*g2*h3+g1^2*h4^2*h0*g3-g1*h4^2*g2^2*h0+2*g2^2*h4*g1*h2^2-2*g3^3*h0*h3*h1-2*g3^2*h0*h3^2*g1+2*g0*h3^3*g3*g1+2*g0*h3^2*g3^2*h1-g0^2*h2*h4^2*g3+g0^2*h3^2*h4*g3-g0^2*h3*h4^2*g2-h4*h1^2*g2^2*g3-g2^3*h4*h1*h2+g0*h4^2*h1*g2^2-g1^2*h3^3*g2+g0*h3^3*g2^2-g3^3*h0*h2^2+2*g3*h0*g0*h4^2*g2-2*g0*h3*h4*h0*g3^2-h1*g3*h3*g2^2*h2+g1*h2^2*h3*g2*g3-2*g3^2*h0*h3*g2*h2+2*g0*h3^2*g2*h2*g3+h1^2*g3^3*h2+2*g2*h4*g1^2*h2*h3+2*g3^2*h4*g2*h0*h1+2*g3*h4*g0*h1*g2*h3+2*g3*h4^2*g1*g0*h1+2*g2*h4*g1*h2*g3*h1+3*g3*h4*g2^2*h0*h2-4*g3*h4*g0*h2*g1*h3-2*g2^2*h4*g0*h2*h3-4*g3^2*h4*g1*h0*h2-6*g3*h4*g0*h2^2*g2+2*h1*g3^2*h2*g1*h3-2*g3*h4*g1^2*h1*h3-2*g1*h3^2*g2*h1*g3,
        h4*h2^2*g2^3-g0^2*h4^3*g2+4*h4*h1*g3^3*h0-2*h1*g3*h3^2*g2^2+2*h3*g3^2*h2^2*g1-2*h4^2*h1*g2^2*g1+4*h3^3*g2*g3*g0-4*g3^3*h0*h2*h3+g0^2*h4^2*g3*h3-g0*h4^2*h0*g3^2-h4*h1^2*g2*g3^2+h4^2*g2*g1^2*h2+g1*h4*h2^2*g3*g2-g2*h4*g1^2*h3^2+g2^2*h4*g0*h3^2-3*g0*h4*h2^2*g3^2+3*g3^2*h4*g2*h0*h2+h2^3*g3^2*g2+g1^2*h4^3*g0-h2*g2^3*h3^2+4*h4*g1*h2*g2^2*h3+2*h3^2*g3*h2*g1*g2-2*h1*g3^2*h3*g2*h2+g1*h4^2*g2*h0*g3+2*g1*h4*g0*h3^2*g3-g2^2*h4*h1*g3*h2-3*g3*h4^2*g0*h2*g1+6*g2^2*h4*h0*g3*h3-4*g1*h4*g2*h3*h1*g3+4*g0*h4*g3^2*h3*h1-2*h3^3*g2^2*g1+2*h2^2*g3^3*h1-2*h1^2*g3^3*h3+2*h3^3*g1^2*g3-2*g3*h4*g1^2*h2*h3-11*g3*h4*g0*h2*g2*h3-6*g1*h4*g3^2*h0*h3+8*g3*h4^2*g0*h1*g2,
        g0^2*h4^3*g3+h4*h1^2*g3^3-3*h2*g2^2*h3^2*g3+6*g3*h3^3*g1*g2+6*g3^2*h3^2*g1*h2-6*h1*g3^2*g2*h3^2-6*h1*g3^3*h2*h3+3*h2^2*g2*g3^2*h3-2*h4^2*g3^2*h0*g1+7*h4^2*g0*h1*g3^2+4*h4^2*g2^2*g3*h0+4*h4^2*g1*g2^2*h2+3*h4*h2^2*g2^2*g3+4*h4*g2^3*h3*h2+5*h4*g1^2*h3^2*g3+5*h4*g3^3*h0*h2-3*h4*g2^2*h3^2*g1+4*g2^2*h4^2*g0*h3-4*g3*h4^2*g1^2*h2+g1^3*h4^3-3*g2^3*h3^3+3*g3^3*h2^3-g1^2*h3*h4^2*g2-g1*h4^2*g0*g3*h3+h4*g0*h3^2*g3*g2+h4^2*h1*g3*g2*g1-2*h4^2*g2^3*h1-6*h4*g1*h3*g3^2*h1-5*h4*g0*h3*g3^2*h2+11*h4*g3^2*h0*g2*h3-3*h4*g2^2*h1*g3*h3-5*h4*g1*h2*g3*g2*h3-3*h4*g2*h1*g3^2*h2-4*g3*h4^2*g0*h2*g2,
        -3*h1*g0*g3*h4+2*h4*g2*h2*g0+h3*g3*h2*g0-g2*h3^2*g0-h4*h0*g2^2+3*h4*g3*h0*g1-h3*g3*h0*g2+h2*h0*g3^2,
        4*h4*g3*h2*g0-2*g3*h3^2*g0+h1*g2^2*h4-2*g1*h4*g2*h2-2*h4*g3*h0*g2-g1*h2*g3*h3+g2*h1*g3*h3+g1*h3^2*g2+2*h3*h0*g3^2-h1*g3^2*h2,
        g0*h4^2*g2-h4*g3*h3*g0+g2^2*h4*h2+3*h4*h0*g3^2-h1*g3*g2*h4-g1*h2*g3*h4+2*h3^2*g3*g1-2*h1*g3^2*h3+h2^2*g3^2-g2^2*h3^2,
        -(3*g3*h4*g0-g1*h4*g2-2*g1*g3*h3+g2^2*h3)*h4,
        -g2^3*h1^2*h3+g1^2*h2^3*g3+h4^2*g0^3*h3-g1^3*h4^2*h0+h1^3*g3^2*g2-h3^2*h2*g1^3+2*h4*g1^2*h1^2*g3-h4^2*g3*h0*g0^2+g3*h2^2*g0^2*h4-h3*g3*h1*g0^2*h4+h1*h0*g3^2*g0*h4+h4*h0^2*g2^2*g3+h1^2*g3^2*g1*h2+h3*g3*h0*g1*g0*h4-h4^2*g2*h1*g0^2-h4*g3^2*h0^2*g1-g1*h4*g2^2*h1^2+g0*h3^2*g2^2*h1-g3^2*h0*h2^2*g1-h1*g1^2*h3^2*g2-g0^2*h4^2*g1*h2-h2^3*g3*g2*g0+g2^3*h3*h2*h0-g2^2*h0*h3*h1*g3+g0*h2^2*g3*g1*h3-3*g1*h4*g2*h0*g3*h1+g2^3*h0*h4*h1+g1*h4*g2^2*h0*h2-3*g1*h2*g3*h1*g0*h4-2*h2*g3*h0*g2*g0*h4+2*g0*h4^2*g1*g2*h0+2*h4*g2*g1^2*h1*h2-2*g2^2*h1*h2*g0*h4+2*g1^3*h4*h2^2-2*h3*h2*g1^2*h1*g3+2*h1^2*g2*g1*g3*h3-2*g1*h3*g2*h2*g3*h0-2*g3^2*h0*h2*g2*h1+2*g0*h3^2*g2*g1*h2-4*g1*h4*g0*h2^2*g2+2*g0*h2*g3*h3*g2*h1,
        g2^3*h0*h3^2-g0*h2^3*g3^2-2*h1*g3*g0^2*h4^2-h2^2*g3^2*g2*h0+g2^2*h3^2*h2*g0-g1^2*h2*h3^2*g2+g1^2*h2^2*h3*g3-g2^2*g3*h1^2*h3+g2*g3^2*h1^2*h2+2*g1^3*h2*h3*h4+2*h4*h2^2*g1^2*g2-2*g2^2*h4*g0*h2^2+2*g0*h3^3*g1*g2-2*g3^3*h0*h1*h2+g0^3*h4^3-g1^3*h3^3+g2^2*h0*g0*h4^2+g3^2*h0^2*h4*g2-g2*h0*g1^2*h4^2-g3^2*h0*h4*h2*g0-g0^2*h2*h4^2*g2+g0^2*h3*h4*g3*h2-g0*h3*h4*g3*h0*g2+g2^3*h4*h0*h2-g2*h4*g1*h0*g3*h2+h1^3*g3^3-g2^3*h1*h2*h3+g1*h2^2*g3^2*h1-g2^2*h1*g1*h3^2+g2^2*h1*h2*g1*h4+g1*h2^3*g2*g3+g2^2*h0*h3*g1*h4+h1^2*g3^2*g1*h3-g1^2*h3^2*h1*g3-g1^3*h1*h4^2+2*g0*h4^2*g3*h0*g1-2*h4*g3^2*h0*h1*g1-2*g0*h1*g3*h3*g1*h4-3*h1*g3*g2*h2*g0*h4+g2^2*h4*h0*g3*h1-4*g2*h4*g0*h2*g1*h3-2*g1*h0*g3^2*h3*h2+2*g2*h4^2*g1*g0*h1-2*g0*h2^2*g3*g1*h4-2*g3^2*h0*h1*g2*h3+2*g0*h3^2*g1*h2*g3+2*g0*h1*g3*h3^2*g2-2*g1*h0*g3*h3^2*g2+2*g0*h1*g3^2*h3*h2,
        g3^3*h0^2*h4+g1*h4^3*g0^2+h4^2*g0*g1^2*h3-g1*h2*g2^2*h3^2+h2^2*g3^2*g2*h1-g2*h4^2*g1^2*h1+2*g2^3*h4*h0*h3+g1^2*h3^2*h2*g3-g0*h2^2*g3^2*h3+g2^2*h0*g3*h3^2-h1^2*g3^2*g2*h3-g3^2*h4*g1*h1^2+g2^2*h4*g1*h2^2-2*g3^3*h0*h3*h1-2*g3^2*h0*h3^2*g1+2*g0*h3^3*g3*g1+2*g0*h3^2*g3^2*h1-g0^2*h2*h4^2*g3+g0^2*h3^2*h4*g3-g0^2*h3*h4^2*g2+h4*h1^2*g2^2*g3+2*g2^3*h4*h1*h2+2*g0*h4^2*h1*g2^2+g1*h2^3*g3^2-h3^2*g2^3*h1+h2^3*g3*g2^2-h3*g2^3*h2^2+g1^3*h4^2*h2+g3*h4*g1^2*h2^2-g1^2*h3^3*g2+g0*h3^3*g2^2-g3^3*h0*h2^2+2*g3*h0*g0*h4^2*g2-2*g0*h3*h4*h0*g3^2-4*h1*g3*h3*g2^2*h2+4*g1*h2^2*h3*g2*g3-2*g3^2*h0*h3*g2*h2+2*g0*h3^2*g2*h2*g3+g0*h4*h1*g3^2*h2+h1^2*g3^3*h2-g1^3*h4*h3^2-g2*h4*g1*h0*g3*h3+2*g2*h4*g1^2*h2*h3+2*g2*h4*g0*h3^2*g1-g3*h4*g0*h1*g2*h3-g3*h4^2*g1*g0*h1-4*g2*h4*g1*h2*g3*h1-2*g2*h4^2*g0*h2*g1+2*g3*h4*g2^2*h0*h2-2*g3*h4*g0*h2*g1*h3-2*g2^2*h4*g0*h2*h3-3*g3^2*h4*g1*h0*h2-2*g3*h4*g0*h2^2*g2+2*h1*g3^2*h2*g1*h3-2*g3*h4*g1^2*h1*h3-2*g1*h3^2*g2*h1*g3,
        h4*h2^2*g2^3-g0^2*h4^3*g2-2*h4*h1*g3^3*h0+2*h4*g2^3*h1*h3-6*h1*g3*h3^2*g2^2+6*h3*g3^2*h2^2*g1+2*h4^2*h1*g2^2*g1-4*g3*h4^2*g1^2*h1+g0^2*h4^2*g3*h3-g0*h4^2*h0*g3^2+h4*h1^2*g2*g3^2+h4^2*g2*g1^2*h2+g1*h4*h2^2*g3*g2-g2*h4*g1^2*h3^2+g2^2*h4*g0*h3^2+g0*h4*h2^2*g3^2+g3^2*h4*g2*h0*h2+3*h2^3*g3^2*g2+3*g1^2*h4^3*g0-3*h2*g2^3*h3^2-2*h4*g1*h2*g2^2*h3+6*h3^2*g3*h2*g1*g2-6*h1*g3^2*h3*g2*h2+3*g1*h4^2*g2*h0*g3+4*g1*h4*g0*h3^2*g3+2*g2*h4^2*g0*h3*g1+3*g2^2*h4*h1*g3*h2-3*g3*h4^2*g0*h2*g1+6*g2^2*h4*h0*g3*h3-10*g1*h4*g2*h3*h1*g3+2*g0*h4*g3^2*h3*h1+4*g3*h4*g1^2*h2*h3+3*g3*h4*g0*h2*g2*h3-4*g1*h4*g3^2*h0*h3-6*g1*h4*h1*g3^2*h2,
        2*h4*g1*h2*g0+g3*h2^2*g0-h3*g3*h1*g0-g1*h3^2*g0+h1*h0*g3^2-h3*h0*g2^2+h3*g3*h0*g1,
        2*h4*g2*h2*g0+h1*g0*g3*h4-h3*g3*h2*g0-g2*h3^2*g0-h4*h0*g2^2-2*g1^2*h2*h4+h4*g3*h0*g1+h3*g3*h0*g2+g1^2*h3^2-h1^2*g3^2+g2^2*h1*h3-g1*h2^2*g3+h2*h0*g3^2,
        g0*h4^2*g1+h4*g3*h2*g0+h1*g2^2*h4-2*h1*g3*g1*h4+h4*g3*h0*g2-g2^2*h3*h2+h2^2*g3*g2-2*g2*h1*g3*h3+2*g1*h2*g3*h3,
        -(g0*h4*g2-g1^2*h4-2*g3*h2*g1+g2^2*h2)*h4,
        h1^2*g2^3*h2-h2^3*g2*g1^2+h1^3*g2^2*g3-h2^2*g2^3*h0-h1^3*g3^2*g1-h2^2*g1^3*h3+h3^2*h1*g1^3+g0*h2^3*g2^2+h4*g0^3*h3^2-h4^2*g0^3*h2+h4*h0^2*g2^3-g0*h4^2*g1^2*h0-g1^3*h4*h3*h0+h4*g1^2*h0*g2*h2+h4*g3^2*h0^2*g0+3*g1^2*h4*g3*h0*h1+3*g0*h2^3*g3*g1-g0*h2*g1^2*h3^2+h1^2*g2^2*g1*h3+h1^2*g3^2*h0*g2+h4*g1^3*h1*h2-g0*h2*g2^2*h3*h1-g0*h1^2*g2*h3*g3+g2*h0*g3*h2^2*g1-g2^2*h0*h2*g1*h3+g0*h2^2*g2*h1*g3+g1^2*h0*g3*h2*h3-h1^2*g2*g1*g3*h2+h1*g1^2*h2*g2*h3-3*g2^2*h0*h2*h1*g3+g2*h2^2*g0^2*h4-h2*g1*h3*g0^2*h4+h4*g2^2*h1^2*g0+h1*g2*h0*g3*g0*h4-3*g2^3*h0*h3*h1+h1*g0^2*g3*h4*h2+g1*g0^2*h1*h4^2-h4*g2*h1*g0*g1*h2-3*g1*h4*g2^2*h0*h1+3*g0*h2^2*g2*g1*h3+h4^2*g2*h0*g0^2-g1^2*h2^2*h1*g3-2*h4*g0^2*h3*g3*h0+4*g1*h0*g3^2*h2*h1+4*g2*h0*g3*h1*g1*h3-2*h3*g2*h1*g0^2*h4-2*h2*h0*g2^2*g0*h4-4*g0*h2*g1*h3*h1*g3-2*h4*g3*h0^2*g1*g2+3*h4*g1*h3*g0*g2*h0-4*g0*h1*g2*h3^2*g1+2*g1^2*h4*g0*h2^2,
        h4^2*g0^3*h3-g1^3*h4^2*h0+h1^3*g3^2*g2-h3^2*h2*g1^3-3*h2^2*g3*g2^2*h0+2*g2^2*h1^2*h2*g3-2*g1^2*h2^2*g2*h3+2*h4*h1*g1^3*h3+3*g2^2*h3*h2^2*g0-g1^2*h4^2*g0*h1+h4*g1^2*h1^2*g3-h4^2*g3*h0*g0^2+g3*h2^2*g0^2*h4-h3*g3*h1*g0^2*h4+h1*h0*g3^2*g0*h4+h4*h0^2*g2^2*g3-h1^2*g3^2*g1*h2+h3*g3*h0*g1*g0*h4-h4^2*g2*h1*g0^2-h4*g3^2*h0^2*g1-3*g0*h3^2*g2^2*h1+3*g3^2*h0*h2^2*g1+h1*g1^2*h3^2*g2-g0^2*h4^2*g1*h2+4*h2^3*g3*g2*g0-4*g2^3*h3*h2*h0-4*g2^2*h0*h3*h1*g3+4*g0*h2^2*g3*g1*h3-3*g1*h4*g2*h0*g3*h1-2*g1*h4*g2^2*h0*h2-5*g1*h2*g3*h1*g0*h4-g1*h2^3*g2^2+h1*g2^3*h2^2-g0*h3^3*g1^2+g3^3*h0*h1^2+g2*g3*h1^2*g0*h4-g0*h1^2*g3^2*h3-g2^2*h0*h3^2*g1+g0*h2^2*g3^2*h1+g1^2*h0*g3*h3^2-2*g0*h3^2*g1*h1*g3+2*g3^2*h0*h1*g1*h3-2*h2*g3*h0*g2*g0*h4+2*g1^2*h4*g0*h2*h3-6*g1*h4*g0*h1*g2*h3+2*g0*h4^2*g1*g2*h0+2*h4*g2*g1^2*h1*h2+3*g1^2*h4*h0*g3*h2-2*h3*h2*g1^2*h1*g3+2*h1^2*g2*g1*g3*h3+4*g1*h3*g2*h2*g3*h0-2*g3^2*h0*h2*g2*h1+2*g0*h3^2*g2*g1*h2+2*g1*h4*g0*h2^2*g2-4*g0*h2*g3*h3*g2*h1-2*g1*h2^2*g2*h1*g3+2*g2^2*h1*h2*g1*h3,
        -3*g2^3*h0*h3^2+3*g0*h2^3*g3^2-2*h1*g3*g0^2*h4^2-5*h2^2*g3^2*g2*h0+5*g2^2*h3^2*h2*g0-3*g1^2*h2*h3^2*g2-g1^2*h2^2*h3*g3+g2^2*g3*h1^2*h3+3*g2*g3^2*h1^2*h2+2*g0*h3^3*g1*g2-2*g3^3*h0*h1*h2+2*g2^2*h1*h2^2*g3-2*g1*h2^2*g2^2*h3+g0^3*h4^3-g1^3*h3^3+g2^2*h0*g0*h4^2+g3^2*h0^2*h4*g2-g2*h0*g1^2*h4^2-g3^2*h0*h4*h2*g0-g0^2*h2*h4^2*g2+g0^2*h3*h4*g3*h2-g0*h3*h4*g3*h0*g2-g2^3*h4*h0*h2+2*g2*h4*g1*g3*h1^2+4*g1^2*h0*g3*h3*h4-3*g2*h4*g1*h0*g3*h2+h1^3*g3^3+g2^3*h1*h2*h3-g1*h2^2*g3^2*h1+g2^2*h1*g1*h3^2+3*g2^2*h1*h2*g1*h4-g1*h2^3*g2*g3-3*g2^2*h0*h3*g1*h4+h1^2*g3^2*g1*h3-g1^2*h3^2*h1*g3+g1^3*h1*h4^2+2*g0*h4^2*g3*h0*g1-2*h4*g3^2*h0*h1*g1-8*g0*h1*g3*h3*g1*h4-7*h1*g3*g2*h2*g0*h4-10*g2^2*h0*h3*h2*g3+10*g0*h2^2*g3*g2*h3-g2^2*h4*h0*g3*h1+2*g2*h4*g0*h2*g1*h3-6*g2^2*h4*g0*h1*h3+4*g2*h4*g1^2*h1*h3+4*g1*h0*g3^2*h3*h2-4*g2*h4^2*g1*g0*h1+2*g0*h2^2*g3*g1*h4-4*g3^2*h0*h1*g2*h3+4*g0*h3^2*g1*h2*g3-4*g0*h1*g3*h3^2*g2+2*g1*h0*g3*h3^2*g2-2*g0*h1*g3^2*h3*h2,
        g3^3*h0^2*h4+g1*h4^3*g0^2+2*h4^2*g0*g1^2*h3-3*g1*h2*g2^2*h3^2+3*h2^2*g3^2*g2*h1+3*g2*h4^2*g1^2*h1-3*g2^3*h4*h0*h3-3*g1^2*h3^2*h2*g3+9*g0*h2^2*g3^2*h3-9*g2^2*h0*g3*h3^2+3*h1^2*g3^2*g2*h3+3*g1^2*h4^2*h0*g3-3*g1*h4^2*g2^2*h0+2*g3^2*h4*g1*h1^2-g0^2*h2*h4^2*g3+g0^2*h3^2*h4*g3-g0^2*h3*h4^2*g2+h4*h1^2*g2^2*g3+g2^3*h4*h1*h2+g0*h4^2*h1*g2^2-3*g1^2*h3^3*g2+9*g0*h3^3*g2^2-9*g3^3*h0*h2^2+2*g3*h0*g0*h4^2*g2-2*g0*h3*h4*h0*g3^2+3*h1*g3*h3*g2^2*h2-3*g1*h2^2*h3*g2*g3-18*g3^2*h0*h3*g2*h2+18*g0*h3^2*g2*h2*g3-8*g0*h4*h1*g3^2*h2+3*h1^2*g3^3*h2-2*g1^3*h4*h3^2-4*g2*h4*g1*h0*g3*h3-2*g2*h4*g1^2*h2*h3-2*g3^2*h4*g2*h0*h1+8*g2*h4*g0*h3^2*g1-14*g3*h4*g0*h1*g2*h3-12*g3*h4^2*g1*g0*h1+4*g2*h4*g1*h2*g3*h1-2*g2*h4^2*g0*h2*g1-5*g3*h4*g2^2*h0*h2+12*g3*h4*g0*h2*g1*h3-4*g2^2*h4*g0*h2*h3-4*g3^2*h4*g1*h0*h2+4*g2^2*h4*h1*g1*h3,
        3*g1*g0*h1*h4-g2*h2^2*g0+2*h2*g3*h1*g0-h2*g1*h3*g0+3*h3*g2*h1*g0-2*g1^2*h0*h4+h2*h0*g2^2-3*h2*g3*h0*g1+h1*g2*h0*g3-2*h3*g2*h0*g1,
        -2*h4*g1*h2*g0-2*h3*g2*h2*g0+g1*h3^2*g0-3*g3*h2^2*g0+h3*g3*h1*g0-g1^2*h1*h4+2*h4*g2*h0*g1+g1*h2*g3*h1+g1^2*h2*h3-g2^2*h1*h2+g1*h2^2*g2-h1*h0*g3^2+2*h2*g3*h0*g2-h3*g3*h0*g1-g2*g3*h1^2+3*h3*h0*g2^2-g2*h1*g1*h3,
        h4*g1*h3*g0-h4*g2*h2*g0-h1*g0*g3*h4+3*g2*h3^2*g0+3*h3*g3*h2*g0+h4*g2*g1*h1-2*h4*g3*h0*g1-g1^2*h3^2+h1^2*g3^2-3*h3*g3*h0*g2-3*h2*h0*g3^2+h1*g3*g2*h2-g1*h3*g2*h2,
        (2*g0*g1*h4+3*g0*h2*g3+3*g0*g2*h3-g1^2*h3-g1*g2*h2)*h4,
        -g0^3*h1*h4^2-g0*h1^3*g3^2+g1^3*h0*h3^2+g0^2*h2^3*g3-g2^3*h0^2*h3+h4*h1^2*g1^3+2*h1*g2^3*h0*h2-2*g1^3*h1*h3*h2+2*h1^3*g2*g1*g3-2*g0*g1*h2^3*g2+2*g0^2*h1*g2*h3^2+2*g0^2*h1^2*g3*h4-2*g1*h0^2*g3^2*h2+3*g0^2*h3^2*g3*h0-3*g0*h3*g3^2*h0^2+2*g0^3*h3*h4*h2+g1^3*h2^3-h1^3*g2^3-g0^3*h3^3+g3^3*h0^3+g1^2*h2^2*g2*h1+g0*g1^2*h2^2*h3-h1^2*g2^2*g1*h2-g0*h1*g2^2*h2^2+h2^2*g1*g2^2*h0-h1^2*g2*g1^2*h3-g2^2*h0^2*h4*g1-h1^2*g2^2*h0*g3+h1^2*h2*g3*g1^2+g1^2*h0^2*g3*h4-g0^2*h2^2*g2*h3+g2^2*h0^2*h2*g3-g2*h0^2*g3^2*h1+g0*h3*g1^2*h4*h0+g1*h0*g3*h2*g0*h3-g2*h0*g3*h1*g0*h3-g0^2*h4*g1*h1*h3+g0^2*h2*g1*h3^2-g0^2*h4*g1*h2^2+g1*h0*g0^2*h4^2-g1^3*h0*h2*h4+g1*h0*h1^2*g3^2-g0*h1*g1^2*h3^2+g1^2*h0*h4*g2*h1-g1^2*h0*h3*g2*h2+g1*h0*g2^2*h1*h3-g0*h1*g1*h2^2*g3+g0*h1^2*g3*g2*h2-g0*h1*g1^2*h2*h4+2*g0*h1^2*g1*h3*g3-3*g0^2*h1*g3*h3*h2+2*g0*h2*g1*h4*g2*h0-2*g3*h0*g0^2*h4*h2-2*g0*h2^2*g2*g3*h0-3*g0*h4*g1*g3*h0*h1+2*g3*h0^2*g0*h4*g2-2*g0^2*h3*h4*g2*h0-2*g1^2*h0*h3*h1*g3+2*g2^2*h0*h2*g0*h3-5*g1*h0*h1*g3*g2*h2-3*g0*h1^2*h4*g2*g1+5*g0*h1*g1*h3*g2*h2+3*g1*h0^2*g3*h3*g2+3*g3^2*h0*h1*g0*h2-3*g0*h3^2*g1*g2*h0,
        -h1^2*g2^3*h2+h2^3*g2*g1^2-h1^3*g2^2*g3+h2^2*g2^3*h0+h1^3*g3^2*g1+h2^2*g1^3*h3-h3^2*h1*g1^3-g0*h2^3*g2^2-h4*g0^3*h3^2+h4^2*g0^3*h2-h4*h0^2*g2^3+g0*h4^2*g1^2*h0+g1^3*h4*h3*h0-h4*g1^2*h0*g2*h2-h4*g3^2*h0^2*g0-g1^2*h4*g3*h0*h1-g0*h2^3*g3*g1+g0*h2*g1^2*h3^2-h1^2*g2^2*g1*h3-h1^2*g3^2*h0*g2-h4*g1^3*h1*h2+g0*h2*g2^2*h3*h1+g0*h1^2*g2*h3*g3-g2*h0*g3*h2^2*g1+g2^2*h0*h2*g1*h3-g0*h2^2*g2*h1*g3-g1^2*h0*g3*h2*h3+h1^2*g2*g1*g3*h2-h1*g1^2*h2*g2*h3+g2^2*h0*h2*h1*g3-g2*h2^2*g0^2*h4+h2*g1*h3*g0^2*h4-h4*g2^2*h1^2*g0-h1*g2*h0*g3*g0*h4+g2^3*h0*h3*h1-h1*g0^2*g3*h4*h2-g1*g0^2*h1*h4^2+h4*g2*h1*g0*g1*h2+g1*h4*g2^2*h0*h1-g0*h2^2*g2*g1*h3-h4^2*g2*h0*g0^2+g1^2*h2^2*h1*g3+2*h4*g0^2*h3*g3*h0-2*g1*h0*g3^2*h2*h1-2*g2*h0*g3*h1*g1*h3+2*h3*g2*h1*g0^2*h4+2*h2*h0*g2^2*g0*h4+2*g0*h2*g1*h3*h1*g3+2*h4*g3*h0^2*g1*g2-3*h4*g1*h3*g0*g2*h0+2*g0*h1*g2*h3^2*g1-2*g1^2*h4*g0*h1*h3,
        -g2^3*h1^2*h3+g1^2*h2^3*g3-h4^2*g0^3*h3+g1^3*h4^2*h0-h1^3*g3^2*g2+h3^2*h2*g1^3+2*h2^2*g3*g2^2*h0-2*g2^2*h1^2*h2*g3+2*g1^2*h2^2*g2*h3-2*h4*h1*g1^3*h3-2*g2^2*h3*h2^2*g0-2*g1^2*h4^2*g0*h1+h4^2*g3*h0*g0^2-g3*h2^2*g0^2*h4+h3*g3*h1*g0^2*h4-h1*h0*g3^2*g0*h4-h4*h0^2*g2^2*g3+h1^2*g3^2*g1*h2-h3*g3*h0*g1*g0*h4+h4^2*g2*h1*g0^2+h4*g3^2*h0^2*g1-g1*h4*g2^2*h1^2+g0*h3^2*g2^2*h1-g3^2*h0*h2^2*g1-h1*g1^2*h3^2*g2+g0^2*h4^2*g1*h2-h2^3*g3*g2*g0+g2^3*h3*h2*h0+g2^2*h0*h3*h1*g3-g0*h2^2*g3*g1*h3-g1*h4*g2*h0*g3*h1+g2^3*h0*h4*h1+g1*h4*g2^2*h0*h2+g1*h2*g3*h1*g0*h4+2*g0*h3^2*g1*h1*g3-2*g3^2*h0*h1*g1*h3+2*h2*g3*h0*g2*g0*h4+2*g1^2*h4*g0*h2*h3+2*g1*h4*g0*h1*g2*h3-2*g0*h4^2*g1*g2*h0-2*h4*g2*g1^2*h1*h2-2*g1^2*h4*h0*g3*h2+2*g2^2*h1*h2*g0*h4,
        -g2^3*h4*h1^2+2*h1*g3*g0^2*h4^2+3*h2^2*g3^2*g2*h0-3*g2^2*h3^2*h2*g0+3*g1^2*h2*h3^2*g2+3*g1^2*h2^2*h3*g3-3*g2^2*g3*h1^2*h3-3*g2*g3^2*h1^2*h2+2*g1^3*h2*h3*h4+2*g1^2*h4^2*g0*h2-g0^3*h4^3-g2^2*h0*g0*h4^2-g3^2*h0^2*h4*g2+g2*h0*g1^2*h4^2+g3^2*h0*h4*h2*g0+g0^2*h2*h4^2*g2-g0^2*h3*h4*g3*h2+g0*h3*h4*g3*h0*g2+g2^3*h4*h0*h2-g2*h4*g1*g3*h1^2-g1^2*h0*g3*h3*h4+g2*h4*g1*h0*g3*h2-g0*h1^2*g3^2*h4-2*g1^3*h1*h4^2-2*g0*h4^2*g3*h0*g1-2*h4*g3^2*h0*h1*g1+4*g0*h1*g3*h3*g1*h4+3*h1*g3*g2*h2*g0*h4+3*g2^2*h0*h3*h2*g3-3*g0*h2^2*g3*g2*h3-3*g1^2*h2*g3*h1*h4+2*g2^2*h4*h0*g3*h1+2*g2*h4*g0*h2*g1*h3+4*g2^2*h4*g0*h1*h3-4*g2*h4*g1^2*h1*h3,
        -h3*h1*g1*g0+h2^2*g1*g0+h1*h0*g3*g1-h1*h0*g2^2,
        g1*g0*h1*h4-h2*g1*h3*g0-h3*g2*h1*g0+g2*h2^2*g0+g1^2*h1*h3-g1^2*h2^2+h2*g3*h0*g1-g1*g3*h1^2-h2*h0*g2^2+g2^2*h1^2+h1*g2*h0*g3,
        h4*g1*h2*g0+h4*g2*h1*g0-h3*g2*h2*g0-g1^2*h1*h4+g1^2*h2*h3+h2*g3*h0*g2-g2*g3*h1^2,
        -h2*h4*(g0*g2-g1^2)

        where g0 := Coefficient(g, 0)	
        where g1 := Coefficient(g, 1)
        where g2 := Coefficient(g, 2)
        where g3 := Coefficient(g, 3)
        where h0 := Coefficient(h, 0)	
        where h1 := Coefficient(h, 1)
        where h2 := Coefficient(h, 2)
        where h3 := Coefficient(h, 3)
        where h4 := Coefficient(h, 4)	
    ]);
end intrinsic;

intrinsic DuplicationPolynomials(f::RngUPolElt) -> SeqEnum
{	Return the conjectural duplication polynomials on K, where K is the
Kummer threefold associated to the Jacobian of a hyperelliptic genus 3 curve
y^2 = f(x).}
	require Degree(f) eq 7:
		"f must have degree 7";
	Pr8<[x]> := PolynomialRing(BaseRing(f), 8);
	return duplication_polynomials(f, x);
end intrinsic;

intrinsic Double(P::Pt, J::JacHyp) -> Pt
{	Return 2*P, where P is a point on the Kummer threefold of the Jacobian J
of a hyperelliptic genus 3 curve with a rational Weierstrass point at infinity. 

WARNING: This relies on the polynomials returned by DuplicationPolynomials,
which only work conjecturally! 
}
    require Dimension(Ambient(Scheme(P))) eq 7:
        "The Kummer threefold must live in P7";
    require Dimension(Scheme(P)) eq 3:
        "The Kummer threefold must have dimension 3";
    require #Equations(Scheme(P)) eq 35:
        "The Kummer threefold must live in P7";
    C := Curve(J);
    f, h := HyperellipticPolynomials(C);
    require IsZero(h):
        "Need a simplified model (h=0).";
    require Genus(C) eq 3:
        "The curve must have genus 3";
    require Degree(f) eq 7:
        "f must have Degree 7.";

    return Parent(P) ! duplication_polynomials(f, Eltseq(P));
end intrinsic;


